--*- coding: utf-8 -*-
--[[- LHpi static set data
 Predefined set data for LHpi library, Externalized from LHpi library to 
 distinguish mere set data updates (such as needed on release of a new set)
 from code changes. Also, I want to test if two smaller files are easier to edit.
Finally, adding a new set will not require touching the library anymore.

Inspired by and loosely based on "MTG Mint Card.lua" by Goblin Hero, Stromglad1 and "Import Prices.lua" by woogerboy21;
who generously granted permission to "do as I like" with their code;
everything else Copyright (C) 2012-2015 by Christian Harms.
If you want to contact me about the script, try its release thread in http://www.slightlymagic.net/forum/viewforum.php?f=32

@module LHpi.Data
@author Christian Harms
@copyright 2012-2015 Christian Harms except parts by Goblin Hero, Stromglad1 or woogerboy21
@release This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>.
]]

--[[ CHANGES
v9
updated/fixed cardcount for 26
]]

local Data={}
---	data file version
-- @field [parent=#Data] #string version
Data.version = "9"

--[[- "main" function called by Magic Album; just display error and return.
 Called by Magic Album to import prices. Parameters are passed from MA.
 We don't want to call the data file directly.
 
 @function [parent=#global] ImportPrice
 @param #string importfoil	"Y"|"N"|"O"
 @param #table importlangs	{ #number (langid)= #string , ... }
 @param #table importsets	{ #number (setid)= #string , ... }
]]
if not ImportPrice then -- only needed if accidentally called directly fom MA
	function ImportPrice( importfoil , importlangs , importsets )
		ma.Log( "Called LHpi.Data instead of site script. Raising error to inform user via dialog box." )
		ma.Log( "LHpi.Data should be in \\lib subdir to prevent this." )
		error( "LHpi.Data-v" .. LHpi.Data.version .. " is a data file. Please select a LHpi-sitescript instead!" )
	end -- function ImportPrice
end--if

--[[- all possible languages.
 fields are for subtables indexed by #number langid.
 @type Data.languages
 @field [parent=#Data.languages] #number id		(see ..\Database\Languages.txt)
 @field [parent=#Data.languages] #string full	language name
 @field [parent=#Data.languages] #string abbr	3 letter abbreviation
]]
Data.languages = {
	[1]  = {id=1,  full = "English",				abbr="ENG" },
	[2]  = {id=2,  full = "Russian",				abbr="RUS" },
	[3]  = {id=3,  full = "German",					abbr="GER" },
	[4]  = {id=4,  full = "French",					abbr="FRA" },
	[5]  = {id=5,  full = "Italian",				abbr="ITA" },
	[6]  = {id=6,  full = "Portuguese",				abbr="POR" },
	[7]  = {id=7,  full = "Spanish",				abbr="SPA" },
	[8]  = {id=8,  full = "Japanese",				abbr="JPN" },
	[9]  = {id=9,  full = "Simplified Chinese",		abbr="SZH" },
	[10] = {id=10, full = "Traditional Chinese",	abbr="ZHT" },
	[11] = {id=11, full = "Korean",					abbr="KOR" },
	[12] = {id=12, full = "Hebrew",					abbr="HEB" },-- Only "Glory" in [22] Prerelease Promos
	[13] = {id=13, full = "Arabic",					abbr="ARA" },-- Only "Stone-Tongue Basilisk" in [22] Prerelease Promos
	[14] = {id=14, full = "Latin",					abbr="LAT" },-- Only "Raging Kavu" in [22] Prerelease Promos
	[15] = {id=15, full = "Sanskrit",				abbr="SAN" },-- Only "Fungal Shambler" in [22] Prerelease Promos
	[16] = {id=16, full = "Ancient Greek",			abbr="GRC" },-- Only "Questing Phelddagrif" in [22] Prerelease Promos
	[17] = {id=17, full = "Phyrexian",				abbr="PHY" },-- Only "Elesh Norn, Grand Cenobite" in [25] Judge Gift Cards
}


--[[- site independent set information.
 fields are for subtables indexed by #number setid.
 @type Data.sets
 @field [parent=#Data.sets] #string name		set name (see ..\"Database\Sets.txt").
 @field [parent=#Data.sets] #table cardcount	number of (English) cards in MA database. { reg= #number , tok= #number }.
 @field [parent=#Data.sets] #boolean foilonly	true if set contains (almost) only foil cards.
 @field [parent=#Data.sets] #table variants		default card variant tables. { #string (name)= #table { #string , #table { (#string or false) , ... } } , ... }
 @field [parent=#Data.sets] #table foiltweak	default foiltweak tables. { #string (name)= #table { foil= #boolean } , ... }
 ]]
Data.sets = {
--- not really a seperate subtable, just a bookmark for quick navigation in eclipse.
-- @field [parent=#Data.sets] #table Coresets
Coresets = nil,
[822] = { name="Magic Origins",
	tla="ORI",
	cardcount={ reg = 288, tok = 14 },
	variants={
["Plains"] 						= { "Plains"	, { 1    , 2    , 3    , 4     } },
["Island"] 						= { "Island" 	, { 1    , 2    , 3    , 4     } },
["Swamp"] 						= { "Swamp"		, { 1    , 2    , 3    , 4     } },
["Mountain"] 					= { "Mountain"	, { 1    , 2    , 3    , 4     } },
["Forest"] 						= { "Forest" 	, { 1    , 2    , 3    , 4     } },
["Plains (253)"]				= { "Plains"	, { 1    , false, false, false } }, 
["Plains (254)"]				= { "Plains"	, { false, 2    , false, false } },
["Plains (255)"]				= { "Plains"	, { false, false, 3    , false } },
["Plains (256)"]				= { "Plains"	, { false, false, false, 4     } },
["Island (257)"]				= { "Island"	, { 1    , false, false, false } },
["Island (258)"]				= { "Island"	, { false, 2    , false, false } },
["Island (259)"]				= { "Island"	, { false, false, 3    , false } },
["Island (260)"]				= { "Island"	, { false, false, false, 4     } },
["Swamp (261)"]					= { "Swamp"		, { 1    , false, false, false } },
["Swamp (262)"]					= { "Swamp"		, { false, 2    , false, false } },
["Swamp (263)"]					= { "Swamp"		, { false, false, 3    , false } },
["Swamp (264)"]					= { "Swamp"		, { false, false, false, 4     } },
["Mountain (265)"]				= { "Mountain"	, { 1    , false, false, false } },
["Mountain (266)"]				= { "Mountain"	, { false, 2    , false, false } },
["Mountain (267)"]				= { "Mountain"	, { false, false, 3    , false } },
["Mountain (268)"]				= { "Mountain"	, { false, false, false, 4     } },
["Forest (269)"]				= { "Forest"	, { 1    , false, false, false } },
["Forest (270)"]				= { "Forest"	, { false, 2    , false, false } },
["Forest (271)"]				= { "Forest"	, { false, false, 3    , false } },
["Forest (272)"]				= { "Forest"	, { false, false, false, 4     } },
["Thopter Token"]				= { "Thopter Token"	, { 1    , 2     } },
["Thopter Token (10)"]			= { "Thopter Token"	, { 1    , false } },--Svetlin Velinov
["Thopter Token (11)"]			= { "Thopter Token"	, { false, 2     } },--Adam Paquette
	},
},
[808] = { name="Magic 2015",
	tla="M15",
	cardcount={ reg = 269+15, tok = 14 },
	variants={
["Plains"] 						= { "Plains"	, { 1    , 2    , 3    , 4     } },
["Island"] 						= { "Island" 	, { 1    , 2    , 3    , 4     } },
["Swamp"] 						= { "Swamp"		, { 1    , 2    , 3    , 4     } },
["Mountain"] 					= { "Mountain"	, { 1    , 2    , 3    , 4     } },
["Forest"] 						= { "Forest" 	, { 1    , 2    , 3    , 4     } },
["Plains (250)"]				= { "Plains"	, { 1    , false, false, false } }, 
["Plains (251)"]				= { "Plains"	, { false, 2    , false, false } },
["Plains (252)"]				= { "Plains"	, { false, false, 3    , false } },
["Plains (253)"]				= { "Plains"	, { false, false, false, 4     } },
["Island (254)"]				= { "Island"	, { 1    , false, false, false } },
["Island (255)"]				= { "Island"	, { false, 2    , false, false } },
["Island (256)"]				= { "Island"	, { false, false, 3    , false } },
["Island (257)"]				= { "Island"	, { false, false, false, 4     } },
["Swamp (258)"]					= { "Swamp"		, { 1    , false, false, false } },
["Swamp (259)"]					= { "Swamp"		, { false, 2    , false, false } },
["Swamp (260)"]					= { "Swamp"		, { false, false, 3    , false } },
["Swamp (261)"]					= { "Swamp"		, { false, false, false, 4     } },
["Mountain (262)"]				= { "Mountain"	, { 1    , false, false, false } },
["Mountain (263)"]				= { "Mountain"	, { false, 2    , false, false } },
["Mountain (264)"]				= { "Mountain"	, { false, false, 3    , false } },
["Mountain (265)"]				= { "Mountain"	, { false, false, false, 4     } },
["Forest (266)"]				= { "Forest"	, { 1    , false, false, false } },
["Forest (267)"]				= { "Forest"	, { false, 2    , false, false } },
["Forest (268)"]				= { "Forest"	, { false, false, 3    , false } },
["Forest (269)"]				= { "Forest"	, { false, false, false, 4     } },
["Beast Token"]					= { "Beast Token"	, { 1    , 2     } },
["Beast Token (5)"]				= { "Beast Token"	, { 1    , false } },--B
["Beast Token (9)"]				= { "Beast Token"	, { false, 2     } },--G
["Bestie Token"]				= { "Bestie Token"	, { 1    , 2     } },
["Bestie Token (5)"]			= { "Bestie Token"	, { 1    , false } },
["Bestie Token (9)"]			= { "Bestie Token"	, { false, 2     } },
	},
},
[797] = { name="Magic 2014",
	tla="M14",
	cardcount={ reg = 249, tok = 13 },
	variants={
["Plains"] 						= { "Plains"	, { 1    , 2    , 3    , 4     } },
["Island"] 						= { "Island" 	, { 1    , 2    , 3    , 4     } },
["Swamp"] 						= { "Swamp"		, { 1    , 2    , 3    , 4     } },
["Mountain"] 					= { "Mountain"	, { 1    , 2    , 3    , 4     } },
["Forest"] 						= { "Forest" 	, { 1    , 2    , 3    , 4     } },
["Plains (230)"]				= { "Plains"	, { 1    , false, false, false } }, 
["Plains (231)"]				= { "Plains"	, { false, 2    , false, false } },
["Plains (232)"]				= { "Plains"	, { false, false, 3    , false } },
["Plains (233)"]				= { "Plains"	, { false, false, false, 4     } },
["Island (234)"]				= { "Island"	, { 1    , false, false, false } },
["Island (235)"]				= { "Island"	, { false, 2    , false, false } },
["Island (236)"]				= { "Island"	, { false, false, 3    , false } },
["Island (237)"]				= { "Island"	, { false, false, false, 4     } },
["Swamp (238)"]					= { "Swamp"		, { 1    , false, false, false } },
["Swamp (239)"]					= { "Swamp"		, { false, 2    , false, false } },
["Swamp (240)"]					= { "Swamp"		, { false, false, 3    , false } },
["Swamp (241)"]					= { "Swamp"		, { false, false, false, 4     } },
["Mountain (242)"]				= { "Mountain"	, { 1    , false, false, false } },
["Mountain (243)"]				= { "Mountain"	, { false, 2    , false, false } },
["Mountain (244)"]				= { "Mountain"	, { false, false, 3    , false } },
["Mountain (245)"]				= { "Mountain"	, { false, false, false, 4     } },
["Forest (246)"]				= { "Forest"	, { 1    , false, false, false } },
["Forest (247)"]				= { "Forest"	, { false, 2    , false, false } },
["Forest (248)"]				= { "Forest"	, { false, false, 3    , false } },
["Forest (249)"]				= { "Forest"	, { false, false, false, 4     } },
["Elemental Token"]				= { "Elemental Token"	, { 1    , 2     } },
["Elemental Token (7)"]			= { "Elemental Token"	, { 1    , false } },
["Elemental Token (8)"]			= { "Elemental Token"	, { false, 2     } },
["Elementarwesen Token"]		= { "Elementarwesen Token"	, { 1    , 2     } },
["Elementarwesen Token (7)"]	= { "Elementarwesen Token"	, { 1    , false } },
["Elementarwesen Token (8)"]	= { "Elementarwesen Token"	, { false, 2     } },
	},
},
[788] = { name="Magic 2013",
	tla="M13",
	cardcount={ reg = 249, tok = 11 },
	variants={
["Plains"] 						= { "Plains"	, { 1    , 2    , 3    , 4     } },
["Island"] 						= { "Island" 	, { 1    , 2    , 3    , 4     } },
["Swamp"] 						= { "Swamp"		, { 1    , 2    , 3    , 4     } },
["Mountain"] 					= { "Mountain"	, { 1    , 2    , 3    , 4     } },
["Forest"] 						= { "Forest" 	, { 1    , 2    , 3    , 4     } },
["Plains (230)"]				= { "Plains"	, { 1    , false, false, false } }, 
["Plains (231)"]				= { "Plains"	, { false, 2    , false, false } },
["Plains (232)"]				= { "Plains"	, { false, false, 3    , false } },
["Plains (233)"]				= { "Plains"	, { false, false, false, 4     } },
["Island (234)"]				= { "Island"	, { 1    , false, false, false } },
["Island (235)"]				= { "Island"	, { false, 2    , false, false } },
["Island (236)"]				= { "Island"	, { false, false, 3    , false } },
["Island (237)"]				= { "Island"	, { false, false, false, 4     } },
["Swamp (238)"]					= { "Swamp"		, { 1    , false, false, false } },
["Swamp (239)"]					= { "Swamp"		, { false, 2    , false, false } },
["Swamp (240)"]					= { "Swamp"		, { false, false, 3    , false } },
["Swamp (241)"]					= { "Swamp"		, { false, false, false, 4     } },
["Mountain (242)"]				= { "Mountain"	, { 1    , false, false, false } },
["Mountain (243)"]				= { "Mountain"	, { false, 2    , false, false } },
["Mountain (244)"]				= { "Mountain"	, { false, false, 3    , false } },
["Mountain (245)"]				= { "Mountain"	, { false, false, false, 4     } },
["Forest (246)"]				= { "Forest"	, { 1    , false, false, false } },
["Forest (247)"]				= { "Forest"	, { false, 2    , false, false } },
["Forest (248)"]				= { "Forest"	, { false, false, 3    , false } },
["Forest (249)"]				= { "Forest"	, { false, false, false, 4     } }
	},
},
[779] = { name="Magic 2012",
	tla="M12",
	cardcount={ reg = 249, tok =  7 }, 
	variants={
["Plains"] 						= { "Plains"	, { 1    , 2    , 3    , 4     } },
["Island"] 						= { "Island" 	, { 1    , 2    , 3    , 4     } },
["Swamp"] 						= { "Swamp"		, { 1    , 2    , 3    , 4     } },
["Mountain"] 					= { "Mountain"	, { 1    , 2    , 3    , 4     } },
["Forest"] 						= { "Forest" 	, { 1    , 2    , 3    , 4     } },
["Plains (230)"]				= { "Plains"	, { 1    , false, false, false } }, 
["Plains (231)"]				= { "Plains"	, { false, 2    , false, false } },
["Plains (232)"]				= { "Plains"	, { false, false, 3    , false } },
["Plains (233)"]				= { "Plains"	, { false, false, false, 4     } },
["Island (234)"]				= { "Island"	, { 1    , false, false, false } },
["Island (235)"]				= { "Island"	, { false, 2    , false, false } },
["Island (236)"]				= { "Island"	, { false, false, 3    , false } },
["Island (237)"]				= { "Island"	, { false, false, false, 4     } },
["Swamp (238)"]					= { "Swamp"		, { 1    , false, false, false } },
["Swamp (239)"]					= { "Swamp"		, { false, 2    , false, false } },
["Swamp (240)"]					= { "Swamp"		, { false, false, 3    , false } },
["Swamp (241)"]					= { "Swamp"		, { false, false, false, 4     } },
["Mountain (242)"]				= { "Mountain"	, { 1    , false, false, false } },
["Mountain (243)"]				= { "Mountain"	, { false, 2    , false, false } },
["Mountain (244)"]				= { "Mountain"	, { false, false, 3    , false } },
["Mountain (245)"]				= { "Mountain"	, { false, false, false, 4     } },
["Forest (246)"]				= { "Forest"	, { 1    , false, false, false } },
["Forest (247)"]				= { "Forest"	, { false, 2    , false, false } },
["Forest (248)"]				= { "Forest"	, { false, false, 3    , false } },
["Forest (249)"]				= { "Forest"	, { false, false, false, 4     } }
	},
},
[770] = { name="Magic 2011",
	tla="M11",
	cardcount={ reg = 249, tok =  6 }, 
	variants={
["Plains"] 						= { "Plains"	, { 1    , 2    , 3    , 4     } },
["Island"] 						= { "Island" 	, { 1    , 2    , 3    , 4     } },
["Swamp"] 						= { "Swamp"		, { 1    , 2    , 3    , 4     } },
["Mountain"] 					= { "Mountain"	, { 1    , 2    , 3    , 4     } },
["Forest"] 						= { "Forest" 	, { 1    , 2    , 3    , 4     } },
["Plains (230)"]				= { "Plains"	, { 1    , false, false, false } }, 
["Plains (231)"]				= { "Plains"	, { false, 2    , false, false } },
["Plains (232)"]				= { "Plains"	, { false, false, 3    , false } },
["Plains (233)"]				= { "Plains"	, { false, false, false, 4     } },
["Island (234)"]				= { "Island"	, { 1    , false, false, false } },
["Island (235)"]				= { "Island"	, { false, 2    , false, false } },
["Island (236)"]				= { "Island"	, { false, false, 3    , false } },
["Island (237)"]				= { "Island"	, { false, false, false, 4     } },
["Swamp (238)"]					= { "Swamp"		, { 1    , false, false, false } },
["Swamp (239)"]					= { "Swamp"		, { false, 2    , false, false } },
["Swamp (240)"]					= { "Swamp"		, { false, false, 3    , false } },
["Swamp (241)"]					= { "Swamp"		, { false, false, false, 4     } },
["Mountain (242)"]				= { "Mountain"	, { 1    , false, false, false } },
["Mountain (243)"]				= { "Mountain"	, { false, 2    , false, false } },
["Mountain (244)"]				= { "Mountain"	, { false, false, 3    , false } },
["Mountain (245)"]				= { "Mountain"	, { false, false, false, 4     } },
["Forest (246)"]				= { "Forest"	, { 1    , false, false, false } },
["Forest (247)"]				= { "Forest"	, { false, 2    , false, false } },
["Forest (248)"]				= { "Forest"	, { false, false, 3    , false } },
["Forest (249)"]				= { "Forest"	, { false, false, false, 4     } },
["Ooze Token"]					= { "Ooze Token"	, { 1    , 2     } },
["Ooze Token (5)"]				= { "Ooze Token"	, { 1    , false } },
["Ooze Token (6)"]				= { "Ooze Token"	, { false, 2     } },
["Schlammwesen Token"]			= { "Schlammwesen Token"	, { 1    , 2     } },
["Schlammwesen Token (5)"]		= { "Schlammwesen Token"	, { 1    , false } },
["Schlammwesen Token (6)"]		= { "Schlammwesen Token"	, { false, 2     } },
	},
},
[759] = { name="Magic 2010",
	tla="M10",
	cardcount={ reg = 249, tok =  8 }, 
	variants={
["Plains"] 						= { "Plains"	, { 1    , 2    , 3    , 4     } },
["Island"] 						= { "Island" 	, { 1    , 2    , 3    , 4     } },
["Swamp"] 						= { "Swamp"		, { 1    , 2    , 3    , 4     } },
["Mountain"] 					= { "Mountain"	, { 1    , 2    , 3    , 4     } },
["Forest"] 						= { "Forest" 	, { 1    , 2    , 3    , 4     } },
["Plains (230)"]				= { "Plains"	, { 1    , false, false, false } }, 
["Plains (231)"]				= { "Plains"	, { false, 2    , false, false } },
["Plains (232)"]				= { "Plains"	, { false, false, 3    , false } },
["Plains (233)"]				= { "Plains"	, { false, false, false, 4     } },
["Island (234)"]				= { "Island"	, { 1    , false, false, false } },
["Island (235)"]				= { "Island"	, { false, 2    , false, false } },
["Island (236)"]				= { "Island"	, { false, false, 3    , false } },
["Island (237)"]				= { "Island"	, { false, false, false, 4     } },
["Swamp (238)"]					= { "Swamp"		, { 1    , false, false, false } },
["Swamp (239)"]					= { "Swamp"		, { false, 2    , false, false } },
["Swamp (240)"]					= { "Swamp"		, { false, false, 3    , false } },
["Swamp (241)"]					= { "Swamp"		, { false, false, false, 4     } },
["Mountain (242)"]				= { "Mountain"	, { 1    , false, false, false } },
["Mountain (243)"]				= { "Mountain"	, { false, 2    , false, false } },
["Mountain (244)"]				= { "Mountain"	, { false, false, 3    , false } },
["Mountain (245)"]				= { "Mountain"	, { false, false, false, 4     } },
["Forest (246)"]				= { "Forest"	, { 1    , false, false, false } },
["Forest (247)"]				= { "Forest"	, { false, 2    , false, false } },
["Forest (248)"]				= { "Forest"	, { false, false, 3    , false } },
["Forest (249)"]				= { "Forest"	, { false, false, false, 4     } }
	},
},
[720] = { name="Tenth Edition",
	tla="10E",
	cardcount={ reg = 384, tok =  6 }, 
	variants={
["Plains"] 						= { "Plains"	, { 1    , 2    , 3    , 4     } },
["Island"] 						= { "Island" 	, { 1    , 2    , 3    , 4     } },
["Swamp"] 						= { "Swamp"		, { 1    , 2    , 3    , 4     } },
["Mountain"] 					= { "Mountain"	, { 1    , 2    , 3    , 4     } },
["Forest"] 						= { "Forest" 	, { 1    , 2    , 3    , 4     } },
["Plains (364)"]				= { "Plains"	, { 1    , false, false, false } },
["Plains (365)"]				= { "Plains"	, { false, 2    , false, false } },
["Plains (366)"]				= { "Plains"	, { false, false, 3    , false } },
["Plains (367)"]				= { "Plains"	, { false, false, false, 4     } },
["Island (368)"]				= { "Island"	, { 1    , false, false, false } },
["Island (369)"]				= { "Island"	, { false, 2    , false, false } },
["Island (370)"]				= { "Island"	, { false, false, 3    , false } },
["Island (371)"]				= { "Island"	, { false, false, false, 4     } },
["Swamp (372)"]					= { "Swamp"		, { 1    , false, false, false } },
["Swamp (373)"]					= { "Swamp"		, { false, 2    , false, false } },
["Swamp (374)"]					= { "Swamp"		, { false, false, 3    , false } },
["Swamp (375)"]					= { "Swamp"		, { false, false, false, 4     } },
["Mountain (376)"]				= { "Mountain"	, { 1    , false, false, false } },
["Mountain (377)"]				= { "Mountain"	, { false, 2    , false, false } },
["Mountain (378)"]				= { "Mountain"	, { false, false, 3    , false } },
["Mountain (379)"]				= { "Mountain"	, { false, false, false, 4     } },
["Forest (380)"]				= { "Forest"	, { 1    , false, false, false } },
["Forest (381)"]				= { "Forest"	, { false, 2    , false, false } },
["Forest (382)"]				= { "Forest"	, { false, false, 3    , false } },
["Forest (383)"]				= { "Forest"	, { false, false, false, 4     } },
["Kamahl, Pit Fighter"]			= {"Kamahl, Pit Fighter"	, { ""    , false } },
["Kamahl, Pit Fighter (ST)"]	= {"Kamahl, Pit Fighter"	, { false , "ST"  } },
	},
},
[630] = { name="9th Edition",
	tla="9ED",
	cardcount={ reg = 359, tok =  0 }, 
	variants={
["Plains"] 						= { "Plains"	, { 1    , 2    , 3    , 4     } },
["Island"] 						= { "Island" 	, { 1    , 2    , 3    , 4     } },
["Swamp"] 						= { "Swamp"		, { 1    , 2    , 3    , 4     } },
["Mountain"] 					= { "Mountain"	, { 1    , 2    , 3    , 4     } },
["Forest"] 						= { "Forest" 	, { 1    , 2    , 3    , 4     } },
["Plains (331)"]				= { "Plains"	, { 1    , false, false, false } }, 
["Plains (332)"]				= { "Plains"	, { false, 2    , false, false } },
["Plains (333)"]				= { "Plains"	, { false, false, 3    , false } },
["Plains (334)"]				= { "Plains"	, { false, false, false, 4     } },
["Island (335)"]				= { "Island"	, { 1    , false, false, false } },
["Island (336)"]				= { "Island"	, { false, 2    , false, false } },
["Island (337)"]				= { "Island"	, { false, false, 3    , false } },
["Island (338)"]				= { "Island"	, { false, false, false, 4     } },
["Swamp (339)"]					= { "Swamp"		, { 1    , false, false, false } },
["Swamp (340)"]					= { "Swamp"		, { false, 2    , false, false } },
["Swamp (341)"]					= { "Swamp"		, { false, false, 3    , false } },
["Swamp (342)"]					= { "Swamp"		, { false, false, false, 4     } },
["Mountain (343)"]				= { "Mountain"	, { 1    , false, false, false } },
["Mountain (344)"]				= { "Mountain"	, { false, 2    , false, false } },
["Mountain (345)"]				= { "Mountain"	, { false, false, 3    , false } },
["Mountain (346)"]				= { "Mountain"	, { false, false, false, 4     } },
["Forest (347)"]				= { "Forest"	, { 1    , false, false, false } },
["Forest (348)"]				= { "Forest"	, { false, 2    , false, false } },
["Forest (349)"]				= { "Forest"	, { false, false, 3    , false } },
["Forest (350)"]				= { "Forest"	, { false, false, false, 4     } },
	},
},
[550] = { name="8th Edition",
	tla="8ED",
	cardcount={ reg = 357, tok =  0 }, 
	variants={
["Plains"] 						= { "Plains"	, { 1    , 2    , 3    , 4     } },
["Island"] 						= { "Island" 	, { 1    , 2    , 3    , 4     } },
["Swamp"] 						= { "Swamp"		, { 1    , 2    , 3    , 4     } },
["Mountain"] 					= { "Mountain"	, { 1    , 2    , 3    , 4     } },
["Forest"] 						= { "Forest" 	, { 1    , 2    , 3    , 4     } },
["Plains (331)"]				= { "Plains"	, { 1    , false, false, false } }, 
["Plains (332)"]				= { "Plains"	, { false, 2    , false, false } },
["Plains (333)"]				= { "Plains"	, { false, false, 3    , false } },
["Plains (334)"]				= { "Plains"	, { false, false, false, 4     } },
["Island (335)"]				= { "Island"	, { 1    , false, false, false } },
["Island (336)"]				= { "Island"	, { false, 2    , false, false } },
["Island (337)"]				= { "Island"	, { false, false, 3    , false } },
["Island (338)"]				= { "Island"	, { false, false, false, 4     } },
["Swamp (339)"]					= { "Swamp"		, { 1    , false, false, false } },
["Swamp (340)"]					= { "Swamp"		, { false, 2    , false, false } },
["Swamp (341)"]					= { "Swamp"		, { false, false, 3    , false } },
["Swamp (342)"]					= { "Swamp"		, { false, false, false, 4     } },
["Mountain (343)"]				= { "Mountain"	, { 1    , false, false, false } },
["Mountain (344)"]				= { "Mountain"	, { false, 2    , false, false } },
["Mountain (345)"]				= { "Mountain"	, { false, false, 3    , false } },
["Mountain (346)"]				= { "Mountain"	, { false, false, false, 4     } },
["Forest (347)"]				= { "Forest"	, { 1    , false, false, false } },
["Forest (348)"]				= { "Forest"	, { false, 2    , false, false } },
["Forest (349)"]				= { "Forest"	, { false, false, 3    , false } },
["Forest (350)"]				= { "Forest"	, { false, false, false, 4     } },
	},
},
[460] = { name="7th Edition",
	tla="7ED",
	cardcount={ reg = 350, tok =  0 },
	variants={
["Plains"] 						= { "Plains"	, { 1    , 2    , 3    , 4     } },
["Island"] 						= { "Island" 	, { 1    , 2    , 3    , 4     } },
["Swamp"] 						= { "Swamp"		, { 1    , 2    , 3    , 4     } },
["Mountain"] 					= { "Mountain"	, { 1    , 2    , 3    , 4     } },
["Forest"] 						= { "Forest" 	, { 1    , 2    , 3    , 4     } },
["Plains (341)"]				= { "Plains"	, { 1    , false, false, false } }, 
["Plains (342)"]				= { "Plains"	, { false, 2    , false, false } },
["Plains (343)"]				= { "Plains"	, { false, false, 3    , false } },
["Plains (344)"]				= { "Plains"	, { false, false, false, 4     } },
["Island (332)"]				= { "Island"	, { 1    , false, false, false } },
["Island (333)"]				= { "Island"	, { false, 2    , false, false } },
["Island (334)"]				= { "Island"	, { false, false, 3    , false } },
["Island (335)"]				= { "Island"	, { false, false, false, 4     } },
["Swamp (346)"]					= { "Swamp"		, { 1    , false, false, false } },
["Swamp (347)"]					= { "Swamp"		, { false, 2    , false, false } },
["Swamp (348)"]					= { "Swamp"		, { false, false, 3    , false } },
["Swamp (349)"]					= { "Swamp"		, { false, false, false, 4     } },
["Mountain (337)"]				= { "Mountain"	, { 1    , false, false, false } },
["Mountain (338)"]				= { "Mountain"	, { false, 2    , false, false } },
["Mountain (339)"]				= { "Mountain"	, { false, false, 3    , false } },
["Mountain (340)"]				= { "Mountain"	, { false, false, false, 4     } },
["Forest (328)"]				= { "Forest"	, { 1    , false, false, false } },
["Forest (329)"]				= { "Forest"	, { false, 2    , false, false } },
["Forest (330)"]				= { "Forest"	, { false, false, 3    , false } },
["Forest (331)"]				= { "Forest"	, { false, false, false, 4     } },
	},
},
[360] = { name="6th Edition",
	tla="6ED",
	cardcount={ reg = 350, tok =  0 }, 
	variants={
["Plains"] 						= { "Plains"	, { 1    , 2    , 3    , 4     } },
["Island"] 						= { "Island" 	, { 1    , 2    , 3    , 4     } },
["Swamp"] 						= { "Swamp"		, { 1    , 2    , 3    , 4     } },
["Mountain"] 					= { "Mountain"	, { 1    , 2    , 3    , 4     } },
["Forest"] 						= { "Forest" 	, { 1    , 2    , 3    , 4     } },
["Plains (331)"]				= { "Plains"	, { 1    , false, false, false } }, 
["Plains (332)"]				= { "Plains"	, { false, 2    , false, false } },
["Plains (333)"]				= { "Plains"	, { false, false, 3    , false } },
["Plains (334)"]				= { "Plains"	, { false, false, false, 4     } },
["Island (335)"]				= { "Island"	, { 1    , false, false, false } },
["Island (336)"]				= { "Island"	, { false, 2    , false, false } },
["Island (337)"]				= { "Island"	, { false, false, 3    , false } },
["Island (338)"]				= { "Island"	, { false, false, false, 4     } },
["Swamp (339)"]					= { "Swamp"		, { 1    , false, false, false } },
["Swamp (340)"]					= { "Swamp"		, { false, 2    , false, false } },
["Swamp (341)"]					= { "Swamp"		, { false, false, 3    , false } },
["Swamp (342)"]					= { "Swamp"		, { false, false, false, 4     } },
["Mountain (343)"]				= { "Mountain"	, { 1    , false, false, false } },
["Mountain (344)"]				= { "Mountain"	, { false, 2    , false, false } },
["Mountain (345)"]				= { "Mountain"	, { false, false, 3    , false } },
["Mountain (346)"]				= { "Mountain"	, { false, false, false, 4     } },
["Forest (347)"]				= { "Forest"	, { 1    , false, false, false } },
["Forest (348)"]				= { "Forest"	, { false, 2    , false, false } },
["Forest (349)"]				= { "Forest"	, { false, false, 3    , false } },
["Forest (350)"]				= { "Forest"	, { false, false, false, 4     } },
	},
},
[250] = { name="5th Edition",
	tla="5ED",
	cardcount={ reg = 449, tok =  0 },
	variants={
["Plains"] 						= { "Plains"	, { 1    , 2    , 3    , 4     } },
["Island"] 						= { "Island" 	, { 1    , 2    , 3    , 4     } },
["Swamp"] 						= { "Swamp"		, { 1    , 2    , 3    , 4     } },
["Mountain"] 					= { "Mountain"	, { 1    , 2    , 3    , 4     } },
["Forest"] 						= { "Forest" 	, { 1    , 2    , 3    , 4     } },
["Plains (1)"]					= { "Plains"	, { 1    , false, false, false } }, 
["Plains (2)"]					= { "Plains"	, { false, 2    , false, false } },
["Plains (3)"]					= { "Plains"	, { false, false, 3    , false } },
["Plains (4)"]					= { "Plains"	, { false, false, false, 4     } },
["Island (1)"]					= { "Island"	, { 1    , false, false, false } },
["Island (2)"]					= { "Island"	, { false, 2    , false, false } },
["Island (3)"]					= { "Island"	, { false, false, 3    , false } },
["Island (4)"]					= { "Island"	, { false, false, false, 4     } },
["Swamp (1)"]					= { "Swamp"		, { 1    , false, false, false } },
["Swamp (2)"]					= { "Swamp"		, { false, 2    , false, false } },
["Swamp (3)"]					= { "Swamp"		, { false, false, 3    , false } },
["Swamp (4)"]					= { "Swamp"		, { false, false, false, 4     } },
["Mountain (1)"]				= { "Mountain"	, { 1    , false, false, false } },
["Mountain (2)"]				= { "Mountain"	, { false, 2    , false, false } },
["Mountain (3)"]				= { "Mountain"	, { false, false, 3    , false } },
["Mountain (4)"]				= { "Mountain"	, { false, false, false, 4     } },
["Forest (1)"]					= { "Forest"	, { 1    , false, false, false } },
["Forest (2)"]					= { "Forest"	, { false, 2    , false, false } },
["Forest (3)"]					= { "Forest"	, { false, false, 3    , false } },
["Forest (4)"]					= { "Forest"	, { false, false, false, 4     } },
	},
},
[180] = { name="4th Edition",
	tla="4ED",
	cardcount={ reg = 378, tok =  0 }, 
	variants={
["Plains"] 						= { "Plains"	, { 1    , 2    , 3     } },
["Island"] 						= { "Island" 	, { 1    , 2    , 3     } },
["Swamp"] 						= { "Swamp"		, { 1    , 2    , 3     } },
["Mountain"] 					= { "Mountain"	, { 1    , 2    , 3     } },
["Forest"] 						= { "Forest" 	, { 1    , 2    , 3     } },
["Plains (1)"]					= { "Plains"	, { 1    , false, false } },--No Mountains
["Plains (2)"]					= { "Plains"	, { false, 2    , false } },--Trees
["Plains (3)"]					= { "Plains"	, { false, false, 3     } },--No Trees
["Island (1)"]					= { "Island"	, { 1    , false, false } },--Green
["Island (2)"]					= { "Island"	, { false, 2    , false } },--Purple
["Island (3)"]					= { "Island"	, { false, false, 3     } },--Blue
["Swamp (1)"]					= { "Swamp"		, { 1    , false, false } },--High Branch
["Swamp (2)"]					= { "Swamp"		, { false, 2    , false } },--Two Branches
["Swamp (3)"]					= { "Swamp"		, { false, false, 3     } },--Low Branch
["Mountain (1)"]				= { "Mountain"	, { 1    , false, false } },--Dirt
["Mountain (2)"]				= { "Mountain"	, { false, 2    , false } },--Slate
["Mountain (3)"]				= { "Mountain"	, { false, false, 3     } },--Fog
["Forest (1)"]					= { "Forest"	, { 1    , false, false } },--Path
["Forest (2)"]					= { "Forest"	, { false, 2    , false } },--Eyes
["Forest (3)"]					= { "Forest"	, { false, false, 3     } },--Rocks
	},
},
[179] = { name="4th Edition (FBB)", -- Foreign Black Bordered / Limited
	tla="4EF",
	cardcount={ reg = 378, tok =  0 }, 
	variants={
["Plains"] 						= { "Plains"	, { 1    , 2    , 3     } },
["Island"] 						= { "Island" 	, { 1    , 2    , 3     } },
["Swamp"] 						= { "Swamp"		, { 1    , 2    , 3     } },
["Mountain"] 					= { "Mountain"	, { 1    , 2    , 3     } },
["Forest"] 						= { "Forest" 	, { 1    , 2    , 3     } },
["Plains (1)"]					= { "Plains"	, { 1    , false, false } },
["Plains (2)"]					= { "Plains"	, { false, 2    , false } },
["Plains (3)"]					= { "Plains"	, { false, false, 3     } },
["Island (1)"]					= { "Island"	, { 1    , false, false } },
["Island (2)"]					= { "Island"	, { false, 2    , false } },
["Island (3)"]					= { "Island"	, { false, false, 3     } },
["Swamp (1)"]					= { "Swamp"		, { 1    , false, false } },
["Swamp (2)"]					= { "Swamp"		, { false, 2    , false } },
["Swamp (3)"]					= { "Swamp"		, { false, false, 3     } },
["Mountain (1)"]				= { "Mountain"	, { 1    , false, false } },
["Mountain (2)"]				= { "Mountain"	, { false, 2    , false } },
["Mountain (3)"]				= { "Mountain"	, { false, false, 3     } },
["Forest (1)"]					= { "Forest"	, { 1    , false, false } },
["Forest (2)"]					= { "Forest"	, { false, 2    , false } },
["Forest (3)"]					= { "Forest"	, { false, false, 3     } },
	},
},
[141] = { name="Revised Edition (Summer Magic)",
	tla="3ES",
	cardcount={ reg=306, tok=0, nontrad=0, repl=0 }, 
	variants={
["Plains"] 						= { "Plains"	, { 1    , 2    , 3     } },
["Island"] 						= { "Island" 	, { 1    , 2    , 3     } },
["Swamp"] 						= { "Swamp"		, { 1    , 2    , 3     } },
["Mountain"] 					= { "Mountain"	, { 1    , 2    , 3     } },
["Forest"] 						= { "Forest" 	, { 1    , 2    , 3     } },
["Plains (1)"]					= { "Plains"	, { 1    , false, false } },
["Plains (2)"]					= { "Plains"	, { false, 2    , false } },
["Plains (3)"]					= { "Plains"	, { false, false, 3     } },
["Island (1)"]					= { "Island"	, { 1    , false, false } },
["Island (2)"]					= { "Island"	, { false, 2    , false } },
["Island (3)"]					= { "Island"	, { false, false, 3     } },
["Swamp (1)"]					= { "Swamp"		, { 1    , false, false } },
["Swamp (2)"]					= { "Swamp"		, { false, 2    , false } },
["Swamp (3)"]					= { "Swamp"		, { false, false, 3     } },
["Mountain (1)"]				= { "Mountain"	, { 1    , false, false } },
["Mountain (2)"]				= { "Mountain"	, { false, 2    , false } },
["Mountain (3)"]				= { "Mountain"	, { false, false, 3     } },
["Forest (1)"]					= { "Forest"	, { 1    , false, false } },
["Forest (2)"]					= { "Forest"	, { false, 2    , false } },
["Forest (3)"]					= { "Forest"	, { false, false, 3     } },
	},
},
[140] = { name="Revised Edition",
	tla="3ED",
	cardcount={ reg = 306, tok =  0 }, 
	variants={
["Plains"] 						= { "Plains"	, { 1    , 2    , 3     } },
["Island"] 						= { "Island" 	, { 1    , 2    , 3     } },
["Swamp"] 						= { "Swamp"		, { 1    , 2    , 3     } },
["Mountain"] 					= { "Mountain"	, { 1    , 2    , 3     } },
["Forest"] 						= { "Forest" 	, { 1    , 2    , 3     } },
["Plains (1)"]					= { "Plains"	, { 1    , false, false } },--No Trees
["Plains (2)"]					= { "Plains"	, { false, 2    , false } },--Trees
["Plains (3)"]					= { "Plains"	, { false, false, 3     } },--No Mountains
["Island (1)"]					= { "Island"	, { 1    , false, false } },--Purple
["Island (2)"]					= { "Island"	, { false, 2    , false } },--Green
["Island (3)"]					= { "Island"	, { false, false, 3     } },--Blue
["Swamp (1)"]					= { "Swamp"		, { 1    , false, false } },--Low Branch
["Swamp (2)"]					= { "Swamp"		, { false, 2    , false } },--High Branch
["Swamp (3)"]					= { "Swamp"		, { false, false, 3     } },--Two Branches
["Mountain (1)"]				= { "Mountain"	, { 1    , false, false } },--Slate
["Mountain (2)"]				= { "Mountain"	, { false, 2    , false } },--Fog
["Mountain (3)"]				= { "Mountain"	, { false, false, 3     } },--Dirt
["Forest (1)"]					= { "Forest"	, { 1    , false, false } },--Rocks
["Forest (2)"]					= { "Forest"	, { false, 2    , false } },--Path
["Forest (3)"]					= { "Forest"	, { false, false, 3     } },--Eyes
	},
},
[139] = { name="Revised Edition (FBB)", -- Foreign Black Bordered / Limited
	tla="3EF",
	cardcount={ reg = 306, tok =  0 }, 
	variants={
["Plains"] 						= { "Plains"	, { 1    , 2    , 3     } },
["Island"] 						= { "Island" 	, { 1    , 2    , 3     } },
["Swamp"] 						= { "Swamp"		, { 1    , 2    , 3     } },
["Mountain"] 					= { "Mountain"	, { 1    , 2    , 3     } },
["Forest"] 						= { "Forest" 	, { 1    , 2    , 3     } },
["Plains (1)"]					= { "Plains"	, { 1    , false, false } },
["Plains (2)"]					= { "Plains"	, { false, 2    , false } },
["Plains (3)"]					= { "Plains"	, { false, false, 3     } },
["Island (1)"]					= { "Island"	, { 1    , false, false } },
["Island (2)"]					= { "Island"	, { false, 2    , false } },
["Island (3)"]					= { "Island"	, { false, false, 3     } },
["Swamp (1)"]					= { "Swamp"		, { 1    , false, false } },
["Swamp (2)"]					= { "Swamp"		, { false, 2    , false } },
["Swamp (3)"]					= { "Swamp"		, { false, false, 3     } },
["Mountain (1)"]				= { "Mountain"	, { 1    , false, false } },
["Mountain (2)"]				= { "Mountain"	, { false, 2    , false } },
["Mountain (3)"]				= { "Mountain"	, { false, false, 3     } },
["Forest (1)"]					= { "Forest"	, { 1    , false, false } },
["Forest (2)"]					= { "Forest"	, { false, 2    , false } },
["Forest (3)"]					= { "Forest"	, { false, false, 3     } },
	},
},
[110] = { name="Unlimited",
	tla="2ED",
	cardcount={ reg = 302, tok =  0 }, 
	variants={
["Plains"] 						= { "Plains"	, { 1    , 2    , 3     } },
["Island"] 						= { "Island" 	, { 1    , 2    , 3     } },
["Swamp"] 						= { "Swamp"		, { 1    , 2    , 3     } },
["Mountain"] 					= { "Mountain"	, { 1    , 2    , 3     } },
["Forest"] 						= { "Forest" 	, { 1    , 2    , 3     } },
["Plains (1)"]					= { "Plains"	, { 1    , false, false } },--No Trees
["Plains (2)"]					= { "Plains"	, { false, 2    , false } },--Trees
["Plains (3)"]					= { "Plains"	, { false, false, 3     } },--No Mountains
["Island (1)"]					= { "Island"	, { 1    , false, false } },--Blue
["Island (2)"]					= { "Island"	, { false, 2    , false } },--Green
["Island (3)"]					= { "Island"	, { false, false, 3     } },--Purple
["Swamp (1)"]					= { "Swamp"		, { 1    , false, false } },--High Branch
["Swamp (2)"]					= { "Swamp"		, { false, 2    , false } },--Low Branch
["Swamp (3)"]					= { "Swamp"		, { false, false, 3     } },--Two Branches
["Mountain (1)"]				= { "Mountain"	, { 1    , false, false } },--Slate
["Mountain (2)"]				= { "Mountain"	, { false, 2    , false } },--Fog
["Mountain (3)"]				= { "Mountain"	, { false, false, 3     } },--Dirt
["Forest (1)"]					= { "Forest"	, { 1    , false, false } },--Path
["Forest (2)"]					= { "Forest"	, { false, 2    , false } },--Eyes
["Forest (3)"]					= { "Forest"	, { false, false, 3     } },--Rocks
	},
},
[100] = { name="Beta", -- "Limited Edition Beta"
	tla="LEB",
	cardcount={ reg = 302, tok =  0 }, 
	variants={
["Plains"] 						= { "Plains"	, { 1    , 2    , 3     } },
["Island"] 						= { "Island" 	, { 1    , 2    , 3     } },
["Swamp"] 						= { "Swamp"		, { 1    , 2    , 3     } },
["Mountain"] 					= { "Mountain"	, { 1    , 2    , 3     } },
["Forest"] 						= { "Forest" 	, { 1    , 2    , 3     } },
["Plains (1)"]					= { "Plains"	, { 1    , false, false } },--No Trees
["Plains (2)"]					= { "Plains"	, { false, 2    , false } },--Trees
["Plains (3)"]					= { "Plains"	, { false, false, 3     } },--No Mountains
["Island (1)"]					= { "Island"	, { 1    , false, false } },--Purple
["Island (2)"]					= { "Island"	, { false, 2    , false } },--Green
["Island (3)"]					= { "Island"	, { false, false, 3     } },--Blue
["Swamp (1)"]					= { "Swamp"		, { 1    , false, false } },--Low Branch
["Swamp (2)"]					= { "Swamp"		, { false, 2    , false } },--High Branch
["Swamp (3)"]					= { "Swamp"		, { false, false, 3     } },--Two Branches
["Mountain (1)"]				= { "Mountain"	, { 1    , false, false } },--Dirt
["Mountain (2)"]				= { "Mountain"	, { false, 2    , false } },--Fog
["Mountain (3)"]				= { "Mountain"	, { false, false, 3     } },--Slate
["Forest (1)"]					= { "Forest"	, { 1    , false, false } },--Rocks
["Forest (2)"]					= { "Forest"	, { false, 2    , false } },--Path
["Forest (3)"]					= { "Forest"	, { false, false, 3     } },--Eyes
	},
},
[90]  = { name="Alpha", -- "Limited Edition Alpha"
	tla="LEA",
	cardcount={ reg = 295, tok =  0 }, 
	variants={
["Plains"] 						= { "Plains"	, { 1    , 2     } },
["Island"] 						= { "Island" 	, { 1    , 2     } },
["Swamp"] 						= { "Swamp"		, { 1    , 2     } },
["Mountain"] 					= { "Mountain"	, { 1    , 2     } },
["Forest"] 						= { "Forest" 	, { 1    , 2     } },
["Plains (1)"]					= { "Plains"	, { 1    , false } },--No Trees
["Plains (2)"]					= { "Plains"	, { false, 2     } },--Trees
["Island (1)"]					= { "Island"	, { 1    , false } },--Purple
["Island (2)"]					= { "Island"	, { false, 2     } },--Green
["Swamp (1)"]					= { "Swamp"		, { 1    , false } },--Low Branch
["Swamp (2)"]					= { "Swamp"		, { false, 2     } },--High Branch
["Mountain (1)"]				= { "Mountain"	, { 1    , false } },--Slate
["Mountain (2)"]				= { "Mountain"	, { false, 2     } },--Fog
["Forest (1)"]					= { "Forest"	, { 1    , false } },--Rocks
["Forest (2)"]					= { "Forest"	, { false, 2     } },--Path
	},
},
--- not really a seperate subtable, just a bookmark for quick navigation in eclipse.
-- @field [parent=#Data.sets] #table Expansions
Expansions = nil,
[825] = { name="Battle for Zendikar",
	tla="BFZ",
	cardcount={ reg = 299, tok = 14 },
	variants={
	-- (000F) is Full Art, (000) is normal
["Plains"] 						= { "Plains"	, { 1    , 2    , 3    , 4    , 5    , "1F" , "2F" , "3F" , "4F" , "5F"  } },
["Island"] 						= { "Island" 	, { 1    , 2    , 3    , 4    , 5    , "1F" , "2F" , "3F" , "4F" , "5F"  } },
["Swamp"] 						= { "Swamp"		, { 1    , 2    , 3    , 4    , 5    , "1F" , "2F" , "3F" , "4F" , "5F"  } },
["Mountain"] 					= { "Mountain"	, { 1    , 2    , 3    , 4    , 5    , "1F" , "2F" , "3F" , "4F" , "5F"  } },
["Forest"] 						= { "Forest" 	, { 1    , 2    , 3    , 4    , 5    , "1F" , "2F" , "3F" , "4F" , "5F"  } },
["Plains (250)"]				= { "Plains"	, { 1    , false, false, false, false, false, false, false, false, false } },
["Plains (250F)"]				= { "Plains"	, { false, false, false, false, false, "1F" , false, false, false, false } },
["Plains (251)"]				= { "Plains"	, { false, 2    , false, false, false, false, false, false, false, false } },
["Plains (251F)"]				= { "Plains"	, { false, false, false, false, false, false, "2F" , false, false, false } },
["Plains (252)"]				= { "Plains"	, { false, false, 3    , false, false, false, false, false, false, false } },
["Plains (252F)"]				= { "Plains"	, { false, false, false, false, false, false, false, "3F" , false, false } },
["Plains (253)"]				= { "Plains"	, { false, false, false, 4    , false, false, false, false, false, false } },
["Plains (253F)"]				= { "Plains"	, { false, false, false, false, false, false, false, false, "4F" , false } },
["Plains (254)"]				= { "Plains"	, { false, false, false, false , 5   , false, false, false ,false, false } },
["Plains (254F)"]				= { "Plains"	, { false, false, false, false ,false, false, false, false ,false, "5F"  } },
["Island (255)"]				= { "Island"	, { 1    , false, false, false, false, false, false, false, false, false } },
["Island (255F)"]				= { "Island"	, { false, false, false, false, false, "1F" , false, false, false, false } },
["Island (256)"]				= { "Island"	, { false, 2    , false, false, false, false, false, false, false, false } },
["Island (256F)"]				= { "Island"	, { false, false, false, false, false, false, "2F" , false, false, false } },
["Island (257)"]				= { "Island"	, { false, false, 3    , false, false, false, false, false, false, false } },
["Island (257F)"]				= { "Island"	, { false, false, false, false, false, false, false, "3F" , false, false } },
["Island (258)"]				= { "Island"	, { false, false, false, 4    , false, false, false, false, false, false } },
["Island (258F)"]				= { "Island"	, { false, false, false, false, false, false, false, false, "4F" , false } },
["Island (259)"]				= { "Island"	, { false, false, false, false, 5    , false, false, false, false, false } },
["Island (259F)"]				= { "Island"	, { false, false, false, false ,false, false, false, false ,false, "5F"  } },
["Swamp (260)"]					= { "Swamp"		, { 1    , false, false, false, false, false, false, false, false, false } },
["Swamp (260F)"]				= { "Swamp"		, { false, false, false, false, false, "1F" , false, false, false, false } },
["Swamp (261)"]					= { "Swamp"		, { false, 2    , false, false, false, false, false, false, false, false } },
["Swamp (261F)"]				= { "Swamp"		, { false, false, false, false, false, false, "2F" , false, false, false } },
["Swamp (262)"]					= { "Swamp"		, { false, false, 3    , false, false, false, false, false, false, false } },
["Swamp (262F)"]				= { "Swamp"		, { false, false, false, false, false, false, false, "3F" , false, false } },
["Swamp (263)"]					= { "Swamp"		, { false, false, false, 4    , false, false, false, false, false, false } },
["Swamp (263F)"]				= { "Swamp"		, { false, false, false, false, false, false, false, false, "4F" , false } },
["Swamp (264)"]					= { "Swamp"		, { false, false, false, false, 5    , false, false, false, false, false } },
["Swamp (264F)"]				= { "Swamp"		, { false, false, false, false ,false, false, false, false ,false, "5F"  } },
["Mountain (265)"]				= { "Mountain"	, { 1    , false, false, false, false, false, false, false, false, false } },
["Mountain (265F)"]				= { "Mountain"	, { false, false, false, false, false, "1F" , false, false, false, false } },
["Mountain (266)"]				= { "Mountain"	, { false, 2    , false, false, false, false, false, false, false, false } },
["Mountain (266F)"]				= { "Mountain"	, { false, false, false, false, false, false, "2F" , false, false, false } },
["Mountain (267)"]				= { "Mountain"	, { false, false, 3    , false, false, false, false, false, false, false } },
["Mountain (267F)"]				= { "Mountain"	, { false, false, false, false, false, false, false, "3F" , false, false } },
["Mountain (268)"]				= { "Mountain"	, { false, false, false, 4    , false, false, false, false, false, false } },
["Mountain (268F)"]				= { "Mountain"	, { false, false, false, false, false, false, false, false, "4F" , false } },
["Mountain (269)"]				= { "Mountain"	, { false, false, false, false, 5    , false, false, false, false, false } },
["Mountain (269F)"]				= { "Mountain"	, { false, false, false, false ,false, false, false, false ,false, "5F"  } },
["Forest (270)"]				= { "Forest"	, { 1    , false, false, false, false, false, false, false, false, false } },
["Forest (270F)"]				= { "Forest"	, { false, false, false, false, false, "1F" , false, false, false, false } },
["Forest (271)"]				= { "Forest"	, { false, 2    , false, false, false, false, false, false, false, false } },
["Forest (271F)"]				= { "Forest"	, { false, false, false, false, false, false, "2F" , false, false, false } },
["Forest (272)"]				= { "Forest"	, { false, false, 3    , false, false, false, false, false, false, false } },
["Forest (272F)"]				= { "Forest"	, { false, false, false, false, false, false, false, "3F" , false, false } },
["Forest (273)"]				= { "Forest"	, { false, false, false, 4    , false, false, false, false, false, false } },
["Forest (273F)"]				= { "Forest"	, { false, false, false, false, false, false, false, false, "4F" , false } },
["Forest (274)"]				= { "Forest"	, { false, false, false, false, 5    , false, false, false, false, false } },
["Forest (274F)"]				= { "Forest"	, { false, false, false, false ,false, false, false, false ,false, "5F"  } },
["Eldrazi Scion Token"]		= { "Eldrazi Scion Token"		, { "1"   , "2"   , "3"   } },
["Eldrazi Scion Token (2)"]	= { "Eldrazi Scion Token"		, { "1"   , false , false } }, -- art:Izzy
["Eldrazi Scion Token (3)"]	= { "Eldrazi Scion Token"		, { false , "2"   , false } }, -- art:Winona Nelson
["Eldrazi Scion Token (4)"]	= { "Eldrazi Scion Token"		, { false , false , "3"   } }, -- art:Svetlin Velinov
["Elemental Token"]			= { "Elemental Token"		, { 1     , 2     } },
["Elemental Token (9)"]		= { "Elemental Token"		, { 1     , false } }, -- R
["Elemental Token (11)"]	= { "Elemental Token"		, { false , 2     } }, -- RG
	},
},
[818] = { name = "Dragons of Tarkir",
	tla="DTK",
	cardcount = { reg=264, tok=8 },
	variants={
["Plains"] 						= { "Plains"	, { 1    , 2    , 3     } },
["Island"] 						= { "Island" 	, { 1    , 2    , 3     } },
["Swamp"] 						= { "Swamp"		, { 1    , 2    , 3     } },
["Mountain"] 					= { "Mountain"	, { 1    , 2    , 3     } },
["Forest"] 						= { "Forest" 	, { 1    , 2    , 3     } },
["Plains (250)"]				= { "Plains"	, { 1    , false, false } },
["Plains (251)"]				= { "Plains"	, { false, 2    , false } },
["Plains (252)"]				= { "Plains"	, { false, false, 3     } },
["Island (253)"]				= { "Island"	, { 1    , false, false } },
["Island (254)"]				= { "Island"	, { false, 2    , false } },
["Island (255)"]				= { "Island"	, { false, false, 3     } },
["Swamp (256)"]					= { "Swamp"		, { 1    , false, false } },
["Swamp (257)"]					= { "Swamp"		, { false, 2    , false } },
["Swamp (258)"]					= { "Swamp"		, { false, false, 3     } },
["Mountain (259)"]				= { "Mountain"	, { 1    , false, false } },
["Mountain (260)"]				= { "Mountain"	, { false, 2    , false } },
["Mountain (261)"]				= { "Mountain"	, { false, false, 3     } },
["Forest (262)"]				= { "Forest"	, { 1    , false, false } },
["Forest (263)"]				= { "Forest"	, { false, 2    , false } },
["Forest (264)"]				= { "Forest"	, { false, false, 3     } },
	},
},
[816] = { name="Fate Reforged",
	tla="FRF",
	cardcount= { reg=185, tok=4 },
	variants={
["Plains"] 						= { "Plains"	, { 1    , 2     } },
["Island"] 						= { "Island" 	, { 1    , 2     } },
["Swamp"] 						= { "Swamp"		, { 1    , 2     } },
["Mountain"] 					= { "Mountain"	, { 1    , 2     } },
["Forest"] 						= { "Forest" 	, { 1    , 2     } },
["Plains (176)"]				= { "Plains"	, { 1    , false } }, 
["Plains (177)"]				= { "Plains"	, { false, 2     } },
["Island (178)"]				= { "Island"	, { 1    , false } },
["Island (179)"]				= { "Island"	, { false, 2     } },
["Swamp (180)"]					= { "Swamp"		, { 1    , false } },
["Swamp (181)"]					= { "Swamp"		, { false, 2     } },
["Mountain (182)"]				= { "Mountain"	, { 1    , false } },
["Mountain (183)"]				= { "Mountain"	, { false, 2     } },
["Forest (184)"]				= { "Forest"	, { 1    , false } },
["Forest (185)"]				= { "Forest"	, { false, 2     } },
	},
},
[813] = { name="Khans of Tarkir",
	tla="KTK",
	cardcount= { reg=269, tok=13 },
	variants={
["Plains"] 						= { "Plains"	, { 1    , 2    , 3    , 4     } },
["Island"] 						= { "Island" 	, { 1    , 2    , 3    , 4     } },
["Swamp"] 						= { "Swamp"		, { 1    , 2    , 3    , 4     } },
["Mountain"] 					= { "Mountain"	, { 1    , 2    , 3    , 4     } },
["Forest"] 						= { "Forest" 	, { 1    , 2    , 3    , 4     } },
["Plains (250)"]				= { "Plains"	, { 1    , false ,false, false } }, 
["Plains (251)"]				= { "Plains"	, { false, 2    , false, false } },
["Plains (252)"]				= { "Plains"	, { false, false, 3    , false } },
["Plains (253)"]				= { "Plains"	, { false, false, false, 4     } },
["Island (254)"]				= { "Island"	, { 1    , false, false, false } },
["Island (255)"]				= { "Island"	, { false, 2    , false, false } },
["Island (256)"]				= { "Island"	, { false, false, 3    , false } },
["Island (257)"]				= { "Island"	, { false, false, false, 4     } },
["Swamp (258)"]					= { "Swamp"		, { 1    , false, false, false } },
["Swamp (259)"]					= { "Swamp"		, { false, 2    , false, false } },
["Swamp (260)"]					= { "Swamp"		, { false, false, 3    , false } },
["Swamp (261)"]					= { "Swamp"		, { false, false, false, 4     } },
["Mountain (262)"]				= { "Mountain"	, { 1    , false, false, false } },
["Mountain (263)"]				= { "Mountain"	, { false, 2    , false, false } },
["Mountain (264)"]				= { "Mountain"	, { false, false, 3    , false } },
["Mountain (265)"]				= { "Mountain"	, { false, false, false, 4     } },
["Forest (266)"]				= { "Forest"	, { 1    , false, false, false } },
["Forest (267)"]				= { "Forest"	, { false, 2    , false, false } },
["Forest (268)"]				= { "Forest"	, { false, false, 3    , false } },
["Forest (269)"]				= { "Forest"	, { false, false, false, 4     } },
["Warrior Token"]				= { "Warrior Token"		, { 1    , 2     } },
["Warrior Token (3)"]			= { "Warrior Token"		, { 1    , false } },--Sword&Shield, by Ryan Barger
["Warrior Token (4)"]			= { "Warrior Token"		, { false, 2     } },--Pike, by Yefim Kligerman
["Krieger Token"]				= { "Krieger Token"		, { 1    , 2     } },
["Krieger Token (3)"]			= { "Krieger Token"		, { 1    , false } },--Ryan Barger
["Krieger Token (4)"]			= { "Krieger Token"		, { false, 2     } },--Yefim Kligerman
	},
},
[806] = { name = "Journey into Nyx",
	tla="JOU",
	cardcount = { reg=165, tok=6 },
},
[802] = { name="Born of the Gods",
	tla="BNG",
	cardcount={ reg=165, tok=11 },
	variants={
["Bird Token"]					= { "Bird Token"	, { 1    , 2     } },
["Bird Token (1)"]				= { "Bird Token"	, { 1    , false } },--White
["Bird Token (4)"]				= { "Bird Token"	, { false, 2     } },--Blue
["Vogel Token"]					= { "Vogel Token"	, { 1    , 2     } },
["Vogel Token (1)"]				= { "Vogel Token"	, { 1    , false } },--White
["Vogel Token (4)"]				= { "Vogel Token"	, { false, 2     } },--Blue
	},
},
[800] = { name="Theros",
	tla="THS",
	cardcount={ reg = 249, tok = 11 },
	variants={
["Plains"] 						= { "Plains"	, { 1    , 2    , 3    , 4     } },
["Island"] 						= { "Island" 	, { 1    , 2    , 3    , 4     } },
["Swamp"] 						= { "Swamp"		, { 1    , 2    , 3    , 4     } },
["Mountain"] 					= { "Mountain"	, { 1    , 2    , 3    , 4     } },
["Forest"] 						= { "Forest" 	, { 1    , 2    , 3    , 4     } },
["Plains (230)"]				= { "Plains"	, { 1    , false ,false, false } }, 
["Plains (231)"]				= { "Plains"	, { false, 2    , false, false } },
["Plains (232)"]				= { "Plains"	, { false, false, 3    , false } },
["Plains (233)"]				= { "Plains"	, { false, false, false, 4     } },
["Island (234)"]				= { "Island"	, { 1    , false, false, false } },
["Island (235)"]				= { "Island"	, { false, 2    , false, false } },
["Island (236)"]				= { "Island"	, { false, false, 3    , false } },
["Island (237)"]				= { "Island"	, { false, false, false, 4     } },
["Swamp (238)"]					= { "Swamp"		, { 1    , false, false, false } },
["Swamp (239)"]					= { "Swamp"		, { false, 2    , false, false } },
["Swamp (240)"]					= { "Swamp"		, { false, false, 3    , false } },
["Swamp (241)"]					= { "Swamp"		, { false, false, false, 4     } },
["Mountain (242)"]				= { "Mountain"	, { 1    , false, false, false } },
["Mountain (243)"]				= { "Mountain"	, { false, 2    , false, false } },
["Mountain (244)"]				= { "Mountain"	, { false, false, 3    , false } },
["Mountain (245)"]				= { "Mountain"	, { false, false, false, 4     } },
["Forest (246)"]				= { "Forest"	, { 1    , false, false, false } },
["Forest (247)"]				= { "Forest"	, { false, 2    , false, false } },
["Forest (248)"]				= { "Forest"	, { false, false, 3    , false } },
["Forest (249)"]				= { "Forest"	, { false, false, false, 4     } },
["Soldier Token"]				= { "Soldier Token"	, { 1    , 2    , 3     } },
["Soldier Token (2)"]			= { "Soldier Token"	, { 1    , false, false } },
["Soldier Token (3)"]			= { "Soldier Token"	, { false, 2    , false } },
["Soldier Token (7)"]			= { "Soldier Token"	, { false, false, 3     } },--Red
["Soldat Token"]				= { "Soldat Token"	, { 1    , 2    , 3     } },
["Soldat Token (2)"]			= { "Soldat Token"	, { 1    , false, false } },
["Soldat Token (3)"]			= { "Soldat Token"	, { false, 2    , false } },
["Soldat Token (7)"]			= { "Soldat Token"	, { false, false, 3     } },
--["Karametra's Acolyte"]						= { "Karametra's Acolyte"	, { ""   , false              } },
--["Karametra's Acolyte (Holiday Gift Box)"]	= { "Karametra's Acolyte"	, { false, "Holiday Gift Box" } },
	},
},
[795] = { name="Dragon’s Maze",
	tla="DGM",
	cardcount={ reg = 156, tok =  1 },
	variants={}
},
[793] = { name="Gatecrash",
	tla="GTC",
	cardcount={ reg = 249, tok =  8 },
	variants={}
},
[791] = { name="Return to Ravnica",
	tla="RTR",
	cardcount={ reg = 274, tok = 12 },
	variants={
["Plains"] 						= { "Plains"	, { 1    , 2    , 3    , 4    , 5     } },
["Island"] 						= { "Island" 	, { 1    , 2    , 3    , 4    , 5     } },
["Swamp"] 						= { "Swamp"		, { 1    , 2    , 3    , 4    , 5     } },
["Mountain"] 					= { "Mountain"	, { 1    , 2    , 3    , 4    , 5     } },
["Forest"] 						= { "Forest" 	, { 1    , 2    , 3    , 4    , 5     } },
["Plains (250)"]				= { "Plains"	, { 1    , false, false, false, false } },
["Plains (251)"]				= { "Plains"	, { false, 2    , false, false, false } },
["Plains (252)"]				= { "Plains"	, { false, false, 3    , false, false } },
["Plains (253)"]				= { "Plains"	, { false, false, false, 4    , false } },
["Plains (254)"]				= { "Plains"	, { false, false, false, false, 5     } },
["Island (255)"]				= { "Island"	, { 1    , false, false, false, false } },
["Island (256)"]				= { "Island"	, { false, 2    , false, false, false } },
["Island (257)"] 				= { "Island"	, { false, false, 3    , false, false } },
["Island (258)"]				= { "Island"	, { false, false, false, 4    , false } },
["Island (259)"]				= { "Island"	, { false, false, false, false, 5     } },
["Swamp (260)"]					= { "Swamp" 	, { 1    , false, false, false, false } },
["Swamp (261)"]					= { "Swamp" 	, { false, 2    , false, false, false } },
["Swamp (262)"]					= { "Swamp" 	, { false, false, 3    , false, false } },
["Swamp (263)"]					= { "Swamp" 	, { false, false, false, 4    , false } },
["Swamp (264)"]					= { "Swamp" 	, { false, false, false, false, 5     } },
["Mountain (265)"]				= { "Mountain"	, { 1    , false, false, false, false } },
["Mountain (266)"]				= { "Mountain"	, { false, 2    , false, false, false } },
["Mountain (267)"]				= { "Mountain"	, { false, false, 3    , false, false } },
["Mountain (268)"]				= { "Mountain"	, { false, false, false, 4    , false } },
["Mountain (269)"]				= { "Mountain"	, { false, false, false, false, 5     } },
["Forest (270)"]				= { "Forest"	, { 1    , false, false, false, false } },
["Forest (271)"]				= { "Forest"	, { false, 2    , false, false, false } },
["Forest (272)"]				= { "Forest"	, { false, false, 3    , false, false } },
["Forest (273)"]				= { "Forest"	, { false, false, false, 4    , false } },
["Forest (274)"]				= { "Forest"	, { false, false, false, false, 5     } },
	},
},
[786] = { name="Avacyn Restored",
	tla="AVR",
	cardcount={ reg = 244, tok =  8 },
	variants={
["Plains"] 						= { "Plains"	, { 1    , 2    , 3     } },
["Island"] 						= { "Island" 	, { 1    , 2    , 3     } },
["Swamp"] 						= { "Swamp"		, { 1    , 2    , 3     } },
["Mountain"] 					= { "Mountain"	, { 1    , 2    , 3     } },
["Forest"] 						= { "Forest" 	, { 1    , 2    , 3     } },
["Plains (230)"]				= { "Plains"	, { 1    , false, false } },
["Plains (231)"]				= { "Plains"	, { false, 2    , false } },
["Plains (232)"]				= { "Plains"	, { false, false, 3     } },
["Island (233)"]				= { "Island"	, { 1    , false, false } },
["Island (234)"]				= { "Island"	, { false, 2    , false } },
["Island (235)"]				= { "Island"	, { false, false, 3     } },
["Swamp (236)"]					= { "Swamp"		, { 1    , false, false } },
["Swamp (237)"]					= { "Swamp"		, { false, 2    , false } },
["Swamp (238)"]					= { "Swamp"		, { false, false, 3     } },
["Mountain (239)"]				= { "Mountain"	, { 1    , false, false } },
["Mountain (240)"]				= { "Mountain"	, { false, 2    , false } },
["Mountain (241)"]				= { "Mountain"	, { false, false, 3     } },
["Forest (242)"]				= { "Forest"	, { 1    , false, false } },
["Forest (243)"]				= { "Forest"	, { false, 2    , false } },
["Forest (244)"]				= { "Forest"	, { false, false, 3     } },
["Human Token"]					= { "Human Token"	, { 1    , 2     } },
["Human Token (2)"]				= { "Human Token"	, { 1    ,false  } },--White
["Human Token (7)"]				= { "Human Token"	, { false, 2     } },--Red
["Spirit Token"]				= { "Spirit Token"	, { 1    , 2     } },
["Spirit Token (3)"]			= { "Spirit Token"	, { 1    , false } },--White
["Spirit Token (4)"]			= { "Spirit Token"	, { false, 2     } },--Blue
["Mensch Token"]				= { "Mensch Token"	, { 1    , 2     } },
["Mensch Token (2)"]			= { "Mensch Token"	, { 1    ,false  } },
["Mensch Token (7)"]			= { "Mensch Token"	, { false, 2     } },
["Geist Token"]					= { "Geist Token"	, { 1    , 2     } },
["Geist Token (3)"]				= { "Geist Token"	, { 1    , false } },
["Geist Token (4)"]				= { "Geist Token"	, { false, 2     } },
["Checklist"]					= { "Checklist"		, { "Insert" } }, 
	},
},
[784] = { name="Dark Ascension",
	tla="DKA",
	cardcount={ reg = 158, tok =  3 }, 
	variants={
["Checklist"]					= { "Checklist"		, { "Insert" } }, 
	}
},
[782] = { name="Innistrad",
	tla="ISD",
	cardcount={ reg = 264, tok = 12 }, 
	variants={
["Plains"] 						= { "Plains"	, { 1    , 2    , 3     } },
["Island"] 						= { "Island" 	, { 1    , 2    , 3     } },
["Swamp"] 						= { "Swamp"		, { 1    , 2    , 3     } },
["Mountain"] 					= { "Mountain"	, { 1    , 2    , 3     } },
["Forest"] 						= { "Forest" 	, { 1    , 2    , 3     } },
["Plains (250)"]				= { "Plains"	, { 1    , false, false } },
["Plains (251)"]				= { "Plains"	, { false, 2    , false } },
["Plains (252)"]				= { "Plains"	, { false, false, 3     } },
["Island (253)"]				= { "Island"	, { 1    , false, false } },
["Island (254)"]				= { "Island"	, { false, 2    , false } },
["Island (255)"]				= { "Island"	, { false, false, 3     } },
["Swamp (256)"]					= { "Swamp"		, { 1    , false, false } },
["Swamp (257)"]					= { "Swamp"		, { false, 2    , false } },
["Swamp (258)"]					= { "Swamp"		, { false, false, 3     } },
["Mountain (259)"]				= { "Mountain"	, { 1    , false, false } },
["Mountain (260)"]				= { "Mountain"	, { false, 2    , false } },
["Mountain (261)"]				= { "Mountain"	, { false, false, 3     } },
["Forest (262)"]				= { "Forest"	, { 1    , false, false } },
["Forest (263)"]				= { "Forest"	, { false, 2    , false } },
["Forest (264)"]				= { "Forest"	, { false, false, 3     } },
["Wolf Token"]					= { "Wolf Token"	, { 1    , 2     } },
["Wolf Token (6)"]				= { "Wolf Token"	, { 1    , false } },--Deathtouch
["Wolf Token (12)"]				= { "Wolf Token"	, { false, 2     } },--Green
["Zombie Token"]				= { "Zombie Token"	, { 1    , 2    , 3		} },
["Zombie Token (7)"]			= { "Zombie Token"	, { 1    , false, false } },
["Zombie Token (8)"]			= { "Zombie Token"	, { false, 2    , false } },
["Zombie Token (9)"]			= { "Zombie Token"	, { false, false, 3     } },
["Checklist"]					= { "Checklist"		, { "Insert" } }, 
	},
},
[776] = { name="New Phyrexia",
	tla="NPH",
	cardcount={ reg = 175, tok =  4 },
	variants={
["Plains"] 						= { "Plains"	, { 1    , 2     } },
["Island"] 						= { "Island" 	, { 1    , 2     } },
["Swamp"] 						= { "Swamp"		, { 1    , 2     } },
["Mountain"] 					= { "Mountain"	, { 1    , 2     } },
["Forest"] 						= { "Forest" 	, { 1    , 2     } },
["Plains (166)"]				= { "Plains"	, { 1    , false } },
["Plains (167)"]				= { "Plains"	, { false, 2     } },
["Island (168)"]				= { "Island"	, { 1    , false } },
["Island (169)"]				= { "Island"	, { false, 2     } },
["Swamp (170)"]					= { "Swamp"		, { 1    , false } },
["Swamp (171)"]					= { "Swamp"		, { false, 2     } },
["Mountain (172)"]				= { "Mountain"	, { 1    , false } },
["Mountain (173)"]				= { "Mountain"	, { false, 2     } },
["Forest (174)"]				= { "Forest"	, { 1    , false } },
["Forest (175)"]				= { "Forest"	, { false, 2     } }
	},
},
[775] = { name="Mirrodin Besieged",
	tla="MBS",
	cardcount={ reg = 155, tok =  5 },
	variants={
["Plains"] 						= { "Plains"	, { 1    , 2     } },
["Island"] 						= { "Island" 	, { 1    , 2     } },
["Swamp"] 						= { "Swamp"		, { 1    , 2     } },
["Mountain"] 					= { "Mountain"	, { 1    , 2     } },
["Forest"] 						= { "Forest" 	, { 1    , 2     } },
["Plains (146)"]				= { "Plains"	, { 1    , false } },
["Plains (147)"]				= { "Plains"	, { false, 2     } },
["Island (148)"]				= { "Island"	, { 1    , false } },
["Island (149)"]				= { "Island"	, { false, 2     } },
["Swamp (150)"]					= { "Swamp"		, { 1    , false } },
["Swamp (151)"]					= { "Swamp"		, { false, 2     } },
["Mountain (152)"]				= { "Mountain"	, { 1    , false } },
["Mountain (153)"]				= { "Mountain"	, { false, 2     } },
["Forest (154)"]				= { "Forest"	, { 1    , false } },
["Forest (155)"]				= { "Forest"	, { false, 2     } }
	},
},
[773] = { name="Scars of Mirrodin",
	tla="SOM",
	cardcount={ reg = 249, tok =  9 },
	variants={
["Plains"] 						= { "Plains"	, { 1    , 2    , 3    , 4     } },
["Island"] 						= { "Island" 	, { 1    , 2    , 3    , 4     } },
["Swamp"] 						= { "Swamp"		, { 1    , 2    , 3    , 4     } },
["Mountain"] 					= { "Mountain"	, { 1    , 2    , 3    , 4     } },
["Forest"] 						= { "Forest" 	, { 1    , 2    , 3    , 4     } },
["Plains (230)"]				= { "Plains"	, { 1    , false ,false, false } }, 
["Plains (231)"]				= { "Plains"	, { false, 2    , false, false } },
["Plains (232)"]				= { "Plains"	, { false, false, 3    , false } },
["Plains (233)"]				= { "Plains"	, { false, false, false, 4     } },
["Island (234)"]				= { "Island"	, { 1    , false, false, false } },
["Island (235)"]				= { "Island"	, { false, 2    , false, false } },
["Island (236)"]				= { "Island"	, { false, false, 3    , false } },
["Island (237)"]				= { "Island"	, { false, false, false, 4     } },
["Swamp (238)"]					= { "Swamp"		, { 1    , false, false, false } },
["Swamp (239)"]					= { "Swamp"		, { false, 2    , false, false } },
["Swamp (240)"]					= { "Swamp"		, { false, false, 3    , false } },
["Swamp (241)"]					= { "Swamp"		, { false, false, false, 4     } },
["Mountain (242)"]				= { "Mountain"	, { 1    , false, false, false } },
["Mountain (243)"]				= { "Mountain"	, { false, 2    , false, false } },
["Mountain (244)"]				= { "Mountain"	, { false, false, 3    , false } },
["Mountain (245)"]				= { "Mountain"	, { false, false, false, 4     } },
["Forest (246)"]				= { "Forest"	, { 1    , false, false, false } },
["Forest (247)"]				= { "Forest"	, { false, 2    , false, false } },
["Forest (248)"]				= { "Forest"	, { false, false, 3    , false } },
["Forest (249)"]				= { "Forest"	, { false, false, false, 4     } },
["Wurm Token"]					= { "Wurm Token"	, { 1    , 2     } },
["Wurm Token (8)"]				= { "Wurm Token"	, { 1    , false } }, -- Deathtouch
["Wurm Token (9)"]				= { "Wurm Token"	, { false, 2     } }, -- Lifelink
["Poison Counter"]				= { "Poison Counter"	, { "Token" } },
	},
},
[767] = { name="Rise of the Eldrazi",
	tla="ROE",
	cardcount={ reg = 248, tok =  7 },
	variants={
["Plains"] 						= { "Plains"	, { 1    , 2    , 3    , 4     } },
["Island"] 						= { "Island" 	, { 1    , 2    , 3    , 4     } },
["Swamp"] 						= { "Swamp"		, { 1    , 2    , 3    , 4     } },
["Mountain"] 					= { "Mountain"	, { 1    , 2    , 3    , 4     } },
["Forest"] 						= { "Forest" 	, { 1    , 2    , 3    , 4     } },
["Plains (229)"]				= { "Plains"	, { 1    , false, false, false } }, 
["Plains (230)"]				= { "Plains"	, { false, 2    , false, false } },
["Plains (231)"]				= { "Plains"	, { false, false, 3    , false } },
["Plains (232)"]				= { "Plains"	, { false, false, false, 4     } },
["Island (233)"]				= { "Island"	, { 1    , false, false, false } },
["Island (234)"]				= { "Island"	, { false, 2    , false, false } },
["Island (235)"]				= { "Island"	, { false, false, 3    , false } },
["Island (236)"]				= { "Island"	, { false, false, false, 4     } },
["Swamp (237)"]					= { "Swamp"		, { 1    , false, false, false } },
["Swamp (238)"]					= { "Swamp"		, { false, 2    , false, false } },
["Swamp (239)"]					= { "Swamp"		, { false, false, 3    , false } },
["Swamp (240)"]					= { "Swamp"		, { false, false, false, 4     } },
["Mountain (241)"]				= { "Mountain"	, { 1    , false, false, false } },
["Mountain (242)"]				= { "Mountain"	, { false, 2    , false, false } },
["Mountain (243)"]				= { "Mountain"	, { false, false, 3    , false } },
["Mountain (244)"]				= { "Mountain"	, { false, false, false, 4     } },
["Forest (245)"]				= { "Forest"	, { 1    , false, false, false } },
["Forest (246)"]				= { "Forest"	, { false, 2    , false, false } },
["Forest (247)"]				= { "Forest"	, { false, false, 3    , false } },
["Forest (248)"]				= { "Forest"	, { false, false, false, 4     } },
["Eldrazi Spawn Token"]		 		= { "Eldrazi Spawn Token"		, { "a"   , "b"   , "c"   } },
["Eldrazi Spawn Token (1a)"]		= { "Eldrazi Spawn Token"		, { "a"   , false , false } }, -- art:Aleksi Briclot
["Eldrazi Spawn Token (1b)"]		= { "Eldrazi Spawn Token"		, { false , "b"   , false } }, -- art:Mark Tedin
["Eldrazi Spawn Token (1c)"]		= { "Eldrazi Spawn Token"		, { false , false , "c"   } }, -- art:Veronique Meignaud
["Eldrazi, Ausgeburt Token"]		= { "Eldrazi, Ausgeburt Token"	, { "a"   , "b"   , "c"   } },
["Eldrazi, Ausgeburt Token (1a)"]	= { "Eldrazi, Ausgeburt Token"	, { "a"   , false , false } },
["Eldrazi, Ausgeburt Token (1b)"]	= { "Eldrazi, Ausgeburt Token"	, { false , "b"   , false } },
["Eldrazi, Ausgeburt Token (1c)"]	= { "Eldrazi, Ausgeburt Token"	, { false , false , "c"   } },
	},
},
[765] = { name="Worldwake",
	tla="WWK",
	cardcount={ reg = 145, tok =  6 },
	variants={}
},
[762] = { name="Zendikar",
	tla="ZEN",
	cardcount={ reg = 269, tok = 11 },
	variants={
	-- (000) is Full Art, (000a) is normal
["Plains"] 						= { "Plains"	, { 1    , 2    , 3    , 4    , "1a" , "2a" , "3a" , "4a"  } },
["Island"] 						= { "Island" 	, { 1    , 2    , 3    , 4    , "1a" , "2a" , "3a" , "4a"  } },
["Swamp"] 						= { "Swamp"		, { 1    , 2    , 3    , 4    , "1a" , "2a" , "3a" , "4a"  } },
["Mountain"] 					= { "Mountain"	, { 1    , 2    , 3    , 4    , "1a" , "2a" , "3a" , "4a"  } },
["Forest"] 						= { "Forest" 	, { 1    , 2    , 3    , 4    , "1a" , "2a" , "3a" , "4a"  } },
["Plains (230)"]				= { "Plains"	, { 1    , false, false, false, false, false, false, false } },
["Plains (230a)"]				= { "Plains"	, { false, false, false, false, "1a" , false, false, false } },
["Plains (231)"]				= { "Plains"	, { false, 2    , false, false, false, false, false, false } },
["Plains (231a)"]				= { "Plains"	, { false, false, false, false, false, "2a" , false, false } },
["Plains (232)"]				= { "Plains"	, { false, false, 3    , false, false, false, false, false } },
["Plains (232a)"]				= { "Plains"	, { false, false, false, false, false, false, "3a" , false } },
["Plains (233)"]				= { "Plains"	, { false, false, false, 4    , false, false, false, false } },
["Plains (233a)"]				= { "Plains"	, { false, false, false, false, false, false, false, "4a"  } },
["Island (234)"]				= { "Island"	, { 1    , false, false, false, false, false, false, false } },
["Island (234a)"]				= { "Island"	, { false, false, false, false, "1a" , false, false, false } },
["Island (235)"]				= { "Island"	, { false, 2    , false, false, false, false, false, false } },
["Island (235a)"]				= { "Island"	, { false, false, false, false, false, "2a" , false, false } },
["Island (236)"]				= { "Island"	, { false, false, 3    , false, false, false, false, false } },
["Island (236a)"]				= { "Island"	, { false, false, false, false, false, false, "3a" , false } },
["Island (237)"]				= { "Island"	, { false, false, false, 4    , false, false, false, false } },
["Island (237a)"]				= { "Island"	, { false, false, false, false, false, false, false, "4a"  } },
["Swamp (238)"]					= { "Swamp"		, { 1    , false, false, false, false, false, false, false } },
["Swamp (238a)"]				= { "Swamp"		, { false, false, false, false, "1a" , false, false, false } },
["Swamp (239)"]					= { "Swamp"		, { false, 2    , false, false, false, false, false, false } },
["Swamp (239a)"]				= { "Swamp"		, { false, false, false, false, false, "2a" , false, false } },
["Swamp (240)"]					= { "Swamp"		, { false, false, 3    , false, false, false, false, false } },
["Swamp (240a)"]				= { "Swamp"		, { false, false, false, false, false, false, "3a" , false } },
["Swamp (241)"]					= { "Swamp"		, { false, false, false, 4    , false, false, false, false } },
["Swamp (241a)"]				= { "Swamp"		, { false, false, false, false, false, false, false, "4a"  } },
["Mountain (242)"]				= { "Mountain"	, { 1    , false, false, false, false, false, false, false } },
["Mountain (242a)"]				= { "Mountain"	, { false, false, false, false, "1a" , false, false, false } },
["Mountain (243)"]				= { "Mountain"	, { false, 2    , false, false, false, false, false, false } },
["Mountain (243a)"]				= { "Mountain"	, { false, false, false, false, false, "2a" , false, false } },
["Mountain (244)"]				= { "Mountain"	, { false, false, 3    , false, false, false, false, false } },
["Mountain (244a)"]				= { "Mountain"	, { false, false, false, false, false, false, "3a" , false } },
["Mountain (245)"]				= { "Mountain"	, { false, false, false, 4    , false, false, false, false } },
["Mountain (245a)"]				= { "Mountain"	, { false, false, false, false, false, false, false, "4a"  } },
["Forest (246)"]				= { "Forest"	, { 1    , false, false, false, false, false, false, false } },
["Forest (246a)"]				= { "Forest"	, { false, false, false, false, "1a" , false, false, false } },
["Forest (247)"]				= { "Forest"	, { false, 2    , false, false, false, false, false, false } },
["Forest (247a)"]				= { "Forest"	, { false, false, false, false, false, "2a" , false, false } },
["Forest (248)"]				= { "Forest"	, { false, false, 3    , false, false, false, false, false } },
["Forest (248a)"]				= { "Forest"	, { false, false, false, false, false, false, "3a" , false } },
["Forest (249)"]				= { "Forest"	, { false, false, false, 4    , false, false, false, false } },
["Forest (249a)"]				= { "Forest"	, { false, false, false, false, false, false, false, "4a"  } },
	},
},
[758] = { name="Alara Reborn",
	tla="ARB",
	cardcount={ reg = 145, tok =  4 },
	variants={}
},
[756] = { name="Conflux",
	tla="CON",
	cardcount={ reg = 145, tok =  2 },
	variants={}
},
[754] = { name="Shards of Alara",
	tla="ALA",
	cardcount={ reg = 249, tok = 10 },
	variants={
["Plains"] 						= { "Plains"	, { 1    , 2    , 3    , 4     } },
["Island"] 						= { "Island" 	, { 1    , 2    , 3    , 4     } },
["Swamp"] 						= { "Swamp"		, { 1    , 2    , 3    , 4     } },
["Mountain"] 					= { "Mountain"	, { 1    , 2    , 3    , 4     } },
["Forest"] 						= { "Forest" 	, { 1    , 2    , 3    , 4     } },
["Plains (230)"]				= { "Plains"	, { 1    , false ,false, false } }, 
["Plains (231)"]				= { "Plains"	, { false, 2    , false, false } },
["Plains (232)"]				= { "Plains"	, { false, false, 3    , false } },
["Plains (233)"]				= { "Plains"	, { false, false, false, 4     } },
["Island (234)"]				= { "Island"	, { 1    , false, false, false } },
["Island (235)"]				= { "Island"	, { false, 2    , false, false } },
["Island (236)"]				= { "Island"	, { false, false, 3    , false } },
["Island (237)"]				= { "Island"	, { false, false, false, 4     } },
["Swamp (238)"]					= { "Swamp"		, { 1    , false, false, false } },
["Swamp (239)"]					= { "Swamp"		, { false, 2    , false, false } },
["Swamp (240)"]					= { "Swamp"		, { false, false, 3    , false } },
["Swamp (241)"]					= { "Swamp"		, { false, false, false, 4     } },
["Mountain (242)"]				= { "Mountain"	, { 1    , false, false, false } },
["Mountain (243)"]				= { "Mountain"	, { false, 2    , false, false } },
["Mountain (244)"]				= { "Mountain"	, { false, false, 3    , false } },
["Mountain (245)"]				= { "Mountain"	, { false, false, false, 4     } },
["Forest (246)"]				= { "Forest"	, { 1    , false, false, false } },
["Forest (247)"]				= { "Forest"	, { false, 2    , false, false } },
["Forest (248)"]				= { "Forest"	, { false, false, 3    , false } },
["Forest (249)"]				= { "Forest"	, { false, false, false, 4     } }
	},
},
[752] = { name="Eventide",
	tla="EVE",
	cardcount={ reg = 180, tok =  7 },
	variants={}
},
[751] = { name="Shadowmoor",
	tla="SHM",
	cardcount={ reg = 301, tok = 12 },
	variants={
["Plains"] 						= { "Plains"	, { 1    , 2    , 3    , 4     } },
["Island"] 						= { "Island" 	, { 1    , 2    , 3    , 4     } },
["Swamp"] 						= { "Swamp"		, { 1    , 2    , 3    , 4     } },
["Mountain"] 					= { "Mountain"	, { 1    , 2    , 3    , 4     } },
["Forest"] 						= { "Forest" 	, { 1    , 2    , 3    , 4     } },
["Plains (282)"]				= { "Plains"	, { 1    , false ,false, false } }, 
["Plains (283)"]				= { "Plains"	, { false, 2    , false, false } },
["Plains (284)"]				= { "Plains"	, { false, false, 3    , false } },
["Plains (285)"]				= { "Plains"	, { false, false, false, 4     } },
["Island (286)"]				= { "Island"	, { 1    , false, false, false } },
["Island (287)"]				= { "Island"	, { false, 2    , false, false } },
["Island (288)"]				= { "Island"	, { false, false, 3    , false } },
["Island (289)"]				= { "Island"	, { false, false, false, 4     } },
["Swamp (290)"]					= { "Swamp"		, { 1    , false, false, false } },
["Swamp (291)"]					= { "Swamp"		, { false, 2    , false, false } },
["Swamp (292)"]					= { "Swamp"		, { false, false, 3    , false } },
["Swamp (293)"]					= { "Swamp"		, { false, false, false, 4     } },
["Mountain (294)"]				= { "Mountain"	, { 1    , false, false, false } },
["Mountain (295)"]				= { "Mountain"	, { false, 2    , false, false } },
["Mountain (296)"]				= { "Mountain"	, { false, false, 3    , false } },
["Mountain (297)"]				= { "Mountain"	, { false, false, false, 4     } },
["Forest (298)"]				= { "Forest"	, { 1    , false, false, false } },
["Forest (299)"]				= { "Forest"	, { false, 2    , false, false } },
["Forest (300)"]				= { "Forest"	, { false, false, 3    , false } },
["Forest (301)"]				= { "Forest"	, { false, false, false, 4     } },
["Elemental Token"] 			= { "Elemental Token"		, { 1    , 2     } },
["Elemental Token (4)"] 		= { "Elemental Token"		, { 1    , false } },--Red
["Elemental Token (9)"] 		= { "Elemental Token"		, { false, 2     } },--Black|Red
["Elf Warrior Token"]			= { "Elf Warrior Token"		, { 1    , 2     } },
["Elf Warrior Token (5)"]		= { "Elf Warrior Token"		, { 1    , false } },--Green
["Elf Warrior Token (12)"]		= { "Elf Warrior Token"		, { false, 2     } },--White|Green
["Elementarwesen Token"] 		= { "Elementarwesen Token"	, { 1    , 2     } },
["Elementarwesen Token (4)"] 	= { "Elementarwesen Token"	, { 1    , false } },
["Elementarwesen Token (9)"] 	= { "Elementarwesen Token"	, { false, 2     } },
["Elf, Krieger Token"]			= { "Elf, Krieger Token"	, { 1    , 2     } },
["Elf, Krieger Token (5)"]		= { "Elf, Krieger Token"	, { 1    , false } },
["Elf, Krieger Token (12)"]		= { "Elf, Krieger Token"	, { false, 2     } },
	},
},
[750] = { name="Morningtide",
	tla="MOR",
	cardcount={ reg = 150, tok =  3 },
	variants={}
},
[730] = { name="Lorwyn",
	tla="LRW",
	cardcount={ reg = 301, tok = 11 },
	variants={
["Plains"] 						= { "Plains"	, { 1    , 2    , 3    , 4     } },
["Island"] 						= { "Island" 	, { 1    , 2    , 3    , 4     } },
["Swamp"] 						= { "Swamp"		, { 1    , 2    , 3    , 4     } },
["Mountain"] 					= { "Mountain"	, { 1    , 2    , 3    , 4     } },
["Forest"] 						= { "Forest" 	, { 1    , 2    , 3    , 4     } },
["Plains (282)"]				= { "Plains"	, { 1    , false ,false, false } }, 
["Plains (283)"]				= { "Plains"	, { false, 2    , false, false } },
["Plains (284)"]				= { "Plains"	, { false, false, 3    , false } },
["Plains (285)"]				= { "Plains"	, { false, false, false, 4     } },
["Island (286)"]				= { "Island"	, { 1    , false, false, false } },
["Island (287)"]				= { "Island"	, { false, 2    , false, false } },
["Island (288)"]				= { "Island"	, { false, false, 3    , false } },
["Island (289)"]				= { "Island"	, { false, false, false, 4     } },
["Swamp (290)"]					= { "Swamp"		, { 1    , false, false, false } },
["Swamp (291)"]					= { "Swamp"		, { false, 2    , false, false } },
["Swamp (292)"]					= { "Swamp"		, { false, false, 3    , false } },
["Swamp (293)"]					= { "Swamp"		, { false, false, false, 4     } },
["Mountain (294)"]				= { "Mountain"	, { 1    , false, false, false } },
["Mountain (295)"]				= { "Mountain"	, { false, 2    , false, false } },
["Mountain (296)"]				= { "Mountain"	, { false, false, 3    , false } },
["Mountain (297)"]				= { "Mountain"	, { false, false, false, 4     } },
["Forest (298)"]				= { "Forest"	, { 1    , false, false, false } },
["Forest (299)"]				= { "Forest"	, { false, 2    , false, false } },
["Forest (300)"]				= { "Forest"	, { false, false, 3    , false } },
["Forest (301)"]				= { "Forest"	, { false, false, false, 4     } },
["Elemental Token"] 			= { "Elemental Token"		, { 1    , 2     } },
["Elemental Token (2)"] 		= { "Elemental Token"		, { 1    , false } },--White
["Elemental Token (8)"] 		= { "Elemental Token"		, { false, 2     } },--Green
["Elementarwesen Token"] 		= { "Elementarwesen Token"	, { 1    , 2     } },
["Elementarwesen Token (2)"]	= { "Elementarwesen Token"	, { 1    , false } },
["Elementarwesen Token (8)"]	= { "Elementarwesen Token"	, { false, 2     } },
	},
},
[710] = { name="Future Sight",
	tla="FUT",
	cardcount={ reg = 180, tok =  0 },
	variants={}
},
[700] = { name="Planar Chaos",
	tla="PLC",
	cardcount={ reg = 165, tok =  0 },
	variants={}
},
[690] = { name="Time Spiral Timeshifted",
	tla="TSB",
	cardcount={ reg = 121, tok =  0 },
	variants={}
},
[680] = { name="Time Spiral",
	tla="TSP",
	cardcount={ reg = 301, tok =  0 },
	variants={
["Plains"] 						= { "Plains"	, { 1    , 2    , 3    , 4     } },
["Island"] 						= { "Island" 	, { 1    , 2    , 3    , 4     } },
["Swamp"] 						= { "Swamp"		, { 1    , 2    , 3    , 4     } },
["Mountain"] 					= { "Mountain"	, { 1    , 2    , 3    , 4     } },
["Forest"] 						= { "Forest" 	, { 1    , 2    , 3    , 4     } },
["Plains (282)"]				= { "Plains"	, { 1    , false ,false, false } }, 
["Plains (283)"]				= { "Plains"	, { false, 2    , false, false } },
["Plains (284)"]				= { "Plains"	, { false, false, 3    , false } },
["Plains (285)"]				= { "Plains"	, { false, false, false, 4     } },
["Island (286)"]				= { "Island"	, { 1    , false, false, false } },
["Island (287)"]				= { "Island"	, { false, 2    , false, false } },
["Island (288)"]				= { "Island"	, { false, false, 3    , false } },
["Island (289)"]				= { "Island"	, { false, false, false, 4     } },
["Swamp (290)"]					= { "Swamp"		, { 1    , false, false, false } },
["Swamp (291)"]					= { "Swamp"		, { false, 2    , false, false } },
["Swamp (292)"]					= { "Swamp"		, { false, false, 3    , false } },
["Swamp (293)"]					= { "Swamp"		, { false, false, false, 4     } },
["Mountain (294)"]				= { "Mountain"	, { 1    , false, false, false } },
["Mountain (295)"]				= { "Mountain"	, { false, 2    , false, false } },
["Mountain (296)"]				= { "Mountain"	, { false, false, 3    , false } },
["Mountain (297)"]				= { "Mountain"	, { false, false, false, 4     } },
["Forest (298)"]				= { "Forest"	, { 1    , false, false, false } },
["Forest (299)"]				= { "Forest"	, { false, 2    , false, false } },
["Forest (300)"]				= { "Forest"	, { false, false, 3    , false } },
["Forest (301)"]				= { "Forest"	, { false, false, false, 4     } },
	},
},
[670] = { name="Coldsnap",
	tla="CSP",
	cardcount={ reg = 155, tok =  0 },
	variants={}
},
[660] = { name="Dissension",
	tla="DIS",
	cardcount={ reg = 180, tok =  0 },
	variants={}
},
[650] = { name="Guildpact",
	tla="GPT",
	cardcount={ reg = 165, tok =  0 },
	variants={}
},
[640] = { name="Ravnica: City of Guilds",
	tla="RAV",
	cardcount={ reg = 306, tok =  0 },
	variants={
["Plains"] 						= { "Plains"	, { 1    , 2    , 3    , 4     } },
["Island"] 						= { "Island" 	, { 1    , 2    , 3    , 4     } },
["Swamp"] 						= { "Swamp"		, { 1    , 2    , 3    , 4     } },
["Mountain"] 					= { "Mountain"	, { 1    , 2    , 3    , 4     } },
["Forest"] 						= { "Forest" 	, { 1    , 2    , 3    , 4     } },
["Plains (287)"]				= { "Plains"	, { 1    , false ,false, false } }, 
["Plains (288)"]				= { "Plains"	, { false, 2    , false, false } },
["Plains (289)"]				= { "Plains"	, { false, false, 3    , false } },
["Plains (290)"]				= { "Plains"	, { false, false, false, 4     } },
["Island (291)"]				= { "Island"	, { 1    , false, false, false } },
["Island (292)"]				= { "Island"	, { false, 2    , false, false } },
["Island (293)"]				= { "Island"	, { false, false, 3    , false } },
["Island (294)"]				= { "Island"	, { false, false, false, 4     } },
["Swamp (295)"]					= { "Swamp"		, { 1    , false, false, false } },
["Swamp (296)"]					= { "Swamp"		, { false, 2    , false, false } },
["Swamp (297)"]					= { "Swamp"		, { false, false, 3    , false } },
["Swamp (298)"]					= { "Swamp"		, { false, false, false, 4     } },
["Mountain (299)"]				= { "Mountain"	, { 1    , false, false, false } },
["Mountain (300)"]				= { "Mountain"	, { false, 2    , false, false } },
["Mountain (301)"]				= { "Mountain"	, { false, false, 3    , false } },
["Mountain (302)"]				= { "Mountain"	, { false, false, false, 4     } },
["Forest (303)"]				= { "Forest"	, { 1    , false, false, false } },
["Forest (304)"]				= { "Forest"	, { false, 2    , false, false } },
["Forest (305)"]				= { "Forest"	, { false, false, 3    , false } },
["Forest (306)"]				= { "Forest"	, { false, false, false, 4     } }
	},
},
[620] = { name="Saviors of Kamigawa",
	tla="SOK",
	cardcount={ reg = 165, tok =  0 },
	variants={}
},
[610] = { name="Betrayers of Kamigawa",
	tla="BOK",
	cardcount={ reg = 165, tok =  0 },
	variants={}
},
[590] = { name="Champions of Kamigawa",
	tla="CHK",
	cardcount={ reg = 307, tok =  0 },
	variants={
["Plains"] 						= { "Plains"	, { 1    , 2    , 3    , 4     } },
["Island"] 						= { "Island" 	, { 1    , 2    , 3    , 4     } },
["Swamp"] 						= { "Swamp"		, { 1    , 2    , 3    , 4     } },
["Mountain"] 					= { "Mountain"	, { 1    , 2    , 3    , 4     } },
["Forest"] 						= { "Forest" 	, { 1    , 2    , 3    , 4     } },
["Plains (287)"]				= { "Plains"	, { 1    , false ,false, false } }, 
["Plains (288)"]				= { "Plains"	, { false, 2    , false, false } },
["Plains (289)"]				= { "Plains"	, { false, false, 3    , false } },
["Plains (290)"]				= { "Plains"	, { false, false, false, 4     } },
["Island (291)"]				= { "Island"	, { 1    , false, false, false } },
["Island (292)"]				= { "Island"	, { false, 2    , false, false } },
["Island (293)"]				= { "Island"	, { false, false, 3    , false } },
["Island (294)"]				= { "Island"	, { false, false, false, 4     } },
["Swamp (295)"]					= { "Swamp"		, { 1    , false, false, false } },
["Swamp (296)"]					= { "Swamp"		, { false, 2    , false, false } },
["Swamp (297)"]					= { "Swamp"		, { false, false, 3    , false } },
["Swamp (298)"]					= { "Swamp"		, { false, false, false, 4     } },
["Mountain (299)"]				= { "Mountain"	, { 1    , false, false, false } },
["Mountain (300)"]				= { "Mountain"	, { false, 2    , false, false } },
["Mountain (301)"]				= { "Mountain"	, { false, false, 3    , false } },
["Mountain (302)"]				= { "Mountain"	, { false, false, false, 4     } },
["Forest (303)"]				= { "Forest"	, { 1    , false, false, false } },
["Forest (304)"]				= { "Forest"	, { false, 2    , false, false } },
["Forest (305)"]				= { "Forest"	, { false, false, 3    , false } },
["Forest (306)"]				= { "Forest"	, { false, false, false, 4     } },
["Brothers Yamazaki"]			= { "Brothers Yamazaki"	, { "a"  , "b"   } },
["Brothers Yamazaki (160a)"]	= { "Brothers Yamazaki"	, { "a"  , false } },
["Brothers Yamazaki (160b)"]	= { "Brothers Yamazaki"	, { false, "b"   } },
["Yamazaki-Brüder"]				= { "Yamazaki-Brüder"	, { "a"  , "b"   } },
["Yamazaki-Brüder (160a)"]		= { "Yamazaki-Brüder"	, { "a"  , false } },
["Yamazaki-Brüder (160b)"]		= { "Yamazaki-Brüder"	, { false, "b"   } },
	},
},
[580] = { name="Fifth Dawn",
	tla="5DN",
	cardcount={ reg = 165, tok =  0 },
	variants={}
},
[570] = { name="Darksteel",
	tla="DST",
	cardcount={ reg = 165, tok =  0 },
	variants={}
},
[560] = { name="Mirrodin",
	tla="MRD",
	cardcount={ reg = 306, tok =  0 },
	variants={
["Plains"] 						= { "Plains"	, { 1    , 2    , 3    , 4     } },
["Island"] 						= { "Island" 	, { 1    , 2    , 3    , 4     } },
["Swamp"] 						= { "Swamp"		, { 1    , 2    , 3    , 4     } },
["Mountain"] 					= { "Mountain"	, { 1    , 2    , 3    , 4     } },
["Forest"] 						= { "Forest" 	, { 1    , 2    , 3    , 4     } },
["Plains (287)"]				= { "Plains"	, { 1    , false ,false, false } }, 
["Plains (288)"]				= { "Plains"	, { false, 2    , false, false } },
["Plains (289)"]				= { "Plains"	, { false, false, 3    , false } },
["Plains (290)"]				= { "Plains"	, { false, false, false, 4     } },
["Island (291)"]				= { "Island"	, { 1    , false, false, false } },
["Island (292)"]				= { "Island"	, { false, 2    , false, false } },
["Island (293)"]				= { "Island"	, { false, false, 3    , false } },
["Island (294)"]				= { "Island"	, { false, false, false, 4     } },
["Swamp (295)"]					= { "Swamp"		, { 1    , false, false, false } },
["Swamp (296)"]					= { "Swamp"		, { false, 2    , false, false } },
["Swamp (297)"]					= { "Swamp"		, { false, false, 3    , false } },
["Swamp (298)"]					= { "Swamp"		, { false, false, false, 4     } },
["Mountain (299)"]				= { "Mountain"	, { 1    , false, false, false } },
["Mountain (300)"]				= { "Mountain"	, { false, 2    , false, false } },
["Mountain (301)"]				= { "Mountain"	, { false, false, 3    , false } },
["Mountain (302)"]				= { "Mountain"	, { false, false, false, 4     } },
["Forest (303)"]				= { "Forest"	, { 1    , false, false, false } },
["Forest (304)"]				= { "Forest"	, { false, 2    , false, false } },
["Forest (305)"]				= { "Forest"	, { false, false, 3    , false } },
["Forest (306)"]				= { "Forest"	, { false, false, false, 4     } },
	},
},
[540] = { name="Scourge",
	tla="SCG",
	cardcount={ reg = 143, tok =  0 },
	variants={}
},
[530] = { name="Legions",
	tla="LGN",
	cardcount={ reg = 145, tok =  0 },
	variants={}
},
[520] = { name="Onslaught",
	tla="ONS",
	cardcount={ reg = 350, tok =  0 },
	variants={
["Plains"] 						= { "Plains"	, { 1    , 2    , 3    , 4     } },
["Island"] 						= { "Island" 	, { 1    , 2    , 3    , 4     } },
["Swamp"] 						= { "Swamp"		, { 1    , 2    , 3    , 4     } },
["Mountain"] 					= { "Mountain"	, { 1    , 2    , 3    , 4     } },
["Forest"] 						= { "Forest" 	, { 1    , 2    , 3    , 4     } },
["Plains (331)"]				= { "Plains"	, { 1    , false, false, false } }, 
["Plains (332)"]				= { "Plains"	, { false, 2    , false, false } },
["Plains (333)"]				= { "Plains"	, { false, false, 3    , false } },
["Plains (334)"]				= { "Plains"	, { false, false, false, 4     } },
["Island (335)"]				= { "Island"	, { 1    , false, false, false } },
["Island (336)"]				= { "Island"	, { false, 2    , false, false } },
["Island (337)"]				= { "Island"	, { false, false, 3    , false } },
["Island (338)"]				= { "Island"	, { false, false, false, 4     } },
["Swamp (339)"]					= { "Swamp"		, { 1    , false, false, false } },
["Swamp (340)"]					= { "Swamp"		, { false, 2    , false, false } },
["Swamp (341)"]					= { "Swamp"		, { false, false, 3    , false } },
["Swamp (342)"]					= { "Swamp"		, { false, false, false, 4     } },
["Mountain (343)"]				= { "Mountain"	, { 1    , false, false, false } },
["Mountain (344)"]				= { "Mountain"	, { false, 2    , false, false } },
["Mountain (345)"]				= { "Mountain"	, { false, false, 3    , false } },
["Mountain (346)"]				= { "Mountain"	, { false, false, false, 4     } },
["Forest (347)"]				= { "Forest"	, { 1    , false, false, false } },
["Forest (348)"]				= { "Forest"	, { false, 2    , false, false } },
["Forest (349)"]				= { "Forest"	, { false, false, 3    , false } },
["Forest (350)"]				= { "Forest"	, { false, false, false, 4     } },
	},
},
[510] = { name="Judgment",
	tla="JUD",
	cardcount={ reg = 143, tok =  0 },
	variants={}
},
[500] = { name="Torment",
	tla="TOR",
	cardcount={ reg = 143, tok =  0 },
	variants={}
},
[480] = { name="Odyssey",
	tla="ODY",
	cardcount={ reg = 350, tok =  0 },
	variants={
["Plains"] 						= { "Plains"	, { 1    , 2    , 3    , 4     } },
["Island"] 						= { "Island" 	, { 1    , 2    , 3    , 4     } },
["Swamp"] 						= { "Swamp"		, { 1    , 2    , 3    , 4     } },
["Mountain"] 					= { "Mountain"	, { 1    , 2    , 3    , 4     } },
["Forest"] 						= { "Forest" 	, { 1    , 2    , 3    , 4     } },
["Plains (331)"]				= { "Plains"	, { 1    , false, false, false } }, 
["Plains (332)"]				= { "Plains"	, { false, 2    , false, false } },
["Plains (333)"]				= { "Plains"	, { false, false, 3    , false } },
["Plains (334)"]				= { "Plains"	, { false, false, false, 4     } },
["Island (335)"]				= { "Island"	, { 1    , false, false, false } },
["Island (336)"]				= { "Island"	, { false, 2    , false, false } },
["Island (337)"]				= { "Island"	, { false, false, 3    , false } },
["Island (338)"]				= { "Island"	, { false, false, false, 4     } },
["Swamp (339)"]					= { "Swamp"		, { 1    , false, false, false } },
["Swamp (340)"]					= { "Swamp"		, { false, 2    , false, false } },
["Swamp (341)"]					= { "Swamp"		, { false, false, 3    , false } },
["Swamp (342)"]					= { "Swamp"		, { false, false, false, 4     } },
["Mountain (343)"]				= { "Mountain"	, { 1    , false, false, false } },
["Mountain (344)"]				= { "Mountain"	, { false, 2    , false, false } },
["Mountain (345)"]				= { "Mountain"	, { false, false, 3    , false } },
["Mountain (346)"]				= { "Mountain"	, { false, false, false, 4     } },
["Forest (347)"]				= { "Forest"	, { 1    , false, false, false } },
["Forest (348)"]				= { "Forest"	, { false, 2    , false, false } },
["Forest (349)"]				= { "Forest"	, { false, false, 3    , false } },
["Forest (350)"]				= { "Forest"	, { false, false, false, 4     } },
	},
},
[470] = { name="Apocalypse",
	tla="APC",
	cardcount={ reg = 143, tok =  0 },
	variants={}
},
[450] = { name="Planeshift",
	tla="PLS",
	cardcount={ reg = 146, tok =  0 },
	variants={
["Ertai, the Corrupted"] 			= { "Ertai, the Corrupted"		, { ""   , false } },
["Ertai, the Corrupted (Alt)"] 		= { "Ertai, the Corrupted"		, { false, "Alt" } },
["Skyship Weatherlight"] 			= { "Skyship Weatherlight"		, { ""   , false } },
["Skyship Weatherlight (Alt)"] 		= { "Skyship Weatherlight"		, { false, "Alt" } },
["Tahngarth, Talruum Hero"] 		= { "Tahngarth, Talruum Hero"	, { ""   , false } },
["Tahngarth, Talruum Hero (Alt)"]	= { "Tahngarth, Talruum Hero"	, { false, "Alt" } },
	},
	foiltweak={
["Ertai, the Corrupted (Alt)"] 		= { foil = true },
["Skyship Weatherlight (Alt)"] 		= { foil = true },
["Tahngarth, Talruum Hero (Alt)"]	= { foil = true },
	}
},
[430] = { name="Invasion",
	tla="INV",
	cardcount={ reg = 350, tok =  0 },
	variants={
["Plains"] 						= { "Plains"	, { 1    , 2    , 3    , 4     } },
["Island"] 						= { "Island" 	, { 1    , 2    , 3    , 4     } },
["Swamp"] 						= { "Swamp"		, { 1    , 2    , 3    , 4     } },
["Mountain"] 					= { "Mountain"	, { 1    , 2    , 3    , 4     } },
["Forest"] 						= { "Forest" 	, { 1    , 2    , 3    , 4     } },
["Plains (331)"]				= { "Plains"	, { 1    , false, false, false } }, 
["Plains (332)"]				= { "Plains"	, { false, 2    , false, false } },
["Plains (333)"]				= { "Plains"	, { false, false, 3    , false } },
["Plains (334)"]				= { "Plains"	, { false, false, false, 4     } },
["Island (335)"]				= { "Island"	, { 1    , false, false, false } },
["Island (336)"]				= { "Island"	, { false, 2    , false, false } },
["Island (337)"]				= { "Island"	, { false, false, 3    , false } },
["Island (338)"]				= { "Island"	, { false, false, false, 4     } },
["Swamp (339)"]					= { "Swamp"		, { 1    , false, false, false } },
["Swamp (340)"]					= { "Swamp"		, { false, 2    , false, false } },
["Swamp (341)"]					= { "Swamp"		, { false, false, 3    , false } },
["Swamp (342)"]					= { "Swamp"		, { false, false, false, 4     } },
["Mountain (343)"]				= { "Mountain"	, { 1    , false, false, false } },
["Mountain (344)"]				= { "Mountain"	, { false, 2    , false, false } },
["Mountain (345)"]				= { "Mountain"	, { false, false, 3    , false } },
["Mountain (346)"]				= { "Mountain"	, { false, false, false, 4     } },
["Forest (347)"]				= { "Forest"	, { 1    , false, false, false } },
["Forest (348)"]				= { "Forest"	, { false, 2    , false, false } },
["Forest (349)"]				= { "Forest"	, { false, false, 3    , false } },
["Forest (350)"]				= { "Forest"	, { false, false, false, 4     } },
	},
},
[420] = { name="Prophecy",
	tla="PCY",
	cardcount={ reg = 143, tok =  0 },
	variants={}
},
[410] = { name="Nemesis",
	tla="NMS",
	cardcount={ reg = 143, tok =  0 },
	variants={}
},
[400] = { name="Mercadian Masques",
	tla="MMQ",
	cardcount={ reg = 350, tok =  0 },
	variants={
["Plains"] 						= { "Plains"	, { 1    , 2    , 3    , 4     } },
["Island"] 						= { "Island" 	, { 1    , 2    , 3    , 4     } },
["Swamp"] 						= { "Swamp"		, { 1    , 2    , 3    , 4     } },
["Mountain"] 					= { "Mountain"	, { 1    , 2    , 3    , 4     } },
["Forest"] 						= { "Forest" 	, { 1    , 2    , 3    , 4     } },
["Plains (331)"]				= { "Plains"	, { 1    , false, false, false } }, 
["Plains (332)"]				= { "Plains"	, { false, 2    , false, false } },
["Plains (333)"]				= { "Plains"	, { false, false, 3    , false } },
["Plains (334)"]				= { "Plains"	, { false, false, false, 4     } },
["Island (335)"]				= { "Island"	, { 1    , false, false, false } },
["Island (336)"]				= { "Island"	, { false, 2    , false, false } },
["Island (337)"]				= { "Island"	, { false, false, 3    , false } },
["Island (338)"]				= { "Island"	, { false, false, false, 4     } },
["Swamp (339)"]					= { "Swamp"		, { 1    , false, false, false } },
["Swamp (340)"]					= { "Swamp"		, { false, 2    , false, false } },
["Swamp (341)"]					= { "Swamp"		, { false, false, 3    , false } },
["Swamp (342)"]					= { "Swamp"		, { false, false, false, 4     } },
["Mountain (343)"]				= { "Mountain"	, { 1    , false, false, false } },
["Mountain (344)"]				= { "Mountain"	, { false, 2    , false, false } },
["Mountain (345)"]				= { "Mountain"	, { false, false, 3    , false } },
["Mountain (346)"]				= { "Mountain"	, { false, false, false, 4     } },
["Forest (347)"]				= { "Forest"	, { 1    , false, false, false } },
["Forest (348)"]				= { "Forest"	, { false, 2    , false, false } },
["Forest (349)"]				= { "Forest"	, { false, false, 3    , false } },
["Forest (350)"]				= { "Forest"	, { false, false, false, 4     } },
	},
},
[370] = { name="Urza’s Destiny",
	tla="UDS",
	cardcount={ reg = 143, tok =  0 },
	variants={}
},
[350] = { name="Urza’s Legacy",
	tla="ULG",
	cardcount={ reg = 143, tok =  0 },
	variants={}
},
[330] = { name="Urza’s Saga",
	tla="USG",
	cardcount={ reg = 350, tok =  0 },
	variants={
["Plains"] 						= { "Plains"	, { 1    , 2    , 3    , 4     } },
["Island"] 						= { "Island" 	, { 1    , 2    , 3    , 4     } },
["Swamp"] 						= { "Swamp"		, { 1    , 2    , 3    , 4     } },
["Mountain"] 					= { "Mountain"	, { 1    , 2    , 3    , 4     } },
["Forest"] 						= { "Forest" 	, { 1    , 2    , 3    , 4     } },
["Plains (331)"]				= { "Plains"	, { 1    , false, false, false } }, 
["Plains (332)"]				= { "Plains"	, { false, 2    , false, false } },
["Plains (333)"]				= { "Plains"	, { false, false, 3    , false } },
["Plains (334)"]				= { "Plains"	, { false, false, false, 4     } },
["Island (335)"]				= { "Island"	, { 1    , false, false, false } },
["Island (336)"]				= { "Island"	, { false, 2    , false, false } },
["Island (337)"]				= { "Island"	, { false, false, 3    , false } },
["Island (338)"]				= { "Island"	, { false, false, false, 4     } },
["Swamp (339)"]					= { "Swamp"		, { 1    , false, false, false } },
["Swamp (340)"]					= { "Swamp"		, { false, 2    , false, false } },
["Swamp (341)"]					= { "Swamp"		, { false, false, 3    , false } },
["Swamp (342)"]					= { "Swamp"		, { false, false, false, 4     } },
["Mountain (343)"]				= { "Mountain"	, { 1    , false, false, false } },
["Mountain (344)"]				= { "Mountain"	, { false, 2    , false, false } },
["Mountain (345)"]				= { "Mountain"	, { false, false, 3    , false } },
["Mountain (346)"]				= { "Mountain"	, { false, false, false, 4     } },
["Forest (347)"]				= { "Forest"	, { 1    , false, false, false } },
["Forest (348)"]				= { "Forest"	, { false, 2    , false, false } },
["Forest (349)"]				= { "Forest"	, { false, false, 3    , false } },
["Forest (350)"]				= { "Forest"	, { false, false, false, 4     } },
	},
},
[300] = { name="Exodus",
	tla="EXO",
	cardcount={ reg = 143, tok =  0 },
	variants={}
},
[290] = { name="Stronghold",
	tla="STH",
	cardcount={ reg = 143, tok =  0 },
	variants={}
},
[280] = { name="Tempest",
	tla="TMP",
	cardcount={ reg = 350, tok =  0 },
	variants={
["Plains"] 						= { "Plains"	, { 1    , 2    , 3    , 4     } },
["Island"] 						= { "Island" 	, { 1    , 2    , 3    , 4     } },
["Swamp"] 						= { "Swamp"		, { 1    , 2    , 3    , 4     } },
["Mountain"] 					= { "Mountain"	, { 1    , 2    , 3    , 4     } },
["Forest"] 						= { "Forest" 	, { 1    , 2    , 3    , 4     } },
["Plains (1)"]					= { "Plains"	, { 1    , false, false, false } },--Rocks
["Plains (2)"]					= { "Plains"	, { false, 2    , false, false } },--Dead Tree
["Plains (3)"]					= { "Plains"	, { false, false, 3    , false } },--Shrub
["Plains (4)"]					= { "Plains"	, { false, false, false, 4     } },--Ant Hill
["Island (1)"]					= { "Island"	, { 1    , false, false, false } },--Rocky Path
["Island (2)"]					= { "Island"	, { false, 2    , false, false } },--Crashing Waves
["Island (3)"]					= { "Island"	, { false, false, 3    , false } },--Spire
["Island (4)"]					= { "Island"	, { false, false, false, 4     } },--Inlet
["Swamp (1)"]					= { "Swamp"		, { 1    , false, false, false } },--Vertical Log
["Swamp (2)"]					= { "Swamp"		, { false, 2    , false, false } },--Horizontal Log
["Swamp (3)"]					= { "Swamp"		, { false, false, 3    , false } },--Boulder
["Swamp (4)"]					= { "Swamp"		, { false, false, false, 4     } },--River
["Mountain (1)"]				= { "Mountain"	, { 1    , false, false, false } },--Vertical
["Mountain (2)"]				= { "Mountain"	, { false, 2    , false, false } },--Right
["Mountain (3)"]				= { "Mountain"	, { false, false, 3    , false } },--Joined
["Mountain (4)"]				= { "Mountain"	, { false, false, false, 4     } },--Left
["Forest (1)"]					= { "Forest"	, { 1    , false, false, false } },--Skyward
["Forest (2)"]					= { "Forest"	, { false, 2    , false, false } },--Pond
["Forest (3)"]					= { "Forest"	, { false, false, 3    , false } },--Cloudy
["Forest (4)"]					= { "Forest"	, { false, false, false, 4     } },--Ledge
	},
},
[270] = { name="Weatherlight",
	tla="WTH",
	cardcount={ reg = 167, tok =  0 },
	variants={}
},
[240] = { name="Visions",
	tla="VIS",
	cardcount={ reg = 167, tok =  0 },
	variants={}
},
[230] = { name="Mirage",
	tla="MIR",
	cardcount={ reg = 350, tok =  0 },
	variants={
["Plains"] 						= { "Plains"	, { 1    , 2    , 3    , 4     } },
["Island"] 						= { "Island" 	, { 1    , 2    , 3    , 4     } },
["Swamp"] 						= { "Swamp"		, { 1    , 2    , 3    , 4     } },
["Mountain"] 					= { "Mountain"	, { 1    , 2    , 3    , 4     } },
["Forest"] 						= { "Forest" 	, { 1    , 2    , 3    , 4     } },
["Plains (1)"]					= { "Plains"	, { 1    , false, false, false } },--Watering Hole
["Plains (2)"]					= { "Plains"	, { false, 2    , false, false } },--Buffalo
["Plains (3)"]					= { "Plains"	, { false, false, 3    , false } },--Zebra
["Plains (4)"]					= { "Plains"	, { false, false, false, 4     } },--Bird
["Island (1)"]					= { "Island"	, { 1    , false, false, false } },--Palm Tree
["Island (2)"]					= { "Island"	, { false, 2    , false, false } },--Off-Center Spire
["Island (3)"]					= { "Island"	, { false, false, 3    , false } },--Rocky Water
["Island (4)"]					= { "Island"	, { false, false, false, 4     } },--Sunset
["Swamp (1)"]					= { "Swamp"		, { 1    , false, false, false } },--Mossy Roots
["Swamp (2)"]					= { "Swamp"		, { false, 2    , false, false } },--Foggy Night
["Swamp (3)"]					= { "Swamp"		, { false, false, 3    , false } },--Eyes in Log
["Swamp (4)"]					= { "Swamp"		, { false, false, false, 4     } },--Tall Grass
["Mountain (1)"]				= { "Mountain"	, { 1    , false, false, false } },--Green
["Mountain (2)"]				= { "Mountain"	, { false, 2    , false, false } },--Orange
["Mountain (3)"]				= { "Mountain"	, { false, false, 3    , false } },--Purple
["Mountain (4)"]				= { "Mountain"	, { false, false, false, 4     } },--Red
["Forest (1)"]					= { "Forest"	, { 1    , false, false, false } },--Pink Flowers Right
["Forest (2)"]					= { "Forest"	, { false, 2    , false, false } },--Waterfall
["Forest (3)"]					= { "Forest"	, { false, false, 3    , false } },--White Flowers Right
["Forest (4)"]					= { "Forest"	, { false, false, false, 4     } },--Red Tree Leaves
	},
},
[220] = { name="Alliances",
	tla="ALL",
	cardcount={ reg = 199, tok =  0 },
	variants={
["Aesthir Glider"] 						= { "Aesthir Glider"				, { 1    , 2     } },
["Aesthir Glider (1)"] 					= { "Aesthir Glider"				, { 1    , false } },--
["Aesthir Glider (2)"] 					= { "Aesthir Glider"				, { false, 2     } },--Moon
	["Aesthirgleiter"] 					= { "Aesthirgleiter"				, { 1    , 2     } },
	["Aesthirgleiter (1)"] 				= { "Aesthirgleiter"				, { 1    , false } },
	["Aesthirgleiter (2)"] 				= { "Aesthirgleiter"				, { false, 2     } },
["Agent of Stromgald"] 					= { "Agent of Stromgald"			, { 1    , 2     } },
["Agent of Stromgald (1)"] 				= { "Agent of Stromgald"			, { 1    , false } },--Woman Holding Staff
["Agent of Stromgald (2)"] 				= { "Agent of Stromgald"			, { false, 2     } },--
	["Agent der Stromgalder"] 			= { "Agent der Stromgalder"			, { 1    , 2     } },
	["Agent der Stromgalder (1)"] 		= { "Agent der Stromgalder"			, { 1    , false } },
	["Agent der Stromgalder (2)"] 		= { "Agent der Stromgalder"			, { false, 2     } },
["Arcane Denial"] 						= { "Arcane Denial"					, { 1    , 2     } },
["Arcane Denial (1)"] 					= { "Arcane Denial"					, { 1    , false } },--Axe
["Arcane Denial (2)"] 					= { "Arcane Denial"					, { false, 2     } },--Sword
	["Mysteriöse Ablehnung"]		 	= { "Mysteriöse Ablehnung"			, { 1    , 2     } },
	["Mysteriöse Ablehnung (1)"] 		= { "Mysteriöse Ablehnung"			, { 1    , false } },
	["Mysteriöse Ablehnung (2)"] 		= { "Mysteriöse Ablehnung"			, { false, 2     } },
["Astrolabe"] 							= { "Astrolabe"						, { 1    , 2     } },
["Astrolabe (1)"] 						= { "Astrolabe"						, { 1    , false } },--Globe
["Astrolabe (2)"] 						= { "Astrolabe"						, { false, 2     } },--
	["Astrolabium"] 					= { "Astrolabium"					, { 1    , 2     } },
	["Astrolabium (1)"] 				= { "Astrolabium"					, { 1    , false } },
	["Astrolabium (2)"] 				= { "Astrolabium"					, { false, 2     } },
["Awesome Presence"] 					= { "Awesome Presence"				, { 1    , 2     } },
["Awesome Presence (1)"] 				= { "Awesome Presence"				, { 1    , false } },--Man Being Chased
["Awesome Presence (2)"] 				= { "Awesome Presence"				, { false, 2     } },--
	["Furchterregende Aura"]		 	= { "Furchterregende Aura"			, { 1    , 2     } },
	["Furchterregende Aura (1)"] 		= { "Furchterregende Aura"			, { 1    , false } },
	["Furchterregende Aura (2)"] 		= { "Furchterregende Aura"			, { false, 2     } },
["Balduvian War-Makers"] 				= { "Balduvian War-Makers"			, { 1    , 2     } },
["Balduvian War-Makers (1)"] 			= { "Balduvian War-Makers"			, { 1    , false } },--Gen. Varchild Flavor
["Balduvian War-Makers (2)"] 			= { "Balduvian War-Makers"			, { false, 2     } },--
	["Balduvianische Kämpfer"] 			= { "Balduvianische Kämpfer"		, { 1    , 2     } },
	["Balduvianische Kämpfer (1)"] 		= { "Balduvianische Kämpfer"		, { 1    , false } },
	["Balduvianische Kämpfer (2)"] 		= { "Balduvianische Kämpfer"		, { false, 2     } },
["Benthic Explorers"] 					= { "Benthic Explorers"				, { 1    , 2     } },
["Benthic Explorers (1)"] 				= { "Benthic Explorers"				, { 1    , false } },--
["Benthic Explorers (2)"] 				= { "Benthic Explorers"				, { false, 2     } },--On the Rocks
	["Meeresforscher"] 					= { "Meeresforscher"				, { 1    , 2     } },
	["Meeresforscher (1)"] 				= { "Meeresforscher"				, { 1    , false } },
	["Meeresforscher (2)"] 				= { "Meeresforscher"				, { false, 2     } },
["Bestial Fury"] 						= { "Bestial Fury"					, { 1    , 2     } },
["Bestial Fury (1)"] 					= { "Bestial Fury"					, { 1    , false } },--Facing Left
["Bestial Fury (2)"] 					= { "Bestial Fury"					, { false, 2     } },--
	["Kampfinstinkt"] 					= { "Kampfinstinkt"					, { 1    , 2     } },
	["Kampfinstinkt (1)"] 				= { "Kampfinstinkt"					, { 1    , false } },
	["Kampfinstinkt (2)"] 				= { "Kampfinstinkt"					, { false, 2     } },
["Carrier Pigeons"] 					= { "Carrier Pigeons"				, { 1    , 2     } },
["Carrier Pigeons (1)"] 				= { "Carrier Pigeons"				, { 1    , false } },--
["Carrier Pigeons (2)"] 				= { "Carrier Pigeons"				, { false, 2     } },--Hand
	["Brieftauben"] 					= { "Brieftauben"					, { 1    , 2     } },
	["Brieftauben (1)"] 				= { "Brieftauben"					, { 1    , false } },
	["Brieftauben (2)"] 				= { "Brieftauben"					, { false, 2     } },
["Casting of Bones"] 					= { "Casting of Bones"				, { 1    , 2     } },
["Casting of Bones (1)"] 				= { "Casting of Bones"				, { 1    , false } },--Hooded Figure
["Casting of Bones (2)"] 				= { "Casting of Bones"				, { false, 2     } },--Close-up
	["Knochenorakel"] 					= { "Knochenorakel"					, { 1    , 2     } },
	["Knochenorakel (1)"] 				= { "Knochenorakel"					, { 1    , false } },
	["Knochenorakel (2)"] 				= { "Knochenorakel"					, { false, 2     } },
["Deadly Insect"] 						= { "Deadly Insect"					, { 1    , 2     } },
["Deadly Insect (1)"] 					= { "Deadly Insect"					, { 1    , false } },--
["Deadly Insect (2)"] 					= { "Deadly Insect"					, { false, 2     } },--Red Robe
	["Killerinsekten"] 					= { "Killerinsekten"				, { 1    , 2     } },
	["Killerinsekten (1)"] 				= { "Killerinsekten"				, { 1    , false } },
	["Killerinsekten (2)"] 				= { "Killerinsekten"				, { false, 2     } },
["Elvish Ranger"] 						= { "Elvish Ranger"					, { 1    , 2     } },
["Elvish Ranger (1)"] 					= { "Elvish Ranger"					, { 1    , false } },--
["Elvish Ranger (2)"] 					= { "Elvish Ranger"					, { false, 2     } },--Woman
	["Elfenwaldläufer"] 				= { "Elfenwaldläufer"				, { 1    , 2     } },
	["Elfenwaldläufer (1)"] 			= { "Elfenwaldläufer"				, { 1    , false } },
	["Elfenwaldläufer (2)"] 			= { "Elfenwaldläufer"				, { false, 2     } },
["Enslaved Scout"] 						= { "Enslaved Scout"				, { 1    , 2     } },
["Enslaved Scout (1)"] 					= { "Enslaved Scout"				, { 1    , false } },--
["Enslaved Scout (2)"] 					= { "Enslaved Scout"				, { false, 2     } },--Solitary Goblin
	["Unterworfener Späher"] 			= { "Unterworfener Späher"			, { 1    , 2     } },
	["Unterworfener Späher (1)"] 		= { "Unterworfener Späher"			, { 1    , false } },
	["Unterworfener Späher (2)"] 		= { "Unterworfener Späher"			, { false, 2     } },
["Errand of Duty"] 						= { "Errand of Duty"				, { 1    , 2     } },
["Errand of Duty (1)"] 					= { "Errand of Duty"				, { 1    , false } },--
["Errand of Duty (2)"] 					= { "Errand of Duty"				, { false, 2     } },--Page Holding Sword
	["Ruf der Pflicht"] 				= { "Ruf der Pflicht"				, { 1    , 2     } },
	["Ruf der Pflicht (1)"] 			= { "Ruf der Pflicht"				, { 1    , false } },
	["Ruf der Pflicht (2)"] 			= { "Ruf der Pflicht"				, { false, 2     } },
["False Demise"] 						= { "False Demise"					, { 1    , 2     } },
["False Demise (1)"] 					= { "False Demise"					, { 1    , false } },--
["False Demise (2)"] 					= { "False Demise"					, { false, 2     } },--Cave-in
	["Vorgetäuschter Tod"] 				= { "Vorgetäuschter Tod"			, { 1    , 2     } },
	["Vorgetäuschter Tod (1)"] 			= { "Vorgetäuschter Tod"			, { 1    , false } },
	["Vorgetäuschter Tod (2)"] 			= { "Vorgetäuschter Tod"			, { false, 2     } },
["Feast or Famine"] 					= { "Feast or Famine"				, { 1    , 2     } },
["Feast or Famine (1)"] 				= { "Feast or Famine"				, { 1    , false } },--Knife
["Feast or Famine (2)"] 				= { "Feast or Famine"				, { false, 2     } },--Falling into Pit
	["Um Leben und Tod"] 				= { "Um Leben und Tod"				, { 1    , 2     } },
	["Um Leben und Tod (1)"] 			= { "Um Leben und Tod"				, { 1    , false } },
	["Um Leben und Tod (2)"] 			= { "Um Leben und Tod"				, { false, 2     } },
["Foresight"] 							= { "Foresight"						, { 1    , 2     } },
["Foresight (1)"] 						= { "Foresight"						, { 1    , false } },--White Dress
["Foresight (2)"] 						= { "Foresight"						, { false, 2     } },--
	["Vorsehung"] 						= { "Vorsehung"						, { 1    , 2     } },
	["Vorsehung (1)"] 					= { "Vorsehung"						, { 1    , false } },
	["Vorsehung (2)"] 					= { "Vorsehung"						, { false, 2     } },
["Fevered Strength"] 					= { "Fevered Strength"				, { 1    , 2     } },
["Fevered Strength (1)"] 				= { "Fevered Strength"				, { 1    , false } },--Foaming at Mouth
["Fevered Strength (2)"] 				= { "Fevered Strength"				, { false, 2     } },--
	["Fieberstärke"] 					= { "Fieberstärke"					, { 1    , 2     } },
	["Fieberstärke (1)"] 				= { "Fieberstärke"					, { 1    , false } },
	["Fieberstärke (2)"] 				= { "Fieberstärke"					, { false, 2     } },
["Fyndhorn Druid"] 						= { "Fyndhorn Druid"				, { 1    , 2     } },
["Fyndhorn Druid (1)"] 					= { "Fyndhorn Druid"				, { 1    , false } },--Facing Right
["Fyndhorn Druid (2)"] 					= { "Fyndhorn Druid"				, { false, 2     } },--
	["Fyndhorndruide"] 					= { "Fyndhorndruide"				, { 1    , 2     } },
	["Fyndhorndruide (1)"] 				= { "Fyndhorndruide"				, { 1    , false } },
	["Fyndhorndruide (2)"] 				= { "Fyndhorndruide"				, { false, 2     } },
["Gift of the Woods"] 					= { "Gift of the Woods"				, { 1    , 2     } },
["Gift of the Woods (1)"] 				= { "Gift of the Woods"				, { 1    , false } },--Girl/ Lynx
["Gift of the Woods (2)"] 				= { "Gift of the Woods"				, { false, 2     } },--
	["Geschenk des Waldes"] 			= { "Geschenk des Waldes"			, { 1    , 2     } },
	["Geschenk des Waldes (1)"] 		= { "Geschenk des Waldes"			, { 1    , false } },
	["Geschenk des Waldes (2)"] 		= { "Geschenk des Waldes"			, { false, 2     } },
["Gorilla Berserkers"] 					= { "Gorilla Berserkers"			, { 1    , 2     } },
["Gorilla Berserkers (1)"] 				= { "Gorilla Berserkers"			, { 1    , false } },--
["Gorilla Berserkers (2)"] 				= { "Gorilla Berserkers"			, { false, 2     } },--Closed-Mouth
	["Rasende Gorillas"] 				= { "Rasende Gorillas"				, { 1    , 2     } },
	["Rasende Gorillas (1)"] 			= { "Rasende Gorillas"				, { 1    , false } },
	["Rasende Gorillas (2)"] 			= { "Rasende Gorillas"				, { false, 2     } },
["Gorilla Chieftain"] 					= { "Gorilla Chieftain"				, { 1    , 2     } },
["Gorilla Chieftain (1)"] 				= { "Gorilla Chieftain"				, { 1    , false } },--2 Gorillas
["Gorilla Chieftain (2)"] 				= { "Gorilla Chieftain"				, { false, 2     } },--
	["Gorillahäuptling"] 				= { "Gorillahäuptling"				, { 1    , 2     } },
	["Gorillahäuptling (1)"] 			= { "Gorillahäuptling"				, { 1    , false } },
	["Gorillahäuptling (2)"]	 		= { "Gorillahäuptling"				, { false, 2     } },
["Gorilla Shaman"] 						= { "Gorilla Shaman"				, { 1    , 2     } },
["Gorilla Shaman (1)"] 					= { "Gorilla Shaman"				, { 1    , false } },--
["Gorilla Shaman (2)"] 					= { "Gorilla Shaman"				, { false, 2     } },--Holding Baby
	["Gorillaschamane"] 				= { "Gorillaschamane"				, { 1    , 2     } },
	["Gorillaschamane (1)"] 			= { "Gorillaschamane"				, { 1    , false } },
	["Gorillaschamane (2)"] 			= { "Gorillaschamane"				, { false, 2     } },
["Gorilla War Cry"] 					= { "Gorilla War Cry"				, { 1    , 2     } },
["Gorilla War Cry (1)"] 				= { "Gorilla War Cry"				, { 1    , false } },--Red Club
["Gorilla War Cry (2)"] 				= { "Gorilla War Cry"				, { false, 2     } },--
	["Schlachtruf der Gorillas"]		= { "Schlachtruf der Gorillas"		, { 1    , 2     } },
	["Schlachtruf der Gorillas (1)"] 	= { "Schlachtruf der Gorillas"		, { 1    , false } },
	["Schlachtruf der Gorillas (2)"] 	= { "Schlachtruf der Gorillas"		, { false, 2     } },
["Guerrilla Tactics"] 					= { "Guerrilla Tactics"				, { 1    , 2     } },
["Guerrilla Tactics (1)"] 				= { "Guerrilla Tactics"				, { 1    , false } },--Kneeling Knight
["Guerrilla Tactics (2)"]	 			= { "Guerrilla Tactics"				, { false, 2     } },--Cliff
	["Guerillataktik"] 					= { "Guerillataktik"				, { 1    , 2     } },
	["Guerillataktik (1)"] 				= { "Guerillataktik"				, { 1    , false } },
	["Guerillataktik (2)"] 				= { "Guerillataktik"				, { false, 2     } },
["Insidious Bookworms"] 				= { "Insidious Bookworms"			, { 1    , 2     } },
["Insidious Bookworms (1)"] 			= { "Insidious Bookworms"			, { 1    , false } },--Horde of Worms
["Insidious Bookworms (2)"] 			= { "Insidious Bookworms"			, { false, 2     } },--Single
	["Heimtückische Bücherwürmer"]		= { "Heimtückische Bücherwürmer"	, { 1    , 2     } },
	["Heimtückische Bücherwürmer (1)"]	= { "Heimtückische Bücherwürmer"	, { 1    , false } },
	["Heimtückische Bücherwürmer (2)"] 	= { "Heimtückische Bücherwürmer"	, { false, 2     } },
["Kjeldoran Escort"] 					= { "Kjeldoran Escort"				, { 1    , 2     } },
["Kjeldoran Escort (1)"] 				= { "Kjeldoran Escort"				, { 1    , false } },--Green Dog
["Kjeldoran Escort (2)"] 				= { "Kjeldoran Escort"				, { false, 2     } },--
	["Kjeldoranische Eskorte"]		 	= { "Kjeldoranische Eskorte"		, { 1    , 2     } },
	["Kjeldoranische Eskorte (1)"] 		= { "Kjeldoranische Eskorte"		, { 1    , false } },
	["Kjeldoranische Eskorte (2)"] 		= { "Kjeldoranische Eskorte"		, { false, 2     } },
["Kjeldoran Pride"] 					= { "Kjeldoran Pride"				, { 1    , 2     } },
["Kjeldoran Pride (1)"] 				= { "Kjeldoran Pride"				, { 1    , false } },--Boy|Hawk
["Kjeldoran Pride (2)"] 				= { "Kjeldoran Pride"				, { false, 2     } },--
	["Kjeldors Stolz"] 					= { "Kjeldors Stolz"				, { 1    , 2     } },
	["Kjeldors Stolz (1)"] 				= { "Kjeldors Stolz"				, { 1    , false } },
	["Kjeldors Stolz (2)"] 				= { "Kjeldors Stolz"				, { false, 2     } },
["Lat-Nam's Legacy"] 					= { "Lat-Nam's Legacy"				, { 1    , 2     } },
["Lat-Nam's Legacy (1)"] 				= { "Lat-Nam's Legacy"				, { 1    , false } },--
["Lat-Nam's Legacy (2)"] 				= { "Lat-Nam's Legacy"				, { false, 2     } },--2 Blue Men
	["Lat-Nams Erbe"] 					= { "Lat-Nams Erbe"					, { 1    , 2     } },
	["Lat-Nams Erbe (1)"] 				= { "Lat-Nams Erbe"					, { 1    , false } },
	["Lat-Nams Erbe (2)"] 				= { "Lat-Nams Erbe"					, { false, 2     } },
["Lim-Dûl's High Guard"]	 			= { "Lim-Dûl's High Guard"			, { 1    , 2     } },
["Lim-Dûl's High Guard (1)"] 			= { "Lim-Dûl's High Guard"			, { 1    , false } },--
["Lim-Dûl's High Guard (2)"] 			= { "Lim-Dûl's High Guard"			, { false, 2     } },--Red Armor
	["Lim-Dûls Ehrengarde"]	 			= { "Lim-Dûls Ehrengarde"			, { 1    , 2     } },
	["Lim-Dûls Ehrengarde (1)"] 		= { "Lim-Dûls Ehrengarde"			, { 1    , false } },
	["Lim-Dûls Ehrengarde (2)"] 		= { "Lim-Dûls Ehrengarde"			, { false, 2     } },
["Martyrdom"] 							= { "Martyrdom"						, { 1    , 2     } },
["Martyrdom (1)"] 						= { "Martyrdom"						, { 1    , false } },--Wounded on Ground
["Martyrdom (2)"] 						= { "Martyrdom"						, { false, 2     } },--
	["Martyrium"] 						= { "Martyrium"						, { 1    , 2     } },
	["Martyrium (1)"] 					= { "Martyrium"						, { 1    , false } },
	["Martyrium (2)"] 					= { "Martyrium"						, { false, 2     } },
["Noble Steeds"] 						= { "Noble Steeds"					, { 1    , 2     } },
["Noble Steeds (1)"] 					= { "Noble Steeds"					, { 1    , false } },--Trees in Forefront
["Noble Steeds (2)"] 					= { "Noble Steeds"					, { false, 2     } },--
	["Edle Rösser"] 					= { "Edle Rösser"					, { 1    , 2     } },
	["Edle Rösser (1)"] 				= { "Edle Rösser"					, { 1    , false } },
	["Edle Rösser (2)"] 				= { "Edle Rösser"					, { false, 2     } },
["Phantasmal Fiend"] 					= { "Phantasmal Fiend"				, { 1    , 2     } },
["Phantasmal Fiend (1)"] 				= { "Phantasmal Fiend"				, { 1    , false } },--Close-up
["Phantasmal Fiend (2)"] 				= { "Phantasmal Fiend"				, { false, 2     } },--
	["Traumunhold"] 					= { "Traumunhold"					, { 1    , 2     } },
	["Traumunhold (1)"] 				= { "Traumunhold"					, { 1    , false } },
	["Traumunhold (2)"] 				= { "Traumunhold"					, { false, 2     } },
["Phyrexian Boon"] 						= { "Phyrexian Boon"				, { 1    , 2     } },
["Phyrexian Boon (1)"] 					= { "Phyrexian Boon"				, { 1    , false } },--
["Phyrexian Boon (2)"] 					= { "Phyrexian Boon"				, { false, 2     } },--Man Held Aloft
	["Phyrexianischer Segen"]		 	= { "Phyrexianischer Segen"			, { 1    , 2     } },
	["Phyrexianischer Segen (1)"] 		= { "Phyrexianischer Segen"			, { 1    , false } },
	["Phyrexianischer Segen (2)"] 		= { "Phyrexianischer Segen"			, { false, 2     } },
["Phyrexian War Beast"] 				= { "Phyrexian War Beast"			, { 1    , 2     } },
["Phyrexian War Beast (1)"] 			= { "Phyrexian War Beast"			, { 1    , false } },--Facing Right
["Phyrexian War Beast (2)"] 			= { "Phyrexian War Beast"			, { false, 2     } },--
	["Phyrexianische Kriegsbestie"]		= { "Phyrexianische Kriegsbestie"	, { 1    , 2     } },
	["Phyrexianische Kriegsbestie (1)"] = { "Phyrexianische Kriegsbestie"	, { 1    , false } },
	["Phyrexianische Kriegsbestie (2)"] = { "Phyrexianische Kriegsbestie"	, { false, 2     } },
["Reprisal"] 							= { "Reprisal"						, { 1    , 2     } },
["Reprisal (1)"] 						= { "Reprisal"						, { 1    , false } },--
["Reprisal (2)"] 						= { "Reprisal"						, { false, 2     } },--Green Monster
	["Revolte"] 						= { "Revolte"						, { 1    , 2     } },
	["Revolte (1)"] 					= { "Revolte"						, { 1    , false } },
	["Revolte (2)"] 					= { "Revolte"						, { false, 2     } },
["Royal Herbalist"] 					= { "Royal Herbalist"				, { 1    , 2     } },
["Royal Herbalist (1)"] 				= { "Royal Herbalist"				, { 1    , false } },--
["Royal Herbalist (2)"] 				= { "Royal Herbalist"				, { false, 2     } },--Man
	["Königlicher Kräuterkundler"]		= { "Königlicher Kräuterkundler"	, { 1    , 2     } },
	["Königlicher Kräuterkundler (1)"] 	= { "Königlicher Kräuterkundler"	, { 1    , false } },
	["Königlicher Kräuterkundler (2)"] 	= { "Königlicher Kräuterkundler"	, { false, 2     } },
["Reinforcements"] 						= { "Reinforcements"				, { 1    , 2     } },
["Reinforcements (1)"] 					= { "Reinforcements"				, { 1    , false } },--
["Reinforcements (2)"] 					= { "Reinforcements"				, { false, 2     } },--Line-up
	["Verstärkungen"] 					= { "Verstärkungen"					, { 1    , 2     } },
	["Verstärkungen (1)"] 				= { "Verstärkungen"					, { 1    , false } },
	["Verstärkungen (2)"] 				= { "Verstärkungen"					, { false, 2     } },
["Stench of Decay"] 					= { "Stench of Decay"				, { 1    , 2     } },
["Stench of Decay (1)"] 				= { "Stench of Decay"				, { 1    , false } },--Red Flower
["Stench of Decay (2)"] 				= { "Stench of Decay"				, { false, 2     } },--
	["Verwesungsgestank"] 				= { "Verwesungsgestank"				, { 1    , 2     } },
	["Verwesungsgestank (1)"] 			= { "Verwesungsgestank"				, { 1    , false } },
	["Verwesungsgestank (2)"] 			= { "Verwesungsgestank"				, { false, 2     } },
["Storm Shaman"]	 					= { "Storm Shaman"					, { 1    , 2     } },
["Storm Shaman (1)"] 					= { "Storm Shaman"					, { 1    , false } },--Male
["Storm Shaman (2)"] 					= { "Storm Shaman"					, { false, 2     } },--Female
	["Sturmschamane"]	 				= { "Sturmschamane"					, { 1    , 2     } },
	["Sturmschamane (1)"] 				= { "Sturmschamane"					, { 1    , false } },
	["Sturmschamane (2)"] 				= { "Sturmschamane"					, { false, 2     } },
["Storm Crow"] 							= { "Storm Crow"					, { 1    , 2     } },
["Storm Crow (1)"] 						= { "Storm Crow"					, { 1    , false } },--Flying Right
["Storm Crow (2)"] 						= { "Storm Crow"					, { false, 2     } },--
	["Sturmkrähe"] 						= { "Sturmkrähe"					, { 1    , 2     } },
	["Sturmkrähe (1)"] 					= { "Sturmkrähe"					, { 1    , false } },
	["Sturmkrähe (2)"] 					= { "Sturmkrähe"					, { false, 2     } },
["Soldevi Adnate"]	 					= { "Soldevi Adnate"				, { 1    , 2     } },
["Soldevi Adnate (1)"] 					= { "Soldevi Adnate"				, { 1    , false } },--
["Soldevi Adnate (2)"] 					= { "Soldevi Adnate"				, { false, 2     } },--Woman
	["Soldevischer Sektierer"]			= { "Soldevischer Sektierer"		, { 1    , 2     } },
	["Soldevischer Sektierer (1)"] 		= { "Soldevischer Sektierer"		, { 1    , false } },
	["Soldevischer Sektierer (2)"] 		= { "Soldevischer Sektierer"		, { false, 2     } },
["Soldevi Heretic"] 					= { "Soldevi Heretic"				, { 1    , 2     } },
["Soldevi Heretic (1)"] 				= { "Soldevi Heretic"				, { 1    , false } },--
["Soldevi Heretic (2)"] 				= { "Soldevi Heretic"				, { false, 2     } },--Scolding Old Men
	["Soldevischer Ketzer"] 			= { "Soldevischer Ketzer"			, { 1    , 2     } },
	["Soldevischer Ketzer (1)"] 		= { "Soldevischer Ketzer"			, { 1    , false } },
	["Soldevischer Ketzer (2)"] 		= { "Soldevischer Ketzer"			, { false, 2     } },
["Soldevi Sage"] 						= { "Soldevi Sage"					, { 1    , 2     } },
["Soldevi Sage (1)"] 					= { "Soldevi Sage"					, { 1    , false } },--
["Soldevi Sage (2)"] 					= { "Soldevi Sage"					, { false, 2     } },--2 Candles
	["Soldevischer Weiser"] 			= { "Soldevischer Weiser"			, { 1    , 2     } },
	["Soldevischer Weiser (1)"] 		= { "Soldevischer Weiser"			, { 1    , false } },
	["Soldevischer Weiser (2)"] 		= { "Soldevischer Weiser"			, { false, 2     } },
["Soldevi Sentry"] 						= { "Soldevi Sentry"				, { 1    , 2     } },
["Soldevi Sentry (1)"] 					= { "Soldevi Sentry"				, { 1    , false } },--Close-Up
["Soldevi Sentry (2)"] 					= { "Soldevi Sentry"				, { false, 2     } },--
	["Soldevischer Wachposten"] 		= { "Soldevischer Wachposten"		, { 1    , 2     } },
	["Soldevischer Wachposten (1)"] 	= { "Soldevischer Wachposten"		, { 1    , false } },
	["Soldevischer Wachposten (2)"] 	= { "Soldevischer Wachposten"		, { false, 2     } },
["Soldevi Steam Beast"] 				= { "Soldevi Steam Beast"			, { 1    , 2     } },
["Soldevi Steam Beast (1)"] 			= { "Soldevi Steam Beast"			, { 1    , false } },--
["Soldevi Steam Beast (2)"] 			= { "Soldevi Steam Beast"			, { false, 2     } },--Purple Sun
	["Soldevische Dampfmaschine"]		= { "Soldevische Dampfmaschine"		, { 1    , 2     } },
	["Soldevische Dampfmaschine (1)"] 	= { "Soldevische Dampfmaschine"		, { 1    , false } },
	["Soldevische Dampfmaschine (2)"] 	= { "Soldevische Dampfmaschine"		, { false, 2     } },
["Swamp Mosquito"] 						= { "Swamp Mosquito"				, { 1    , 2     } },
["Swamp Mosquito (1)"] 					= { "Swamp Mosquito"				, { 1    , false } },--Fallen Tree
["Swamp Mosquito (2)"] 					= { "Swamp Mosquito"				, { false, 2     } },--
	["Sumpfmoskito"] 					= { "Sumpfmoskito"					, { 1    , 2     } },
	["Sumpfmoskito (1)"] 				= { "Sumpfmoskito"					, { 1    , false } },
	["Sumpfmoskito (2)"] 				= { "Sumpfmoskito"					, { false, 2     } },
["Taste of Paradise"] 					= { "Taste of Paradise"				, { 1    , 2     } },
["Taste of Paradise (1)"] 				= { "Taste of Paradise"				, { 1    , false } },--Holding Fruit
["Taste of Paradise (2)"] 				= { "Taste of Paradise"				, { false, 2     } },--
	["Vorgeschmack des Paradieses"]		= { "Vorgeschmack des Paradieses"	, { 1    , 2     } },
	["Vorgeschmack des Paradieses (1)"] = { "Vorgeschmack des Paradieses"	, { 1    , false } },
	["Vorgeschmack des Paradieses (2)"] = { "Vorgeschmack des Paradieses"	, { false, 2     } },
["Undergrowth"] 						= { "Undergrowth"					, { 1    , 2     } },
["Undergrowth (1)"] 					= { "Undergrowth"					, { 1    , false } },--
["Undergrowth (2)"] 					= { "Undergrowth"					, { false, 2     } },--Holding Ax
	["Unterholz"] 						= { "Unterholz"						, { 1    , 2     } },
	["Unterholz (1)"] 					= { "Unterholz"						, { 1    , false } },
	["Unterholz (2)"] 					= { "Unterholz"						, { false, 2     } },
["Varchild's Crusader"] 				= { "Varchild's Crusader"			, { 1    , 2     } },
["Varchild's Crusader (1)"] 			= { "Varchild's Crusader"			, { 1    , false } },--Castle
["Varchild's Crusader (2)"] 			= { "Varchild's Crusader"			, { false, 2     } },--
	["Varchilds Kreuzritter"]		 	= { "Varchilds Kreuzritter"			, { 1    , 2     } },
	["Varchilds Kreuzritter (1)"] 		= { "Varchilds Kreuzritter"			, { 1    , false } },
	["Varchilds Kreuzritter (2)"] 		= { "Varchilds Kreuzritter"			, { false, 2     } },
["Veteran's Voice"] 					= { "Veteran's Voice"				, { 1    , 2     } },
["Veteran's Voice (1)"] 				= { "Veteran's Voice"				, { 1    , false } },--
["Veteran's Voice (2)"] 				= { "Veteran's Voice"				, { false, 2     } },--Side-by-side
	["Stimme des Veteranen"] 			= { "Stimme des Veteranen"			, { 1    , 2     } },
	["Stimme des Veteranen (1)"] 		= { "Stimme des Veteranen"			, { 1    , false } },
	["Stimme des Veteranen (2)"] 		= { "Stimme des Veteranen"			, { false, 2     } },
["Viscerid Armor"] 						= { "Viscerid Armor"				, { 1    , 2     } },
["Viscerid Armor (1)"] 					= { "Viscerid Armor"				, { 1    , false } },--Crashing Wave
["Viscerid Armor (2)"] 					= { "Viscerid Armor"				, { false, 2     } },--
	["Visceridenpanzer"] 				= { "Visceridenpanzer"				, { 1    , 2     } },
	["Visceridenpanzer (1)"] 			= { "Visceridenpanzer"				, { 1    , false } },
	["Visceridenpanzer (2)"] 			= { "Visceridenpanzer"				, { false, 2     } },
["Whip Vine"] 							= { "Whip Vine"						, { 1    , 2     } },
["Whip Vine (1)"] 						= { "Whip Vine"						, { 1    , false } },--Only Plants
["Whip Vine (2)"] 						= { "Whip Vine"						, { false, 2     } },--
	["Kletterranken"] 					= { "Kletterranken"					, { 1    , 2     } },
	["Kletterranken (1)"] 				= { "Kletterranken"					, { 1    , false } },
	["Kletterranken (2)"] 				= { "Kletterranken"					, { false, 2     } },
["Wild Aesthir"] 						= { "Wild Aesthir"					, { 1    , 2     } },
["Wild Aesthir (1)"] 					= { "Wild Aesthir"					, { 1    , false } },--
["Wild Aesthir (2)"] 					= { "Wild Aesthir"					, { false, 2     } },--Lightning Strike
	["Wilder Aesthir"] 					= { "Wilder Aesthir"				, { 1    , 2     } },
	["Wilder Aesthir (1)"] 				= { "Wilder Aesthir"				, { 1    , false } },
	["Wilder Aesthir (2)"] 				= { "Wilder Aesthir"				, { false, 2     } },
["Yavimaya Ancients"] 					= { "Yavimaya Ancients"				, { 1    , 2     } },
["Yavimaya Ancients (1)"] 				= { "Yavimaya Ancients"				, { 1    , false } },--Rearing Horse
["Yavimaya Ancients (2)"] 				= { "Yavimaya Ancients"				, { false, 2     } },--
	["Ahnen aus Yavimaya"] 				= { "Ahnen aus Yavimaya"			, { 1    , 2     } },
	["Ahnen aus Yavimaya (1)"] 			= { "Ahnen aus Yavimaya"			, { 1    , false } },
	["Ahnen aus Yavimaya (2)"] 			= { "Ahnen aus Yavimaya"			, { false, 2     } },
	},
},
[210] = { name="Homelands",
	tla="HML",
	cardcount={ reg = 140, tok =  0 },
	variants={
["Abbey Matron"] 					= { "Abbey Matron"				, { 1    , 2     } },
["Abbey Matron (1)"] 				= { "Abbey Matron"				, { 1    , false } },
["Abbey Matron (2)"] 				= { "Abbey Matron"				, { false, 2     } },
	["Oberin der Abtei"] 			= { "Oberin der Abtei"			, { 1    , 2     } },
	["Oberin der Abtei (1)"] 		= { "Oberin der Abtei"			, { 1    , false } },
	["Oberin der Abtei (2)"] 		= { "Oberin der Abtei"			, { false, 2     } },
["Aliban's Tower"] 					= { "Aliban's Tower"			, { 1    , 2     } },
["Aliban's Tower (1)"] 				= { "Aliban's Tower"			, { 1    , false } },
["Aliban's Tower (2)"] 				= { "Aliban's Tower"			, { false, 2     } },
	["Armax' Turm"] 				= { "Armax' Turm"				, { 1    , 2     } },
	["Armax' Turm (1)"] 			= { "Armax' Turm"				, { 1    , false } },
	["Armax' Turm (2)"] 			= { "Armax' Turm"				, { false, 2     } },
["Ambush Party"] 					= { "Ambush Party"				, { 1    , 2     } },
["Ambush Party (1)"] 				= { "Ambush Party"				, { 1    , false } },
["Ambush Party (2)"] 				= { "Ambush Party"				, { false, 2     } },
	["Lauernde Räuber"] 			= { "Lauernde Räuber"			, { 1    , 2     } },
	["Lauernde Räuber (1)"] 		= { "Lauernde Räuber"			, { 1    , false } },
	["Lauernde Räuber (2)"] 		= { "Lauernde Räuber"			, { false, 2     } },
["Anaba Bodyguard"] 				= { "Anaba Bodyguard"			, { 1    , 2     } },
["Anaba Bodyguard (1)"] 			= { "Anaba Bodyguard"			, { 1    , false } },
["Anaba Bodyguard (2)"] 			= { "Anaba Bodyguard"			, { false, 2     } },
	["Anaba-Leibwächter"] 			= { "Anaba-Leibwächter"			, { 1    , 2     } },
	["Anaba-Leibwächter (1)"] 		= { "Anaba-Leibwächter"			, { 1    , false } },
	["Anaba-Leibwächter (2)"] 		= { "Anaba-Leibwächter"			, { false, 2     } },
["Anaba Shaman"] 					= { "Anaba Shaman"				, { 1    , 2     } },
["Anaba Shaman (1)"] 				= { "Anaba Shaman"				, { 1    , false } },
["Anaba Shaman (2)"] 				= { "Anaba Shaman"				, { false, 2     } },
	["Anaba-Schamane"] 				= { "Anaba-Schamane"			, { 1    , 2     } },
	["Anaba-Schamane (1)"] 			= { "Anaba-Schamane"			, { 1    , false } },
	["Anaba-Schamane (2)"] 			= { "Anaba-Schamane"			, { false, 2     } },
["Aysen Bureaucrats"] 				= { "Aysen Bureaucrats"			, { 1    , 2     } },
["Aysen Bureaucrats (1)"] 			= { "Aysen Bureaucrats"			, { 1    , false } },
["Aysen Bureaucrats (2)"] 			= { "Aysen Bureaucrats"			, { false, 2     } },
	["Aysenischer Bürokrat"] 		= { "Aysenischer Bürokrat"		, { 1    , 2     } },
	["Aysenischer Bürokrat (1)"] 	= { "Aysenischer Bürokrat"		, { 1    , false } },
	["Aysenischer Bürokrat (2)"] 	= { "Aysenischer Bürokrat"		, { false, 2     } },
["Carapace"] 						= { "Carapace"					, { 1    , 2     } },
["Carapace (1)"] 					= { "Carapace"					, { 1    , false } },
["Carapace (2)"] 					= { "Carapace"					, { false, 2     } },
	["Rückenpanzer"] 				= { "Rückenpanzer"				, { 1    , 2     } },
	["Rückenpanzer (1)"] 			= { "Rückenpanzer"				, { 1    , false } },
	["Rückenpanzer (2)"] 			= { "Rückenpanzer"				, { false, 2     } },
["Cemetery Gate"] 					= { "Cemetery Gate"				, { 1    , 2     } },
["Cemetery Gate (1)"] 				= { "Cemetery Gate"				, { 1    , false } },
["Cemetery Gate (2)"] 				= { "Cemetery Gate"				, { false, 2     } },
	["Friedhofspforte"]	 			= { "Friedhofspforte"			, { 1    , 2     } },
	["Friedhofspforte (1)"] 		= { "Friedhofspforte"			, { 1    , false } },
	["Friedhofspforte (2)"] 		= { "Friedhofspforte"			, { false, 2     } },
["Dark Maze"] 						= { "Dark Maze"					, { 1    , 2     } },
["Dark Maze (1)"] 					= { "Dark Maze"					, { 1    , false } },
["Dark Maze (2)"] 					= { "Dark Maze"					, { false, 2     } },
	["Dunkler Irrgarten"] 			= { "Dunkler Irrgarten"			, { 1    , 2     } },
	["Dunkler Irrgarten (1)"] 		= { "Dunkler Irrgarten"			, { 1    , false } },
	["Dunkler Irrgarten (2)"] 		= { "Dunkler Irrgarten"			, { false, 2     } },
["Dry Spell"] 						= { "Dry Spell"					, { 1    , 2     } },
["Dry Spell (1)"] 					= { "Dry Spell"					, { 1    , false } },
["Dry Spell (2)"] 					= { "Dry Spell"					, { false, 2     } },
	["Trockenheit"]					= { "Trockenheit"				, { 1    , 2     } },
	["Trockenheit (1)"] 			= { "Trockenheit"				, { 1    , false } },
	["Trockenheit (2)"] 			= { "Trockenheit"				, { false, 2     } },
["Dwarven Trader"] 					= { "Dwarven Trader"			, { 1    , 2     } },
["Dwarven Trader (1)"] 				= { "Dwarven Trader"			, { 1    , false } },
["Dwarven Trader (2)"] 				= { "Dwarven Trader"			, { false, 2     } },
	["Zwergenkaufmann"]	 			= { "Zwergenkaufmann"			, { 1    , 2     } },
	["Zwergenkaufmann (1)"] 		= { "Zwergenkaufmann"			, { 1    , false } },
	["Zwergenkaufmann (2)"] 		= { "Zwergenkaufmann"			, { false, 2     } },
["Feast of the Unicorn"] 			= { "Feast of the Unicorn"		, { 1    , 2     } },
["Feast of the Unicorn (1)"] 		= { "Feast of the Unicorn"		, { 1    , false } },
["Feast of the Unicorn (2)"] 		= { "Feast of the Unicorn"		, { false, 2     } },
	["Einhornschlachtfest"] 		= { "Einhornschlachtfest"		, { 1    , 2     } },
	["Einhornschlachtfest (1)"] 	= { "Einhornschlachtfest"		, { 1    , false } },
	["Einhornschlachtfest (2)"] 	= { "Einhornschlachtfest"		, { false, 2     } },
["Folk of An-Havva"] 				= { "Folk of An-Havva"			, { 1    , 2     } },
["Folk of An-Havva (1)"] 			= { "Folk of An-Havva"			, { 1    , false } },
["Folk of An-Havva (2)"] 			= { "Folk of An-Havva"			, { false, 2     } },
	["Bewohner von An-Havva"]	 	= { "Bewohner von An-Havva"		, { 1    , 2     } },
	["Bewohner von An-Havva (1)"] 	= { "Bewohner von An-Havva"		, { 1    , false } },
	["Bewohner von An-Havva (2)"] 	= { "Bewohner von An-Havva"		, { false, 2     } },
["Giant Albatross"] 				= { "Giant Albatross"			, { 1    , 2     } },
["Giant Albatross (1)"] 			= { "Giant Albatross"			, { 1    , false } },
["Giant Albatross (2)"] 			= { "Giant Albatross"			, { false, 2     } },
	["Riesenalbatros"] 				= { "Riesenalbatros"			, { 1    , 2     } },
	["Riesenalbatros (1)"] 			= { "Riesenalbatros"			, { 1    , false } },
	["Riesenalbatros (2)"] 			= { "Riesenalbatros"			, { false, 2     } },
["Hungry Mist"] 					= { "Hungry Mist"				, { 1    , 2     } },
["Hungry Mist (1)"] 				= { "Hungry Mist"				, { 1    , false } },
["Hungry Mist (2)"] 				= { "Hungry Mist"				, { false, 2     } },
	["Hungrige Nebelschwaden"]	 	= { "Hungrige Nebelschwaden"	, { 1    , 2     } },
	["Hungrige Nebelschwaden (1)"]	= { "Hungrige Nebelschwaden"	, { 1    , false } },
	["Hungrige Nebelschwaden (2)"]	= { "Hungrige Nebelschwaden"	, { false, 2     } },
["Labyrinth Minotaur"] 				= { "Labyrinth Minotaur"		, { 1    , 2     } },
["Labyrinth Minotaur (1)"] 			= { "Labyrinth Minotaur"		, { 1    , false } },
["Labyrinth Minotaur (2)"] 			= { "Labyrinth Minotaur"		, { false, 2     } },
	["Labyrinthminotaurus"] 		= { "Labyrinthminotaurus"		, { 1    , 2     } },
	["Labyrinthminotaurus (1)"] 	= { "Labyrinthminotaurus"		, { 1    , false } },
	["Labyrinthminotaurus (2)"] 	= { "Labyrinthminotaurus"		, { false, 2     } },
["Memory Lapse"] 					= { "Memory Lapse"				, { 1    , 2     } },
["Memory Lapse (1)"]	 			= { "Memory Lapse"				, { 1    , false } },
["Memory Lapse (2)"] 				= { "Memory Lapse"				, { false, 2     } },
	["Gedächtnislücke"] 			= { "Gedächtnislücke"			, { 1    , 2     } },
	["Gedächnislücke (1)"] 			= { "Gedächnislücke"			, { 1    , false } },
	["Gedächnislücke (2)"]	 		= { "Gedächnislücke"			, { false, 2     } },
["Mesa Falcon"] 					= { "Mesa Falcon"				, { 1    , 2     } },
["Mesa Falcon (1)"] 				= { "Mesa Falcon"				, { 1    , false } },
["Mesa Falcon (2)"]	 				= { "Mesa Falcon"				, { false, 2     } },
	["Mesafalken"] 					= { "Mesafalken"				, { 1    , 2     } },
	["Mesafalken (1)"] 				= { "Mesafalken"				, { 1    , false } },
	["Mesafalken (2)"] 				= { "Mesafalken"				, { false, 2     } },
["Reef Pirates"] 					= { "Reef Pirates"				, { 1    , 2     } },
["Reef Pirates (1)"] 				= { "Reef Pirates"				, { 1    , false } },
["Reef Pirates (2)"] 				= { "Reef Pirates"				, { false, 2     } },
	["Riffpiraten"] 				= { "Riffpiraten"				, { 1    , 2     } },
	["Riffpiraten (1)"] 			= { "Riffpiraten"				, { 1    , false } },
	["Riffpiraten (2)"] 			= { "Riffpiraten"				, { false, 2     } },
["Samite Alchemist"] 				= { "Samite Alchemist"			, { 1    , 2     } },
["Samite Alchemist (1)"] 			= { "Samite Alchemist"			, { 1    , false } },
["Samite Alchemist (2)"] 			= { "Samite Alchemist"			, { false, 2     } },
	["Samitischer Alchimist"]	 	= { "Samitischer Alchimist"		, { 1    , 2     } },
	["Samitischer Alchimist (1)"] 	= { "Samitischer Alchimist"		, { 1    , false } },
	["Samitischer Alchimist (2)"] 	= { "Samitischer Alchimist"		, { false, 2     } },
["Shrink"] 							= { "Shrink"					, { 1    , 2     } },
["Shrink (1)"]	 					= { "Shrink"					, { 1    , false } },
["Shrink (2)"] 						= { "Shrink"					, { false, 2     } },
	["Schrumpfen"] 					= { "Schrumpfen"				, { 1    , 2     } },
	["Schrumpfen (1)"] 				= { "Schrumpfen"				, { 1    , false } },
	["Schrumpfen (2)"] 				= { "Schrumpfen"				, { false, 2     } },
["Sengir Bats"] 					= { "Sengir Bats"				, { 1    , 2     } },
["Sengir Bats (1)"] 				= { "Sengir Bats"				, { 1    , false } },
["Sengir Bats (2)"] 				= { "Sengir Bats"				, { false, 2     } },
	["Sengirs Fledermäuse"] 		= { "Sengirs Fledermäuse"		, { 1    , 2     } },
	["Sengirs Fledermäuse (1)"] 	= { "Sengirs Fledermäuse"		, { 1    , false } },
	["Sengirs Fledermäuse (2)"] 	= { "Sengirs Fledermäuse"		, { false, 2     } },
["Torture"] 						= { "Torture"					, { 1    , 2     } },
["Torture (1)"] 					= { "Torture"					, { 1    , false } },
["Torture (2)"] 					= { "Torture"					, { false, 2     } },
	["Folterung"] 					= { "Folterung"					, { 1    , 2     } },
	["Folterung (1)"]	 			= { "Folterung"					, { 1    , false } },
	["Folterung (2)"] 				= { "Folterung"					, { false, 2     } },
["Trade Caravan"] 					= { "Trade Caravan"				, { 1    , 2     } },
["Trade Caravan (1)"]	 			= { "Trade Caravan"				, { 1    , false } },
["Trade Caravan (2)"] 				= { "Trade Caravan"				, { false, 2     } },
	["Handelskarawane"] 			= { "Handelskarawane"			, { 1    , 2     } },
	["Handelskarawane (1)"] 		= { "Handelskarawane"			, { 1    , false } },
	["Handelskarawane (2)"] 		= { "Handelskarawane"			, { false, 2     } },
["Willow Faerie"]	 				= { "Willow Faerie"				, { 1    , 2     } },
["Willow Faerie (1)"] 				= { "Willow Faerie"				, { 1    , false } },
["Willow Faerie (2)"] 				= { "Willow Faerie"				, { false, 2     } },
	["Weidenfee"] 					= { "Weidenfee"					, { 1    , 2     } },
	["Weidenfee (1)"]		 		= { "Weidenfee"					, { 1    , false } },
	["Weidenfee (2)"] 				= { "Weidenfee"					, { false, 2     } },
	},
},
[190] = { name="Ice Age",
	tla="ICE",
	cardcount={ reg = 383, tok =  0 },
	variants={
["Plains"] 						= { "Plains"	, { 1    , 2    , 3     } },
["Island"] 						= { "Island" 	, { 1    , 2    , 3     } },
["Swamp"] 						= { "Swamp"		, { 1    , 2    , 3     } },
["Mountain"] 					= { "Mountain"	, { 1    , 2    , 3     } },
["Forest"] 						= { "Forest" 	, { 1    , 2    , 3     } },
["Plains (1)"]					= { "Plains"	, { 1    , false, false } },
["Plains (2)"]					= { "Plains"	, { false, 2    , false } },
["Plains (3)"]					= { "Plains"	, { false, false, 3     } },
["Island (1)"]					= { "Island"	, { 1    , false, false } },
["Island (2)"]					= { "Island"	, { false, 2    , false } },
["Island (3)"]					= { "Island"	, { false, false, 3     } },
["Swamp (1)"]					= { "Swamp"		, { 1    , false, false } },
["Swamp (2)"]					= { "Swamp"		, { false, 2    , false } },
["Swamp (3)"]					= { "Swamp"		, { false, false, 3     } },
["Mountain (1)"]				= { "Mountain"	, { 1    , false, false } },
["Mountain (2)"]				= { "Mountain"	, { false, 2    , false } },
["Mountain (3)"]				= { "Mountain"	, { false, false, 3     } },
["Forest (1)"]					= { "Forest"	, { 1    , false, false } },
["Forest (2)"]					= { "Forest"	, { false, 2    , false } },
["Forest (3)"]					= { "Forest"	, { false, false, 3     } },
	},
},
[170] = { name="Fallen Empires",
	tla="FEM",
	cardcount={ reg = 187, tok =  0 },
	variants={
["Armor Thrull"]	 				= { "Armor Thrull"					, { 1    , 2    , 3    , 4     } },
["Armor Thrull (1)"]	 			= { "Armor Thrull"					, { 1    , false, false, false } },--
["Armor Thrull (2)"] 				= { "Armor Thrull"					, { false, 2    , false, false } },--Spencer
["Armor Thrull (3)"] 				= { "Armor Thrull"					, { false, false, 3    , false } },--Menges
["Armor Thrull (4)"] 				= { "Armor Thrull"					, { false, false, false, 4     } },--Kirschner
["Basal Thrull"] 					= { "Basal Thrull"					, { 1    , 2    , 3    , 4     } },
["Basal Thrull (1)"]	 			= { "Basal Thrull"					, { 1    , false, false, false } },--
["Basal Thrull (2)"] 				= { "Basal Thrull"					, { false, 2    , false, false } },--P. Foglio
["Basal Thrull (3)"] 				= { "Basal Thrull"					, { false, false, 3    , false } },--Ferguson
["Basal Thrull (4)"] 				= { "Basal Thrull"					, { false, false, false, 4     } },--Rush
["Brassclaw Orcs"] 					= { "Brassclaw Orcs"				, { 1    , 2    , 3    , 4     } },
["Brassclaw Orcs (1)"]	 			= { "Brassclaw Orcs"				, { 1    , false, false, false } },--Pike
["Brassclaw Orcs (2)"] 				= { "Brassclaw Orcs"				, { false, 2    , false, false } },--Map
["Brassclaw Orcs (3)"] 				= { "Brassclaw Orcs"				, { false, false, 3    , false } },--Glove
["Brassclaw Orcs (4)"] 				= { "Brassclaw Orcs"				, { false, false, false, 4     } },--
["Combat Medic"] 					= { "Combat Medic"					, { 1    , 2    , 3    , 4     } },
["Combat Medic (1)"] 				= { "Combat Medic"					, { 1    , false, false, false } },--
["Combat Medic (2)"] 				= { "Combat Medic"					, { false, 2    , false, false } },--Camp
["Combat Medic (3)"] 				= { "Combat Medic"					, { false, false, 3    , false } },--Maddocks
["Combat Medic (4)"] 				= { "Combat Medic"					, { false, false, false, 4     } },--Danforth
["Dwarven Soldier"] 				= { "Dwarven Soldier"				, { 1    , 2    , 3     } },
["Dwarven Soldier (1)"]				= { "Dwarven Soldier"				, { 1    , false, false } },--
["Dwarven Soldier (2)"]				= { "Dwarven Soldier"				, { false, 2    , false } },--Asplund-Faith
["Dwarven Soldier (3)"]				= { "Dwarven Soldier"				, { false, false, 3     } },--Shuler
["Elven Fortress"] 					= { "Elven Fortress"				, { 1    , 2    , 3    , 4     } },
["Elven Fortress (1)"] 				= { "Elven Fortress"				, { 1    , false, false, false } },--
["Elven Fortress (2)"] 				= { "Elven Fortress"				, { false, 2    , false, false } },--Asplund-Faith
["Elven Fortress (3)"] 				= { "Elven Fortress"				, { false, false, 3    , false } },--Poole
["Elven Fortress (4)"] 				= { "Elven Fortress"				, { false, false, false, 4     } },--Wanerstrand
["Elvish Hunter"] 					= { "Elvish Hunter"					, { 1    , 2    , 3     } },
["Elvish Hunter (1)"]				= { "Elvish Hunter"					, { 1    , false, false } },--
["Elvish Hunter (2)"]				= { "Elvish Hunter"					, { false, 2    , false } },--Maddocks
["Elvish Hunter (3)"]				= { "Elvish Hunter"					, { false, false, 3     } },--Camp
["Elvish Scout"] 					= { "Elvish Scout"					, { 1    , 2    , 3     } },
["Elvish Scout (1)"]				= { "Elvish Scout"					, { 1    , false, false } },--
["Elvish Scout (2)"]				= { "Elvish Scout"					, { false, 2    , false } },--Venters
["Elvish Scout (3)"]				= { "Elvish Scout"					, { false, false, 3     } },--Rush
["Farrel's Zealot"] 				= { "Farrel's Zealot"				, { 1    , 2    , 3     } },
["Farrel's Zealot (1)"]				= { "Farrel's Zealot"				, { 1    , false, false } },--
["Farrel's Zealot (2)"]				= { "Farrel's Zealot"				, { false, 2    , false } },--Ferguson
["Farrel's Zealot (3)"]				= { "Farrel's Zealot"				, { false, false, 3     } },--Beard
["Goblin Chirurgeon"] 				= { "Goblin Chirurgeon"				, { 1    , 2    , 3     } },
["Goblin Chirurgeon (1)"]			= { "Goblin Chirurgeon"				, { 1    , false, false } },--
["Goblin Chirurgeon (2)"]			= { "Goblin Chirurgeon"				, { false, 2    , false } },--Foglio
["Goblin Chirurgeon (3)"]			= { "Goblin Chirurgeon"				, { false, false, 3     } },--Frazier
["Goblin Grenade"] 					= { "Goblin Grenade"				, { 1    , 2    , 3     } },
["Goblin Grenade (1)"]				= { "Goblin Grenade"				, { 1    , false, false } },--
["Goblin Grenade (2)"]				= { "Goblin Grenade"				, { false, 2    , false } },--Frazier
["Goblin Grenade (3)"]				= { "Goblin Grenade"				, { false, false, 3     } },--Rush
["Goblin War Drums"] 				= { "Goblin War Drums"				, { 1    , 2    , 3    , 4     } },
["Goblin War Drums (1)"]	 		= { "Goblin War Drums"				, { 1    , false, false, false } },--
["Goblin War Drums (2)"] 			= { "Goblin War Drums"				, { false, 2    , false, false } },--Ferguson
["Goblin War Drums (3)"] 			= { "Goblin War Drums"				, { false, false, 3    , false } },--Hudson
["Goblin War Drums (4)"]	 		= { "Goblin War Drums"				, { false, false, false, 4     } },--Menges
["High Tide"] 						= { "High Tide"						, { 1    , 2    , 3     } },
["High Tide (1)"]					= { "High Tide"						, { 1    , false, false } },--Wave
["High Tide (2)"]					= { "High Tide"						, { false, 2    , false } },--Merfolk
["High Tide (3)"]					= { "High Tide"						, { false, false, 3     } },--Coral
["Homarid"] 						= { "Homarid"						, { 1    , 2    , 3    , 4     } },
["Homarid (1)"] 					= { "Homarid"						, { 1    , false, false, false } },--Hoover
["Homarid (2)"] 					= { "Homarid"						, { false, 2    , false, false } },--Hudson
["Homarid (3)"] 					= { "Homarid"						, { false, false, 3    , false } },--Tedin
["Homarid (4)"] 					= { "Homarid"						, { false, false, false, 4     } },--Wackwitz
["Homarid Warrior"] 				= { "Homarid Warrior"				, { 1    , 2    , 3     } },
["Homarid Warrior (1)"]				= { "Homarid Warrior"				, { 1    , false, false } },--
["Homarid Warrior (2)"]				= { "Homarid Warrior"				, { false, 2    , false } },--Asplund-Faith
["Homarid Warrior (3)"]				= { "Homarid Warrior"				, { false, false, 3     } },--Shuler
["Hymn to Tourach"] 				= { "Hymn to Tourach"				, { 1    , 2    , 3    , 4     } },
["Hymn to Tourach (1)"] 			= { "Hymn to Tourach"				, { 1    , false, false, false } },--Wolf
["Hymn to Tourach (2)"] 			= { "Hymn to Tourach"				, { false, 2    , false, false } },--Circle
["Hymn to Tourach (3)"] 			= { "Hymn to Tourach"				, { false, false, 3    , false } },--Cloak
["Hymn to Tourach (4)"] 			= { "Hymn to Tourach"				, { false, false, false, 4     } },--Table
["Icatian Infantry"] 				= { "Icatian Infantry"				, { 1    , 2    , 3    , 4     } },
["Icatian Infantry (1)"] 			= { "Icatian Infantry"				, { 1    , false, false, false } },--
["Icatian Infantry (2)"] 			= { "Icatian Infantry"				, { false, 2    , false, false } },--Rush
["Icatian Infantry (3)"]	 		= { "Icatian Infantry"				, { false, false, 3    , false } },--Shuler
["Icatian Infantry (4)"] 			= { "Icatian Infantry"				, { false, false, false, 4     } },--Tucker
["Icatian Javelineers"] 			= { "Icatian Javelineers"			, { 1    , 2    , 3     } },
["Icatian Javelineers (1)"]			= { "Icatian Javelineers"			, { 1    , false, false } },--Benson
["Icatian Javelineers (2)"]			= { "Icatian Javelineers"			, { false, 2    , false } },--Beard
["Icatian Javelineers (3)"]			= { "Icatian Javelineers"			, { false, false, 3     } },--Kirschner
["Icatian Moneychanger"] 			= { "Icatian Moneychanger"			, { 1    , 2    , 3     } },
["Icatian Moneychanger (1)"]		= { "Icatian Moneychanger"			, { 1    , false, false } },--
["Icatian Moneychanger (2)"]		= { "Icatian Moneychanger"			, { false, 2    , false } },--Beard
["Icatian Moneychanger (3)"]		= { "Icatian Moneychanger"			, { false, false, 3     } },--Benson
["Icatian Scout"] 					= { "Icatian Scout"					, { 1    , 2    , 3    , 4     } },
["Icatian Scout (1)"] 				= { "Icatian Scout"					, { 1    , false, false, false } },--
["Icatian Scout (2)"] 				= { "Icatian Scout"					, { false, 2    , false, false } },--Shuler
["Icatian Scout (3)"] 				= { "Icatian Scout"					, { false, false, 3    , false } },--Alexander
["Icatian Scout (4)"] 				= { "Icatian Scout"					, { false, false, false, 4     } },--Foglio
["Initiates of the Ebon Hand"]	 	= { "Initiates of the Ebon Hand"	, { 1    , 2    , 3     } },
["Initiates of the Ebon Hand (1)"]	= { "Initiates of the Ebon Hand"	, { 1    , false, false } },--
["Initiates of the Ebon Hand (2)"]	= { "Initiates of the Ebon Hand"	, { false, 2    , false } },--Foglio
["Initiates of the Ebon Hand (3)"]	= { "Initiates of the Ebon Hand"	, { false, false, 3     } },--Hudson
["Merseine"] 						= { "Merseine"						, { 1    , 2    , 3    , 4     } },
["Merseine (1)"] 					= { "Merseine"						, { 1    , false, false, false } },--
["Merseine (2)"] 					= { "Merseine"						, { false, 2    , false, false } },--Organ-Kean
["Merseine (3)"] 					= { "Merseine"						, { false, false, 3    , false } },--Tucker
["Merseine (4)"]	 				= { "Merseine"						, { false, false, false, 4     } },--Venters
["Mindstab Thrull"]	 				= { "Mindstab Thrull"				, { 1    , 2    , 3     } },
["Mindstab Thrull (1)"]				= { "Mindstab Thrull"				, { 1    , false, false } },--
["Mindstab Thrull (2)"]				= { "Mindstab Thrull"				, { false, 2    , false } },--Hudson
["Mindstab Thrull (3)"]				= { "Mindstab Thrull"				, { false, false, 3     } },--Tedin
["Necrite"] 						= { "Necrite"						, { 1    , 2    , 3     } },
["Necrite (1)"]						= { "Necrite"						, { 1    , false, false } },--
["Necrite (2)"]						= { "Necrite"						, { false, 2    , false } },--Rush
["Necrite (3)"]						= { "Necrite"						, { false, false, 3     } },--Tucker
["Night Soil"] 						= { "Night Soil"					, { 1    , 2    , 3     } },
["Night Soil (1)"]					= { "Night Soil"					, { 1    , false, false } },--
["Night Soil (2)"]					= { "Night Soil"					, { false, 2    , false } },--Hudson
["Night Soil (3)"]					= { "Night Soil"					, { false, false, 3     } },--Tucker
["Orcish Spy"] 						= { "Orcish Spy"					, { 1    , 2    , 3     } },
["Orcish Spy (1)"]					= { "Orcish Spy"					, { 1    , false, false } },--
["Orcish Spy (2)"]					= { "Orcish Spy"					, { false, 2    , false } },--Gelon
["Orcish Spy (3)"]					= { "Orcish Spy"					, { false, false, 3     } },--Venters
["Orcish Veteran"] 					= { "Orcish Veteran"				, { 1    , 2    , 3    , 4     } },
["Orcish Veteran (1)"] 				= { "Orcish Veteran"				, { 1    , false, false, false } },--
["Orcish Veteran (2)"] 				= { "Orcish Veteran"				, { false, 2    , false, false } },--Frazier
["Orcish Veteran (3)"] 				= { "Orcish Veteran"				, { false, false, 3    , false } },--Hoover
["Orcish Veteran (4)"]	 			= { "Orcish Veteran"				, { false, false, false, 4     } },--Benson
["Order of the Ebon Hand"]	 		= { "Order of the Ebon Hand"		, { 1    , 2    , 3     } },
["Order of the Ebon Hand (1)"]		= { "Order of the Ebon Hand"		, { 1    , false, false } },--
["Order of the Ebon Hand (2)"]		= { "Order of the Ebon Hand"		, { false, 2    , false } },--Rush
["Order of the Ebon Hand (3)"]		= { "Order of the Ebon Hand"		, { false, false, 3     } },--Spencer
["Order of Leitbur"]	 			= { "Order of Leitbur"				, { 1    , 2    , 3     } },
["Order of Leitbur (1)"]			= { "Order of Leitbur"				, { 1    , false, false } },--Female
["Order of Leitbur (2)"]			= { "Order of Leitbur"				, { false, 2    , false } },--Male
["Order of Leitbur (3)"]			= { "Order of Leitbur"				, { false, false, 3     } },--
["Spore Cloud"] 					= { "Spore Cloud"					, { 1    , 2    , 3     } },
["Spore Cloud (1)"]					= { "Spore Cloud"					, { 1    , false, false } },--
["Spore Cloud (2)"]					= { "Spore Cloud"					, { false, 2    , false } },--Weber
["Spore Cloud (3)"]					= { "Spore Cloud"					, { false, false, 3     } },--Myrfors
["Thallid"] 						= { "Thallid"						, { 1    , 2    , 3    , 4     } },
["Thallid (1)"] 					= { "Thallid"						, { 1    , false, false, false } },--
["Thallid (2)"] 					= { "Thallid"						, { false, 2    , false, false } },--Myrfors
["Thallid (3)"] 					= { "Thallid"						, { false, false, 3    , false } },--Spencer
["Thallid (4)"] 					= { "Thallid"						, { false, false, false, 4     } },--Gelon
["Thorn Thallid"] 					= { "Thorn Thallid"					, { 1    , 2    , 3    , 4     } },
["Thorn Thallid (1)"] 				= { "Thorn Thallid"					, { 1    , false, false, false } },--
["Thorn Thallid (2)"] 				= { "Thorn Thallid"					, { false, 2    , false, false } },--Hudson
["Thorn Thallid (3)"] 				= { "Thorn Thallid"					, { false, false, 3    , false } },--Myrfors
["Thorn Thallid (4)"] 				= { "Thorn Thallid"					, { false, false, false, 4     } },--Tedin
["Tidal Flats"] 					= { "Tidal Flats"					, { 1    , 2    , 3     } },
["Tidal Flats (1)"]					= { "Tidal Flats"					, { 1    , false, false } },--
["Tidal Flats (2)"]					= { "Tidal Flats"					, { false, 2    , false } },--Sky
["Tidal Flats (3)"]					= { "Tidal Flats"					, { false, false, 3     } },--Earth
["Vodalian Soldiers"] 				= { "Vodalian Soldiers"				, { 1    , 2    , 3    , 4     } },
["Vodalian Soldiers (1)"] 			= { "Vodalian Soldiers"				, { 1    , false, false, false } },--
["Vodalian Soldiers (2)"] 			= { "Vodalian Soldiers"				, { false, 2    , false, false } },--Menges
["Vodalian Soldiers (3)"] 			= { "Vodalian Soldiers"				, { false, false, 3    , false } },--Ferguson
["Vodalian Soldiers (4)"] 			= { "Vodalian Soldiers"				, { false, false, false, 4     } },--Camp
["Vodalian Mage"] 					= { "Vodalian Mage"					, { 1    , 2    , 3     } },
["Vodalian Mage (1)"]				= { "Vodalian Mage"					, { 1    , false, false } },--
["Vodalian Mage (2)"]				= { "Vodalian Mage"					, { false, 2    , false } },--Poole
["Vodalian Mage (3)"]				= { "Vodalian Mage"					, { false, false, 3     } },--Hoover
	},
},
[160] = { name="The Dark",
	tla="DRK",
	cardcount={ reg = 119, tok =  0 },
	variants={}
},
[150] = { name="Legends",
	tla="LEG",
	cardcount={ reg = 310, tok =  0 },
	variants={}
},
[130] = { name="Antiquities",
	tla="ATQ",
	cardcount={ reg = 100, tok =  0 },
	variants={
["Mishra's Factory"] 			= { "Mishra's Factory"	, { 1    , 2    , 3    , 4     } },
["Mishra's Factory (Spring)"] 	= { "Mishra's Factory"	, { 1    , false, false, false } },
["Mishra's Factory (Summer)"] 	= { "Mishra's Factory"	, { false, 2    , false, false } },
["Mishra's Factory (Autumn)"] 	= { "Mishra's Factory"	, { false, false, 3    , false } },
["Mishra's Factory (Winter)"] 	= { "Mishra's Factory"	, { false, false, false, 4     } },
["Mishra's Factory (1)"]	 	= { "Mishra's Factory"	, { 1    , false, false, false } },
["Mishra's Factory (2)"]	 	= { "Mishra's Factory"	, { false, 2    , false, false } },
["Mishra's Factory (3)"] 		= { "Mishra's Factory"	, { false, false, 3    , false } },
["Mishra's Factory (4)"] 		= { "Mishra's Factory"	, { false, false, false, 4     } },
["Strip Mine"] 					= { "Strip Mine"		, { 1    , 2    , 3    , 4     } },
["Strip Mine (1)"] 				= { "Strip Mine"		, { 1    , false, false, false } },--No Horizon
["Strip Mine (2)"] 				= { "Strip Mine"		, { false, 2    , false, false } },--Uneven Horizon
["Strip Mine (3)"] 				= { "Strip Mine"		, { false, false, 3    , false } },--Tower
["Strip Mine (4)"] 				= { "Strip Mine"		, { false, false, false, 4     } },--Even Horizon
["Urza's Mine"] 				= { "Urza's Mine"		, { 1    , 2    , 3    , 4     } },
["Urza's Mine (1)"]	 			= { "Urza's Mine"		, { 1    , false, false, false } },--Pully
["Urza's Mine (2)"] 			= { "Urza's Mine"		, { false, 2    , false, false } },--Mouth
["Urza's Mine (3)"] 			= { "Urza's Mine"		, { false, false, 3    , false } },--Clawed Sphere
["Urza's Mine (4)"] 			= { "Urza's Mine"		, { false, false, false, 4     } },--Tower
["Urza's Power Plant"] 			= { "Urza's Power Plant", { 1    , 2    , 3    , 4     } },
["Urza's Power Plant (1)"]	 	= { "Urza's Power Plant", { 1    , false, false, false } },--Sphere
["Urza's Power Plant (2)"] 		= { "Urza's Power Plant", { false, 2    , false, false } },--Columns
["Urza's Power Plant (3)"] 		= { "Urza's Power Plant", { false, false, 3    , false } },--Bug
["Urza's Power Plant (4)"] 		= { "Urza's Power Plant", { false, false, false, 4     } },--Rock in Pot
["Urza's Tower"] 				= { "Urza's Tower"		, { 1    , 2    , 3    , 4     } },
["Urza's Tower (1)"] 			= { "Urza's Tower"		, { 1    , false, false, false } },--Forest
["Urza's Tower (2)"] 			= { "Urza's Tower"		, { false, 2    , false, false } },--Shore
["Urza's Tower (3)"] 			= { "Urza's Tower"		, { false, false, 3    , false } },--Plains
["Urza's Tower (4)"] 			= { "Urza's Tower"		, { false, false, false, 4     } },--Mountains
	},
},
[120] = { name="Arabian Nights",
	tla="ARN",
	cardcount={ reg = 92 , tok =  0 },
	variants={
["Army of Allah"] 				= { "Army of Allah"			, { 1    , 2     } },
["Army of Allah (1)"] 			= { "Army of Allah"			, { 1    , false } },
["Army of Allah (2)"] 			= { "Army of Allah"			, { false, 2     } },
["Bird Maiden"] 				= { "Bird Maiden"			, { 1    , 2     } },
["Bird Maiden (1)"] 			= { "Bird Maiden"			, { 1    , false } },
["Bird Maiden (2)"] 			= { "Bird Maiden"			, { false, 2     } },
["Erg Raiders"] 				= { "Erg Raiders"			, { 1    , 2     } },
["Erg Raiders (1)"] 			= { "Erg Raiders"			, { 1    , false } },
["Erg Raiders (2)"] 			= { "Erg Raiders"			, { false, 2     } },
["Fishliver Oil"] 				= { "Fishliver Oil"			, { 1    , 2     } },
["Fishliver Oil (1)"] 			= { "Fishliver Oil"			, { 1    , false } },
["Fishliver Oil (2)"] 			= { "Fishliver Oil"			, { false, 2     } },
["Giant Tortoise"] 				= { "Giant Tortoise"		, { 1    , 2     } },
["Giant Tortoise (1)"] 			= { "Giant Tortoise"		, { 1    , false } },
["Giant Tortoise (2)"]			= { "Giant Tortoise"		, { false, 2     } },
["Hasran Ogress"] 				= { "Hasran Ogress"			, { 1    , 2     } },
["Hasran Ogress (1)"] 			= { "Hasran Ogress"			, { 1    , false } },
["Hasran Ogress (2)"] 			= { "Hasran Ogress"			, { false, 2     } },
["Moorish Cavalry"] 			= { "Moorish Cavalry"		, { 1    , 2     } },
["Moorish Cavalry (1)"] 		= { "Moorish Cavalry"		, { 1    , false } },
["Moorish Cavalry (2)"]			= { "Moorish Cavalry"		, { false, 2     } },
["Nafs Asp"] 					= { "Nafs Asp"				, { 1    , 2     } },
["Nafs Asp (1)"] 				= { "Nafs Asp"				, { 1    , false } },
["Nafs Asp (2)"] 				= { "Nafs Asp"				, { false, 2     } },
["Oubliette"] 					= { "Oubliette"				, { 1    , 2     } },
["Oubliette (1)"] 				= { "Oubliette"				, { 1    , false } },
["Oubliette (2)"] 				= { "Oubliette"				, { false, 2     } },
["Rukh Egg"] 					= { "Rukh Egg"				, { 1    , 2     } },
["Rukh Egg (1)"] 				= { "Rukh Egg"				, { 1    , false } },
["Rukh Egg (2)"] 				= { "Rukh Egg"				, { false, 2     } },
["Piety"] 						= { "Piety"					, { 1    , 2     } },
["Piety (1)"] 					= { "Piety"					, { 1    , false } },
["Piety (2)"] 					= { "Piety"					, { false, 2     } },
["Stone-Throwing Devils"] 		= { "Stone-Throwing Devils"	, { 1    , 2     } },
["Stone-Throwing Devils (1)"] 	= { "Stone-Throwing Devils"	, { 1    , false } },
["Stone-Throwing Devils (2)"] 	= { "Stone-Throwing Devils"	, { false, 2     } },
["War Elephant"] 				= { "War Elephant"			, { 1    , 2     } },
["War Elephant (1)"] 			= { "War Elephant"			, { 1    , false } },
["War Elephant (2)"]		 	= { "War Elephant"			, { false, 2     } },
["Wyluli Wolf"] 				= { "Wyluli Wolf"			, { 1    , 2     } },
["Wyluli Wolf (1)"] 			= { "Wyluli Wolf"			, { 1    , false } },
["Wyluli Wolf (2)"] 			= { "Wyluli Wolf"			, { false, 2     } },
	},
},
--- not really a seperate subtable, just a bookmark for quick navigation in eclipse.
-- @field [parent=#Data.sets] #table SpecialSets
SpecialSets = nil,
[826] = { name="Zendikar Expeditions",
	tla="EXP",
	foilonly=true,
	cardcount={ reg=25, tok=0, nontrad=0, repl=0 },
},
[824] = { name="Duel Decks: Zendikar vs. Eldrazi",
	tla="DDP",
	foil="n",
	cardcount={ reg=75, tok=5, nontrad=0, repl=0 },
	variants={
["Plains"] 						= { "Plains"	, { 1    , 2    , 3     } },
["Island"] 						= { "Island" 	, { 1    , 2    , 3     } },
["Swamp"] 						= { "Swamp" 	, { 1    , 2    , 3     } },
["Mountain"] 					= { "Mountain" 	, { 1    , 2    , 3     } },
["Plains (35)"]					= { "Plains" 	, { 1    , false, false } },
["Plains (36)"]					= { "Plains" 	, { false, 2    , false } },
["Plains (37)"]					= { "Plains" 	, { false, false, 3     } },
["Plains (33)"]					= { "Plains" 	, { false, false, false } },
["Forest (38)"]					= { "Forest"	, { 1    , false, false } },
["Forest (39)"]					= { "Forest"	, { false, 2    , false } },
["Forest (40)"]					= { "Forest"	, { false, false, 3     } },
["Swamp (70)"]					= { "Swamp"		, { 1    , false, false } },
["Swamp (71)"]					= { "Swamp"		, { false, 2    , false } },
["Swamp (72)"]					= { "Swamp"		, { false, false, 3     } },
["Mountain (73)"]				= { "Mountain"	, { 1    , false, false } },
["Mountain (74)"]				= { "Mountain"	, { false, 2    , false } },
["Mountain (75)"]				= { "Mountain"	, { false, false, 3     } },
["Eldrazi Spawn Token"]			= { "Eldrazi Spawn Token"	, { "1"   , "2"   , "3"   } },
["Eldrazi Spawn Token (76)"]	= { "Eldrazi Spawn Token"	, { "1"   , false , false } }, -- art:Aleksi Briclot
["Eldrazi Spawn Token (77)"]	= { "Eldrazi Spawn Token"	, { false , "2"   , false } }, -- art:Véronique Meignaud
["Eldrazi Spawn Token (78)"]	= { "Eldrazi Spawn Token"	, { false , false , "3"   } }, -- art:Mark Tedin
	},
	foiltweak={
["Avenger of Zendikar"]		= { foil = true},
["Oblivion Sower"]			= { foil = true},
	},
},
[823] = { name="From the Vault: Angels",
	tla="V15",
	foilonly=true,
	cardcount={ reg=15, tok=0, nontrad=0, repl=0 },
},
[821] = { name="Challenge Deck: Defeat a God",
	tla="CD3",
	foil="n",
	cardcount={ reg=0, tok=0, nontrad=15, repl=0 },
},
[820] = { name="Duel Decks: Elspeth vs. Kiora",
	tla="DDO",
	foil="n",
	cardcount={ reg=65, tok=2, nontrad=0, repl=0 },
	variants={
["Plains"] 						= { "Plains"	, { 1    , 2    , 3    , 4    } },
["Island"] 						= { "Island" 	, { 1    , 2    , 3    } },
["Forest"] 						= { "Forest" 	, { 1    , 2    , 3    } },
["Plains (30)"]					= { "Plains" 	, { 1    , false, false, false } },
["Plains (31)"]					= { "Plains" 	, { false, 2    , false, false } },
["Plains (32)"]					= { "Plains" 	, { false, false, 3    , false } },
["Plains (33)"]					= { "Plains" 	, { false, false, false, 4     } },
["Island (60)"]					= { "Island"	, { 1    , false, false } },
["Island (61)"]					= { "Island"	, { false, 2    , false } },
["Island (62)"]					= { "Island"	, { false, false, 3     } },
["Forest (63)"]					= { "Forest"	, { 1    , false, false } },
["Forest (64)"]					= { "Forest"	, { false, 2    , false } },
["Forest (65)"]					= { "Forest"	, { false, false, 3     } },
	},
	foiltweak={
["Elspeth, Sun’s Champion"]		= { foil = true},
["Kiora, the Crashing Wave"]	= { foil = true},
	},
},
[819] = { name="Modern Masters 2015 Edition",
	tla="MM2",
	foil="y",
	cardcount={ reg=249, tok=16, nontrad=0, repl=0 },
	variants={
["Eldrazi Spawn Token"]			= { "Eldrazi Spawn Token"	, { 1    , 2    , 3     } },
["Eldrazi Spawn Token (1)"]		= { "Eldrazi Spawn Token"	, { 1    , false, false } }, -- art:Aleksi Briclot
["Eldrazi Spawn Token (2)"]		= { "Eldrazi Spawn Token"	, { false, 2    , false } }, -- art:Véronique Meignaud
["Eldrazi Spawn Token (3)"]		= { "Eldrazi Spawn Token"	, { false, false, 3     } }, -- art:Mark Tedin
	},
},
[817] = { name="Duel Decks: Anthology",
	tla="DD3",
	foil="n",
	cardcount={ reg=249, tok=11, nontrad=0, repl=0 },
	variants={
["Plains"]			= { "Plains"	, { "DVD 1", "DVD 2", "DVD 3", "DVD 4" } },
["Plains (DVD 26)"]	= { "Plains"	, { "DVD 1", false  , false  , false   } },
["Plains (DVD 27)"]	= { "Plains"	, { false  , "DVD 2", false  , false   } },
["Plains (DVD 28)"]	= { "Plains"	, { false  , false  , "DVD 3", false   } },
["Plains (DVD 29)"]	= { "Plains"	, { false  , false  , false  , "DVD 4" } },
["Island"]			= { "Island"	, { "JVC 1", "JVC 2", "JVC 3", "JVC 4" } },
["Island (JVC 30)"]	= { "Island"	, { "JVC 1", false  , false  , false   } },
["Island (JVC 31)"]	= { "Island"	, { false  , "JVC 2", false  , false   } },
["Island (JVC 32)"]	= { "Island"	, { false  , false  , "JVC 3", false   } },
["Island (JVC 33)"]	= { "Island"	, { false  , false  , false  , "JVC 4" } },
["Swamp"]			= { "Swamp"		, { "DVD 1", "DVD 2", "DVD 3", "DVD 4", "GVL 1", "GVL 2", "GVL 3", "GVL 4" } },
["Swamp (DVD 59)"]	= { "Swamp"		, { "DVD 1", false  , false  , false  , false  , false  , false  , false   } },
["Swamp (DVD 60)"]	= { "Swamp"		, { false  , "DVD 2", false  , false  , false  , false  , false  , false   } },
["Swamp (DVD 61)"]	= { "Swamp"		, { false  , false  , "DVD 3", false  , false  , false  , false  , false   } },
["Swamp (DVD 62)"]	= { "Swamp"		, { false  , false  , false  , "DVD 4", false  , false  , false  , false   } },
["Swamp (GVL 60)"]	= { "Swamp"		, { false  , false  , false  , false  , "GVL 1", false  , false  , false   } },
["Swamp (GVL 61)"]	= { "Swamp"		, { false  , false  , false  , false  , false  , "GVL 2", false  , false   } },
["Swamp (GVL 62)"]	= { "Swamp"		, { false  , false  , false  , false  , false  , false  , "GVL 3", false   } },
["Swamp (GVL 63)"]	= { "Swamp"		, { false  , false  , false  , false  , false  , false  , false  , "GVL 4" } },
["Mountain"]		= { "Mountain"	, { "JVC 1", "JVC 2", "JVC 3", "JVC 4", "EVG 1", "EVG 2", "EVG 3", "EVG 4" } },
["Mountain (JVC 59)"]= { "Mountain"	, { "JVC 1", false  , false  , false  , false  , false  , false  , false   } },
["Mountain (JVC 60)"]= { "Mountain"	, { false  , "JVC 2", false  , false  , false  , false  , false  , false   } },
["Mountain (JVC 61)"]= { "Mountain"	, { false  , false  , "JVC 3", false  , false  , false  , false  , false   } },
["Mountain (JVC 62)"]= { "Mountain"	, { false  , false  , false  , "JVC 4", false  , false  , false  , false   } },
["Mountain (EVG 59)"]= { "Mountain"	, { false  , false  , false  , false  , "EVG 1", false  , false  , false   } },
["Mountain (EVG 60)"]= { "Mountain"	, { false  , false  , false  , false  , false  , "EVG 2", false  , false   } },
["Mountain (EVG 61)"]= { "Mountain"	, { false  , false  , false  , false  , false  , false  , "EVG 3", false   } },
["Mountain (EVG 62)"]= { "Mountain"	, { false  , false  , false  , false  , false  , false  , false  , "EVG 4" } },
["Forest"]			= { "Forest"	, { "EVG 1", "EVG 2", "EVG 3", "EVG 4", "GVL 1", "GVL 2", "GVL 3", "GVL 4" } },
["Forest (EVG 28)"]	= { "Forest"	, { "EVG 1", false  , false  , false  , false  , false  , false  , false   } },
["Forest (EVG 29)"]	= { "Forest"	, { false  , "EVG 2", false  , false  , false  , false  , false  , false   } },
["Forest (EVG 30)"]	= { "Forest"	, { false  , false  , "EVG 3", false  , false  , false  , false  , false   } },
["Forest (EVG 31)"]	= { "Forest"	, { false  , false  , false  , "EVG 4", false  , false  , false  , false   } },
["Forest (GVL 28)"]	= { "Forest"	, { false  , false  , false  , false  , "GVL 1", false  , false  , false   } },
["Forest (GVL 29)"]	= { "Forest"	, { false  , false  , false  , false  , false  , "GVL 2", false  , false   } },
["Forest (GVL 30)"]	= { "Forest"	, { false  , false  , false  , false  , false  , false  , "GVL 3", false   } },
["Forest (GVL 31)"]	= { "Forest"	, { false  , false  , false  , false  , false  , false  , false  , "GVL 4" } },
["Abyssal Gatekeeper"]				= { "Abyssal Gatekeeper"			, { "DVD" } },
["Abyssal Specter"]					= { "Abyssal Specter"				, { "DVD" } },
["Æthersnipe"]						= { "Æthersnipe"					, { "JVC" } },
["Air Elemental"]					= { "Air Elemental"					, { "JVC" } },
["Akki Coalflinger"]				= { "Akki Coalflinger"				, { "EVG" } },
["Akroma, Angel of Wrath"]			= { "Akroma, Angel of Wrath"		, { "DVD" } },
["Albino Troll"]					= { "Albino Troll"					, { "GVL" } },
["Allosaurus Rider"]				= { "Allosaurus Rider"				, { "EVG" } },
["Ambush Commander"]				= { "Ambush Commander"				, { "EVG" } },
["Ancestral Vision"]				= { "Ancestral Vision"				, { "JVC" } },
["Angel of Mercy"]					= { "Angel of Mercy"				, { "DVD" } },
["Angel’s Feather"]					= { "Angel’s Feather"				, { "DVD" } },
["Angelic Benediction"]				= { "Angelic Benediction"			, { "DVD" } },
["Angelic Page"]					= { "Angelic Page"					, { "DVD" } },
["Angelic Protector"]				= { "Angelic Protector"				, { "DVD" } },
["Angelsong"]						= { "Angelsong"						, { "DVD" } },
["Bad Moon"]						= { "Bad Moon"						, { "GVL" } },
["Barren Moor"]						= { "Barren Moor"					, { "DVD" } },
["Barter in Blood"]					= { "Barter in Blood"				, { "DVD" } },
["Basking Rootwalla"]				= { "Basking Rootwalla"				, { "GVL" } },
["Beast Attack"]					= { "Beast Attack"					, { "GVL" } },
["Blastoderm"]						= { "Blastoderm"					, { "GVL" } },
["Boggart Shenanigans"]				= { "Boggart Shenanigans"			, { "EVG" } },
["Bottle Gnomes"]					= { "Bottle Gnomes"					, { "JVC" } },
["Breeding Pit"]					= { "Breeding Pit"					, { "DVD" } },
["Brine Elemental"]					= { "Brine Elemental"				, { "JVC" } },
["Cackling Imp"]					= { "Cackling Imp"					, { "DVD" } },
["Chandra Nalaar"]					= { "Chandra Nalaar"				, { "JVC" } },
["Charging Paladin"]				= { "Charging Paladin"				, { "DVD" } },
["Chartooth Cougar"]				= { "Chartooth Cougar"				, { "JVC" } },
["Clickslither"]					= { "Clickslither"					, { "EVG" } },
["Condescend"]						= { "Condescend"					, { "JVC" } },
["Cone of Flame"]					= { "Cone of Flame"					, { "JVC" } },
["Consume Spirit"]					= { "Consume Spirit"				, { "DVD" } },
["Corrupt"]							= { "Corrupt"						, { "DVD", "GVL" } },
["Corrupt (55)"]					= { "Corrupt"						, { "DVD", false } },
["Corrupt (57)"]					= { "Corrupt"						, { false, "GVL" } },
["Counterspell"]					= { "Counterspell"					, { "JVC" } },
["Cruel Edict"]						= { "Cruel Edict"					, { "DVD" } },
["Daggerclaw Imp"]					= { "Daggerclaw Imp"				, { "DVD" } },
["Dark Banishing"]					= { "Dark Banishing"				, { "DVD" } },
["Dark Ritual"]						= { "Dark Ritual"					, { "DVD" } },
["Daze"]							= { "Daze"							, { "JVC" } },
["Deathgreeter"]					= { "Deathgreeter"					, { "GVL" } },
["Demon’s Horn"]					= { "Demon’s Horn"					, { "DVD" } },
["Demon’s Jester"]					= { "Demon’s Jester"				, { "DVD" } },
["Demonfire"]						= { "Demonfire"						, { "JVC" } },
["Demonic Tutor"]					= { "Demonic Tutor"					, { "DVD" } },
["Drudge Skeletons"]				= { "Drudge Skeletons"				, { "GVL" } },
["Duress"]							= { "Duress"						, { "DVD" } },
["Dusk Imp"]						= { "Dusk Imp"						, { "DVD" } },
["Elephant Guide"]					= { "Elephant Guide"				, { "GVL" } },
["Elvish Eulogist"]					= { "Elvish Eulogist"				, { "EVG" } },
["Elvish Harbinger"]				= { "Elvish Harbinger"				, { "EVG" } },
["Elvish Promenade"]				= { "Elvish Promenade"				, { "EVG" } },
["Elvish Warrior"]					= { "Elvish Warrior"				, { "EVG" } },
["Emberwilde Augur"]				= { "Emberwilde Augur"				, { "EVG" } },
["Enslave"]							= { "Enslave"						, { "GVL" } },
["Errant Ephemeron"]				= { "Errant Ephemeron"				, { "JVC" } },
["Fact or Fiction"]					= { "Fact or Fiction"				, { "JVC" } },
["Faerie Macabre"]					= { "Faerie Macabre"				, { "GVL" } },
["Faith’s Fetters"]					= { "Faith’s Fetters"				, { "DVD" } },
["Fallen Angel"]					= { "Fallen Angel"					, { "DVD" } },
["Fathom Seer"]						= { "Fathom Seer"					, { "JVC" } },
["Fireball"]						= { "Fireball"						, { "JVC" } },
["Fireblast"]						= { "Fireblast"						, { "JVC" } },
["Firebolt"]						= { "Firebolt"						, { "JVC" } },
["Fireslinger"]						= { "Fireslinger"					, { "JVC" } },
["Flame Javelin"]					= { "Flame Javelin"					, { "JVC" } },
["Flamekin Brawler"]				= { "Flamekin Brawler"				, { "JVC" } },
["Flametongue Kavu"]				= { "Flametongue Kavu"				, { "JVC" } },
["Flamewave Invoker"]				= { "Flamewave Invoker"				, { "EVG", "JVC" } },
["Flamewave Invoker (36)"]			= { "Flamewave Invoker"				, { "EVG", false } },
["Flamewave Invoker (40)"]			= { "Flamewave Invoker"				, { false, "JVC" } },
["Fledgling Mawcor"]				= { "Fledgling Mawcor"				, { "JVC" } },
["Fleshbag Marauder"]				= { "Fleshbag Marauder"				, { "GVL" } },
["Forgotten Cave"]					= { "Forgotten Cave"				, { "EVG" } },
["Foul Imp"]						= { "Foul Imp"						, { "DVD" } },
["Furnace Whelp"]					= { "Furnace Whelp"					, { "JVC" } },
["Garruk Wildspeaker"]				= { "Garruk Wildspeaker"			, { "GVL" } },
["Gempalm Incinerator"]				= { "Gempalm Incinerator"			, { "EVG" } },
["Gempalm Strider"]					= { "Gempalm Strider"				, { "EVG" } },
["Genju of the Cedars"]				= { "Genju of the Cedars"			, { "GVL" } },
["Genju of the Fens"]				= { "Genju of the Fens"				, { "GVL" } },
["Ghost-Lit Stalker"]				= { "Ghost-Lit Stalker"				, { "GVL" } },
["Giant Growth"]					= { "Giant Growth"					, { "EVG", "GVL" } },
["Giant Growth (21)"]				= { "Giant Growth"					, { "EVG", false } },
["Giant Growth (14)"]				= { "Giant Growth"					, { false, "GVL" } },
["Goblin Burrows"]					= { "Goblin Burrows"				, { "EVG" } },
["Goblin Cohort"]					= { "Goblin Cohort"					, { "EVG" } },
["Goblin Matron"]					= { "Goblin Matron"					, { "EVG" } },
["Goblin Ringleader"]				= { "Goblin Ringleader"				, { "EVG" } },
["Goblin Sledder"]					= { "Goblin Sledder"				, { "EVG" } },
["Goblin Warchief"]					= { "Goblin Warchief"				, { "EVG" } },
["Guile"]							= { "Guile"							, { "JVC" } },
["Gush"]							= { "Gush"							, { "JVC" } },
["Harmonize"]						= { "Harmonize"						, { "EVG", "GVL" } },
["Harmonize (22)"]					= { "Harmonize"						, { "EVG", false } },
["Harmonize (21)"]					= { "Harmonize"						, { false, "GVL" } },
["Healing Salve"]					= { "Healing Salve"					, { "DVD" } },
["Heedless One"]					= { "Heedless One"					, { "EVG" } },
["Hideous End"]						= { "Hideous End"					, { "GVL" } },
["Hostility"]						= { "Hostility"						, { "JVC" } },
["Howling Banshee"]					= { "Howling Banshee"				, { "GVL" } },
["Ib Halfheart, Goblin Tactician"]	= { "Ib Halfheart, Goblin Tactician", { "EVG" } },
["Icatian Priest"]					= { "Icatian Priest"				, { "DVD" } },
["Ichor Slick"]						= { "Ichor Slick"					, { "GVL" } },
["Imperious Perfect"]				= { "Imperious Perfect"				, { "EVG" } },
["Incinerate"]						= { "Incinerate"					, { "JVC" } },
["Indrik Stomphowler"]				= { "Indrik Stomphowler"			, { "GVL" } },
["Ingot Chewer"]					= { "Ingot Chewer"					, { "JVC" } },
["Inner-Flame Acolyte"]				= { "Inner-Flame Acolyte"			, { "JVC" } },
["Invigorate"]						= { "Invigorate"					, { "GVL" } },
["Jace Beleren"]					= { "Jace Beleren"					, { "JVC" } },
["Keening Banshee"]					= { "Keening Banshee"				, { "GVL" } },
["Keldon Megaliths"]				= { "Keldon Megaliths"				, { "JVC" } },
["Krosan Tusker"]					= { "Krosan Tusker"					, { "GVL" } },
["Kuro, Pitlord"]					= { "Kuro, Pitlord"					, { "DVD" } },
["Lignify"]							= { "Lignify"						, { "GVL" } },
["Liliana Vess"]					= { "Liliana Vess"					, { "GVL" } },
["Llanowar Elves"]					= { "Llanowar Elves"				, { "EVG" } },
["Lord of the Pit"]					= { "Lord of the Pit"				, { "DVD" } },
["Luminous Angel"]					= { "Luminous Angel"				, { "DVD" } },
["Lys Alana Huntmaster"]			= { "Lys Alana Huntmaster"			, { "EVG" } },
["Magma Jet"]						= { "Magma Jet"						, { "JVC" } },
["Man-o’-War"]						= { "Man-o’-War"					, { "JVC" } },
["Marble Diamond"]					= { "Marble Diamond"				, { "DVD" } },
["Martyr of Frost"]					= { "Martyr of Frost"				, { "JVC" } },
["Mind Stone"]						= { "Mind Stone"					, { "JVC" } },
["Mogg Fanatic"]					= { "Mogg Fanatic"					, { "EVG" } },
["Mogg War Marshal"]				= { "Mogg War Marshal"				, { "EVG" } },
["Moonglove Extract"]				= { "Moonglove Extract"				, { "EVG" } },
["Mudbutton Torchrunner"]			= { "Mudbutton Torchrunner"			, { "EVG" } },
["Mulldrifter"]		 				= { "Mulldrifter"					, { "JVC" } },
["Mutilate"]		 				= { "Mutilate"						, { "GVL" } },
["Nature’s Lore"]		 		 	= { "Nature’s Lore"					, { "GVL" } },
["Oni Possession"]		 			= { "Oni Possession"				, { "DVD" } },
["Ophidian"]		 				= { "Ophidian"						, { "JVC" } },
["Otherworldly Journey"]		 	= { "Otherworldly Journey"			, { "DVD" } },
["Overeager Apprentice"]		 	= { "Overeager Apprentice"			, { "DVD" } },
["Overrun"]		 					= { "Overrun"						, { "GVL" } },
["Oxidda Golem"]		 			= { "Oxidda Golem"					, { "JVC" } },
["Pacifism"]		 				= { "Pacifism"						, { "DVD" } },
["Phyrexian Rager"]		 			= { "Phyrexian Rager"				, { "GVL" } },
["Plated Slagwurm"]		 			= { "Plated Slagwurm"				, { "GVL" } },
["Polluted Mire"]		 			= { "Polluted Mire"					, { "GVL" } },
["Promise of Power"]		 		= { "Promise of Power"				, { "DVD" } },
["Pyre Charger"]		 			= { "Pyre Charger"					, { "JVC" } },
["Quicksilver Dragon"]		 		= { "Quicksilver Dragon"			, { "JVC" } },
["Raging Goblin"]		 			= { "Raging Goblin"					, { "EVG" } },
["Rakdos Pit Dragon"]		 		= { "Rakdos Pit Dragon"				, { "JVC" } },
["Rancor"]		 					= { "Rancor"						, { "GVL" } },
["Ravenous Baloth"]		 			= { "Ravenous Baloth"				, { "GVL" } },
["Ravenous Rats"]		 			= { "Ravenous Rats"					, { "GVL" } },
["Reckless One"]		 			= { "Reckless One"					, { "EVG" } },
["Reiver Demon"]		 			= { "Reiver Demon"					, { "DVD" } },
["Repulse"]		 					= { "Repulse"						, { "JVC" } },
["Reya Dawnbringer"]		 		= { "Reya Dawnbringer"				, { "DVD" } },
["Riftwing Cloudskate"]				= { "Riftwing Cloudskate"			, { "JVC" } },
["Righteous Cause"]		 			= { "Righteous Cause"				, { "DVD" } },
["Rise from the Grave"]				= { "Rise from the Grave"			, { "GVL" } },
["Rude Awakening"]		 			= { "Rude Awakening"				, { "GVL" } },
["Seal of Fire"]		 			= { "Seal of Fire"					, { "JVC" } },
["Secluded Steppe"]		 			= { "Secluded Steppe"				, { "DVD" } },
["Serra Advocate"]		 			= { "Serra Advocate"				, { "DVD" } },
["Serra Angel"]		 				= { "Serra Angel"					, { "DVD" } },
["Serra’s Boon"]		 			= { "Serra’s Boon"					, { "DVD" } },
["Serra’s Embrace"]		 			= { "Serra’s Embrace"				, { "DVD" } },
["Serrated Arrows"]		 			= { "Serrated Arrows"				, { "GVL" } },
["Siege-Gang Commander"]			= { "Siege-Gang Commander"			, { "EVG" } },
["Sign in Blood"]		 			= { "Sign in Blood"					, { "GVL" } },
["Skeletal Vampire"]		 		= { "Skeletal Vampire"				, { "GVL" } },
["Skirk Drill Sergeant"]			= { "Skirk Drill Sergeant"			, { "EVG" } },
["Skirk Fire Marshal"]		 		= { "Skirk Fire Marshal"			, { "EVG" } },
["Skirk Prospector"]		 		= { "Skirk Prospector"				, { "EVG" } },
["Skirk Shaman"]		 			= { "Skirk Shaman"					, { "EVG" } },
["Slate of Ancestry"]		 		= { "Slate of Ancestry"				, { "EVG" } },
["Slippery Karst"]		 			= { "Slippery Karst"				, { "GVL" } },
["Slith Firewalker"]		 		= { "Slith Firewalker"				, { "JVC" } },
["Snuff Out"]		 				= { "Snuff Out"						, { "GVL" } },
["Soot Imp"]		 				= { "Soot Imp"						, { "DVD" } },
["Soulbright Flamekin"]				= { "Soulbright Flamekin"			, { "JVC" } },
["Souldrinker"]		 				= { "Souldrinker"					, { "DVD" } },
["Spire Golem"]		 				= { "Spire Golem"					, { "JVC" } },
["Spitting Earth"]		 			= { "Spitting Earth"				, { "EVG" } },
["Stampeding Wildebeests"]			= { "Stampeding Wildebeests"		, { "GVL" } },
["Stinkweed Imp"]		 			= { "Stinkweed Imp"					, { "DVD" } },
["Stonewood Invoker"]		 		= { "Stonewood Invoker"				, { "EVG" } },
["Sustainer of the Realm"]			= { "Sustainer of the Realm"		, { "DVD" } },
["Sylvan Messenger"]		 		= { "Sylvan Messenger"				, { "EVG" } },
["Tar Pitcher"]		 				= { "Tar Pitcher"					, { "EVG" } },
["Tarfire"]		 					= { "Tarfire"						, { "EVG" } },
["Tendrils of Corruption"]			= { "Tendrils of Corruption"		, { "GVL" } },
["Terrain Generator"]		 		= { "Terrain Generator"				, { "JVC" } },
["Timberwatch Elf"]		 			= { "Timberwatch Elf"				, { "EVG" } },
["Tranquil Thicket"]		 		= { "Tranquil Thicket"				, { "EVG" } },
["Treetop Village"]		 			= { "Treetop Village"				, { "GVL" } },
["Twilight Shepherd"]		 		= { "Twilight Shepherd"				, { "DVD" } },
["Twisted Abomination"]				= { "Twisted Abomination"			, { "GVL" } },
["Unholy Strength"]		 			= { "Unholy Strength"				, { "DVD" } },
["Urborg Syphon-Mage"]		 		= { "Urborg Syphon-Mage"			, { "GVL" } },
["Vampire Bats"]		 			= { "Vampire Bats"					, { "GVL" } },
["Venerable Monk"]		 			= { "Venerable Monk"				, { "DVD" } },
["Vicious Hunger"]		 			= { "Vicious Hunger"				, { "GVL" } },
["Vine Trellis"]		 			= { "Vine Trellis"					, { "GVL" } },
["Voice of the Woods"]		 		= { "Voice of the Woods"			, { "EVG" } },
["Voidmage Apprentice"]		 		= { "Voidmage Apprentice"			, { "JVC" } },
["Wall of Bone"]		 			= { "Wall of Bone"					, { "GVL" } },
["Wall of Deceit"]		 			= { "Wall of Deceit"				, { "JVC" } },
["Waterspout Djinn"]		 		= { "Waterspout Djinn"				, { "JVC" } },
["Wellwisher"]		 				= { "Wellwisher"					, { "EVG" } },
["Wild Mongrel"]		 			= { "Wild Mongrel"					, { "GVL" } },
["Wildsize"]		 				= { "Wildsize"						, { "EVG" } },
["Willbender"]		 				= { "Willbender"					, { "JVC" } },
["Windstorm"]		 				= { "Windstorm"						, { "GVL" } },
["Wirewood Herald"]		 			= { "Wirewood Herald"				, { "EVG" } },
["Wirewood Lodge"]		 			= { "Wirewood Lodge"				, { "EVG" } },
["Wirewood Savage"]		 			= { "Wirewood Savage"				, { "GVL" } },
["Wirewood Symbiote"]		 		= { "Wirewood Symbiote"				, { "EVG" } },
["Wood Elves"]		 				= { "Wood Elves"					, { "EVG" } },
["Wren’s Run Vanquisher"]			= { "Wren’s Run Vanquisher"			, { "EVG" } },
["Bat Token"]				= { "Bat Token"				, { "GVL" } },
["Beast Token"]				= { "Beast Token"				, { "GVL 1", "GVL 2" } },
["Beast Token (8)"]			= { "Beast Token"				, { "GVL 1", false   } },--3/3
["Beast Token (9)"]			= { "Beast Token"				, { false  , "GVL 2" } },--4/4
["Demon Token"]				= { "Demon Token"				, { "DVD" } },
["Elemental Token"]			= { "Elemental Token"			, { "EVG" } },
["Elemental Shaman Token"]	= { "Elemental Shaman Token"	, { "JVC" } },
["Elephant Token"]			= { "Elephant Token"			, { "GVL" } },
["Elf Warrior Token"]		= { "Elf Warrior Token"		, { "EVG" } },
["Goblin Token"]			= { "Goblin Token"			, { "EVG" } },
["Spirit Token"]			= { "Spirit Token"			, { "DVD" } },
["Thrull Token"]			= { "Thrull Token"			, { "DVD" } },
	},
	foiltweak={
["Ambush Commander"]		= { foil = true },	
["Akroma, Angel of Wrath"]	= { foil = true },	
["Jace Beleren"]			= { foil = true },	
["Lord of the Pit"]			= { foil = true },	
["Siege-Gang Commander"]	= { foil = true },	
["Chandra Nalaar"]			= { foil = true },	
["Garruk Wildspeaker"]		= { foil = true },	
["Liliana Vess"]			= { foil = true },	
	},
},
[815] = { name="Fate Reforged Clash Pack",
	tla="CP2",
	foilonly=true,
	cardcount={ reg=6, tok=0, nontrad=0, repl=0 },	
},
[814] = { name="Commander 2014 Edition",
	tla="C14",
	foil="n",--5 oversized are foilonly
	cardcount={ reg=337, tok=36, nontrad=0, repl=5 },
	variants={
["Plains"] 					= { "Plains"	, { 1    , 2    , 3    , 4     } },
["Island"] 					= { "Island" 	, { 1    , 2    , 3    , 4     } },
["Swamp"] 					= { "Swamp"		, { 1    , 2    , 3    , 4     } },
["Mountain"] 				= { "Mountain"	, { 1    , 2    , 3    , 4     } },
["Forest"] 					= { "Forest" 	, { 1    , 2    , 3    , 4     } },
["Plains (318)"]			= { "Plains"	, { 1    , false, false, false } }, 
["Plains (319)"]			= { "Plains"	, { false, 2    , false, false } },
["Plains (320)"]			= { "Plains"	, { false, false, 3    , false } },
["Plains (321)"]			= { "Plains"	, { false, false, false, 4     } },
["Island (322)"]			= { "Island"	, { 1    , false, false, false } },
["Island (323)"]			= { "Island"	, { false, 2    , false, false } },
["Island (324)"]			= { "Island"	, { false, false, 3    , false } },
["Island (325)"]			= { "Island"	, { false, false, false, 4     } },
["Swamp (326)"]				= { "Swamp"		, { 1    , false, false, false } },
["Swamp (327)"]				= { "Swamp"		, { false, 2    , false, false } },
["Swamp (328)"]				= { "Swamp"		, { false, false, 3    , false } },
["Swamp (329)"]				= { "Swamp"		, { false, false, false, 4     } },
["Mountain (330)"]			= { "Mountain"	, { 1    , false, false, false } },
["Mountain (331)"]			= { "Mountain"	, { false, 2    , false, false } },
["Mountain (332)"]			= { "Mountain"	, { false, false, 3    , false } },
["Mountain (333)"]			= { "Mountain"	, { false, false, false, 4     } },
["Forest (334)"]			= { "Forest"	, { 1    , false, false, false } },
["Forest (335)"]			= { "Forest"	, { false, 2    , false, false } },
["Forest (336)"]			= { "Forest"	, { false, false, 3    , false } },
["Forest (337)"]			= { "Forest"	, { false, false, false, 4     } },
["Beast Token"]				= { "Beast Token"		, { 1    , 2     } },
["Beast Token (19)"]		= { "Beast Token"		, { 1    , false } }, -- 3/3
["Beast Token (20)"]		= { "Beast Token"		, { false, 2     } }, -- 4/4
["Demon Token"]				= { "Demon Token"		, { 1    , 2     } },
["Demon Token (12)"]		= { "Demon Token"		, { 1    , false } }, -- */*
["Demon Token (13)"]		= { "Demon Token"		, { false, 2     } }, -- 5/5
["Wurm Token"]				= { "Wurm Token"		, { 1    , 2     } },
["Wurm Token (32)"]			= { "Wurm Token"		, { 1    , false } }, -- Deathtouch
["Wurm Token (33)"]			= { "Wurm Token"		, { false, 2     } }, -- Lifelink
["Zombie Token"]			= { "Zombie Token"	, { 1    , 2     } }, -- B 2/2
["Zombie Token (11)"]		= { "Zombie Token"	, { 1    , false } }, -- U */*
["Zombie Token (16)"]		= { "Zombie Token"	, { false, 2     } },
["Nahiri, the Lithomancer"]					= { "Nahiri, the Lithomancer"		, { ""   , false     } },
["Nahiri, the Lithomancer (oversized)"]		= { "Nahiri, the Lithomancer"		, { false, "replica" } },
["Teferi, Temporal Archmage"]				= { "Teferi, Temporal Archmage"		, { ""   , false     } },
["Teferi, Temporal Archmage (oversized)"]	= { "Teferi, Temporal Archmage"		, { false, "replica" } },
["Ob Nixilis of the Black Oath"]			= { "Ob Nixilis of the Black Oath"	, { ""   , false     } },
["Ob Nixilis of the Black Oath (oversized)"]= { "Ob Nixilis of the Black Oath"	, { false, "replica" } },
["Daretti, Scrap Savant"]					= { "Daretti, Scrap Savant"			, { ""   , false     } },
["Daretti, Scrap Savant (oversized)"]		= { "Daretti, Scrap Savant"			, { false, "replica" } },
["Freyalise, Llanowar’s Fury"]				= { "Freyalise, Llanowar’s Fury"	, { ""   , false     } },
["Freyalise, Llanowar’s Fury (oversized)"]	= { "Freyalise, Llanowar’s Fury"	, { false, "replica" } },
--TODO [814] "Commander 2014 Edition" tokens are double sided, but MA treats them as 2 seperate objects. expect fails until a solution is found.
	},
	foiltweak= {
["Nahiri, the Lithomancer (oversized)"]			= { foil = true },
["Teferi, Temporal Archmage (oversized)"]		= { foil = true },
["Ob Nixilis of the Black Oath (oversized)"]	= { foil = true },
["Daretti, Scrap Savant (oversized)"]			= { foil = true },
["Freyalise, Llanowar’s Fury (oversized)"]		= { foil = true },
	},
},
[812] = { name="Duel Decks: Speed vs. Cunning",
	tla="DDN",
	foil="n",
	cardcount={ reg=81, tok=1, nontrad=0, repl=0},
	variants={
["Plains"] 						= { "Plains" 	, { 1    , 2    , 3    , 4     } },
["Island"] 						= { "Island" 	, { 1    , 2    , 3     } },
["Swamp"] 						= { "Swamp"		, { 1    , 2    , 3     } },
["Mountain"]					= { "Mountain" 	, { 1    , 2    , 3    , 4     } },
["Plains (38)"]					= { "Plains" 	, { 1    , false, false, false } },
["Plains (79)"]					= { "Plains" 	, { false, 2    , false, false } },
["Plains (80)"]					= { "Plains" 	, { false, false, 3    , false } },
["Plains (81)"]					= { "Plains" 	, { false, false, false, 4     } },
["Mountain (35)"]				= { "Mountain" 	, { 1    , false, false, false } },
["Mountain (36)"]				= { "Mountain" 	, { false, 2    , false, false } },
["Mountain (37)"]				= { "Mountain" 	, { false, false, 3    , false } },
["Mountain (78)"]				= { "Mountain" 	, { false, false, false, 4     } },
["Swamp (39)"]					= { "Swamp" 	, { 1    , false, false } },
["Swamp (40)"]					= { "Swamp" 	, { false, 2    , false } },
["Swamp (41)"]					= { "Swamp" 	, { false, false, 3     } },
["Island (75)"]					= { "Island" 	, { 1    , false, false } },
["Island (76)"]					= { "Island" 	, { false, 2    , false } },
["Island (77)"]					= { "Island" 	, { false, false, 3     } },
	},
	foiltweak={
["Arcanis the Omnipotent"]		= { foil = true},
["Zurgo Helmsmasher"]			= { foil = true},
	},
},
[811] = { name="Magic 2015 Clash Pack",
	tla="CP1",
	foilonly=true,
	cardcount={ reg=6, tok=0, nontrad=0, repl=0},
},
[810] = { name="Modern Event Deck 2014",
	tla="MD1",
	foil="n",
	cardcount={ reg=26, tok=3, nontrad=0, repl=0},
},
[809] = { name="From the Vault: Annihilation",
	tla="V14",
	foilonly=true,
	cardcount={ reg=15, tok=0, nontrad=0, repl=0 },
},
[807] = { name="Conspiracy",
	tla="CNS",
	foil="y",
	cardcount={ reg=197, tok=9, nontrad=13, repl=0 },
	variants={
["Muzzio's Preparations"]		= { "Muzzio's Preparations"		, { "Nontrad" } },
["Unexpected Potential"]		= { "Unexpected Potential"		, { "Nontrad" } },
["Sentinel Dispatch"]			= { "Sentinel Dispatch"			, { "Nontrad" } },
["Power Play"]					= { "Power Play"				, { "Nontrad" } },
["Iterative Analysis"]			= { "Iterative Analysis"		, { "Nontrad" } },
["Double Stroke"]				= { "Double Stroke"				, { "Nontrad" } },
["Advantageous Proclamation"]	= { "Advantageous Proclamation"	, { "Nontrad" } },
["Secret Summoning"]			= { "Secret Summoning"			, { "Nontrad" } },
["Worldknit"]					= { "Worldknit"					, { "Nontrad" } },
["Secrets of Paradise"]			= { "Secrets of Paradise"		, { "Nontrad" } },
["Backup Plan"]					= { "Backup Plan"				, { "Nontrad" } },
["Immediate Action"]			= { "Immediate Action"			, { "Nontrad" } },
["Brago's Favor"]				= { "Brago's Favor"				, { "Nontrad" } },
	},
},
[805] = { name="Duel Decks: Jace vs. Vraska",
	tla="DDM",
	foil="n",
	cardcount={ reg=88, tok=1, nontrad=0, repl=0 },
	variants={
["Island"] 						= { "Island" 	, { 1    , 2    , 3    , 4    , 5     } },
["Swamp"] 						= { "Swamp"		, { 1    , 2    , 3    , 4    , 5     } },
["Forest"] 						= { "Forest" 	, { 1    , 2    , 3    , 4    , 5     } },
["Island (37)"]					= { "Island"	, { 1    , false, false, false, false } },
["Island (38)"]					= { "Island"	, { false, 2    , false, false, false } },
["Island (39)"]					= { "Island"	, { false, false, 3    , false, false } },
["Island (40)"]					= { "Island"	, { false, false, false, 4    , false } },
["Island (41)"]					= { "Island"	, { false, false, false, false, 5     } },
["Swamp (79)"]					= { "Swamp" 	, { 1    , false, false, false, false } },
["Swamp (80)"]					= { "Swamp" 	, { false, 2    , false, false, false } },
["Swamp (81)"]					= { "Swamp" 	, { false, false, 3    , false, false } },
["Swamp (82)"]					= { "Swamp" 	, { false, false, false, 4    , false } },
["Swamp (83)"]					= { "Swamp" 	, { false, false, false, false, 5     } },
["Forest (84)"]					= { "Forest"	, { 1    , false, false, false, false } },
["Forest (85)"]					= { "Forest"	, { false, 2    , false, false, false } },
["Forest (86)"]					= { "Forest"	, { false, false, 3    , false, false } },
["Forest (87)"]					= { "Forest"	, { false, false, false, 4    , false } },
["Forest (88)"]					= { "Forest"	, { false, false, false, false, 5     } }
	},
	foiltweak={
["Jace, Architect of Thought"]	= { foil = true},
["Vraska the Unseen"]			= { foil = true},
	},
},
[804] = { name="Challenge Deck: Battle the Horde",
	tla="CD2",
	foil="n",
	cardcount={ reg=0, tok=0, nontrad=15, repl=0 },
},
[803] = { name="Challenge Deck: Face the Hydra",
	tla="CD1",
	foil="n",
	cardcount={ reg=0, tok=0, nontrad=15, repl=0 },
},
[801] = { name="Commander 2013 Edition",
	tla="C13",
	foil="n",--15 oversized are foilonly
	cardcount={ reg=356, tok=0, nontrad=0, repl=15 },
	variants={
["Plains"] 						= { "Plains"	, { 1    , 2    , 3    , 4     } },
["Island"] 						= { "Island" 	, { 1    , 2    , 3    , 4     } },
["Swamp"] 						= { "Swamp"		, { 1    , 2    , 3    , 4     } },
["Mountain"] 					= { "Mountain"	, { 1    , 2    , 3    , 4     } },
["Forest"] 						= { "Forest" 	, { 1    , 2    , 3    , 4     } },
["Plains (337)"]				= { "Plains"	, { 1    , false, false, false } }, 
["Plains (338)"]				= { "Plains"	, { false, 2    , false, false } },
["Plains (339)"]				= { "Plains"	, { false, false, 3    , false } },
["Plains (340)"]				= { "Plains"	, { false, false, false, 4     } },
["Island (341)"]				= { "Island"	, { 1    , false, false, false } },
["Island (342)"]				= { "Island"	, { false, 2    , false, false } },
["Island (343)"]				= { "Island"	, { false, false, 3    , false } },
["Island (344)"]				= { "Island"	, { false, false, false, 4     } },
["Swamp (345)"]					= { "Swamp"		, { 1    , false, false, false } },
["Swamp (346)"]					= { "Swamp"		, { false, 2    , false, false } },
["Swamp (347)"]					= { "Swamp"		, { false, false, 3    , false } },
["Swamp (348)"]					= { "Swamp"		, { false, false, false, 4     } },
["Mountain (349)"]				= { "Mountain"	, { 1    , false, false, false } },
["Mountain (350)"]				= { "Mountain"	, { false, 2    , false, false } },
["Mountain (351)"]				= { "Mountain"	, { false, false, 3    , false } },
["Mountain (352)"]				= { "Mountain"	, { false, false, false, 4     } },
["Forest (353)"]				= { "Forest"	, { 1    , false, false, false } },
["Forest (354)"]				= { "Forest"	, { false, 2    , false, false } },
["Forest (355)"]				= { "Forest"	, { false, false, 3    , false } },
["Forest (356)"]				= { "Forest"	, { false, false, false, 4     } },
["Derevi, Empyrial Tactician"]				= { "Derevi, Empyrial Tactician"	, { ""   , false     } },
["Derevi, Empyrial Tactician (oversized)"]	= { "Derevi, Empyrial Tactician"	, { false, "replica" } },
["Gahiji, Honored One"]						= { "Gahiji, Honored One"			, { ""   , false     } },
["Gahiji, Honored One (oversized)"]			= { "Gahiji, Honored One"			, { false, "replica" } },
["Jeleva, Nephalia’s Scourge"]				= { "Jeleva, Nephalia’s Scourge"	, { ""   , false     } },
["Jeleva, Nephalia’s Scourge (oversized)"]	= { "Jeleva, Nephalia’s Scourge"	, { false, "replica" } },
["Marath, Will of the Wild"]				= { "Marath, Will of the Wild"		, { ""   , false     } },
["Marath, Will of the Wild (oversized)"]	= { "Marath, Will of the Wild"		, { false, "replica" } },
["Mayael the Anima"]						= { "Mayael the Anima"				, { ""   , false     } },
["Mayael the Anima (oversized)"]			= { "Mayael the Anima"				, { false, "replica" } },
["Nekusar, the Mindrazer"]					= { "Nekusar, the Mindrazer"		, { ""   , false     } },
["Nekusar, the Mindrazer (oversized)"]		= { "Nekusar, the Mindrazer"		, { false, "replica" } },
["Oloro, Ageless Ascetic"]					= { "Oloro, Ageless Ascetic"		, { ""   , false     } },
["Oloro, Ageless Ascetic (oversized)"]		= { "Oloro, Ageless Ascetic"		, { false, "replica" } },
["Prossh, Skyraider of Kher"]				= { "Prossh, Skyraider of Kher"		, { ""   , false     } },
["Prossh, Skyraider of Kher (oversized)"]	= { "Prossh, Skyraider of Kher"		, { false, "replica" } },
["Roon of the Hidden Realm"]				= { "Roon of the Hidden Realm"		, { ""   , false     } },
["Roon of the Hidden Realm (oversized)"]	= { "Roon of the Hidden Realm"		, { false, "replica" } },
["Rubinia Soulsinger"]						= { "Rubinia Soulsinger"			, { ""   , false     } },
["Rubinia Soulsinger (oversized)"]			= { "Rubinia Soulsinger"			, { false, "replica" } },
["Sek’Kuar, Deathkeeper"]					= { "Sek’Kuar, Deathkeeper"			, { ""   , false     } },
["Sek’Kuar, Deathkeeper (oversized)"]		= { "Sek’Kuar, Deathkeeper"			, { false, "replica" } },
["Sharuum the Hegemon"]						= { "Sharuum the Hegemon"			, { ""   , false     } },
["Sharuum the Hegemon (oversized)"]			= { "Sharuum the Hegemon"			, { false, "replica" } },
["Shattergang Brothers"]					= { "Shattergang Brothers"			, { ""   , false     } },
["Shattergang Brothers (oversized)"]		= { "Shattergang Brothers"			, { false, "replica" } },
["Sydri, Galvanic Genius"]					= { "Sydri, Galvanic Genius"		, { ""   , false     } },
["Sydri, Galvanic Genius (oversized)"]		= { "Sydri, Galvanic Genius"		, { false, "replica" } },
["Thraximundar"]							= { "Thraximundar"					, { ""   , false     } },
["Thraximundar (oversized)"]				= { "Thraximundar"					, { false, "replica" } },
["Derevi, Himmlische Taktikerin"]				= { "Derevi, Himmlische Taktikerin"	, { ""   , false     } },
["Derevi, Himmlische Taktikerin (oversized)"]	= { "Derevi, Himmlische Taktikerin"	, { false, "replica" } },
["Gahiji der Verehrte"]							= { "Gahiji der Verehrte"			, { ""   , false     } },
["Gahiji der Verehrte (oversized)"]				= { "Gahiji der Verehrte"			, { false, "replica" } },
["Jeleva, Nefalens Geißel"]						= { "Jeleva, Nefalens Geißel"		, { ""   , false     } },
["Jeleva, Nefalens Geißel (oversized)"]			= { "Jeleva, Nefalens Geißel"		, { false, "replica" } },
["Marath, Wille der Wildnis"]					= { "Marath, Wille der Wildnis"		, { ""   , false     } },
["Marath, Wille der Wildnis (oversized)"]		= { "Marath, Wille der Wildnis"		, { false, "replica" } },
["Mayael die Anima"]							= { "Mayael die Anima"				, { ""   , false     } },
["Mayael die Anima (oversized)"]				= { "Mayael die Anima"				, { false, "replica" } },
["Nekusar, der Gedankenreißer"]					= { "Nekusar, der Gedankenreißer"	, { ""   , false     } },
["Nekusar, der Gedankenreißer (oversized)"]		= { "Nekusar, der Gedankenreißer"	, { false, "replica" } },
["Oloro, der zeitlose Asket"]					= { "Oloro, der zeitlose Asket"		, { ""   , false     } },
["Oloro, der zeitlose Asket (oversized)"]		= { "Oloro, der zeitlose Asket"		, { false, "replica" } },
["Prossh, Himmelsjäger von Kher"]				= { "Prossh, Himmelsjäger von Kher"	, { ""   , false     } },
["Prossh, Himmelsjäger von Kher (oversized)"]	= { "Prossh, Himmelsjäger von Kher"	, { false, "replica" } },
["Roon aus dem Verborgenen Reich"]				= { "Roon aus dem Verborgenen Reich", { ""   , false     } },
["Roon aus dem Verborgenen Reich (oversized)"]	= { "Roon aus dem Verborgenen Reich", { false, "replica" } },
["Rubinia Seelensang"]							= { "Rubinia Seelensang"			, { ""   , false     } },
["Rubinia Seelensang (oversized)"]				= { "Rubinia Seelensang"			, { false, "replica" } },
["Sek’Kuar, der Todesbewahrer"]					= { "Sek’Kuar, der Todesbewahrer"	, { ""   , false     } },
["Sek’Kuar, der Todesbewahrer (oversized)"]		= { "Sek’Kuar, der Todesbewahrer"	, { false, "replica" } },
["Sharuum Sphinx-Hegemon"]						= { "Sharuum Sphinx-Hegemon"		, { ""   , false     } },
["Sharuum Sphinx-Hegemon (oversized)"]			= { "Sharuum Sphinx-Hegemon"		, { false, "replica" } },
["Sprengbandenbrüder"]							= { "Sprengbandenbrüder"			, { ""   , false     } },
["Sprengbandenbrüder (oversized)"]				= { "Sprengbandenbrüder"			, { false, "replica" } },
["Sydri, Elektrisierendes Genie"]				= { "Sydri, Elektrisierendes Genie"	, { ""   , false     } },
["Sydri, Elektrisierendes Genie (oversized)"]	= { "Sydri, Elektrisierendes Genie"	, { false, "replica" } },
	},
	foiltweak= {
["Derevi, Empyrial Tactician (oversized)"]	= { foil = true },
["Gahiji, Honored One (oversized)"]			= { foil = true },
["Jeleva, Nephalia’s Scourge (oversized)"]	= { foil = true },
["Marath, Will of the Wild (oversized)"]	= { foil = true },
["Mayael the Anima (oversized)"]			= { foil = true },
["Nekusar, the Mindrazer (oversized)"]		= { foil = true },
["Oloro, Ageless Ascetic (oversized)"]		= { foil = true },
["Prossh, Skyraider of Kher (oversized)"]	= { foil = true },
["Roon of the Hidden Realm (oversized)"]	= { foil = true },
["Rubinia Soulsinger (oversized)"]			= { foil = true },
["Sek’Kuar, Deathkeeper (oversized)"]		= { foil = true },
["Sharuum the Hegemon (oversized)"]			= { foil = true },
["Shattergang Brothers (oversized)"]		= { foil = true },
["Sydri, Galvanic Genius (oversized)"]		= { foil = true },
["Thraximundar (oversized)"]				= { foil = true },
["Derevi, Himmlische Taktikerin (oversized)"]	= { foil = true },
["Gahiji der Verehrte (oversized)"]				= { foil = true },
["Jeleva, Nefalens Geißel (oversized)"]			= { foil = true },
["Marath, Wille der Wildnis (oversized)"]		= { foil = true },
["Mayael die Anima (oversized)"]				= { foil = true },
["Nekusar der Gedankenreißer (oversized)"]		= { foil = true },
["Oloro, der zeitlose Asket (oversized)"]		= { foil = true },
["Prossh, Himmelsjäger von Kher (oversized)"]	= { foil = true },
["Roon aus dem Verborgenen Reich (oversized)"]	= { foil = true },
["Rubinia Seelensang (oversized)"]				= { foil = true },
["Sek'Kuar, der Todesbewahrer (oversized)"]		= { foil = true },
["Sharuum, Sphinx-Hegemon (oversized)"]			= { foil = true },
["Sprengbandenbrüder (oversized)"]				= { foil = true },
["Sydri, Elektrisierendes Genie (oversized)"]	= { foil = true },
	},
},
[799] = { name="Duel Decks: Heroes vs. Monsters",
	tla="DDL",
	foil="n",
	cardcount={ reg=81, tok=2, nontrad=0, repl=0 }, 
	variants={
["Plains"] 						= { "Plains"	, { 1    , 2    , 3    , 4     } },
["Mountain"] 					= { "Mountain"	, { 1    , 2    , 3    , 4     , 5    , 6    , 7    , 8    } },
["Forest"] 						= { "Forest" 	, { 1    , 2    , 3    , 4     } },
["Mountain (35)"]				= { "Mountain"	, { 1    , false, false, false, false, false, false, false } },
["Mountain (36)"]				= { "Mountain"	, { false, 2    , false, false, false, false, false, false } },
["Mountain (37)"]				= { "Mountain"	, { false, false, 3    , false, false, false, false, false } },
["Mountain (38)"]				= { "Mountain"	, { false, false, false, 4    , false, false, false, false } },
["Plains (39)"]					= { "Plains"	, { 1    , false, false, false } }, 
["Plains (40)"]					= { "Plains"	, { false, 2    , false, false } },
["Plains (41)"]					= { "Plains"	, { false, false, 3    , false } },
["Plains (42)"]					= { "Plains"	, { false, false, false, 4     } },
["Mountain (74)"]				= { "Mountain"	, { false, false, false, false, 5    , false, false, false } },
["Mountain (75)"]				= { "Mountain"	, { false, false, false, false, false, 6    , false, false } },
["Mountain (76)"]				= { "Mountain"	, { false, false, false, false, false, false, 7    , false } },
["Mountain (77)"]				= { "Mountain"	, { false, false, false, false, false, false, false, 8     } },
["Forest (78)"]					= { "Forest"	, { 1    , false, false, false } },
["Forest (79)"]					= { "Forest"	, { false, 2    , false, false } },
["Forest (80)"]					= { "Forest"	, { false, false, 3    , false } },
["Forest (81)"]					= { "Forest"	, { false, false, false, 4     } },
	},
	foiltweak={
["Sun Titan"]					= { foil = false},
["Polukranos, World Eater"]		= { foil = false},
	},
},
[798] = { name="From the Vault: Twenty",
	tla="V13",
	foilonly=true,
	cardcount={ reg=20, tok=0, nontrad=0, repl=0 }, 
},
[796] = { name="Modern Masters",
	tla="MMA",
	cardcount={ reg = 229, tok = 16 },
},
[794] = { name="Duel Decks: Sorin vs. Tibalt",
	tla="DDK",
	foil="n",
	cardcount={ reg=80, tok=1, nontrad=0, repl=0 }, 
	variants={
["Plains"] 						= { "Plains"	, { 1    , 2    , 3 } },
["Swamp"] 						= { "Swamp"		, { 1    , 2    , 3    , 4    , 5    , 6     } },
["Mountain"] 					= { "Mountain"	, { 1    , 2    , 3 } },
["Plains (38)"]					= { "Plains"	, { 1    , false, false } },
["Plains (39)"]					= { "Plains"	, { false, 2    , false } },
["Plains (40)"]					= { "Plains"	, { false, false, 3     } },
["Swamp (35)"]					= { "Swamp"		, { 1    , false, false, false, false, false } },
["Swamp (36)"] 					= { "Swamp"		, { false, 2    , false, false, false, false } },
["Swamp (37)"] 					= { "Swamp"		, { false, false, 3    , false, false, false } },
["Swamp (78)"] 					= { "Swamp"		, { false, false, false, 4    , false, false } },
["Swamp (79)"] 					= { "Swamp"		, { false, false, false, false, 5    , false } },
["Swamp (80)"] 					= { "Swamp"		, { false, false, false, false, false, 6     } },
["Mountain (75)"]				= { "Mountain"	, { 1    , false, false } },
["Mountain (76)"]				= { "Mountain"	, { false, 2    , false } },
["Mountain (77)"]				= { "Mountain"	, { false, false, 3     } },
	},
	foiltweak={
["Sorin, Lord of Innistrad"]		= { foil = true},
["Tibalt, the Fiend-Blooded"]		= { foil = true},
	},
},
[792] = { name="Commander’s Arsenal",
	tla="CM1",
	foilonly=true,
	cardcount={ reg=18, tok=0, nontrad=0, repl=10 }, 
},
[790] = { name="Duel Decks: Izzet vs. Golgari",
	tla="DDJ",
	foil="n",
	cardcount={ reg=90, tok=1, nontrad=0, repl=0 }, 
	variants={
["Island"] 						= { "Island"	, { 1    , 2    , 3    , 4     } },
["Swamp"] 						= { "Swamp"		, { 1    , 2    , 3    , 4     } },
["Mountain"] 					= { "Mountain"	, { 1    , 2    , 3    , 4     } },
["Forest"] 						= { "Forest"	, { 1    , 2    , 3    , 4     } },
["Island (37)"]					= { "Island"	, { 1    , false, false, false } }, 
["Island (38)"]					= { "Island"	, { false, 2    , false, false } },
["Island (39)"]					= { "Island"	, { false, false, 3    , false } },
["Island (40)"]					= { "Island"	, { false, false, false, 4     } },
["Swamp (83)"]					= { "Swamp"		, { 1    , false, false, false } }, 
["Swamp (84)"]					= { "Swamp"		, { false, 2    , false, false } },
["Swamp (85)"]					= { "Swamp"		, { false, false, 3    , false } },
["Swamp (86)"]					= { "Swamp"		, { false, false, false, 4     } },
["Mountain (41)"]				= { "Mountain"	, { 1    , false, false, false } }, 
["Mountain (42)"]				= { "Mountain"	, { false, 2    , false, false } },
["Mountain (43)"]				= { "Mountain"	, { false, false, 3    , false } },
["Mountain (44)"]				= { "Mountain"	, { false, false, false, 4     } },
["Forest (87)"]					= { "Forest"	, { 1    , false, false, false } }, 
["Forest (88)"]					= { "Forest"	, { false, 2    , false, false } },
["Forest (89)"]					= { "Forest"	, { false, false, 3    , false } },
["Forest (90)"]					= { "Forest"	, { false, false, false, 4     } },
	},
	foiltweak={
["Niv-Mizzet, the Firemind"]		= { foil = true},
["Jarad, Golgari Lich Lord"]		= { foil = true},
	},
},
[789] = { name="From the Vault: Realms",
	tla="V12",
	foilonly=true,
	cardcount={ reg=15, tok=0, nontrad=0, repl=0 }, 
},
[787] = { name="Planechase 2012 Edition",
	tla="PC2",
	foil="n",
	cardcount={ reg=156, tok=0, nontrad=40, repl=0 }, 
	variants={
["Plains"] 						= { "Plains"	, { 1    , 2    , 3    , 4    , 5     } },
["Island"] 						= { "Island" 	, { 1    , 2    , 3    , 4    , 5     } },
["Swamp"] 						= { "Swamp"		, { 1    , 2    , 3    , 4    , 5     } },
["Mountain"] 					= { "Mountain"	, { 1    , 2    , 3    , 4     } },
["Forest"] 						= { "Forest" 	, { 1    , 2    , 3    , 4    , 5    , 6     } },
["Plains (132)"]				= { "Plains"	, { 1    , false, false, false, false } },
["Plains (133)"]				= { "Plains"	, { false, 2    , false, false, false } },
["Plains (134)"]				= { "Plains"	, { false, false, 3    , false, false } },
["Plains (135)"]				= { "Plains"	, { false, false, false, 4    , false } },
["Plains (136)"]				= { "Plains"	, { false, false, false, false, 5     } },
["Island (137)"]				= { "Island"	, { 1    , false, false, false, false } },
["Island (138)"]				= { "Island"	, { false, 2    , false, false, false } },
["Island (139)"] 				= { "Island"	, { false, false, 3    , false, false } },
["Island (140)"]				= { "Island"	, { false, false, false, 4    , false } },
["Island (141)"]				= { "Island"	, { false, false, false, false, 5     } },
["Swamp (142)"]					= { "Swamp" 	, { 1    , false, false, false, false } },
["Swamp (143)"]					= { "Swamp" 	, { false, 2    , false, false, false } },
["Swamp (144)"]					= { "Swamp" 	, { false, false, 3    , false, false } },
["Swamp (145)"]					= { "Swamp" 	, { false, false, false, 4    , false } },
["Swamp (146)"]					= { "Swamp" 	, { false, false, false, false, 5     } },
["Mountain (147)"]				= { "Mountain"	, { 1    , false, false, false } },
["Mountain (148)"]				= { "Mountain"	, { false, 2    , false, false } },
["Mountain (149)"]				= { "Mountain"	, { false, false, 3    , false } },
["Mountain (150)"]				= { "Mountain"	, { false, false, false, 4     } },
["Forest (151)"]				= { "Forest"	, { 1    , false, false, false, false, false } },
["Forest (152)"]				= { "Forest"	, { false, 2    , false, false, false, false } },
["Forest (153)"]				= { "Forest"	, { false, false, 3    , false, false, false } },
["Forest (154)"]				= { "Forest"	, { false, false, false, 4    , false, false } },
["Forest (155)"]				= { "Forest"	, { false, false, false, false, 5    , false } },
["Forest (156)"]				= { "Forest"	, { false, false, false, false, false, 6     } },
["Akoum"]						= { "Akoum" 					, {  "Nontrad" } },
["Aretopolis"]					= { "Aretopolis" 				, {  "Nontrad" } },
["Astral Arena"]				= { "Astral Arena" 				, {  "Nontrad" } },
["Bloodhill Bastion"]			= { "Bloodhill Bastion" 		, {  "Nontrad" } },
["Chaotic Æther"]				= { "Chaotic Æther" 			, {  "Nontrad" } },
["Edge of Malacol"]				= { "Edge of Malacol" 			, {  "Nontrad" } },
["Furnace Layer"]				= { "Furnace Layer" 			, {  "Nontrad" } },
["Gavony"]						= { "Gavony" 					, {  "Nontrad" } },
["Glen Elendra"]				= { "Glen Elendra" 				, {  "Nontrad" } },
["Grand Ossuary"]				= { "Grand Ossuary" 			, {  "Nontrad" } },
["Grove of the Dreampods"]		= { "Grove of the Dreampods" 	, {  "Nontrad" } },
["Hedron Fields of Agadeem"]	= { "Hedron Fields of Agadeem"	, {  "Nontrad" } },
["Interplanar Tunnel"]			= { "Interplanar Tunnel" 		, {  "Nontrad" } },
["Jund"]						= { "Jund" 						, {  "Nontrad" } },
["Kessig"]						= { "Kessig" 					, {  "Nontrad" } },
["Kharasha Foothills"]			= { "Kharasha Foothills" 		, {  "Nontrad" } },
["Kilnspire District"]			= { "Kilnspire District" 		, {  "Nontrad" } },
["Lair of the Ashen Idol"]		= { "Lair of the Ashen Idol" 	, {  "Nontrad" } },
["Morphic Tide"]				= { "Morphic Tide" 				, {  "Nontrad" } },
["Mount Keralia"]				= { "Mount Keralia" 			, {  "Nontrad" } },
["Mutual Epiphany"]				= { "Mutual Epiphany" 			, {  "Nontrad" } },
["Nephalia"]					= { "Nephalia" 					, {  "Nontrad" } },
["Norn’s Dominion"]				= { "Norn’s Dominion" 			, {  "Nontrad" } },
["Onakke Catacomb"]				= { "Onakke Catacomb" 			, {  "Nontrad" } },
["Orochi Colony"]				= { "Orochi Colony" 			, {  "Nontrad" } },
["Orzhova"]						= { "Orzhova" 					, {  "Nontrad" } },
["Planewide Disaster"]			= { "Planewide Disaster" 		, {  "Nontrad" } },
["Prahv"]						= { "Prahv" 					, {  "Nontrad" } },
["Quicksilver Sea"]				= { "Quicksilver Sea" 			, {  "Nontrad" } },
["Reality Shaping"]				= { "Reality Shaping" 			, {  "Nontrad" } },
["Spatial Merging"]				= { "Spatial Merging" 			, {  "Nontrad" } },
["Selesnya Loft Gardens"]		= { "Selesnya Loft Gardens" 	, {  "Nontrad" } },
["Stensia"]						= { "Stensia" 					, {  "Nontrad" } },
["Takenuma"]					= { "Takenuma" 					, {  "Nontrad" } },
["Talon Gates"]					= { "Talon Gates" 				, {  "Nontrad" } },
["The Zephyr Maze"]				= { "The Zephyr Maze" 			, {  "Nontrad" } },
["Time Distortion"]				= { "Time Distortion" 			, {  "Nontrad" } },
["Trail of the Mage-Rings"]		= { "Trail of the Mage-Rings" 	, {  "Nontrad" } },
["Truga Jungle"]				= { "Truga Jungle" 				, {  "Nontrad" } },
["Windriddle Palaces"]			= { "Windriddle Palaces" 		, {  "Nontrad" } },
	},
},
[785] = { name="Duel Decks: Venser vs. Koth",
	tla="DDI",
	foil="n",
	cardcount={ reg=77, tok=2, nontrad=0, repl=0 }, 
	variants={
["Plains"] 						= { "Plains"	, { 1    , 2    , 3 } },
["Island"] 						= { "Island"	, { 1    , 2    , 3 } },
["Mountain"] 					= { "Mountain"	, { 1    , 2    , 3    , 4     } },
["Plains (38)"]					= { "Plains"	, { 1    , false, false } },
["Plains (39)"]					= { "Plains"	, { false, 2    , false } },
["Plains (40)"]					= { "Plains"	, { false, false, 3     } },
["Island (41)"]					= { "Island"	, { 1    , false, false } },
["Island (42)"]					= { "Island"	, { false, 2    , false } },
["Island (43)"]					= { "Island"	, { false, false, 3     } },
["Mountain (74)"]				= { "Mountain"	, { 1    , false, false, false } }, 
["Mountain (75)"]				= { "Mountain"	, { false, 2    , false, false } },
["Mountain (76)"]				= { "Mountain"	, { false, false, 3    , false } },
["Mountain (77)"]				= { "Mountain"	, { false, false, false, 4     } },
	},
	foiltweak={
["Venser, the Sojourner"]		= { foil = true},
["Koth of the Hammer"]			= { foil = true},
	},
},
[783] = { name="Premium Deck Series: Graveborn",
	tla="PD3",
	foilonly=true,
	cardcount={ reg=30, tok=0, nontrad=0, repl=0 }, 
	variants={
["Swamp"] 						= { "Swamp"		, { 1    , 2    , 3    , 4     } },
["Swamp (27)"]					= { "Swamp"		, { 1    , false, false, false } }, 
["Swamp (28)"]					= { "Swamp"		, { false, 2    , false, false } },
["Swamp (29)"]					= { "Swamp"		, { false, false, 3    , false } },
["Swamp (30)"]					= { "Swamp"		, { false, false, false, 4     } },
	},
},
[781] = { name="Duel Decks: Ajani vs. Nicol Bolas",
	tla="DDH",
	foil="n",
	cardcount={ reg=80, tok=2, nontrad=0, repl=0 }, 
	variants={
["Swamp"] 						= { "Swamp"		, { 1    , 2     } },
["Mountain"] 					= { "Mountain"	, { 1    , 2     } },
["Forest"] 						= { "Forest"	, { 1    , 2     } },
["Plains (40)"]					= { "Plains"	, nil },
["Island (79)"]					= { "Island"	, nil },
["Swamp (77)"] 					= { "Swamp"		, { 1    , false } },
["Swamp (78)"] 					= { "Swamp"		, { false, 2     } },
["Mountain (41)"]				= { "Mountain"	, { 1    , false } },
["Mountain (80)"]				= { "Mountain"	, { false, 2     } },
["Forest (38)"] 				= { "Forest"	, { 1    , false } },
["Forest (39)"] 				= { "Forest"	, { false, 2     } },
	},
	foiltweak={
["Ajani Vengeant"]				= { foil = true},
["Nicol Bolas, Planeswalker"]	= { foil = true},
	},
},
[780] = { name="From the Vault: Legends",
	tla="V11",
	foilonly=true,
	cardcount={ reg=15, tok=0, nontrad=0, repl=0 }, 
},
[778] = { name="Magic: The Gathering Commander",
	tla="CMD",
	foil="n", -- 15 oversized are foilonly
	cardcount={ reg=318, tok=0, nontrad=0, repl=15 },
	variants={
["Plains"] 						= { "Plains"	, { 1    , 2    , 3    , 4     } },
["Island"] 						= { "Island" 	, { 1    , 2    , 3    , 4     } },
["Swamp"] 						= { "Swamp"		, { 1    , 2    , 3    , 4     } },
["Mountain"] 					= { "Mountain"	, { 1    , 2    , 3    , 4     } },
["Forest"] 						= { "Forest" 	, { 1    , 2    , 3    , 4     } },
["Plains (299)"]				= { "Plains"	, { 1    , false, false, false } }, 
["Plains (300)"]				= { "Plains"	, { false, 2    , false, false } },
["Plains (301)"]				= { "Plains"	, { false, false, 3    , false } },
["Plains (302)"]				= { "Plains"	, { false, false, false, 4     } },
["Island (303)"]				= { "Island"	, { 1    , false, false, false } },
["Island (304)"]				= { "Island"	, { false, 2    , false, false } },
["Island (305)"]				= { "Island"	, { false, false, 3    , false } },
["Island (306)"]				= { "Island"	, { false, false, false, 4     } },
["Swamp (307)"]					= { "Swamp"		, { 1    , false, false, false } },
["Swamp (308)"]					= { "Swamp"		, { false, 2    , false, false } },
["Swamp (309)"]					= { "Swamp"		, { false, false, 3    , false } },
["Swamp (310)"]					= { "Swamp"		, { false, false, false, 4     } },
["Mountain (311)"]				= { "Mountain"	, { 1    , false, false, false } },
["Mountain (312)"]				= { "Mountain"	, { false, 2    , false, false } },
["Mountain (313)"]				= { "Mountain"	, { false, false, 3    , false } },
["Mountain (314)"]				= { "Mountain"	, { false, false, false, 4     } },
["Forest (315)"]				= { "Forest"	, { 1    , false, false, false } },
["Forest (316)"]				= { "Forest"	, { false, 2    , false, false } },
["Forest (317)"]				= { "Forest"	, { false, false, 3    , false } },
["Forest (318)"]				= { "Forest"	, { false, false, false, 4     } },
["Animar, Soul of Elements"]				= { "Animar, Soul of Elements"	, { ""   , false     } },
["Animar, Soul of Elements (oversized)"]	= { "Animar, Soul of Elements"	, { false, "replica" } },
["Damia, Sage of Stone"]					= { "Damia, Sage of Stone"		, { ""   , false     } },
["Damia, Sage of Stone (oversized)"]		= { "Damia, Sage of Stone"		, { false, "replica" } },
["Ghave, Guru of Spores"]					= { "Ghave, Guru of Spores"		, { ""   , false     } },
["Ghave, Guru of Spores (oversized)"]		= { "Ghave, Guru of Spores"		, { false, "replica" } },
["Intet, the Dreamer"]						= { "Intet, the Dreamer"		, { ""   , false     } },
["Intet, the Dreamer (oversized)"]			= { "Intet, the Dreamer"		, { false, "replica" } },
["Kaalia of the Vast"]						= { "Kaalia of the Vast"		, { ""   , false     } },
["Kaalia of the Vast (oversized)"]			= { "Kaalia of the Vast"		, { false, "replica" } },
["Karador, Ghost Chieftain"]				= { "Karador, Ghost Chieftain"	, { ""   , false     } },
["Karador, Ghost Chieftain (oversized)"]	= { "Karador, Ghost Chieftain"	, { false, "replica" } },
["Numot, the Devastator"]					= { "Numot, the Devastator"		, { ""   , false     } },
["Numot, the Devastator (oversized)"]		= { "Numot, the Devastator"		, { false, "replica" } },
["Oros, the Avenger"]						= { "Oros, the Avenger"			, { ""   , false     } },
["Oros, the Avenger (oversized)"]			= { "Oros, the Avenger"			, { false, "replica" } },
["Riku of Two Reflections"]					= { "Riku of Two Reflections"	, { ""   , false     } },
["Riku of Two Reflections (oversized)"]		= { "Riku of Two Reflections"	, { false, "replica" } },
["Ruhan of the Fomori"]						= { "Ruhan of the Fomori"		, { ""   , false     } },
["Ruhan of the Fomori (oversized)"]			= { "Ruhan of the Fomori"		, { false, "replica" } },
["Tariel, Reckoner of Souls"]				= { "Tariel, Reckoner of Souls"	, { ""   , false     } },
["Tariel, Reckoner of Souls (oversized)"]	= { "Tariel, Reckoner of Souls"	, { false, "replica" } },
["Teneb, the Harvester"]					= { "Teneb, the Harvester"		, { ""   , false     } },
["Teneb, the Harvester (oversized)"]		= { "Teneb, the Harvester"		, { false, "replica" } },
["The Mimeoplasm"]							= { "The Mimeoplasm"			, { ""   , false     } },
["The Mimeoplasm (oversized)"]				= { "The Mimeoplasm"			, { false, "replica" } },
["Vorosh, the Hunter"]						= { "Vorosh, the Hunter"		, { ""   , false     } },
["Vorosh, the Hunter (oversized)"]			= { "Vorosh, the Hunter"		, { false, "replica" } },
["Zedruu the Greathearted"]					= { "Zedruu the Greathearted"	, { ""   , false     } },
["Zedruu the Greathearted (oversized)"]		= { "Zedruu the Greathearted"	, { false, "replica" } },
	},
	foiltweak= {
["Animar, Soul of Elements (oversized)"]	= { foil = true },
["Damia, Sage of Stone (oversized)"]		= { foil = true },
["Ghave, Guru of Spores (oversized)"]		= { foil = true },
["Intet, the Dreamer (oversized)"]			= { foil = true },
["Kaalia of the Vast (oversized)"]			= { foil = true },
["Karador, Ghost Chieftain (oversized)"]	= { foil = true },
["Numot, the Devastator (oversized)"]		= { foil = true },
["Oros, the Avenger (oversized)"]			= { foil = true },
["Riku of Two Reflections (oversized)"]		= { foil = true },
["Ruhan of the Fomori (oversized)"]			= { foil = true },
["Tariel, Reckoner of Souls (oversized)"]	= { foil = true },
["Teneb, the Harvester (oversized)"]		= { foil = true },
["The Mimeoplasm (oversized)"]				= { foil = true },
["Vorosh, the Hunter (oversized)"]			= { foil = true },
["Zedruu the Greathearted (oversized)"]		= { foil = true },
	},
},
[777] = { name="Duel Decks: Knights vs. Dragons",
	tla="DDG",
	foil="n",
	cardcount={ reg=81, tok=1, nontrad=0, repl=0 }, 
	variants={
["Plains"] 						= { "Plains"	, { 1    , 2    , 3    , 4     } },
["Mountain"] 					= { "Mountain"	, { 1    , 2    , 3    , 4     } },
["Forest"] 						= { "Forest"	, { 1    , 2    , 3    , 4     } },
["Plains (39)"]					= { "Plains"	, { 1    , false, false, false } }, 
["Plains (40)"]					= { "Plains"	, { false, 2    , false, false } },
["Plains (41)"]					= { "Plains"	, { false, false, 3    , false } },
["Plains (42)"]					= { "Plains"	, { false, false, false, 4     } },
["Mountain (78)"]				= { "Mountain"	, { 1    , false, false, false } }, 
["Mountain (79)"]				= { "Mountain"	, { false, 2    , false, false } },
["Mountain (80)"]				= { "Mountain"	, { false, false, 3    , false } },
["Mountain (81)"]				= { "Mountain"	, { false, false, false, 4     } },
["Forest (43)"]					= { "Forest"	, { 1    , false, false, false } }, 
["Forest (44)"]					= { "Forest"	, { false, 2    , false, false } },
["Forest (45)"]					= { "Forest"	, { false, false, 3    , false } },
["Forest (46)"]					= { "Forest"	, { false, false, false, 4     } },
	},
	foiltweak={
["Knight of the Reliquary"]		= { foil = true},
["Bogardan Hellkite"]			= { foil = true},
	},
},
[774] = { name="Premium Deck Series: Fire & Lightning",
	tla="PD2",
	foilonly=true,
	cardcount={ reg=34, tok=0, nontrad=0, repl=0 }, 
	variants={
["Mountain"] 					= { "Mountain"	, { 1    , 2    , 3    , 4     } },
["Mountain (31)"]				= { "Mountain"	, { 1    , false, false, false } }, 
["Mountain (32)"]				= { "Mountain"	, { false, 2    , false, false } },
["Mountain (33)"]				= { "Mountain"	, { false, false, 3    , false } },
["Mountain (34)"]				= { "Mountain"	, { false, false, false, 4     } },
	},
},
[772] = { name="Duel Decks: Elspeth vs. Tezzeret",
	tla="DDF",
	foil="n",
	cardcount={ reg=79, tok=1, nontrad=0, repl=0 }, 
	variants={
["Plains"] 						= { "Plains"	, { 1    , 2    , 3    , 4     } },
["Island"] 						= { "Island"	, { 1    , 2    , 3    , 4     } },
["Mountain"] 					= { "Mountain"	, { 1    , 2    , 3    , 4     } },
["Plains (35)"]					= { "Plains"	, { 1    , false, false, false } },
["Plains (36)"]					= { "Plains"	, { false, 2    , false, false } },
["Plains (37)"]					= { "Plains"	, { false, false, 3    , false } },
["Plains (38)"]					= { "Plains"	, { 1    , false, false, 4     } }, 
["Island (76)"]					= { "Island"	, { 1    , false, false, false } },
["Island (77)"]					= { "Island"	, { false, 2    , false, false } },
["Island (78)"]					= { "Island"	, { false, false, 3    , false } },
["Island (79)"]					= { "Island"	, { 1    , false, false, 4     } }, 
	},
	foiltweak={
["Elspeth, Knight-Errant"]		= { foil = true},
["Tezzeret the Seeker"]			= { foil = true},
	},
},
[771] = { name="From the Vault: Relics",
	tla="V10",
	foilonly=true,
	cardcount={ reg=15, tok=0, nontrad=0, repl=0 }, 
},
[769] = { name="Archenemy",
	tla="ARC",
	foil="n",
	cardcount={ reg=150, tok=0, nontrad=45, repl=0 }, 
	variants={
["Plains"] 						= { "Plains"	, { 1    , 2     } },
["Island"] 						= { "Island" 	, { 1    , 2    , 3     } },
["Swamp"] 						= { "Swamp"		, { 1    , 2    , 3     } },
["Mountain"] 					= { "Mountain"	, { 1    , 2    , 3     } },
["Forest"] 						= { "Forest" 	, { 1    , 2    , 3     } },
["Plains (137)"]				= { "Plains"	, { 1    , false } },
["Plains (138)"]				= { "Plains"	, { false, 2     } },
["Island (139)"]				= { "Island"	, { 1    , false, false } },
["Island (140)"]				= { "Island"	, { false, 2    , false } },
["Island (141)"]				= { "Island"	, { false, false, 3     } },
["Swamp (142)"]					= { "Swamp"		, { 1    , false, false } },
["Swamp (143)"]					= { "Swamp"		, { false, 2    , false } },
["Swamp (144)"]					= { "Swamp"		, { false, false, 3     } },
["Mountain (145)"]				= { "Mountain"	, { 1    , false, false } },
["Mountain (146)"]				= { "Mountain"	, { false, 2    , false } },
["Mountain (147)"]				= { "Mountain"	, { false, false, 3     } },
["Forest (148)"]				= { "Forest"	, { 1    , false, false } },
["Forest (149)"]				= { "Forest"	, { false, 2    , false } },
["Forest (150)"]				= { "Forest"	, { false, false, 3     } },
["A Display of My Dark Power"]		= { "A Display of My Dark Power" 		, { "Nontrad" } },
["All in Good Time"]				= { "All in Good Time" 					, { "Nontrad" } },
["All Shall Smolder in My Wake"]	= { "All Shall Smolder in My Wake" 		, { "Nontrad" } },
["Approach My Molten Realm"]		= { "Approach My Molten Realm" 			, { "Nontrad" } },
["Behold the Power of Destruction"]	= { "Behold the Power of Destruction"	, { "Nontrad" } },
["Choose Your Champion"]			= { "Choose Your Champion" 				, { "Nontrad" } },
["Dance, Pathetic Marionette"]		= { "Dance, Pathetic Marionette" 		, { "Nontrad" } },
["Embrace My Diabolical Vision"]	= { "Embrace My Diabolical Vision" 		, { "Nontrad" } },
["Evil Comes to Fruition"]			= { "Evil Comes to Fruition" 			, { "Nontrad" } },
["Every Hope Shall Vanish"]			= { "Every Hope Shall Vanish" 			, { "Nontrad" } },
["Every Last Vestige Shall Rot"]	= { "Every Last Vestige Shall Rot" 		, { "Nontrad" } },
["Feed the Machine"]				= { "Feed the Machine" 					, { "Nontrad" } },
["I Bask in Your Silent Awe"]		= { "I Bask in Your Silent Awe" 		, { "Nontrad" } },
["I Call on the Ancient Magics"]	= { "I Call on the Ancient Magics" 		, { "Nontrad" } },
["I Delight in Your Convulsions"]	= { "I Delight in Your Convulsions" 	, { "Nontrad" } },
["I Know All, I See All"]			= { "I Know All, I See All" 			, { "Nontrad" } },
["Ignite the Cloneforge!"]			= { "Ignite the Cloneforge!" 			, { "Nontrad" } },
["Into the Earthen Maw"]			= { "Into the Earthen Maw" 				, { "Nontrad" } },
["Introductions Are in Order"]		= { "Introductions Are in Order" 		, { "Nontrad" } },
["Know Naught but Fire"]			= { "Know Naught but Fire" 				, { "Nontrad" } },
["Look Skyward and Despair"]		= { "Look Skyward and Despair" 			, { "Nontrad" } },
["Mortal Flesh Is Weak"]			= { "Mortal Flesh Is Weak" 				, { "Nontrad" } },
["May Civilization Collapse"]		= { "May Civilization Collapse" 		, { "Nontrad" } },
["My Crushing Masterstroke"]		= { "My Crushing Masterstroke" 			, { "Nontrad" } },
["My Genius Knows No Bounds"]		= { "My Genius Knows No Bounds" 		, { "Nontrad" } },
["My Undead Horde Awakens"]			= { "My Undead Horde Awakens" 			, { "Nontrad" } },
["My Wish Is Your Command"]			= { "My Wish Is Your Command" 			, { "Nontrad" } },
["Nature Demands an Offering"]		= { "Nature Demands an Offering" 		, { "Nontrad" } },
["Nature Shields Its Own"]			= { "Nature Shields Its Own" 			, { "Nontrad" } },
["Nothing Can Stop Me Now"]			= { "Nothing Can Stop Me Now" 			, { "Nontrad" } },
["Only Blood Ends Your Nightmares"]	= { "Only Blood Ends Your Nightmares" 	, { "Nontrad" } },
["Realms Befitting My Majesty"]		= { "Realms Befitting My Majesty" 		, { "Nontrad" } },
["Rotted Ones, Lay Siege"]			= { "Rotted Ones, Lay Siege" 			, { "Nontrad" } },
["Roots of All Evil"]				= { "Roots of All Evil" 				, { "Nontrad" } },
["Surrender Your Thoughts"]			= { "Surrender Your Thoughts" 			, { "Nontrad" } },
["The Dead Shall Serve"]			= { "The Dead Shall Serve" 				, { "Nontrad" } },
["The Fate of the Flammable"]		= { "The Fate of the Flammable" 		, { "Nontrad" } },
["The Iron Guardian Stirs"]			= { "The Iron Guardian Stirs" 			, { "Nontrad" } },
["The Pieces Are Coming Together"]	= { "The Pieces Are Coming Together" 	, { "Nontrad" } },
["The Very Soil Shall Shake"]		= { "The Very Soil Shall Shake" 		, { "Nontrad" } },
["Tooth, Claw, and Tail"]			= { "Tooth, Claw, and Tail" 			, { "Nontrad" } },
["Which of You Burns Brightest?"]	= { "Which of You Burns Brightest?" 	, { "Nontrad" } },
["Your Fate Is Thrice Sealed"]		= { "Your Fate Is Thrice Sealed" 		, { "Nontrad" } },
["Your Puny Minds Cannot Fathom"]	= { "Your Puny Minds Cannot Fathom" 	, { "Nontrad" } },
["Your Will Is Not Your Own"]		= { "Your Will Is Not Your Own" 		, { "Nontrad" } },
	},
},
[768] = { name="Duels of the Planeswalkers",
	tla="DPA",
	foil="n",
	cardcount={ reg=113, tok=0, nontrad=0, repl=0 }, 
	variants={
["Island"] 						= { "Island" 	, { 1    , 2    , 3    , 4     } },
["Swamp"] 						= { "Swamp"		, { 1    , 2    , 3    , 4     } },
["Mountain"] 					= { "Mountain"	, { 1    , 2    , 3    , 4     } },
["Forest"] 						= { "Forest" 	, { 1    , 2    , 3    , 4     } },
["Island (98)"]					= { "Island"	, { 1    , false, false, false } },
["Island (99)"]					= { "Island"	, { false, 2    , false, false } },
["Island (100)"]				= { "Island"	, { false, false, 3    , false } },
["Island (101)"]				= { "Island"	, { false, false, false, 4     } },
["Swamp (102)"]					= { "Swamp"		, { 1    , false, false, false } },
["Swamp (103)"]					= { "Swamp"		, { false, 2    , false, false } },
["Swamp (104)"]					= { "Swamp"		, { false, false, 3    , false } },
["Swamp (105)"]					= { "Swamp"		, { false, false, false, 4     } },
["Mountain (106)"]				= { "Mountain"	, { 1    , false, false, false } },
["Mountain (107)"]				= { "Mountain"	, { false, 2    , false, false } },
["Mountain (108)"]				= { "Mountain"	, { false, false, 3    , false } },
["Mountain (109)"]				= { "Mountain"	, { false, false, false, 4     } },
["Forest (110)"]				= { "Forest"	, { 1    , false, false, false } },
["Forest (111)"]				= { "Forest"	, { false, 2    , false, false } },
["Forest (112)"]				= { "Forest"	, { false, false, 3    , false } },
["Forest (113)"]				= { "Forest"	, { false, false, false, 4     } },
	},
	foiltweak={
["Mahamoti Djinn"]				= { foil = true},
["Ascendant Evincar"]			= { foil = true},
["Kamahl, Pit Fighter"]			= { foil = true},
["Immaculate Magistrate"]		= { foil = true},
["Verdant Force"]				= { foil = true},
	},
},
[766] = { name="Duel Decks: Phyrexia vs. The Coalition",
	tla="DDE",
	foil="n",
	cardcount={ reg=71, tok=3, nontrad=0, repl=0 }, 
	variants={
["Swamp"] 						= { "Swamp"		, { 1    , 2    , 3    , 4     } },
["Forest"] 						= { "Forest" 	, { 1    , 2     } },
["Plains (67)"]					= { "Plains"	, nil },
["Island (68)"]					= { "Island"	, nil },
["Swamp (32)"]					= { "Swamp"		, { 1    , false, false, false } },
["Swamp (33)"]					= { "Swamp"		, { false, 2    , false, false } },
["Swamp (34)"]					= { "Swamp"		, { false, false, 3    , false } },
["Swamp (35)"]					= { "Swamp"		, { false, false, false, 4     } },
["Mountain (69)"]				= { "Mountain"	, nil },
["Forest (70)"]					= { "Forest"	, { 1    , false } },
["Forest (71)"]					= { "Forest"	, { false, 2     } },
	},
	foiltweak={
["Phyrexian Negator"]			= { foil = true},
["Urza’s Rage"]					= { foil = true},
	},
},
[764] = { name="Premium Deck Series: Slivers",
	tla="H09",
	foilonly=true,
	cardcount={ reg=41, tok=0, nontrad=0, repl=0 },
	variants= {
["Plains (37)"]				= { "Plains"	, nil },
["Island (38)"]				= { "Island"	, nil },
["Swamp (39)"]				= { "Swamp"		, nil },
["Mountain (40)"]			= { "Mountain"	, nil },
["Forest (41)"]				= { "Forest"	, nil },
	}, 
},
[763] = { name="Duel Decks: Garruk vs. Liliana",
	tla="DDD",
	foil="n",
	cardcount={ reg=63, tok=3, nontrad=0, repl=0 }, 
	variants={
["Swamp"] 						= { "Swamp"		, { 1    , 2    , 3    , 4     } },
["Forest"] 						= { "Forest" 	, { 1    , 2    , 3    , 4     } },
["Swamp (60)"]					= { "Swamp"		, { 1    , false, false, false } },
["Swamp (61)"]					= { "Swamp"		, { false, 2    , false, false } },
["Swamp (62)"]					= { "Swamp"		, { false, false, 3    , false } },
["Swamp (63)"]					= { "Swamp"		, { false, false, false, 4     } },
["Forest (28)"]					= { "Forest"	, { 1    , false, false, false } },
["Forest (29)"]					= { "Forest"	, { false, 2    , false, false } },
["Forest (30)"]					= { "Forest"	, { false, false, 3    , false } },
["Forest (31)"]					= { "Forest"	, { false, false, false, 4     } },
["Beast Token"] 				= { "Beast Token" 	, { 1    , 2     } },
["Beast Token (1)"]				= { "Beast Token" 	, { 1    , false } },-- 3/3
["Beast Token (2)"]				= { "Beast Token" 	, { false, 2     } },-- 4/4
	},
	foiltweak={
["Garruk Wildspeaker"]			= { foil = true},
["Liliana Vess"]				= { foil = true},
	},
},
[761] = { name="Planechase",
	tla="HOP",
	foil="n",
	cardcount={ reg=169, tok=0, nontrad=40, repl=0 }, 
	variants={
["Plains"] 						= { "Plains" 	, { 1    , 2    , 3    , 4    , 5     } },
["Island"] 						= { "Island"	, { 1    , 2    , 3    , 4     } },
["Swamp"] 						= { "Swamp"		, { 1    , 2    , 3    , 4    , 5     } },
["Mountain"] 					= { "Mountain"	, { 1    , 2    , 3    , 4    , 5    , 6    , 7    , 8   , 9     } },
["Forest"] 						= { "Forest" 	, { 1    , 2    , 3    , 4    , 5     } },
["Plains (142)"]				= { "Plains"	, { 1    , false, false, false, false } },
["Plains (143)"]				= { "Plains"	, { false, 2    , false, false, false } },
["Plains (144)"]				= { "Plains"	, { false, false, 3    , false, false } },
["Plains (145)"]				= { "Plains"	, { false, false, false, 4    , false } },
["Plains (146)"]				= { "Plains"	, { false, false, false, false, 5     } },
["Island (147)"]				= { "Island"	, { 1    , false, false, false } }, 
["Island (148)"]				= { "Island"	, { false, 2    , false, false } },
["Island (149)"]				= { "Island"	, { false, false, 3    , false } },
["Island (150)"]				= { "Island"	, { false, false, false, 4     } },
["Swamp (151)"]					= { "Swamp"		, { 1    , false, false, false, false } },
["Swamp (152)"]					= { "Swamp"		, { false, 2    , false, false, false } },
["Swamp (153)"]					= { "Swamp"		, { false, false, 3    , false, false } },
["Swamp (154)"]					= { "Swamp"		, { false, false, false, 4    , false } },
["Swamp (155)"]					= { "Swamp"		, { false, false, false, false, 5     } },
["Mountain (156)"]				= { "Mountain"	, { 1    , false, false, false, false, false, false, false, false } },
["Mountain (157)"]				= { "Mountain"	, { false, 2    , false, false, false, false, false, false, false } },
["Mountain (158)"]				= { "Mountain"	, { false, false, 3    , false, false, false, false, false, false } },
["Mountain (159)"]				= { "Mountain"	, { false, false, false, 4    , false, false, false, false, false } },
["Mountain (160)"]				= { "Mountain"	, { false, false, false, false, 5    , false, false, false, false } },
["Mountain (161)"]				= { "Mountain"	, { false, false, false, false, false, 6    , false, false, false } },
["Mountain (162)"]				= { "Mountain"	, { false, false, false, false, false, false, 7    , false, false } },
["Mountain (163)"]				= { "Mountain"	, { false, false, false, false, false, false, false, 8    , false } },
["Mountain (164)"]				= { "Mountain"	, { false, false, false, false, false, false, false, false, 9     } },
["Forest (165)"]				= { "Forest"	, { 1    , false, false, false, false } },
["Forest (166)"]				= { "Forest"	, { false, 2    , false, false, false } },
["Forest (167)"]				= { "Forest"	, { false, false, 3    , false, false } },
["Forest (168)"]				= { "Forest"	, { false, false, false, 4    , false } },
["Forest (169)"]				= { "Forest"	, { false, false, false, false, 5     } },
["Pools of Becoming"]		= { "Pools of Becoming" 		, { "Nontrad" } },
["Immersturm"]				= { "Immersturm" 				, { "Nontrad" } },
["Goldmeadow"]				= { "Goldmeadow" 				, { "Nontrad" } },
["Panopticon"]				= { "Panopticon" 				, { "Nontrad" } },
["Naar Isle"]				= { "Naar Isle" 				, { "Nontrad" } },
["Shiv"]					= { "Shiv" 						, { "Nontrad" } },
["Stronghold Furnace"]		= { "Stronghold Furnace" 		, { "Nontrad" } },
["Naya"]					= { "Naya" 						, { "Nontrad" } },
["Izzet Steam Maze"]		= { "Izzet Steam Maze" 			, { "Nontrad" } },
["Skybreen"]				= { "Skybreen" 					, { "Nontrad" } },
["Feeding Grounds"]			= { "Feeding Grounds" 			, { "Nontrad" } },
["Bant"]					= { "Bant" 						, { "Nontrad" } },
["Grixis"]					= { "Grixis" 					, { "Nontrad" } },
["Murasa"]					= { "Murasa" 					, { "Nontrad" } },
["Minamo"]					= { "Minamo" 					, { "Nontrad" } },
["Krosa"]					= { "Krosa" 					, { "Nontrad" } },
["Velis Vel"]				= { "Velis Vel" 				, { "Nontrad" } },
["Undercity Reaches"]		= { "Undercity Reaches" 		, { "Nontrad" } },
["Lethe Lake"]				= { "Lethe Lake" 				, { "Nontrad" } },
["The Maelstrom"]			= { "The Maelstrom" 			, { "Nontrad" } },
["The Hippodrome"]			= { "The Hippodrome" 			, { "Nontrad" } },
["The Fourth Sphere"]		= { "The Fourth Sphere" 		, { "Nontrad" } },
["Sanctum of Serra"]		= { "Sanctum of Serra" 			, { "Nontrad" } },
["The Æther Flues"]			= { "The Æther Flues" 			, { "Nontrad" } },
["Tember City"]				= { "Tember City" 				, { "Nontrad" } },
["Academy at Tolaria West"]	= { "Academy at Tolaria West"	, { "Nontrad" } },
["Tazeem"]					= { "Tazeem" 					, { "Nontrad" } },
["Agyrem"]					= { "Agyrem" 					, { "Nontrad" } },
["Sokenzan"]				= { "Sokenzan" 					, { "Nontrad" } },
["The Eon Fog"]				= { "The Eon Fog" 				, { "Nontrad" } },
["Otaria"]					= { "Otaria" 					, { "Nontrad" } },
["Eloren Wilds"]			= { "Eloren Wilds" 				, { "Nontrad" } },
["Llanowar"]				= { "Llanowar" 					, { "Nontrad" } },
["Isle of Vesuva"]			= { "Isle of Vesuva" 			, { "Nontrad" } },
["The Dark Barony"]			= { "The Dark Barony" 			, { "Nontrad" } },
["Glimmervoid Basin"]		= { "Glimmervoid Basin" 		, { "Nontrad" } },
["Raven's Run"]				= { "Raven's Run" 				, { "Nontrad" } },
["Cliffside Market"]		= { "Cliffside Market" 			, { "Nontrad" } },
["Sea of Sand"]				= { "Sea of Sand" 				, { "Nontrad" } },
["Turri Island"]			= { "Turri Island" 				, { "Nontrad" } },
["Mirrored Depths"]			= { "Mirrored Depths" 			, { "Nontrad" } },
["The Great Forest"]		= { "The Great Forest" 			, { "Nontrad" } },
["Horizon Boughs"]			= { "Horizon Boughs" 			, { "Nontrad" } },
["Fields of Summer"]		= { "Fields of Summer" 			, { "Nontrad" } },
	},
},
[760] = { name="From the Vault: Exiled",
	tla="V09",
	foilonly=true,
	cardcount={ reg=15, tok=0, nontrad=0, repl=0 }, 
},
[757] = { name="Duel Decks: Divine vs. Demonic",
	tla="DDC",
	foil="n",
	cardcount={ reg=62, tok=3, nontrad=0, repl=0 }, 
	variants={
["Plains"] 						= { "Plains"	, { 1    , 2    , 3    , 4     } },
["Swamp"] 						= { "Swamp"		, { 1    , 2    , 3    , 4     } },
["Plains (26)"]					= { "Plains"	, { 1    , false, false, false } },
["Plains (27)"]					= { "Plains"	, { false, 2    , false, false } },
["Plains (28)"]					= { "Plains"	, { false, false, 3    , false } },
["Plains (29)"]					= { "Plains"	, { false, false, false, 4     } },
["Swamp (59)"]					= { "Swamp"		, { 1    , false, false, false } },
["Swamp (60)"] 					= { "Swamp"		, { false, 2    , false, false } },
["Swamp (61)"] 					= { "Swamp"		, { false, false, 3    , false } },
["Swamp (62)"] 					= { "Swamp"		, { false, false, false, 4     } },
	},
	foiltweak={
["Akroma, Angel of Wrath"]		= { foil = true},
["Lord of the Pit"]				= { foil = true},
	},
},
[755] = { name="Duel Decks: Jace vs. Chandra",
	tla="DD2",
	foil="n",
	cardcount={ reg=62, tok=1, nontrad=0, repl=0 }, 
	variants={
["Island"] 						= { "Island"	, { 1    , 2    , 3    , 4     } },
["Mountain"] 					= { "Mountain"	, { 1    , 2    , 3    , 4     } },
["Island (30)"]					= { "Island"	, { 1    , false, false, false } },
["Island (31)"]					= { "Island"	, { false, 2    , false, false } },
["Island (32)"]					= { "Island"	, { false, false, 3    , false } },
["Island (33)"]					= { "Island"	, { false, false, false, 4     } },
["Mountain (59)"]				= { "Mountain"	, { 1    , false, false, false } },
["Mountain (60)"]				= { "Mountain"	, { false, 2    , false, false } },
["Mountain (61)"]				= { "Mountain"	, { false, false, 3    , false } },
["Mountain (62)"]				= { "Mountain"	, { false, false, false, 4     } },
	},
	foiltweak={
["Jace Beleren"]				= { foil = true},
["Chandra Nalaar"]				= { foil = true},
	},
},
[753] = { name="From the Vault: Dragons",
	tla="DRB",
	foilonly=true,
	cardcount={ reg=15, tok=0, nontrad=0, repl=0 }, 
},
[740] = { name="Duel Decks: Elves vs. Goblins",
	tla="EVG",
	foil="n",
	cardcount={ reg=62, tok=3, nontrad=0, repl=0 }, 
	variants={
["Forest"] 						= { "Forest"	, { 1    , 2    , 3    , 4     } },
["Mountain"] 					= { "Mountain"	, { 1    , 2    , 3    , 4     } },
["Forest (28)"]					= { "Forest"	, { 1    , false, false, false } },
["Forest (29)"]					= { "Forest"	, { false, 2    , false, false } },
["Forest (30)"]					= { "Forest"	, { false, false, 3    , false } },
["Forest (31)"]					= { "Forest"	, { false, false, false, 4     } },
["Mountain (59)"]				= { "Mountain"	, { 1    , false, false, false } },
["Mountain (60)"]				= { "Mountain"	, { false, 2    , false, false } },
["Mountain (61)"]				= { "Mountain"	, { false, false, 3    , false } },
["Mountain (62)"]				= { "Mountain"	, { false, false, false, 4     } },
	},
	foiltweak={
["Ambush Commander"]			= { foil = true},
["Siege-Gang Commander"]					= { foil = true},
	},
},
[675] = { name="Coldsnap Theme Decks",
	tla="CST",
	foil="n",
	cardcount={ reg=62, tok=0, nontrad=0, repl=0 }, 
	variants={
["Plains"] 						= { "Plains"	, { 1    , 2    , 3     } },
["Island"] 						= { "Island" 	, { 1    , 2    , 3     } },
["Swamp"] 						= { "Swamp"		, { 1    , 2    , 3     } },
["Mountain"] 					= { "Mountain"	, { 1    , 2    , 3     } },
["Forest"] 						= { "Forest" 	, { 1    , 2    , 3     } },
["Plains (369)"]				= { "Plains"	, { 1    , false, false } },
["Plains (370)"]				= { "Plains"	, { false, 2    , false } },
["Plains (371)"]				= { "Plains"	, { false, false, 3     } },
["Island (372)"]				= { "Island"	, { 1    , false, false } },
["Island (373)"]				= { "Island"	, { false, 2    , false } },
["Island (374)"]				= { "Island"	, { false, false, 3     } },
["Swamp (375)"]					= { "Swamp"		, { 1    , false, false } },
["Swamp (376)"]					= { "Swamp"		, { false, 2    , false } },
["Swamp (377)"]					= { "Swamp"		, { false, false, 3     } },
["Mountain (378)"]				= { "Mountain"	, { 1    , false, false } },
["Mountain (379)"]				= { "Mountain"	, { false, 2    , false } },
["Mountain (380)"]				= { "Mountain"	, { false, false, 3     } },
["Forest (381)"]				= { "Forest"	, { 1    , false, false } },
["Forest (382)"]				= { "Forest"	, { false, 2    , false } },
["Forest (383)"]				= { "Forest"	, { false, false, 3     } },
	},
},
[636] = { name="Salvat 2011",
	tla="S11",
	foil="n",
	cardcount={ reg=224, tok=0, nontrad=0, repl=0 },
	lang={ [7]=true },
	variants={
["Plains"] 						= { "Plains"	, { 1    , 2    , 3    , 4     } },
["Island"] 						= { "Island" 	, { 1    , 2    , 3    , 4     } },
["Swamp"] 						= { "Swamp"		, { 1    , 2    , 3    , 4     } },
["Mountain"] 					= { "Mountain"	, { 1    , 2    , 3    , 4     } },
["Forest"] 						= { "Forest" 	, { 1    , 2    , 3    , 4     } },
["Plains (205)"]				= { "Plains"	, { 1    , false ,false, false } }, 
["Plains (206)"]				= { "Plains"	, { false, 2    , false, false } },
["Plains (207)"]				= { "Plains"	, { false, false, 3    , false } },
["Plains (208)"]				= { "Plains"	, { false, false, false, 4     } },
["Island (209)"]				= { "Island"	, { 1    , false, false, false } },
["Island (210)"]				= { "Island"	, { false, 2    , false, false } },
["Island (211)"]				= { "Island"	, { false, false, 3    , false } },
["Island (212)"]				= { "Island"	, { false, false, false, 4     } },
["Swamp (213)"]					= { "Swamp"		, { 1    , false, false, false } },
["Swamp (214)"]					= { "Swamp"		, { false, 2    , false, false } },
["Swamp (215)"]					= { "Swamp"		, { false, false, 3    , false } },
["Swamp (216)"]					= { "Swamp"		, { false, false, false, 4     } },
["Mountain (217)"]				= { "Mountain"	, { 1    , false, false, false } },
["Mountain (218)"]				= { "Mountain"	, { false, 2    , false, false } },
["Mountain (219)"]				= { "Mountain"	, { false, false, 3    , false } },
["Mountain (220)"]				= { "Mountain"	, { false, false, false, 4     } },
["Forest (221)"]				= { "Forest"	, { 1    , false, false, false } },
["Forest (222)"]				= { "Forest"	, { false, 2    , false, false } },
["Forest (223)"]				= { "Forest"	, { false, false, 3    , false } },
["Forest (224)"]				= { "Forest"	, { false, false, false, 4     } }
	},
},
[635] = { name="Salvat Magic Encyclopedia",
	tla="MAE",
	foil="n",
	cardcount={ reg=0, tok=0, nontrad=0, repl=0 }, -- ITA 720, FRA 600, SPA 600
	variants={
["Plains (all)"]				= { "Plains"	, { "Angels 01", "Angels 02", "Angels 03", "Angels 04", "Angels 05", "Angels 06", "Angels 07", "Angels 08", "Angels 09", "Angels 10", "Angels 11", "Angels 12", "Angels 13", "Angels 14", "Angels 15", "Cats 01", "Cats 02", "Cats 03", "Cats 04", "Cats 05", "Cats 06", "Cats 07", "Cats 08", "Cats 09", "Cats 10", "Cats 11", "Cats 12", "Spirits 01", "Spirits 02", "Spirits 03", "Spirits 04", "Spirits 05", "Spirits 06", "Spirits 07", "Spirits 08", "Spirits 09", "Spirits 10", "Spirits 11", "Spirits 12", "Thallids 01", "Thallids 02", "Thallids 03", "Thallids 04", "Thallids 05", "Thallids 06", "Thallids 07", "Thallids 08", "Thallids 09", "Thallids 10" } }, 
["Plains (Angels 8)"]			= { "Plains"	, { "Angels 01", false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false        , false        , false        , false        , false        , false        , false        , false        , false        , false         } },
["Plains (Angels 9)"]			= { "Plains"	, { false      , "Angels 02", false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false        , false        , false        , false        , false        , false        , false        , false        , false        , false         } },
["Plains (Angels 10)"]			= { "Plains"	, { false      , false      , "Angels 03", false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false        , false        , false        , false        , false        , false        , false        , false        , false        , false         } },
["Plains (Angels 20)"]			= { "Plains"	, { false      , false      , false      , "Angels 04", false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false        , false        , false        , false        , false        , false        , false        , false        , false        , false         } },
["Plains (Angels 21)"]			= { "Plains"	, { false      , false      , false      , false      , "Angels 05", false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false        , false        , false        , false        , false        , false        , false        , false        , false        , false         } },
["Plains (Angels 22)"]			= { "Plains"	, { false      , false      , false      , false      , false      , "Angels 06", false      , false      , false      , false      , false      , false      , false      , false      , false      , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false        , false        , false        , false        , false        , false        , false        , false        , false        , false         } },
["Plains (Angels 23)"]			= { "Plains"	, { false      , false      , false      , false      , false      , false      , "Angels 07", false      , false      , false      , false      , false      , false      , false      , false      , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false        , false        , false        , false        , false        , false        , false        , false        , false        , false         } },
["Plains (Angels 32)"]			= { "Plains"	, { false      , false      , false      , false      , false      , false      , false      , "Angels 08", false      , false      , false      , false      , false      , false      , false      , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false        , false        , false        , false        , false        , false        , false        , false        , false        , false         } },
["Plains (Angels 33)"]			= { "Plains"	, { false      , false      , false      , false      , false      , false      , false      , false      , "Angels 09", false      , false      , false      , false      , false      , false      , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false        , false        , false        , false        , false        , false        , false        , false        , false        , false         } },
["Plains (Angels 34)"]			= { "Plains"	, { false      , false      , false      , false      , false      , false      , false      , false      , false      , "Angels 10", false      , false      , false      , false      , false      , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false        , false        , false        , false        , false        , false        , false        , false        , false        , false         } },
["Plains (Angels 45)"]			= { "Plains"	, { false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , "Angels 11", false      , false      , false      , false      , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false        , false        , false        , false        , false        , false        , false        , false        , false        , false         } },
["Plains (Angels 46)"]			= { "Plains"	, { false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , "Angels 12", false      , false      , false      , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false        , false        , false        , false        , false        , false        , false        , false        , false        , false         } },
["Plains (Angels 56)"]			= { "Plains"	, { false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , "Angels 13", false      , false      , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false        , false        , false        , false        , false        , false        , false        , false        , false        , false         } },
["Plains (Angels 57)"]			= { "Plains"	, { false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , "Angels 14", false      , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false        , false        , false        , false        , false        , false        , false        , false        , false        , false         } },
["Plains (Angels 58)"]			= { "Plains"	, { false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , "Angels 15", false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false        , false        , false        , false        , false        , false        , false        , false        , false        , false         } },
["Plains (Cats 9)"]				= { "Plains"	, { false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , "Cats 01", false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false        , false        , false        , false        , false        , false        , false        , false        , false        , false         } },
["Plains (Cats 10)"]			= { "Plains"	, { false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false    , "Cats 02", false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false        , false        , false        , false        , false        , false        , false        , false        , false        , false         } },
["Plains (Cats 11)"]			= { "Plains"	, { false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false    , false    , "Cats 03", false    , false    , false    , false    , false    , false    , false    , false    , false    , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false        , false        , false        , false        , false        , false        , false        , false        , false        , false         } },
["Plains (Cats 21)"]			= { "Plains"	, { false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false    , false    , false    , "Cats 04", false    , false    , false    , false    , false    , false    , false    , false    , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false        , false        , false        , false        , false        , false        , false        , false        , false        , false         } },
["Plains (Cats 22)"]			= { "Plains"	, { false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false    , false    , false    , false    , "Cats 05", false    , false    , false    , false    , false    , false    , false    , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false        , false        , false        , false        , false        , false        , false        , false        , false        , false         } },
["Plains (Cats 23)"]			= { "Plains"	, { false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false    , false    , false    , false    , false    , "Cats 06", false    , false    , false    , false    , false    , false    , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false        , false        , false        , false        , false        , false        , false        , false        , false        , false         } },
["Plains (Cats 35)"]			= { "Plains"	, { false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false    , false    , false    , false    , false    , false    , "Cats 07", false    , false    , false    , false    , false    , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false        , false        , false        , false        , false        , false        , false        , false        , false        , false         } },
["Plains (Cats 46)"]			= { "Plains"	, { false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false    , false    , false    , false    , false    , false    , false    , "Cats 08", false    , false    , false    , false    , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false        , false        , false        , false        , false        , false        , false        , false        , false        , false         } },
["Plains (Cats 47)"]			= { "Plains"	, { false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false    , false    , false    , false    , false    , false    , false    , false    , "Cats 09", false    , false    , false    , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false        , false        , false        , false        , false        , false        , false        , false        , false        , false         } },
["Plains (Cats 57)"]			= { "Plains"	, { false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false    , false    , false    , false    , false    , false    , false    , false    , false    , "Cats 10", false    , false    , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false        , false        , false        , false        , false        , false        , false        , false        , false        , false         } },
["Plains (Cats 58)"]			= { "Plains"	, { false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , "Cats 11", false    , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false        , false        , false        , false        , false        , false        , false        , false        , false        , false         } },
["Plains (Cats 59)"]			= { "Plains"	, { false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , "Cats 12", false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false        , false        , false        , false        , false        , false        , false        , false        , false        , false         } },
["Plains (Spirits 8)"]			= { "Plains"	, { false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , "Spirits 01", false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false        , false        , false        , false        , false        , false        , false        , false        , false        , false         } },
["Plains (Spirits 9)"]			= { "Plains"	, { false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false       , "Spirits 02", false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false        , false        , false        , false        , false        , false        , false        , false        , false        , false         } },
["Plains (Spirits 10)"]			= { "Plains"	, { false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false       , false       , "Spirits 03", false       , false       , false       , false       , false       , false       , false       , false       , false       , false        , false        , false        , false        , false        , false        , false        , false        , false        , false         } },
["Plains (Spirits 20)"]			= { "Plains"	, { false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false       , false       , false       , "Spirits 04", false       , false       , false       , false       , false       , false       , false       , false       , false        , false        , false        , false        , false        , false        , false        , false        , false        , false         } },
["Plains (Spirits 21)"]			= { "Plains"	, { false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false       , false       , false       , false       , "Spirits 05", false       , false       , false       , false       , false       , false       , false       , false        , false        , false        , false        , false        , false        , false        , false        , false        , false         } },
["Plains (Spirits 33)"]			= { "Plains"	, { false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false       , false       , false       , false       , false       , "Spirits 06", false       , false       , false       , false       , false       , false       , false        , false        , false        , false        , false        , false        , false        , false        , false        , false         } },
["Plains (Spirits 34)"]			= { "Plains"	, { false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false       , false       , false       , false       , false       , false       , "Spirits 07", false       , false       , false       , false       , false       , false        , false        , false        , false        , false        , false        , false        , false        , false        , false         } },
["Plains (Spirits 44)"]			= { "Plains"	, { false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false       , false       , false       , false       , false       , false       , false       , "Spirits 08", false       , false       , false       , false       , false        , false        , false        , false        , false        , false        , false        , false        , false        , false         } },
["Plains (Spirits 45)"]			= { "Plains"	, { false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false       , false       , false       , false       , false       , false       , false       , false       , "Spirits 09", false       , false       , false       , false        , false        , false        , false        , false        , false        , false        , false        , false        , false         } },
["Plains (Spirits 46)"]			= { "Plains"	, { false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false       , false       , false       , false       , false       , false       , false       , false       , false       , "Spirits 10", false       , false       , false        , false        , false        , false        , false        , false        , false        , false        , false        , false         } },
["Plains (Spirits 56)"]			= { "Plains"	, { false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , "Spirits 11", false       , false        , false        , false        , false        , false        , false        , false        , false        , false        , false         } },
["Plains (Spirits 57)"]			= { "Plains"	, { false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , "Spirits 12", false        , false        , false        , false        , false        , false        , false        , false        , false        , false         } },
["Plains (Thallids 11)"]		= { "Plains"	, { false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , "Thallids 01", false        , false        , false        , false        , false        , false        , false        , false        , false         } },
["Plains (Thallids 12)"]		= { "Plains"	, { false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false        , "Thallids 02", false        , false        , false        , false        , false        , false        , false        , false         } },
["Plains (Thallids 23)"]		= { "Plains"	, { false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false        , false        , "Thallids 03", false        , false        , false        , false        , false        , false        , false         } },
["Plains (Thallids 24)"]		= { "Plains"	, { false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false        , false        , false        , "Thallids 04", false        , false        , false        , false        , false        , false         } },
["Plains (Thallids 35)"]		= { "Plains"	, { false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false        , false        , false        , false        , "Thallids 05", false        , false        , false        , false        , false         } },
["Plains (Thallids 36)"]		= { "Plains"	, { false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false        , false        , false        , false        , false        , "Thallids 06", false        , false        , false        , false         } },
["Plains (Thallids 47)"]		= { "Plains"	, { false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false        , false        , false        , false        , false        , false        , "Thallids 07", false        , false        , false         } },
["Plains (Thallids 48)"]		= { "Plains"	, { false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false        , false        , false        , false        , false        , false        , false        , "Thallids 08", false        , false         } },
["Plains (Thallids 59)"]		= { "Plains"	, { false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false        , false        , false        , false        , false        , false        , false        , false        , "Thallids 09", false         } },
["Plains (Thallids 60)"]		= { "Plains"	, { false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false        , false        , false        , false        , false        , false        , false        , false        , false        , "Thallids 10" } },
["Island (all)"]				= { "Island"	, { "Angels 1"    , "Angels 2", "Angels 3", "Angels 4", "Angels 5", "Angels 6", "Angels 7", "Angels 8", "Angels 9", "Ninjas 01", "Ninjas 02", "Ninjas 03", "Ninjas 04", "Ninjas 05", "Ninjas 06", "Ninjas 07", "Ninjas 08", "Ninjas 09", "Ninjas 10", "Ninjas 11", "Ninjas 12", "Ninjas 13", "Wizards 01", "Wizards 02", "Wizards 03", "Wizards 04", "Wizards 05", "Wizards 06", "Wizards 07", "Wizards 08", "Wizards 09", "Wizards 10", "Wizards 11", "Wizards 12", "Wizards 13", "Wizards 14", "Wizards 15", "Wizards 16", "Wizards 17", "Wizards 18", "Wizards 19", "Wizards 20", "Wizards 21", "Wizards 22", "Wizards 23", "Wizards 24" } },
["Island (Angels 11)"]			= { "Island"	, { "Angels 1"    , false     , false     , false     , false     , false     , false     , false     , false     , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false        } },
["Island (Angels 12)"]			= { "Island"	, { false     , "Angels 2", false     , false     , false     , false     , false     , false     , false     , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false        } },
["Island (Angels 24)"]			= { "Island"	, { false     , false     , "Angels 3", false     , false     , false     , false     , false     , false     , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false        } },
["Island (Angels 35)"]			= { "Island"	, { false     , false     , false     , "Angels 4", false     , false     , false     , false     , false     , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false        } },
["Island (Angels 36)"]			= { "Island"	, { false     , false     , false     , false     , "Angels 5", false     , false     , false     , false     , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false        } },
["Island (Angels 47)"]			= { "Island"	, { false     , false     , false     , false     , false     , "Angels 6", false     , false     , false     , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false        } },
["Island (Angels 48)"]			= { "Island"	, { false     , false     , false     , false     , false     , false     , "Angels 7", false     , false     , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false        } },
["Island (Angels 59)"]			= { "Island"	, { false     , false     , false     , false     , false     , false     , false     , "Angels 8", false     , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false        } },
["Island (Angels 60)"]			= { "Island"	, { false     , false     , false     , false     , false     , false     , false     , false     , "Angels 9", false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false        } },
["Island (Ninjas 8)"]			= { "Island"	, { false     , false     , false     , false     , false     , false     , false     , false     , false     , "Ninjas 01", false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false        } },
["Island (Ninjas 9)"]			= { "Island"	, { false     , false     , false     , false     , false     , false     , false     , false     , false     , false      , "Ninjas 02", false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false        } },
["Island (Ninjas 10)"]			= { "Island"	, { false     , false     , false     , false     , false     , false     , false     , false     , false     , false      , false      , "Ninjas 03", false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false        } },
["Island (Ninjas 20)"]			= { "Island"	, { false     , false     , false     , false     , false     , false     , false     , false     , false     , false      , false      , false      , "Ninjas 04", false      , false      , false      , false      , false      , false      , false      , false      , false      , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false        } },
["Island (Ninjas 21)"]			= { "Island"	, { false     , false     , false     , false     , false     , false     , false     , false     , false     , false      , false      , false      , false      , "Ninjas 05", false      , false      , false      , false      , false      , false      , false      , false      , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false        } },
["Island (Ninjas 32)"]			= { "Island"	, { false     , false     , false     , false     , false     , false     , false     , false     , false     , false      , false      , false      , false      , false      , "Ninjas 06", false      , false      , false      , false      , false      , false      , false      , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false        } },
["Island (Ninjas 33)"]			= { "Island"	, { false     , false     , false     , false     , false     , false     , false     , false     , false     , false      , false      , false      , false      , false      , false      , "Ninjas 07", false      , false      , false      , false      , false      , false      , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false        } },
["Island (Ninjas 34)"]			= { "Island"	, { false     , false     , false     , false     , false     , false     , false     , false     , false     , false      , false      , false      , false      , false      , false      , false      , "Ninjas 08", false      , false      , false      , false      , false      , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false        } },
["Island (Ninjas 45)"]			= { "Island"	, { false     , false     , false     , false     , false     , false     , false     , false     , false     , false      , false      , false      , false      , false      , false      , false      , false      , "Ninjas 09", false      , false      , false      , false      , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false        } },
["Island (Ninjas 46)"]			= { "Island"	, { false     , false     , false     , false     , false     , false     , false     , false     , false     , false      , false      , false      , false      , false      , false      , false      , false      , false      , "Ninjas 10", false      , false      , false      , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false        } },
["Island (Ninjas 56)"]			= { "Island"	, { false     , false     , false     , false     , false     , false     , false     , false     , false     , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , "Ninjas 11", false      , false      , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false        } },
["Island (Ninjas 57)"]			= { "Island"	, { false     , false     , false     , false     , false     , false     , false     , false     , false     , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , "Ninjas 12", false      , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false        } },
["Island (Ninjas 58)"]			= { "Island"	, { false     , false     , false     , false     , false     , false     , false     , false     , false     , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , "Ninjas 13", false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false        } },
["Island (Wizards 8)"]			= { "Island"	, { false     , false     , false     , false     , false     , false     , false     , false     , false     , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , "Wizards 01", false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false        } },
["Island (Wizards 9)"]			= { "Island"	, { false     , false     , false     , false     , false     , false     , false     , false     , false     , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false       , "Wizards 02", false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false        } },
["Island (Wizards 10)"]			= { "Island"	, { false     , false     , false     , false     , false     , false     , false     , false     , false     , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false       , false       , "Wizards 03", false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false        } },
["Island (Wizards 11)"]			= { "Island"	, { false     , false     , false     , false     , false     , false     , false     , false     , false     , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false       , false       , false       , "Wizards 04", false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false        } },
["Island (Wizards 12)"]			= { "Island"	, { false     , false     , false     , false     , false     , false     , false     , false     , false     , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false       , false       , false       , false       , "Wizards 05", false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false        } },
["Island (Wizards 20)"]			= { "Island"	, { false     , false     , false     , false     , false     , false     , false     , false     , false     , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false       , false       , false       , false       , false       , "Wizards 06", false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false        } },
["Island (Wizards 21)"]			= { "Island"	, { false     , false     , false     , false     , false     , false     , false     , false     , false     , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false       , false       , false       , false       , false       , false       , "Wizards 07", false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false        } },
["Island (Wizards 22)"]			= { "Island"	, { false     , false     , false     , false     , false     , false     , false     , false     , false     , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false       , false       , false       , false       , false       , false       , false       , "Wizards 08", false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false        } },
["Island (Wizards 23)"]			= { "Island"	, { false     , false     , false     , false     , false     , false     , false     , false     , false     , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false       , false       , false       , false       , false       , false       , false       , false       , "Wizards 09", false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false        } },
["Island (Wizards 24)"]			= { "Island"	, { false     , false     , false     , false     , false     , false     , false     , false     , false     , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false       , false       , false       , false       , false       , false       , false       , false       , false       , "Wizards 10", false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false        } },
["Island (Wizards 32)"]			= { "Island"	, { false     , false     , false     , false     , false     , false     , false     , false     , false     , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , "Wizards 11", false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false        } },
["Island (Wizards 33)"]			= { "Island"	, { false     , false     , false     , false     , false     , false     , false     , false     , false     , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , "Wizards 12", false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false        } },
["Island (Wizards 34)"]			= { "Island"	, { false     , false     , false     , false     , false     , false     , false     , false     , false     , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , "Wizards 13", false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false        } },
["Island (Wizards 35)"]			= { "Island"	, { false     , false     , false     , false     , false     , false     , false     , false     , false     , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , "Wizards 14", false       , false       , false       , false       , false       , false       , false       , false       , false       , false        } },
["Island (Wizards 36)"]			= { "Island"	, { false     , false     , false     , false     , false     , false     , false     , false     , false     , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , "Wizards 15", false       , false       , false       , false       , false       , false       , false       , false       , false        } },
["Island (Wizards 45)"]			= { "Island"	, { false     , false     , false     , false     , false     , false     , false     , false     , false     , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , "Wizards 16", false       , false       , false       , false       , false       , false       , false       , false        } },
["Island (Wizards 46)"]			= { "Island"	, { false     , false     , false     , false     , false     , false     , false     , false     , false     , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , "Wizards 17", false       , false       , false       , false       , false       , false       , false        } },
["Island (Wizards 47)"]			= { "Island"	, { false     , false     , false     , false     , false     , false     , false     , false     , false     , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , "Wizards 18", false       , false       , false       , false       , false       , false        } },
["Island (Wizards 48)"]			= { "Island"	, { false     , false     , false     , false     , false     , false     , false     , false     , false     , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , "Wizards 19", false       , false       , false       , false       , false        } },
["Island (Wizards 56)"]			= { "Island"	, { false     , false     , false     , false     , false     , false     , false     , false     , false     , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , "Wizards 20", false       , false       , false       , false        } },
["Island (Wizards 57)"]			= { "Island"	, { false     , false     , false     , false     , false     , false     , false     , false     , false     , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , "Wizards 21", false       , false       , false        } },
["Island (Wizards 58)"]			= { "Island"	, { false     , false     , false     , false     , false     , false     , false     , false     , false     , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , "Wizards 22", false       , false        } },
["Island (Wizards 59)"]			= { "Island"	, { false     , false     , false     , false     , false     , false     , false     , false     , false     , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , "Wizards 23", false        } },
["Island (Wizards 60)"]			= { "Island"	, { false     , false     , false     , false     , false     , false     , false     , false     , false     , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , "Wizards 24" } },
["Swamp (all)"]					= { "Swamp"	, { "Ninjas 01", "Ninjas 02", "Ninjas 03", "Ninjas 04", "Ninjas 05", "Ninjas 06", "Ninjas 07", "Ninjas 08", "Ninjas 09", "Ninjas 10", "Ninjas 11", "Rats 01", "Rats 02", "Rats 03", "Rats 04", "Rats 05", "Rats 06", "Rats 07", "Rats 08", "Rats 09", "Rats 10", "Rats 11", "Rats 12", "Rats 13", "Rats 14", "Rats 15", "Rats 16", "Rats 17", "Rats 18", "Rats 19", "Rats 20", "Rats 21", "Rats 22", "Rats 23", "Rats 24", "Slivers 1", "Slivers 2", "Slivers 3", "Slivers 4", "Slivers 5", "Slivers 6", "Slivers 7", "Zombies 01", "Zombies 02", "Zombies 03", "Zombies 04", "Zombies 05", "Zombies 06", "Zombies 07", "Zombies 08", "Zombies 09", "Zombies 10", "Zombies 11", "Zombies 12", "Zombies 13", "Zombies 14", "Zombies 15", "Zombies 16", "Zombies 17", "Zombies 18", "Zombies 19", "Zombies 20", "Zombies 21", "Zombies 22", "Zombies 23", "Zombies 24" } }, 
["Swamp (Ninjas 11)"]			= { "Swamp"	, { "Ninjas 01", false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false      , false      , false      , false      , false      , false      , false      , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false        } },
["Swamp (Ninjas 12)"]			= { "Swamp"	, { false      , "Ninjas 02", false      , false      , false      , false      , false      , false      , false      , false      , false      , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false      , false      , false      , false      , false      , false      , false      , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false        } },
["Swamp (Ninjas 22)"]			= { "Swamp"	, { false      , false      , "Ninjas 03", false      , false      , false      , false      , false      , false      , false      , false      , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false      , false      , false      , false      , false      , false      , false      , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false        } },
["Swamp (Ninjas 23)"]			= { "Swamp"	, { false      , false      , false      , "Ninjas 04", false      , false      , false      , false      , false      , false      , false      , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false      , false      , false      , false      , false      , false      , false      , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false        } },
["Swamp (Ninjas 24)"]			= { "Swamp"	, { false      , false      , false      , false      , "Ninjas 05", false      , false      , false      , false      , false      , false      , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false      , false      , false      , false      , false      , false      , false      , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false        } },
["Swamp (Ninjas 35)"]			= { "Swamp"	, { false      , false      , false      , false      , false      , "Ninjas 06", false      , false      , false      , false      , false      , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false      , false      , false      , false      , false      , false      , false      , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false        } },
["Swamp (Ninjas 36)"]			= { "Swamp"	, { false      , false      , false      , false      , false      , false      , "Ninjas 07", false      , false      , false      , false      , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false      , false      , false      , false      , false      , false      , false      , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false        } },
["Swamp (Ninjas 47)"]			= { "Swamp"	, { false      , false      , false      , false      , false      , false      , false      , "Ninjas 08", false      , false      , false      , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false      , false      , false      , false      , false      , false      , false      , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false        } },
["Swamp (Ninjas 48)"]			= { "Swamp"	, { false      , false      , false      , false      , false      , false      , false      , false      , "Ninjas 09", false      , false      , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false      , false      , false      , false      , false      , false      , false      , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false        } },
["Swamp (Ninjas 59)"]			= { "Swamp"	, { false      , false      , false      , false      , false      , false      , false      , false      , false      , "Ninjas 10", false      , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false      , false      , false      , false      , false      , false      , false      , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false        } },
["Swamp (Ninjas 60)"]			= { "Swamp"	, { false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , "Ninjas 11", false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false      , false      , false      , false      , false      , false      , false      , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false        } },
["Swamp (Rats 8)"]				= { "Swamp"	, { false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , "Rats 01", false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false      , false      , false      , false      , false      , false      , false      , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false        } },
["Swamp (Rats 9)"]				= { "Swamp"	, { false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false    , "Rats 02", false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false      , false      , false      , false      , false      , false      , false      , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false        } },
["Swamp (Rats 10)"]				= { "Swamp"	, { false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false    , false    , "Rats 03", false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false      , false      , false      , false      , false      , false      , false      , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false        } },
["Swamp (Rats 11)"]				= { "Swamp"	, { false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false    , false    , false    , "Rats 04", false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false      , false      , false      , false      , false      , false      , false      , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false        } },
["Swamp (Rats 12)"]				= { "Swamp"	, { false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false    , false    , false    , false    , "Rats 05", false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false      , false      , false      , false      , false      , false      , false      , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false        } },
["Swamp (Rats 20)"]				= { "Swamp"	, { false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false    , false    , false    , false    , false    , "Rats 06", false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false      , false      , false      , false      , false      , false      , false      , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false        } },
["Swamp (Rats 21)"]				= { "Swamp"	, { false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false    , false    , false    , false    , false    , false    , "Rats 07", false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false      , false      , false      , false      , false      , false      , false      , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false        } },
["Swamp (Rats 22)"]				= { "Swamp"	, { false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false    , false    , false    , false    , false    , false    , false    , "Rats 08", false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false      , false      , false      , false      , false      , false      , false      , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false        } },
["Swamp (Rats 23)"]				= { "Swamp"	, { false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false    , false    , false    , false    , false    , false    , false    , false    , "Rats 09", false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false      , false      , false      , false      , false      , false      , false      , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false        } },
["Swamp (Rats 24)"]				= { "Swamp"	, { false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false    , false    , false    , false    , false    , false    , false    , false    , false    , "Rats 10", false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false      , false      , false      , false      , false      , false      , false      , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false        } },
["Swamp (Rats 32)"]				= { "Swamp"	, { false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , "Rats 11", false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false      , false      , false      , false      , false      , false      , false      , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false        } },
["Swamp (Rats 33)"]				= { "Swamp"	, { false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , "Rats 12", false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false      , false      , false      , false      , false      , false      , false      , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false        } },
["Swamp (Rats 34)"]				= { "Swamp"	, { false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , "Rats 13", false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false      , false      , false      , false      , false      , false      , false      , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false        } },
["Swamp (Rats 35)"]				= { "Swamp"	, { false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , "Rats 14", false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false      , false      , false      , false      , false      , false      , false      , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false        } },
["Swamp (Rats 36)"]				= { "Swamp"	, { false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , "Rats 15", false    , false    , false    , false    , false    , false    , false    , false    , false    , false      , false      , false      , false      , false      , false      , false      , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false        } },
["Swamp (Rats 45)"]				= { "Swamp"	, { false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , "Rats 16", false    , false    , false    , false    , false    , false    , false    , false    , false      , false      , false      , false      , false      , false      , false      , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false        } },
["Swamp (Rats 46)"]				= { "Swamp"	, { false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , "Rats 17", false    , false    , false    , false    , false    , false    , false    , false      , false      , false      , false      , false      , false      , false      , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false        } },
["Swamp (Rats 47)"]				= { "Swamp"	, { false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , "Rats 18", false    , false    , false    , false    , false    , false    , false      , false      , false      , false      , false      , false      , false      , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false        } },
["Swamp (Rats 48)"]				= { "Swamp"	, { false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , "Rats 19", false    , false    , false    , false    , false    , false      , false      , false      , false      , false      , false      , false      , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false        } },
["Swamp (Rats 56)"]				= { "Swamp"	, { false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , "Rats 20", false    , false    , false    , false    , false      , false      , false      , false      , false      , false      , false      , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false        } },
["Swamp (Rats 57)"]				= { "Swamp"	, { false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , "Rats 21", false    , false    , false    , false      , false      , false      , false      , false      , false      , false      , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false        } },
["Swamp (Rats 58)"]				= {	"Swamp"	, { false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , "Rats 22", false    , false    , false      , false      , false      , false      , false      , false      , false      , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false        } },
["Swamp (Rats 59)"]				= {	"Swamp"	, { false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , "Rats 23", false    , false      , false      , false      , false      , false      , false      , false      , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false        } },
["Swamp (Rats 60)"]				= { "Swamp"	, { false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , "Rats 24", false      , false      , false      , false      , false      , false      , false      , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false        } },
["Swamp (Slivers 33)"]			= { "Swamp"	, { false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , "Slivers 1", false      , false      , false      , false      , false      , false      , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false        } },
["Swamp (Slivers 34)"]			= { "Swamp"	, { false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false      , "Slivers 2", false      , false      , false      , false      , false      , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false        } },
["Swamp (Slivers 35)"]			= { "Swamp"	, { false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false      , false      , "Slivers 3", false      , false      , false      , false      , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false        } },
["Swamp (Slivers 36)"]			= { "Swamp"	, { false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false      , false      , false      , "Slivers 4", false      , false      , false      , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false        } },
["Swamp (Slivers 45)"]			= { "Swamp"	, { false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false      , false      , false      , false      , "Slivers 5", false      , false      , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false        } },
["Swamp (Slivers 46)"]			= { "Swamp"	, { false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false      , false      , false      , false      , false      , "Slivers 6", false      , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false        } },
["Swamp (Slivers 56)"]			= { "Swamp"	, { false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false      , false      , false      , false      , false      , false      , "Slivers 7", false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false        } },
["Swamp (Zombies 8)"]			= { "Swamp"	, { false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false      , false      , false      , false      , false      , false      , false      , "Zombies 01", false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false        } },
["Swamp (Zombies 9)"]			= { "Swamp"	, { false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false      , false      , false      , false      , false      , false      , false      , false       , "Zombies 02", false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false        } },
["Swamp (Zombies 10)"]			= { "Swamp"	, { false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false      , false      , false      , false      , false      , false      , false      , false       , false       , "Zombies 03", false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false        } },
["Swamp (Zombies 11)"]			= { "Swamp"	, { false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false      , false      , false      , false      , false      , false      , false      , false       , false       , false       , "Zombies 04", false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false        } },
["Swamp (Zombies 12)"]			= { "Swamp"	, { false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false      , false      , false      , false      , false      , false      , false      , false       , false       , false       , false       , "Zombies 05", false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false        } },
["Swamp (Zombies 20)"]			= { "Swamp"	, { false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false      , false      , false      , false      , false      , false      , false      , false       , false       , false       , false       , false       , "Zombies 06", false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false        } },
["Swamp (Zombies 21)"]			= { "Swamp"	, { false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false      , false      , false      , false      , false      , false      , false      , false       , false       , false       , false       , false       , false       , "Zombies 07", false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false        } },
["Swamp (Zombies 22)"]			= { "Swamp"	, { false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false      , false      , false      , false      , false      , false      , false      , false       , false       , false       , false       , false       , false       , false       , "Zombies 08", false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false        } },
["Swamp (Zombies 23)"]			= { "Swamp"	, { false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false      , false      , false      , false      , false      , false      , false      , false       , false       , false       , false       , false       , false       , false       , false       , "Zombies 09", false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false        } },
["Swamp (Zombies 24)"]			= { "Swamp"	, { false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false      , false      , false      , false      , false      , false      , false      , false       , false       , false       , false       , false       , false       , false       , false       , false       , "Zombies 10", false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false        } },
["Swamp (Zombies 32)"]			= { "Swamp"	, { false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false      , false      , false      , false      , false      , false      , false      , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , "Zombies 11", false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false        } },
["Swamp (Zombies 33)"]			= { "Swamp"	, { false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false      , false      , false      , false      , false      , false      , false      , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , "Zombies 12", false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false        } },
["Swamp (Zombies 34)"]			= { "Swamp"	, { false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false      , false      , false      , false      , false      , false      , false      , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , "Zombies 13", false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false        } },
["Swamp (Zombies 35)"]			= { "Swamp"	, { false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false      , false      , false      , false      , false      , false      , false      , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , "Zombies 14", false       , false       , false       , false       , false       , false       , false       , false       , false       , false        } },
["Swamp (Zombies 36)"]			= { "Swamp"	, { false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false      , false      , false      , false      , false      , false      , false      , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , "Zombies 15", false       , false       , false       , false       , false       , false       , false       , false       , false        } },
["Swamp (Zombies 45)"]			= { "Swamp"	, { false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false      , false      , false      , false      , false      , false      , false      , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , "Zombies 16", false       , false       , false       , false       , false       , false       , false       , false        } },
["Swamp (Zombies 46)"]			= { "Swamp"	, { false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false      , false      , false      , false      , false      , false      , false      , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , "Zombies 17", false       , false       , false       , false       , false       , false       , false        } },
["Swamp (Zombies 47)"]			= { "Swamp"	, { false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false      , false      , false      , false      , false      , false      , false      , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , "Zombies 18", false       , false       , false       , false       , false       , false        } },
["Swamp (Zombies 48)"]			= { "Swamp"	, { false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false      , false      , false      , false      , false      , false      , false      , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , "Zombies 19", false       , false       , false       , false       , false        } },
["Swamp (Zombies 56)"]			= { "Swamp"	, { false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false      , false      , false      , false      , false      , false      , false      , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , "Zombies 20", false       , false       , false       , false        } },
["Swamp (Zombies 57)"]			= { "Swamp"	, { false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false      , false      , false      , false      , false      , false      , false      , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , "Zombies 21", false       , false       , false        } },
["Swamp (Zombies 58)"]			= { "Swamp"	, { false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false      , false      , false      , false      , false      , false      , false      , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , "Zombies 22", false       , false        } },
["Swamp (Zombies 59)"]			= { "Swamp"	, { false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false      , false      , false      , false      , false      , false      , false      , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , "Zombies 23", false        } },
["Swamp (Zombies 60)"]			= { "Swamp"	, { false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false    , false      , false      , false      , false      , false      , false      , false      , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , "Zombies 24" } },
["Mountain (all)"]				= { "Mountain"	, { "Beasts 1"    , "Beasts 2", "Beasts 3", "Beasts 4", "Beasts 5", "Beasts 6", "Beasts 7", "Beasts 8", "Berserkers 01", "Berserkers 02", "Berserkers 03", "Berserkers 04", "Berserkers 05", "Berserkers 06", "Berserkers 07", "Berserkers 08", "Berserkers 09", "Berserkers 10", "Berserkers 11", "Berserkers 12", "Berserkers 13", "Slivers 1", "Slivers 2", "Slivers 3", "Slivers 4", "Slivers 5", "Slivers 6", "Slivers 7", "Spirits 01", "Spirits 02", "Spirits 03", "Spirits 04", "Spirits 05", "Spirits 06", "Spirits 07", "Spirits 08", "Spirits 09", "Spirits 10", "Spirits 11", "Spirits 12" } },
["Mountain (Beasts 11)"]		= { "Mountain"	, { "Beasts 1"    , false     , false     , false     , false     , false     , false     , false     , false          , false          , false          , false          , false          , false          , false          , false          , false          , false          , false          , false          , false          , false      , false      , false      , false      , false      , false      , false      , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false        } },
["Mountain (Beasts 12)"]		= { "Mountain"	, { false     , "Beasts 2", false     , false     , false     , false     , false     , false     , false          , false          , false          , false          , false          , false          , false          , false          , false          , false          , false          , false          , false          , false      , false      , false      , false      , false      , false      , false      , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false        } },
["Mountain (Beasts 24)"]		= { "Mountain"	, { false     , false     , "Beasts 3", false     , false     , false     , false     , false     , false          , false          , false          , false          , false          , false          , false          , false          , false          , false          , false          , false          , false          , false      , false      , false      , false      , false      , false      , false      , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false        } },
["Mountain (Beasts 35)"]		= { "Mountain"	, { false     , false     , false     , "Beasts 4", false     , false     , false     , false     , false          , false          , false          , false          , false          , false          , false          , false          , false          , false          , false          , false          , false          , false      , false      , false      , false      , false      , false      , false      , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false        } },
["Mountain (Beasts 36)"]		= { "Mountain"	, { false     , false     , false     , false     , "Beasts 5", false     , false     , false     , false          , false          , false          , false          , false          , false          , false          , false          , false          , false          , false          , false          , false          , false      , false      , false      , false      , false      , false      , false      , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false        } },
["Mountain (Beasts 48)"]		= { "Mountain"	, { false     , false     , false     , false     , false     , "Beasts 6", false     , false     , false          , false          , false          , false          , false          , false          , false          , false          , false          , false          , false          , false          , false          , false      , false      , false      , false      , false      , false      , false      , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false        } },
["Mountain (Beasts 59)"]		= { "Mountain"	, { false     , false     , false     , false     , false     , false     , "Beasts 7", false     , false          , false          , false          , false          , false          , false          , false          , false          , false          , false          , false          , false          , false          , false      , false      , false      , false      , false      , false      , false      , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false        } },
["Mountain (Beasts 60)"]		= { "Mountain"	, { false     , false     , false     , false     , false     , false     , false     , "Beasts 8", false          , false          , false          , false          , false          , false          , false          , false          , false          , false          , false          , false          , false          , false      , false      , false      , false      , false      , false      , false      , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false        } },
["Mountain (Berserkers 9)"]		= { "Mountain"	, { false     , false     , false     , false     , false     , false     , false     , false     , "Berserkers 01", false          , false          , false          , false          , false          , false          , false          , false          , false          , false          , false          , false          , false      , false      , false      , false      , false      , false      , false      , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false        } },
["Mountain (Berserkers 10)"]	= { "Mountain"	, { false     , false     , false     , false     , false     , false     , false     , false     , false          , "Berserkers 02", false          , false          , false          , false          , false          , false          , false          , false          , false          , false          , false          , false      , false      , false      , false      , false      , false      , false      , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false        } },
["Mountain (Berserkers 11)"]	= { "Mountain"	, { false     , false     , false     , false     , false     , false     , false     , false     , false          , false          , "Berserkers 03", false          , false          , false          , false          , false          , false          , false          , false          , false          , false          , false      , false      , false      , false      , false      , false      , false      , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false        } },
["Mountain (Berserkers 12)"]	= { "Mountain"	, { false     , false     , false     , false     , false     , false     , false     , false     , false          , false          , false          , "Berserkers 04", false          , false          , false          , false          , false          , false          , false          , false          , false          , false      , false      , false      , false      , false      , false      , false      , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false        } },
["Mountain (Berserkers 20)"]	= { "Mountain"	, { false     , false     , false     , false     , false     , false     , false     , false     , false          , false          , false          , false          , "Berserkers 05", false          , false          , false          , false          , false          , false          , false          , false          , false      , false      , false      , false      , false      , false      , false      , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false        } },
["Mountain (Berserkers 21)"]	= { "Mountain"	, { false     , false     , false     , false     , false     , false     , false     , false     , false          , false          , false          , false          , false          , "Berserkers 06", false          , false          , false          , false          , false          , false          , false          , false      , false      , false      , false      , false      , false      , false      , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false        } },
["Mountain (Berserkers 22)"]	= { "Mountain"	, { false     , false     , false     , false     , false     , false     , false     , false     , false          , false          , false          , false          , false          , false          , "Berserkers 07", false          , false          , false          , false          , false          , false          , false      , false      , false      , false      , false      , false      , false      , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false        } },
["Mountain (Berserkers 23)"]	= { "Mountain"	, { false     , false     , false     , false     , false     , false     , false     , false     , false          , false          , false          , false          , false          , false          , false          , "Berserkers 08", false          , false          , false          , false          , false          , false      , false      , false      , false      , false      , false      , false      , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false        } },
["Mountain (Berserkers 24)"]	= { "Mountain"	, { false     , false     , false     , false     , false     , false     , false     , false     , false          , false          , false          , false          , false          , false          , false          , false          , "Berserkers 09", false          , false          , false          , false          , false      , false      , false      , false      , false      , false      , false      , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false        } },
["Mountain (Berserkers 32)"]	= { "Mountain"	, { false     , false     , false     , false     , false     , false     , false     , false     , false          , false          , false          , false          , false          , false          , false          , false          , false          , "Berserkers 10", false          , false          , false          , false      , false      , false      , false      , false      , false      , false      , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false        } },
["Mountain (Berserkers 44)"]	= { "Mountain"	, { false     , false     , false     , false     , false     , false     , false     , false     , false          , false          , false          , false          , false          , false          , false          , false          , false          , false          , "Berserkers 11", false          , false          , false      , false      , false      , false      , false      , false      , false      , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false        } },
["Mountain (Berserkers 45)"]	= { "Mountain"	, { false     , false     , false     , false     , false     , false     , false     , false     , false          , false          , false          , false          , false          , false          , false          , false          , false          , false          , false          , "Berserkers 12", false          , false      , false      , false      , false      , false      , false      , false      , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false        } },
["Mountain (Berserkers 57)"]	= { "Mountain"	, { false     , false     , false     , false     , false     , false     , false     , false     , false          , false          , false          , false          , false          , false          , false          , false          , false          , false          , false          , false          , "Berserkers 13", false      , false      , false      , false      , false      , false      , false      , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false        } },
["Mountain (Slivers 9)"]		= { "Mountain"	, { false     , false     , false     , false     , false     , false     , false     , false     , false          , false          , false          , false          , false          , false          , false          , false          , false          , false          , false          , false          , false          , "Slivers 1", false      , false      , false      , false      , false      , false      , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false        } },
["Mountain (Slivers 10)"]		= { "Mountain"	, { false     , false     , false     , false     , false     , false     , false     , false     , false          , false          , false          , false          , false          , false          , false          , false          , false          , false          , false          , false          , false          , false      , "Slivers 2", false      , false      , false      , false      , false      , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false        } },
["Mountain (Slivers 21)"]		= { "Mountain"	, { false     , false     , false     , false     , false     , false     , false     , false     , false          , false          , false          , false          , false          , false          , false          , false          , false          , false          , false          , false          , false          , false      , false      , "Slivers 3", false      , false      , false      , false      , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false        } },
["Mountain (Slivers 22)"]		= { "Mountain"	, { false     , false     , false     , false     , false     , false     , false     , false     , false          , false          , false          , false          , false          , false          , false          , false          , false          , false          , false          , false          , false          , false      , false      , false      , "Slivers 4", false      , false      , false      , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false        } },
["Mountain (Slivers 47)"]		= { "Mountain"	, { false     , false     , false     , false     , false     , false     , false     , false     , false          , false          , false          , false          , false          , false          , false          , false          , false          , false          , false          , false          , false          , false      , false      , false      , false      , "Slivers 5", false      , false      , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false        } },
["Mountain (Slivers 57)"]		= { "Mountain"	, { false     , false     , false     , false     , false     , false     , false     , false     , false          , false          , false          , false          , false          , false          , false          , false          , false          , false          , false          , false          , false          , false      , false      , false      , false      , false      , "Slivers 6", false      , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false        } },
["Mountain (Slivers 58)"]		= { "Mountain"	, { false     , false     , false     , false     , false     , false     , false     , false     , false          , false          , false          , false          , false          , false          , false          , false          , false          , false          , false          , false          , false          , false      , false      , false      , false      , false      , false      , "Slivers 7", false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false        } },
["Mountain (Spirits 11)"]		= { "Mountain"	, { false     , false     , false     , false     , false     , false     , false     , false     , false          , false          , false          , false          , false          , false          , false          , false          , false          , false          , false          , false          , false          , false      , false      , false      , false      , false      , false      , false      , "Spirits 01", false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false        } },
["Mountain (Spirits 12)"]		= { "Mountain"	, { false     , false     , false     , false     , false     , false     , false     , false     , false          , false          , false          , false          , false          , false          , false          , false          , false          , false          , false          , false          , false          , false      , false      , false      , false      , false      , false      , false      , false       , "Spirits 02", false       , false       , false       , false       , false       , false       , false       , false       , false       , false        } },
["Mountain (Spirits 22)"]		= { "Mountain"	, { false     , false     , false     , false     , false     , false     , false     , false     , false          , false          , false          , false          , false          , false          , false          , false          , false          , false          , false          , false          , false          , false      , false      , false      , false      , false      , false      , false      , false       , false       , "Spirits 03", false       , false       , false       , false       , false       , false       , false       , false       , false        } },
["Mountain (Spirits 23)"]		= { "Mountain"	, { false     , false     , false     , false     , false     , false     , false     , false     , false          , false          , false          , false          , false          , false          , false          , false          , false          , false          , false          , false          , false          , false      , false      , false      , false      , false      , false      , false      , false       , false       , false       , "Spirits 04", false       , false       , false       , false       , false       , false       , false       , false        } },
["Mountain (Spirits 24)"]		= { "Mountain"	, { false     , false     , false     , false     , false     , false     , false     , false     , false          , false          , false          , false          , false          , false          , false          , false          , false          , false          , false          , false          , false          , false      , false      , false      , false      , false      , false      , false      , false       , false       , false       , false       , "Spirits 05", false       , false       , false       , false       , false       , false       , false        } },
["Mountain (Spirits 35)"]		= { "Mountain"	, { false     , false     , false     , false     , false     , false     , false     , false     , false          , false          , false          , false          , false          , false          , false          , false          , false          , false          , false          , false          , false          , false      , false      , false      , false      , false      , false      , false      , false       , false       , false       , false       , false       , "Spirits 06", false       , false       , false       , false       , false       , false        } },
["Mountain (Spirits 36)"]		= { "Mountain"	, { false     , false     , false     , false     , false     , false     , false     , false     , false          , false          , false          , false          , false          , false          , false          , false          , false          , false          , false          , false          , false          , false      , false      , false      , false      , false      , false      , false      , false       , false       , false       , false       , false       , false       , "Spirits 07", false       , false       , false       , false       , false        } },
["Mountain (Spirits 47)"]		= { "Mountain"	, { false     , false     , false     , false     , false     , false     , false     , false     , false          , false          , false          , false          , false          , false          , false          , false          , false          , false          , false          , false          , false          , false      , false      , false      , false      , false      , false      , false      , false       , false       , false       , false       , false       , false       , false       , "Spirits 08", false       , false       , false       , false        } },
["Mountain (Spirits 48)"]		= { "Mountain"	, { false     , false     , false     , false     , false     , false     , false     , false     , false          , false          , false          , false          , false          , false          , false          , false          , false          , false          , false          , false          , false          , false      , false      , false      , false      , false      , false      , false      , false       , false       , false       , false       , false       , false       , false       , false       , "Spirits 09", false       , false       , false        } },
["Mountain (Spirits 58)"]		= { "Mountain"	, { false     , false     , false     , false     , false     , false     , false     , false     , false          , false          , false          , false          , false          , false          , false          , false          , false          , false          , false          , false          , false          , false      , false      , false      , false      , false      , false      , false      , false       , false       , false       , false       , false       , false       , false       , false       , false       , "Spirits 10", false       , false        } },
["Mountain (Spirits 59)"]		= { "Mountain"	, { false     , false     , false     , false     , false     , false     , false     , false     , false          , false          , false          , false          , false          , false          , false          , false          , false          , false          , false          , false          , false          , false      , false      , false      , false      , false      , false      , false      , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , "Spirits 11", false        } },
["Mountain (Spirits 60)"]		= { "Mountain"	, { false     , false     , false     , false     , false     , false     , false     , false     , false          , false          , false          , false          , false          , false          , false          , false          , false          , false          , false          , false          , false          , false      , false      , false      , false      , false      , false      , false      , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , false       , "Spirits 12" } },
["Forest (all)"]				= { "Forest"	, { "Beasts 01", "Beasts 02", "Beasts 03", "Beasts 04", "Beasts 05", "Beasts 06", "Beasts 07", "Beasts 08", "Beasts 09", "Beasts 10", "Beasts 11", "Beasts 12", "Beasts 13", "Beasts 14", "Beasts 15", "Beasts 16", "Berserkers 01", "Berserkers 02", "Berserkers 03", "Berserkers 04", "Berserkers 05", "Berserkers 06", "Berserkers 07", "Berserkers 08", "Berserkers 09", "Berserkers 10", "Cats 1", "Cats 2", "Cats 3", "Cats 4", "Cats 5", "Elves 01", "Elves 02", "Elves 03", "Elves 04", "Elves 05", "Elves 06", "Elves 07", "Elves 08", "Elves 09", "Elves 10", "Elves 11", "Elves 12", "Elves 13", "Elves 14", "Elves 15", "Elves 16", "Elves 17", "Elves 18", "Elves 19", "Elves 20", "Elves 21", "Elves 22", "Elves 23", "Slivers 1", "Slivers 2", "Slivers 3", "Slivers 4", "Slivers 5", "Slivers 6", "Slivers 7", "Thallids 01", "Thallids 02", "Thallids 03", "Thallids 04", "Thallids 05", "Thallids 06", "Thallids 07", "Thallids 08", "Thallids 09", "Thallids 10", "Thallids 11", "Thallids 12", "Thallids 13", "Thallids 14" } },
["Forest (Beasts 8)"]			= {	"Forest"	, { "Beasts 01", false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false          , false          , false          , false          , false          , false          , false          , false          , false          , false          , false   , false   , false   , false   , false   , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false      , false      , false      , false      , false      , false      , false      , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false         } },
["Forest (Beasts 9)"]			= { "Forest"	, { false      , "Beasts 02", false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false          , false          , false          , false          , false          , false          , false          , false          , false          , false          , false   , false   , false   , false   , false   , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false      , false      , false      , false      , false      , false      , false      , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false         } },
["Forest (Beasts 10)"]			= { "Forest"	, { false      , false      , "Beasts 03", false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false          , false          , false          , false          , false          , false          , false          , false          , false          , false          , false   , false   , false   , false   , false   , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false      , false      , false      , false      , false      , false      , false      , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false         } },
["Forest (Beasts 20)"]			= { "Forest"	, { false      , false      , false      , "Beasts 04", false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false          , false          , false          , false          , false          , false          , false          , false          , false          , false          , false   , false   , false   , false   , false   , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false      , false      , false      , false      , false      , false      , false      , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false         } },
["Forest (Beasts 21)"]			= { "Forest"	, { false      , false      , false      , false      , "Beasts 05", false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false          , false          , false          , false          , false          , false          , false          , false          , false          , false          , false   , false   , false   , false   , false   , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false      , false      , false      , false      , false      , false      , false      , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false         } },
["Forest (Beasts 22)"]			= { "Forest"	, { false      , false      , false      , false      , false      , "Beasts 06", false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false          , false          , false          , false          , false          , false          , false          , false          , false          , false          , false   , false   , false   , false   , false   , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false      , false      , false      , false      , false      , false      , false      , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false         } },
["Forest (Beasts 23)"]			= { "Forest"	, { false      , false      , false      , false      , false      , false      , "Beasts 07", false      , false      , false      , false      , false      , false      , false      , false      , false      , false          , false          , false          , false          , false          , false          , false          , false          , false          , false          , false   , false   , false   , false   , false   , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false      , false      , false      , false      , false      , false      , false      , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false         } },
["Forest (Beasts 32)"]			= { "Forest"	, { false      , false      , false      , false      , false      , false      , false      , "Beasts 08", false      , false      , false      , false      , false      , false      , false      , false      , false          , false          , false          , false          , false          , false          , false          , false          , false          , false          , false   , false   , false   , false   , false   , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false      , false      , false      , false      , false      , false      , false      , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false         } },
["Forest (Beasts 33)"]			= { "Forest"	, { false      , false      , false      , false      , false      , false      , false      , false      , "Beasts 09", false      , false      , false      , false      , false      , false      , false      , false          , false          , false          , false          , false          , false          , false          , false          , false          , false          , false   , false   , false   , false   , false   , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false      , false      , false      , false      , false      , false      , false      , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false         } },
["Forest (Beasts 34)"]			= { "Forest"	, { false      , false      , false      , false      , false      , false      , false      , false      , false      , "Beasts 10", false      , false      , false      , false      , false      , false      , false          , false          , false          , false          , false          , false          , false          , false          , false          , false          , false   , false   , false   , false   , false   , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false      , false      , false      , false      , false      , false      , false      , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false         } },
["Forest (Beasts 45)"]			= { "Forest"	, { false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , "Beasts 11", false      , false      , false      , false      , false      , false          , false          , false          , false          , false          , false          , false          , false          , false          , false          , false   , false   , false   , false   , false   , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false      , false      , false      , false      , false      , false      , false      , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false         } },
["Forest (Beasts 46)"]			= { "Forest"	, { false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , "Beasts 12", false      , false      , false      , false      , false          , false          , false          , false          , false          , false          , false          , false          , false          , false          , false   , false   , false   , false   , false   , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false      , false      , false      , false      , false      , false      , false      , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false         } },
["Forest (Beasts 47)"]			= { "Forest"	, { false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , "Beasts 13", false      , false      , false      , false          , false          , false          , false          , false          , false          , false          , false          , false          , false          , false   , false   , false   , false   , false   , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false      , false      , false      , false      , false      , false      , false      , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false         } },
["Forest (Beasts 56)"]			= { "Forest"	, { false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , "Beasts 14", false      , false      , false          , false          , false          , false          , false          , false          , false          , false          , false          , false          , false   , false   , false   , false   , false   , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false      , false      , false      , false      , false      , false      , false      , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false         } },
["Forest (Beasts 57)"]			= { "Forest"	, { false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , "Beasts 15", false      , false          , false          , false          , false          , false          , false          , false          , false          , false          , false          , false   , false   , false   , false   , false   , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false      , false      , false      , false      , false      , false      , false      , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false         } },
["Forest (Beasts 58)"]			= { "Forest"	, { false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , "Beasts 16", false          , false          , false          , false          , false          , false          , false          , false          , false          , false          , false   , false   , false   , false   , false   , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false      , false      , false      , false      , false      , false      , false      , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false         } },
["Forest (Berserkers 33)"]		= { "Forest"	, { false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , "Berserkers 01", false          , false          , false          , false          , false          , false          , false          , false          , false          , false   , false   , false   , false   , false   , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false      , false      , false      , false      , false      , false      , false      , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false         } },
["Forest (Berserkers 34)"]		= { "Forest"	, { false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false          , "Berserkers 02", false          , false          , false          , false          , false          , false          , false          , false          , false   , false   , false   , false   , false   , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false      , false      , false      , false      , false      , false      , false      , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false         } },
["Forest (Berserkers 35)"]		= { "Forest"	, { false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false          , false          , "Berserkers 03", false          , false          , false          , false          , false          , false          , false          , false   , false   , false   , false   , false   , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false      , false      , false      , false      , false      , false      , false      , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false         } },
["Forest (Berserkers 36)"]		= { "Forest"	, { false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false          , false          , false          , "Berserkers 04", false          , false          , false          , false          , false          , false          , false   , false   , false   , false   , false   , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false      , false      , false      , false      , false      , false      , false      , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false         } },
["Forest (Berserkers 46)"]		= { "Forest"	, { false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false          , false          , false          , false          , "Berserkers 05", false          , false          , false          , false          , false          , false   , false   , false   , false   , false   , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false      , false      , false      , false      , false      , false      , false      , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false         } },
["Forest (Berserkers 47)"]		= { "Forest"	, { false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false          , false          , false          , false          , false          , "Berserkers 06", false          , false          , false          , false          , false   , false   , false   , false   , false   , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false      , false      , false      , false      , false      , false      , false      , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false         } },
["Forest (Berserkers 48)"]		= { "Forest"	, { false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false          , false          , false          , false          , false          , false          , "Berserkers 07", false          , false          , false          , false   , false   , false   , false   , false   , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false      , false      , false      , false      , false      , false      , false      , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false         } },
["Forest (Berserkers 58)"]		= { "Forest"	, { false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false          , false          , false          , false          , false          , false          , false          , "Berserkers 08", false          , false          , false   , false   , false   , false   , false   , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false      , false      , false      , false      , false      , false      , false      , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false         } },
["Forest (Berserkers 59)"]		= { "Forest"	, { false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false          , false          , false          , false          , false          , false          , false          , false          , "Berserkers 09", false          , false   , false   , false   , false   , false   , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false      , false      , false      , false      , false      , false      , false      , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false         } },
["Forest (Berserkers 60)"]		= { "Forest"	, { false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false          , false          , false          , false          , false          , false          , false          , false          , false          , "Berserkers 10", false   , false   , false   , false   , false   , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false      , false      , false      , false      , false      , false      , false      , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false         } },
["Forest (Cats 12)"]			= { "Forest"	, { false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false          , false          , false          , false          , false          , false          , false          , false          , false          , false          , "Cats 1", false   , false   , false   , false   , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false      , false      , false      , false      , false      , false      , false      , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false         } },
["Forest (Cats 24)"]			= { "Forest"	, { false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false          , false          , false          , false          , false          , false          , false          , false          , false          , false          , false   , "Cats 2", false   , false   , false   , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false      , false      , false      , false      , false      , false      , false      , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false         } },
["Forest (Cats 36)"]			= { "Forest"	, { false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false          , false          , false          , false          , false          , false          , false          , false          , false          , false          , false   , false   , "Cats 3", false   , false   , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false      , false      , false      , false      , false      , false      , false      , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false         } },
["Forest (Cats 48)"]			= { "Forest"	, { false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false          , false          , false          , false          , false          , false          , false          , false          , false          , false          , false   , false   , false   , "Cats 4", false   , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false      , false      , false      , false      , false      , false      , false      , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false         } },
["Forest (Cats 60)"]			= { "Forest"	, { false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false          , false          , false          , false          , false          , false          , false          , false          , false          , false          , false   , false   , false   , false   , "Cats 5", false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false      , false      , false      , false      , false      , false      , false      , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false         } },
["Forest (Elves 8)"]			= { "Forest"	, { false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false          , false          , false          , false          , false          , false          , false          , false          , false          , false          , false   , false   , false   , false   , false   , "Elves 01", false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false      , false      , false      , false      , false      , false      , false      , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false         } },
["Forest (Elves 9)"]			= { "Forest"	, { false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false          , false          , false          , false          , false          , false          , false          , false          , false          , false          , false   , false   , false   , false   , false   , false     , "Elves 02", false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false      , false      , false      , false      , false      , false      , false      , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false         } },
["Forest (Elves 10)"]			= { "Forest"	, { false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false          , false          , false          , false          , false          , false          , false          , false          , false          , false          , false   , false   , false   , false   , false   , false     , false     , "Elves 03", false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false      , false      , false      , false      , false      , false      , false      , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false         } },
["Forest (Elves 11)"]			= { "Forest"	, { false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false          , false          , false          , false          , false          , false          , false          , false          , false          , false          , false   , false   , false   , false   , false   , false     , false     , false     , "Elves 04", false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false      , false      , false      , false      , false      , false      , false      , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false         } },
["Forest (Elves 12)"]			= { "Forest"	, { false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false          , false          , false          , false          , false          , false          , false          , false          , false          , false          , false   , false   , false   , false   , false   , false     , false     , false     , false     , "Elves 05", false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false      , false      , false      , false      , false      , false      , false      , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false         } },
["Forest (Elves 20)"]			= { "Forest"	, { false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false          , false          , false          , false          , false          , false          , false          , false          , false          , false          , false   , false   , false   , false   , false   , false     , false     , false     , false     , false     , "Elves 06", false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false      , false      , false      , false      , false      , false      , false      , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false         } },
["Forest (Elves 21)"]			= { "Forest"	, { false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false          , false          , false          , false          , false          , false          , false          , false          , false          , false          , false   , false   , false   , false   , false   , false     , false     , false     , false     , false     , false     , "Elves 07", false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false      , false      , false      , false      , false      , false      , false      , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false         } },
["Forest (Elves 22)"]			= { "Forest"	, { false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false          , false          , false          , false          , false          , false          , false          , false          , false          , false          , false   , false   , false   , false   , false   , false     , false     , false     , false     , false     , false     , false     , "Elves 08", false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false      , false      , false      , false      , false      , false      , false      , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false         } },
["Forest (Elves 23)"]			= { "Forest"	, { false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false          , false          , false          , false          , false          , false          , false          , false          , false          , false          , false   , false   , false   , false   , false   , false     , false     , false     , false     , false     , false     , false     , false     , "Elves 09", false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false      , false      , false      , false      , false      , false      , false      , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false         } },
["Forest (Elves 24)"]			= { "Forest"	, { false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false          , false          , false          , false          , false          , false          , false          , false          , false          , false          , false   , false   , false   , false   , false   , false     , false     , false     , false     , false     , false     , false     , false     , false     , "Elves 10", false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false      , false      , false      , false      , false      , false      , false      , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false         } },
["Forest (Elves 33)"]			= { "Forest"	, { false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false          , false          , false          , false          , false          , false          , false          , false          , false          , false          , false   , false   , false   , false   , false   , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , "Elves 11", false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false      , false      , false      , false      , false      , false      , false      , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false         } },
["Forest (Elves 34)"]			= { "Forest"	, { false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false          , false          , false          , false          , false          , false          , false          , false          , false          , false          , false   , false   , false   , false   , false   , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , "Elves 12", false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false      , false      , false      , false      , false      , false      , false      , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false         } },
["Forest (Elves 35)"]			= { "Forest"	, { false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false          , false          , false          , false          , false          , false          , false          , false          , false          , false          , false   , false   , false   , false   , false   , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , "Elves 13", false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false      , false      , false      , false      , false      , false      , false      , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false         } },
["Forest (Elves 36)"]			= { "Forest"	, { false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false          , false          , false          , false          , false          , false          , false          , false          , false          , false          , false   , false   , false   , false   , false   , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , "Elves 14", false     , false     , false     , false     , false     , false     , false     , false     , false     , false      , false      , false      , false      , false      , false      , false      , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false         } },
["Forest (Elves 45)"]			= { "Forest"	, { false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false          , false          , false          , false          , false          , false          , false          , false          , false          , false          , false   , false   , false   , false   , false   , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , "Elves 15", false     , false     , false     , false     , false     , false     , false     , false     , false      , false      , false      , false      , false      , false      , false      , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false         } },
["Forest (Elves 46)"]			= { "Forest"	, { false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false          , false          , false          , false          , false          , false          , false          , false          , false          , false          , false   , false   , false   , false   , false   , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , "Elves 16", false     , false     , false     , false     , false     , false     , false     , false      , false      , false      , false      , false      , false      , false      , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false         } },
["Forest (Elves 47)"]			= { "Forest"	, { false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false          , false          , false          , false          , false          , false          , false          , false          , false          , false          , false   , false   , false   , false   , false   , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , "Elves 17", false     , false     , false     , false     , false     , false     , false      , false      , false      , false      , false      , false      , false      , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false         } },
["Forest (Elves 48)"]			= { "Forest"	, { false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false          , false          , false          , false          , false          , false          , false          , false          , false          , false          , false   , false   , false   , false   , false   , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , "Elves 18", false     , false     , false     , false     , false     , false      , false      , false      , false      , false      , false      , false      , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false         } },
["Forest (Elves 56)"]			= { "Forest"	, { false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false          , false          , false          , false          , false          , false          , false          , false          , false          , false          , false   , false   , false   , false   , false   , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , "Elves 19", false     , false     , false     , false     , false      , false      , false      , false      , false      , false      , false      , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false         } },
["Forest (Elves 57)"]			= { "Forest"	, { false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false          , false          , false          , false          , false          , false          , false          , false          , false          , false          , false   , false   , false   , false   , false   , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , "Elves 20", false     , false     , false     , false      , false      , false      , false      , false      , false      , false      , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false         } },
["Forest (Elves 58)"]			= { "Forest"	, { false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false          , false          , false          , false          , false          , false          , false          , false          , false          , false          , false   , false   , false   , false   , false   , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , "Elves 21", false     , false     , false      , false      , false      , false      , false      , false      , false      , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false         } },
["Forest (Elves 59)"]			= { "Forest"	, { false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false          , false          , false          , false          , false          , false          , false          , false          , false          , false          , false   , false   , false   , false   , false   , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , "Elves 22", false     , false      , false      , false      , false      , false      , false      , false      , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false         } },
["Forest (Elves 60)"]			= { "Forest"	, { false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false          , false          , false          , false          , false          , false          , false          , false          , false          , false          , false   , false   , false   , false   , false   , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , "Elves 23", false      , false      , false      , false      , false      , false      , false      , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false         } },
["Forest (Slivers 11)"]			= { "Forest"	, { false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false          , false          , false          , false          , false          , false          , false          , false          , false          , false          , false   , false   , false   , false   , false   , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , "Slivers 1", false      , false      , false      , false      , false      , false      , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false         } },
["Forest (Slivers 12)"]			= { "Forest"	, { false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false          , false          , false          , false          , false          , false          , false          , false          , false          , false          , false   , false   , false   , false   , false   , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false      , "Slivers 2", false      , false      , false      , false      , false      , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false         } },
["Forest (Slivers 23)"]			= { "Forest"	, { false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false          , false          , false          , false          , false          , false          , false          , false          , false          , false          , false   , false   , false   , false   , false   , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false      , false      , "Slivers 3", false      , false      , false      , false      , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false         } },
["Forest (Slivers 24)"]			= { "Forest"	, { false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false          , false          , false          , false          , false          , false          , false          , false          , false          , false          , false   , false   , false   , false   , false   , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false      , false      , false      , "Slivers 4", false      , false      , false      , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false         } },
["Forest (Slivers 48)"]			= { "Forest"	, { false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false          , false          , false          , false          , false          , false          , false          , false          , false          , false          , false   , false   , false   , false   , false   , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false      , false      , false      , false      , "Slivers 5", false      , false      , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false         } },
["Forest (Slivers 59)"]			= { "Forest"	, { false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false          , false          , false          , false          , false          , false          , false          , false          , false          , false          , false   , false   , false   , false   , false   , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false      , false      , false      , false      , false      , "Slivers 6", false      , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false         } },
["Forest (Slivers 60)"]			= { "Forest"	, { false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false          , false          , false          , false          , false          , false          , false          , false          , false          , false          , false   , false   , false   , false   , false   , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false      , false      , false      , false      , false      , false      , "Slivers 7", false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false         } },
["Forest (Thallids 8)"]			= { "Forest"	, { false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false          , false          , false          , false          , false          , false          , false          , false          , false          , false          , false   , false   , false   , false   , false   , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false      , false      , false      , false      , false      , false      , false      , "Thallids 01", false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false         } },
["Forest (Thallids 9)"]			= { "Forest"	, { false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false          , false          , false          , false          , false          , false          , false          , false          , false          , false          , false   , false   , false   , false   , false   , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false      , false      , false      , false      , false      , false      , false      , false        , "Thallids 02", false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false         } },
["Forest (Thallids 10)"]		= { "Forest"	, { false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false          , false          , false          , false          , false          , false          , false          , false          , false          , false          , false   , false   , false   , false   , false   , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false      , false      , false      , false      , false      , false      , false      , false        , false        , "Thallids 03", false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false         } },
["Forest (Thallids 20)"]		= { "Forest"	, { false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false          , false          , false          , false          , false          , false          , false          , false          , false          , false          , false   , false   , false   , false   , false   , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false      , false      , false      , false      , false      , false      , false      , false        , false        , false        , "Thallids 04", false        , false        , false        , false        , false        , false        , false        , false        , false        , false         } },
["Forest (Thallids 21)"]		= { "Forest"	, { false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false          , false          , false          , false          , false          , false          , false          , false          , false          , false          , false   , false   , false   , false   , false   , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false      , false      , false      , false      , false      , false      , false      , false        , false        , false        , false        , "Thallids 05", false        , false        , false        , false        , false        , false        , false        , false        , false         } },
["Forest (Thallids 22)"]		= { "Forest"	, { false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false          , false          , false          , false          , false          , false          , false          , false          , false          , false          , false   , false   , false   , false   , false   , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false      , false      , false      , false      , false      , false      , false      , false        , false        , false        , false        , false        , "Thallids 06", false        , false        , false        , false        , false        , false        , false        , false         } },
["Forest (Thallids 33)"]		= { "Forest"	, { false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false          , false          , false          , false          , false          , false          , false          , false          , false          , false          , false   , false   , false   , false   , false   , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false      , false      , false      , false      , false      , false      , false      , false        , false        , false        , false        , false        , false        , "Thallids 07", false        , false        , false        , false        , false        , false        , false         } },
["Forest (Thallids 34)"]		= { "Forest"	, { false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false          , false          , false          , false          , false          , false          , false          , false          , false          , false          , false   , false   , false   , false   , false   , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false      , false      , false      , false      , false      , false      , false      , false        , false        , false        , false        , false        , false        , false        , "Thallids 08", false        , false        , false        , false        , false        , false         } },
["Forest (Thallids 44)"]		= { "Forest"	, { false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false          , false          , false          , false          , false          , false          , false          , false          , false          , false          , false   , false   , false   , false   , false   , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false      , false      , false      , false      , false      , false      , false      , false        , false        , false        , false        , false        , false        , false        , false        , "Thallids 09", false        , false        , false        , false        , false         } },
["Forest (Thallids 45)"]		= { "Forest"	, { false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false          , false          , false          , false          , false          , false          , false          , false          , false          , false          , false   , false   , false   , false   , false   , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false      , false      , false      , false      , false      , false      , false      , false        , false        , false        , false        , false        , false        , false        , false        , false        , "Thallids 10", false        , false        , false        , false         } },
["Forest (Thallids 46)"]		= { "Forest"	, { false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false          , false          , false          , false          , false          , false          , false          , false          , false          , false          , false   , false   , false   , false   , false   , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false      , false      , false      , false      , false      , false      , false      , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , "Thallids 11", false        , false        , false         } },
["Forest (Thallids 56)"]		= { "Forest"	, { false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false          , false          , false          , false          , false          , false          , false          , false          , false          , false          , false   , false   , false   , false   , false   , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false      , false      , false      , false      , false      , false      , false      , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , "Thallids 12", false        , false         } },
["Forest (Thallids 57)"]		= { "Forest"	, { false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false          , false          , false          , false          , false          , false          , false          , false          , false          , false          , false   , false   , false   , false   , false   , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false      , false      , false      , false      , false      , false      , false      , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , "Thallids 13", false         } },
["Forest (Thallids 58)"]		= { "Forest"	, { false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false      , false          , false          , false          , false          , false          , false          , false          , false          , false          , false          , false   , false   , false   , false   , false   , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false     , false      , false      , false      , false      , false      , false      , false      , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , false        , "Thallids 14" } },
["Æther Shockwave"]							= { "Æther Shockwave"				, { "Spirits"    } },-- (Spirits 26)
["Alpha Status"]							= { "Alpha Status"					, { "Elves"      } },-- (Elves 38)
["Ambush Commander"]						= { "Ambush Commander"				, { "Elves"      } },-- (Elves 25)
["Angel of Mercy (Angels 14)"]				= { "Angel of Mercy"				, { "Angels 1"    , false          } },
["Angel of Mercy (Angels 38)"]				= { "Angel of Mercy"				, { false         , "Angels 2"     } },
["Angel of Retribution"]					= { "Angel of Retribution"			, { "Angels"     } },-- (Angels 1)
["Angelic Page"]							= { "Angelic Page"					, { "Spirits"    } },-- (Spirits 14)
["Aphetto Dredging (Slivers 40)"]			= { "Aphetto Dredging"				, { "Slivers 1"   , false          } },
["Aphetto Dredging (Slivers 41)"]			= { "Aphetto Dredging"				, { false         , "Slivers 2"    } },
["Arctic Nishoba (Cats 14)"]				= { "Arctic Nishoba"				, { "Cats 1"      , false          } },
["Arctic Nishoba (Cats 26)"]				= { "Arctic Nishoba"				, { false         , "Cats 2"       } },
["Ardent Militia (Angels 15)"]				= { "Ardent Militia"				, { "Angels 1"    , false          } },
["Ardent Militia (Angels 26)"]				= { "Ardent Militia"				, { false         , "Angels 2"     } },
["Auratouched Mage (Angels 27)"]			= { "Auratouched Mage"				, { "Angels 1"    , false          } },
["Auratouched Mage (Angels 50)"]			= { "Auratouched Mage"				, { false         , "Angels 2"     } },
["Aven Windreader (Wizards 52)"]			= { "Aven Windreader"				, { "Wizards 1"   , false          } },
["Aven Windreader (Wizards 53)"]			= { "Aven Windreader"				, { false         , "Wizards 2"    } },
["Azami, Lady of Scrolls"]					= { "Azami, Lady of Scrolls"		, { "Wizards"    } },-- (Wizards 1)
["Balduvian Rage (Berserkers 14)"]			= { "Balduvian Rage"				, { "Berserkers 1", false          } },
["Balduvian Rage (Berserkers 15)"]			= { "Balduvian Rage"				, { false         , "Berserkers 2" } },
["Beast of Burden"]							= { "Beast of Burden"				, { "Thallids"   } },-- (Thallids 25)
["Belltower Sphinx (Wizards 14)"]			= { "Belltower Sphinx"				, { "Wizards 1"   , false          } },
["Belltower Sphinx (Wizards 26)"]			= { "Belltower Sphinx"				, { false         , "Wizards 2"    } },
["Betrayal of Flesh"]						= { "Betrayal of Flesh"				, { "Rats"       } },-- (Rats 52)
["Birchlore Rangers (Elves 52)"]			= { "Birchlore Rangers"				, { "Elves 1"     , false          } },
["Birchlore Rangers (Elves 53)"]			= { "Birchlore Rangers"				, { false         , "Elves 2"      } },
["Blade Sliver (Slivers 2)"]				= { "Blade Sliver"					, { "Slivers 1"   , false          , false         , false         } },
["Blade Sliver (Slivers 3)"]				= { "Blade Sliver"					, { false         , "Slivers 2"    , false         , false         } },
["Blade Sliver (Slivers 38)"]				= { "Blade Sliver"					, { false         , false          , "Slivers 3"   , false         } },
["Blade Sliver (Slivers 52)"]				= { "Blade Sliver"					, { false         , false          , false         , "Slivers 4"   } },
["Blademane Baku (Spirits 4)"]				= { "Blademane Baku"				, { "Spirits 1"   , false          , false          } },
["Blademane Baku (Spirits 30)"]				= { "Blademane Baku"				, { false         , "Spirits 2"    , false          } },
["Blademane Baku (Spirits 53)"]				= { "Blademane Baku"				, { false         , false          , "Spirits 3"    } },
["Blind Creeper (Zombies 4)"]				= { "Blind Creeper"					, { "Zombies 1"   , false          } },
["Blind Creeper (Zombies 29)"]				= { "Blind Creeper"					, { false         , "Zombies 2"    } },
["Blinking Spirit"]							= { "Blinking Spirit"				, { "Spirits"    } },-- (Spirits 49)
["Bloodline Shaman"]						= { "Bloodline Shaman"				, { "Elves"      } },-- (Elves 26)
["Bloodscent"]								= { "Bloodscent"					, { "Slivers"    } },-- (Slivers 4)
["Bonesplitter (Cats 5)"]					= { "Bonesplitter"					, { "Cats 1"      , false          } },
["Bonesplitter (Cats 40)"]					= { "Bonesplitter"					, { false         , "Cats 2"       } },
["Booby Trap"]								= { "Booby Trap"					, { "Wizards"    } },-- (Wizards 49)
["Boomerang (Wizards 16)"]					= { "Boomerang"						, { "Wizards 1"   , false          } },
["Boomerang (Wizards 29)"]					= { "Boomerang"						, { false         , "Wizards 2"    } },
["Bramble Elemental"]						= { "Bramble Elemental"				, { "Thallids"   } },-- (Thallids 29)
["Brood Sliver"]							= { "Brood Sliver"					, { "Slivers"    } },-- (Slivers 13)
["Burning-Tree Bloodscale"]					= { "Burning-Tree Bloodscale"		, { "Berserkers" } },-- (Berserkers 30)
["Call for Blood"]							= { "Call for Blood"				, { "Zombies"    } },-- (Zombies 52)
["Caller of the Claw"]						= { "Caller of the Claw"			, { "Elves"      } },-- (Elves 37)
["Carrion Howler"]							= { "Carrion Howler"				, { "Zombies"    } },-- (Zombies 38)
["Carrion Rats (Rats 40)"]					= { "Carrion Rats"					, { "Rats 1"      , false          , false          } },
["Carrion Rats (Rats 41)"]					= { "Carrion Rats"					, { false         , "Rats 2"       , false          } },
["Carrion Rats (Rats 53)"]					= { "Carrion Rats"					, { false         , false          , "Rats 3"       } },
["Celestial Kirin"]							= { "Celestial Kirin"				, { "Spirits"    } },-- (Spirits 25)
["Cephalid Constable"]						= { "Cephalid Constable"			, { "Ninjas"     } },-- (Ninjas 25)
["Chill Haunting"]							= { "Chill Haunting"				, { "Ninjas"     } },-- (Ninjas 26)
["Chittering Rats (Rats 5)"]				= { "Chittering Rats"				, { "Rats 1"      , false          , false          } },
["Chittering Rats (Rats 19)"]				= { "Chittering Rats"				, { false         , "Rats 2"       , false          } },
["Chittering Rats (Rats 54)"]				= { "Chittering Rats"				, { false         , false          , "Rats 3"       } },
["Clutch of the Undercity (Ninjas 14)"]		= { "Clutch of the Undercity"		, { "Ninjas 1"    , false          } },
["Clutch of the Undercity (Ninjas 38)"]		= { "Clutch of the Undercity"		, { false         , "Ninjas 2"     } },
["Coastal Piracy"]							= { "Coastal Piracy"				, { "Ninjas"     } },-- (Ninjas 49)
["Confiscate"]								= { "Confiscate"					, { "Angels"     } },-- (Angels 39)
["Cover of Darkness"]						= { "Cover of Darkness"				, { "Slivers"    } },-- (Slivers 37)
["Crippling Fatigue (Rats 6)"]				= { "Crippling Fatigue"				, { "Rats 1"      , false          } },
["Crippling Fatigue (Rats 30)"]				= { "Crippling Fatigue"				, { false         , "Rats 2"       } },
["Crown of Ascension"]						= { "Crown of Ascension"			, { "Ninjas"     } },-- (Ninjas 28)
["Crown of Vigor (Elves 54)"]				= { "Crown of Vigor"				, { "Elves"       , false          } },
["Crown of Vigor (Slivers 6)"]				= { "Crown of Vigor"				, { false         , "Slivers"      } },
["Crushing Pain"]							= { "Crushing Pain"					, { "Spirits"    } },-- (Spirits 15)
["Crypt Rats"]								= { "Crypt Rats"					, { "Rats"       } },-- (Rats 28)
["Crypt Sliver (Slivers 29)"]				= { "Crypt Sliver"					, { "Slivers 1"   , false          , false          } },
["Crypt Sliver (Slivers 30)"]				= { "Crypt Sliver"					, { false         , "Slivers 2"    , false          } },
["Crypt Sliver (Slivers 50)"]				= { "Crypt Sliver"					, { false         , false          , "Slivers 3"    } },
["Dance of Shadows"]						= { "Dance of Shadows"				, { "Zombies"    } },-- (Zombies 50)
["Darigaaz’s Caldera"]						= { "Darigaaz’s Caldera"			, { "Slivers"    } },-- (Slivers 26)
["Darigaaz’s Charm (Slivers 39)"]			= { "Darigaaz’s Charm"				, { "Slivers 1"   , false          } },
["Darigaaz’s Charm (Slivers 51)"]			= { "Darigaaz’s Charm"				, { false         , "Slivers 2"    } },
["Dark Banishing (Slivers 31)"]				= { "Dark Banishing"				, { "Slivers 1"   , false          , false          , false          , false          } },
["Dark Banishing (Slivers 32)"]				= { "Dark Banishing"				, { false         , "Slivers 2"    , false          , false          , false          } },
["Dark Banishing (Zombies 30)"]				= { "Dark Banishing"				, { false         , false          , "Zombies 1"    , false          , false          } },
["Dark Banishing (Zombies 41)"]				= { "Dark Banishing"				, { false         , false          , false          , "Zombies 2"    , false          } },
["Dark Banishing (Zombies 53)"]				= { "Dark Banishing"				, { false         , false          , false          , false          , "Zombies 3"    } },
["Death Denied (Zombies 42)"]				= { "Death Denied"					, { "Zombies 1"   , false          } },
["Death Denied (Zombies 54)"]				= { "Death Denied"					, { false         , "Zombies 2"    } },
["Death Pit Offering"]						= { "Death Pit Offering"			, { "Zombies"    } },-- (Zombies 25)
["Deflection"]								= { "Deflection"					, { "Ninjas"     } },-- (Ninjas 37)
["Dehydration (Wizards 41)"]				= { "Dehydration"					, { "Wizards 1"   , false          } },
["Dehydration (Wizards 42)"]				= { "Dehydration"					, { false         , "Wizards 2"    } },
["Detainment Spell"]						= { "Detainment Spell"				, { "Thallids"   } },-- (Thallids 32)
["Devouring Rage"]							= { "Devouring Rage"				, { "Spirits"    } },-- (Spirits 5)
["Diabolic Tutor"]							= { "Diabolic Tutor"				, { "Rats"       } },-- (Rats 51)
["Dimir Guildmage"]							= { "Dimir Guildmage"				, { "Wizards"    } },-- (Wizards 15)
["Dimir Infiltrator (Ninjas 4)"]			= { "Dimir Infiltrator"				, { "Ninjas 1"    , false          } },
["Dimir Infiltrator (Ninjas 5)"]			= { "Dimir Infiltrator"				, { false         , "Ninjas 2"     } },
["Dirge of Dread"]							= { "Dirge of Dread"				, { "Rats"       } },-- (Rats 18)
["Dirty Wererat (Rats 7)"]					= { "Dirty Wererat"					, { "Rats 1"      , false          } },
["Dirty Wererat (Rats 31)"]					= { "Dirty Wererat"					, { false         , "Rats 2"       } },
["Doomsday Specter"]						= { "Doomsday Specter"				, { "Ninjas"     } },-- (Ninjas 13)
["Elvish Champion"]							= { "Elvish Champion"				, { "Elves"      } },-- (Elves 49)
["Elvish Vanguard"]							= { "Elvish Vanguard"				, { "Elves"      } },-- (Elves 13)
["Elvish Warrior (Elves 41)"]				= { "Elvish Warrior"				, { "Elves 1"     , false          } },
["Elvish Warrior (Elves 42)"]				= { "Elvish Warrior"				, { false         , "Elves 2"      } },
["Engulfing Flames"]						= { "Engulfing Flames"				, { "Slivers"    } },-- (Slivers 5)
["Enormous Baloth (Beasts 2)"]				= { "Enormous Baloth"				, { "Beasts 1"    , false          } },
["Enormous Baloth (Beasts 50)"]				= { "Enormous Baloth"				, { false         , "Beasts 2"     } },
["Fallen Angel"]							= { "Fallen Angel"					, { "Zombies"    } },-- (Zombies 37)
["Fangren Firstborn"]						= { "Fangren Firstborn"				, { "Beasts"     } },-- (Beasts 13)
["Fangren Hunter"]							= { "Fangren Hunter"				, { "Beasts"     } },-- (Beasts 29)
["Fangren Pathcutter (Beasts 14)"]			= { "Fangren Pathcutter"			, { "Beasts 1"    , false          } },
["Fangren Pathcutter (Beasts 15)"]			= { "Fangren Pathcutter"			, { false         , "Beasts 2"     } },
["Feral Lightning (Berserkers 2)"]			= { "Feral Lightning"				, { "Berserkers 1", false          } },
["Feral Lightning (Berserkers 50)"]			= { "Feral Lightning"				, { false         , "Berserkers 2" } },
["Fertile Ground (Beasts 5)"]				= { "Fertile Ground"				, { "Beasts 1"    , false          } },
["Fertile Ground (Beasts 6)"]				= { "Fertile Ground"				, { false         , "Beasts 2"     } },
["Fertile Imagination (Thallids 2)"]		= { "Fertile Imagination"			, { "Thallids 1"  , false          } },
["Fertile Imagination (Thallids 38)"]		= { "Fertile Imagination"			, { false         , "Thallids 2"   } },
["Festering Goblin (Zombies 5)"]			= { "Festering Goblin"				, { "Zombies 1"   , false          , false          } },
["Festering Goblin (Zombies 6)"]			= { "Festering Goblin"				, { false         , "Zombies 2"    , false          } },
["Festering Goblin (Zombies 17)"]			= { "Festering Goblin"				, { false         , false          , "Zombies 3"    } },
["Flight of Fancy"]							= { "Flight of Fancy"				, { "Angels"     } },-- (Angels 30)
["Flowstone Shambler (Beasts 7)"]			= { "Flowstone Shambler"			, { "Beasts 1"    , false          } },
["Flowstone Shambler (Beasts 53)"]			= { "Flowstone Shambler"			, { false         , "Beasts 2"     } },
["Freewind Equenaut (Angels 4)"]			= { "Freewind Equenaut"				, { "Angels 1"    , false          , false          } },
["Freewind Equenaut (Angels 17)"]			= { "Freewind Equenaut"				, { false         , "Angels 2"     , false          } },
["Freewind Equenaut (Angels 41)"]			= { "Freewind Equenaut"				, { false         , false          , "Angels 3"     } },
["Frenzied Goblin"]							= { "Frenzied Goblin"				, { "Berserkers" } },-- (Berserkers 16)
["Frostling (Spirits 6)"]					= { "Frostling"						, { "Spirits 1"   , false          } },
["Frostling (Spirits 16)"]					= { "Frostling"						, { false         , "Spirits 2"    } },
["Genju of the Falls"]						= { "Genju of the Falls"			, { "Angels"     } },-- (Angels 40)
["Genju of the Fields"]						= { "Genju of the Fields"			, { "Angels"     } },-- (Angels 28)
["Ghor-Clan Savage (Berserkers 29)"]		= { "Ghor-Clan Savage"				, { "Berserkers 1", false          } },
["Ghor-Clan Savage (Berserkers 55)"]		= { "Ghor-Clan Savage"				, { false         , "Berserkers 2" } },
["Gluttonous Zombie"]						= { "Gluttonous Zombie"				, { "Zombies"    } },-- (Zombies 2)
["Goblin Chariot (Berserkers 4)"]			= { "Goblin Chariot"				, { "Berserkers 1", false          , false          } },
["Goblin Chariot (Berserkers 17)"]			= { "Goblin Chariot"				, { false         , "Berserkers 2" , false          } },
["Goblin Chariot (Berserkers 18)"]			= { "Goblin Chariot"				, { false         , false          , "Berserkers 3" } },
["Goblin Fire Fiend"]						= { "Goblin Fire Fiend"				, { "Berserkers" } },-- (Berserkers 5)
["Goblin Striker"]							= { "Goblin Striker"				, { "Berserkers" } },-- (Berserkers 19)
["Golgari Guildmage (Elves 50)"]			= { "Golgari Guildmage"				, { "Elves"       , false          } },
["Golgari Guildmage (Zombies 39)"]			= { "Golgari Guildmage"				, { false         , "Zombies"      } },
["Gravedigger (Zombies 7)"]					= { "Gravedigger"					, { "Zombies 1"   , false          , false          } },
["Gravedigger (Zombies 43)"]				= { "Gravedigger"					, { false         , "Zombies 2"    , false          } },
["Gravedigger (Zombies 55)"]				= { "Gravedigger"					, { false         , false          , "Zombies 3"    } },
["Gravestorm"]								= { "Gravestorm"					, { "Rats"       } },-- (Rats 37)
["Grifter’s Blade (Cats 27)"]				= { "Grifter’s Blade"				, { "Cats 1"      , false          } },
["Grifter’s Blade (Cats 50)"]				= { "Grifter’s Blade"				, { false         , "Cats 2"       } },
["Groffskithur (Beasts 30)"]				= { "Groffskithur"					, { "Beasts 1"    , false          , false          , false          } },
["Groffskithur (Beasts 41)"]				= { "Groffskithur"					, { false         , "Beasts 2"     , false          , false          } },
["Groffskithur (Beasts 42)"]				= { "Groffskithur"					, { false         , false          , "Beasts 3"     , false          } },
["Groffskithur (Beasts 55)"]				= { "Groffskithur"					, { false         , false          , false          , "Beasts 4"      } },
["Gruul Nodorog"]							= { "Gruul Nodorog"					, { "Beasts"     } },-- (Beasts 54)
["Gruul Scrapper (Berserkers 42)"]			= { "Gruul Scrapper"				, { "Berserkers 1", false          } },
["Gruul Scrapper (Berserkers 43)"]			= { "Gruul Scrapper"				, { false         , "Berserkers 2" } },
["Guardian’s Magemark (Angels 5)"]			= { "Guardian’s Magemark"			, { "Angels 1"    , false          } },
["Guardian’s Magemark (Angels 52)"]			= { "Guardian’s Magemark"			, { false         , "Angels 2"     } },
["Hair-Strung Koto"]						= { "Hair-Strung Koto"				, { "Wizards"    } },-- (Wizards 37)
["Heedless One"]							= { "Heedless One"					, { "Elves"      } },-- (Elves 39)
["Helldozer"]								= { "Helldozer"						, { "Zombies"    } },-- (Zombies 13)
["Herd Gnarr"]								= { "Herd Gnarr"					, { "Thallids"   } },-- (Thallids 17)
["Higure, the Still Wind"]					= { "Higure, the Still Wind"		, { "Ninjas"     } },-- (Ninjas 1)
["Hinder"]									= { "Hinder"						, { "Wizards"    } },-- (Wizards 38)
["Horizon Seed"]							= { "Horizon Seed"					, { "Spirits"    } },-- (Spirits 38)
["Horror of Horrors"]						= { "Horror of Horrors"				, { "Zombies"    } },-- (Zombies 26)
["Hunted Wumpus"]							= { "Hunted Wumpus"					, { "Beasts"     } },-- (Beasts 26)
["Hunter Sliver (Slivers 7)"]				= { "Hunter Sliver"					, { "Slivers 1"   , false          , false          } },
["Hunter Sliver (Slivers 8)"]				= { "Hunter Sliver"					, { false         , "Slivers 2"    , false          } },
["Hunter Sliver (Slivers 53)"]				= { "Hunter Sliver"					, { false         , false          , "Slivers 3"    } },
["Indrik Stomphowler (Beasts 38)"]			= {	"Indrik Stomphowler"			, { "Beasts 1"    , false          , false          } },
["Indrik Stomphowler (Beasts 51)"]			= { "Indrik Stomphowler"			, { false         , "Beasts 2"     , false          } },
["Indrik Stomphowler (Berserkers 38)"]		= { "Indrik Stomphowler"			, { false         , false          , "Berserkers"   } },
["Infernal Contract"]						= { "Infernal Contract"				, { "Rats"       } },-- (Rats 13)
["Infiltrator’s Magemark (Angels 7)"]		= { "Infiltrator’s Magemark"		, { "Angels 1"    , false          } },
["Infiltrator’s Magemark (Angels 19)"]		= { "Infiltrator’s Magemark"		, { false         , "Angels 2"     } },
["Iron-Barb Hellion (Beasts 3)"]			= { "Iron-Barb Hellion"				, { "Beasts 1"    , false          } },
["Iron-Barb Hellion (Beasts 4)"]			= { "Iron-Barb Hellion"				, { false         , "Beasts 2"     } },
["Jedit Ojanen of Efrava"]					= { "Jedit Ojanen of Efrava"		, { "Cats"       } },-- (Cats 1)
["Jedit’s Dragoons"]						= { "Jedit’s Dragoons"				, { "Cats"       } },-- (Cats 6)
["Jetting Glasskite"]						= { "Jetting Glasskite"				, { "Wizards"    } },-- (Wizards 27)
["Juniper Order Ranger"]					= { "Juniper Order Ranger"			, { "Thallids"   } },-- (Thallids 15)
["Kamahl, Pit Fighter"]						= { "Kamahl, Pit Fighter"			, { "Berserkers" } },-- (Berserkers 1)
["Kami of the Palace Fields (Spirits 27)"]	= { "Kami of the Palace Fields"		, { "Spirits 1"   , false          } },
["Kami of the Palace Fields (Spirits 50)"]	= { "Kami of the Palace Fields"		, { false         , "Spirits 2"    } },
["Karplusan Wolverine"]						= { "Karplusan Wolverine"			, { "Beasts"     } },-- (Beasts 18)
["Keening Banshee"]							= { "Keening Banshee"				, { "Ninjas"     } },-- (Ninjas 15)
["Keldon Mantle"]							= { "Keldon Mantle"					, { "Slivers"    } },-- (Slivers 54)
["Kirtar’s Wrath"]							= { "Kirtar’s Wrath"				, { "Spirits"    } },-- (Spirits 37)
["Kitsune Mystic|Autumn-Tail, Kitsune Sage"]= { "Kitsune Mystic|Autumn-Tail, Kitsune Sage"	, { "Angels"     } },-- (Angels 37)
["Kodama’s Reach"]							= { "Kodama’s Reach"				, { "Beasts"     } },-- (Beasts 43)
["Larceny"]									= { "Larceny"						, { "Rats"       } },-- (Rats 49)
["Lavaborn Muse"]							= { "Lavaborn Muse"					, { "Spirits"    } },-- (Spirits 13)
["Leonin Bola"]								= { "Leonin Bola"					, { "Cats"       } },-- (Cats 16)
["Leonin Den-Guard (Cats 17)"]				= { "Leonin Den-Guard"				, { "Cats 1"      , false          , false          } },
["Leonin Den-Guard (Cats 29)"]				= { "Leonin Den-Guard"				, { false         , "Cats 2"       , false          } },
["Leonin Den-Guard (Cats 30)"]				= { "Leonin Den-Guard"				, { false         , false          , "Cats 3"       } },
["Leonin Elder"]							= { "Leonin Elder"					, { "Cats"       } },-- (Cats 51)
["Leonin Shikari"]							= { "Leonin Shikari"				, { "Cats"       } },-- (Cats 37)
["Leonin Skyhunter"]						= { "Leonin Skyhunter"				, { "Cats"       } },-- (Cats 52)
["Leyline of the Meek"]						= { "Leyline of the Meek"			, { "Thallids"   } },-- (Thallids 13)
["Lightning Coils"]							= { "Lightning Coils"				, { "Berserkers" } },-- (Berserkers 37)
["Lightning Greaves"]						= { "Lightning Greaves"				, { "Cats"       } },-- (Cats 2)
["Llanowar Elite (Elves 16)"]				= { "Llanowar Elite"				, { "Elves 1"     , false          } },
["Llanowar Elite (Elves 17)"]				= { "Llanowar Elite"				, { false         , "Elves 2"      } },
["Lord of the Undead"]						= { "Lord of the Undead"			, { "Zombies"    } },-- (Zombies 1)
["Lovisa Coldeyes"]							= { "Lovisa Coldeyes"				, { "Berserkers" } },-- (Berserkers 13)
["Loxodon Stalwart"]						= { "Loxodon Stalwart"				, { "Angels"     } },-- (Angels 2)
["Luminous Angel"]							= { "Luminous Angel"				, { "Angels"     } },-- (Angels 25)
["Lure (Beasts 16)"]						= { "Lure"							, { "Beasts 1"    , false          } },
["Lure (Beasts 39)"]						= { "Lure"							, { false         , "Beasts 2"     } },
["Magma Sliver"]							= { "Magma Sliver"					, { "Slivers"    } },-- (Slivers 1)
["Marrow-Gnawer"]							= { "Marrow-Gnawer"					, { "Rats"       } },-- (Rats 1)
["Marsh Crocodile"]							= { "Marsh Crocodile"				, { "Ninjas"     } },-- (Ninjas 27)
["Martyr of Frost (Wizards 5)"]				= { "Martyr of Frost"				, { "Wizards 1"   , false          } },
["Martyr of Frost (Wizards 17)"]			= { "Martyr of Frost"				, { false         , "Wizards 2"    } },
["Merfolk of the Pearl Trident (Ninjas 42)"]= { "Merfolk of the Pearl Trident"	, { "Ninjas 1"    , false          } },
["Merfolk of the Pearl Trident (Ninjas 43)"]= { "Merfolk of the Pearl Trident"	, { false         , "Ninjas 2"     } },
["Mesmeric Orb"]							= { "Mesmeric Orb"					, { "Wizards"    } },-- (Wizards 13)
["Minamo Scrollkeeper"]						= { "Minamo Scrollkeeper"			, { "Wizards"    } },-- (Wizards 6)
["Mind Slash"]								= { "Mind Slash"					, { "Zombies"    } },-- (Zombies 14)
["Mirri, Cat Warrior"]						= { "Mirri, Cat Warrior"			, { "Cats"       } },-- (Cats 25)
["Mistblade Shinobi"]						= { "Mistblade Shinobi"				, { "Ninjas"     } },-- (Ninjas 29)
["Molder Slug"]								= { "Molder Slug"					, { "Beasts"     } },-- (Beasts 37)
["Nacatl War-Pride"]						= { "Nacatl War-Pride"				, { "Cats"       } },-- (Cats 38)
["Nantuko Husk (Zombies 3)"]				= { "Nantuko Husk"					, { "Zombies 1"   , false          , false          } },
["Nantuko Husk (Zombies 15)"]				= { "Nantuko Husk"					, { false         , "Zombies 2"    , false          } },
["Nantuko Husk (Zombies 27)"]				= { "Nantuko Husk"					, { false         , false          , "Zombies 3"    } },
["Naturalize"]								= { "Naturalize"					, { "Slivers"    } },-- (Slivers 55)
["Necromantic Thirst"]						= { "Necromantic Thirst"			, { "Zombies"    } },-- (Zombies 44)
["Nezumi Bone-Reader"]						= { "Nezumi Bone-Reader"			, { "Rats"       } },-- (Rats 50)
["Nezumi Cutthroat (Rats 17)"]				= { "Nezumi Cutthroat"				, { "Rats 1"      , false          } },
["Nezumi Cutthroat (Rats 29)"]				= { "Nezumi Cutthroat"				, { false         , "Rats 2"       } },
["Nezumi Graverobber|Nighteyes the Desecrator (Rats 38)"]	= { "Nezumi Graverobber|Nighteyes the Desecrator"	, { "Rats 1"      , false          } },
["Nezumi Graverobber|Nighteyes the Desecrator (Rats 39)"]	= { "Nezumi Graverobber|Nighteyes the Desecrator"	, { false         , "Rats 2"       } },
["Nightguard Patrol (Angels 18)"]			= { "Nightguard Patrol"				, { "Angels 1"    , false          } },
["Nightguard Patrol (Angels 29)"]			= { "Nightguard Patrol"				, { false         , "Angels 2"     } },
["Nightscape Battlemage"]					= { "Nightscape Battlemage"			, { "Ninjas"     } },-- (Ninjas 39)
["Nikko-Onna"]								= { "Nikko-Onna"					, { "Spirits"    } },-- (Spirits 2)
["Ninja of the Deep Hours (Ninjas 6)"]		= { "Ninja of the Deep Hours"		, { "Ninjas 1"    , false          , false          } },
["Ninja of the Deep Hours (Ninjas 30)"]		= { "Ninja of the Deep Hours"		, { false         , "Ninjas 2"     , false          } },
["Ninja of the Deep Hours (Ninjas 41)"]		= { "Ninja of the Deep Hours"		, { false         , false          , "Ninjas 3"     } },
["Nocturnal Raid"]							= { "Nocturnal Raid"				, { "Rats"       } },-- (Rats 3)
["Nullmage Shepherd (Elves 2)"]				= { "Nullmage Shepherd"				, { "Elves 1"     , false          } },
["Nullmage Shepherd (Elves 40)"]			= { "Nullmage Shepherd"				, { false         , "Elves 2"      } },
["Okiba-Gang Shinobi (Ninjas 53)"]			= { "Okiba-Gang Shinobi"			, { "Ninjas 1"    , false          } },
["Okiba-Gang Shinobi (Ninjas 54)"]			= { "Okiba-Gang Shinobi"			, { false         , "Ninjas 2"     } },
["One Dozen Eyes"]							= { "One Dozen Eyes"				, { "Beasts"     } },-- (Beasts 40)
["Overwhelm"]								= { "Overwhelm"						, { "Thallids"   } },-- (Thallids 39)
["Oyobi, Who Split the Heavens"]			= { "Oyobi, Who Split the Heavens"	, { "Spirits"    } },-- (Spirits 1)
["Pacifism (Angels 42)"]					= { "Pacifism"						, { "Angels 1"    , false          } },
["Pacifism (Angels 53)"]					= { "Pacifism"						, { false         , "Angels 2"     } },
["Pain Kami (Spirits 28)"]					= { "Pain Kami"						, { "Spirits 1"   , false          } },
["Pain Kami (Spirits 29)"]					= { "Pain Kami"						, { false         , "Spirits 2"    } },
["Patron of the Nezumi"]					= { "Patron of the Nezumi"			, { "Rats"       } },-- (Rats 25)
["Phantom Flock (Spirits 3)"]				= { "Phantom Flock"					, { "Spirits 1"   , false          } },
["Phantom Flock (Spirits 39)"]				= { "Phantom Flock"					, { false         , "Spirits 2"    } },
["Phantom Nomad (Spirits 7)"]				= { "Phantom Nomad"					, { "Spirits 1"   , false          } },
["Phantom Nomad (Spirits 17)"]				= { "Phantom Nomad"					, { false         , "Spirits 2"    } },
["Phantom Wings"]							= { "Phantom Wings"					, { "Ninjas"     } },-- (Ninjas 55)
["Plagued Rusalka (Zombies 28)"]			= { "Plagued Rusalka"				, { "Zombies 1"   , false          } },
["Plagued Rusalka (Zombies 40)"]			= { "Plagued Rusalka"				, { false         , "Zombies 2"    } },
["Plumes of Peace (Angels 31)"]				= { "Plumes of Peace"				, { "Angels 1"    , false          } },
["Plumes of Peace (Angels 55)"]				= { "Plumes of Peace"				, { false         , "Angels 2"     } },
["Predator’s Strike"]						= { "Predator’s Strike"				, { "Beasts"     } },-- (Beasts 52)
["Primal Forcemage (Berserkers 39)"]		= { "Primal Forcemage"				, { "Berserkers 1", false          , false          } },
["Primal Forcemage (Berserkers 40)"]		= { "Primal Forcemage"				, { false         , "Berserkers 2" , false          } },
["Primal Forcemage (Berserkers 52)"]		= { "Primal Forcemage"				, { false         , false          , "Berserkers 3" } },
["Pulse of the Tangle"]						= { "Pulse of the Tangle"			, { "Beasts"     } },-- (Beasts 25)
["Puppeteer (Wizards 2)"]					= { "Puppeteer"						, { "Wizards 1"   , false          } },
["Puppeteer (Wizards 39)"]					= { "Puppeteer"						, { false         , "Wizards 2"    } },
["Pyroclasm"]								= { "Pyroclasm"						, { "Beasts"     } },--(Beasts 27)
["Quick Sliver (Slivers 16)"]				= { "Quick Sliver"					, { "Slivers 1"   , false          , false          } },
["Quick Sliver (Slivers 17)"]				= { "Quick Sliver"					, { false         , "Slivers 2"    , false          } },
["Quick Sliver (Slivers 42)"]				= { "Quick Sliver"					, { false         , false          , "Slivers 3"    } },
["Raging Goblin (Berserkers 6)"]			= { "Raging Goblin"					, { "Berserkers 1", false          , false          } },
["Raging Goblin (Berserkers 7)"]			= { "Raging Goblin"					, { false         , "Berserkers 2" , false          } },
["Raging Goblin (Berserkers 41)"]			= { "Raging Goblin"					, { false         , false          , "Berserkers 3" } },
["Raksha Golden Cub"]						= { "Raksha Golden Cub"				, { "Cats"       } },-- (Cats 49)
["Rampant Growth (Beasts 19)"]				= { "Rampant Growth"				, { "Beasts 1"    , false          } },
["Rampant Growth (Beasts 28)"]				= { "Rampant Growth"				, { false         , "Beasts 2"     } },
["Rats’ Feast (Rats 44)"]					= { "Rats’ Feast"					, { "Rats 1"      , false          } },
["Rats’ Feast (Rats 55)"]					= { "Rats’ Feast"					, { false         , "Rats 2"       } },
["Rhox"]									= { "Rhox"							, { "Beasts"     } },-- (Beasts 1)
["Riptide Replicator"]						= { "Riptide Replicator"			, { "Slivers"    } },-- (Slivers 49)
["Root Sliver (Slivers 14)"]				= { "Root Sliver"					, { "Slivers 1"   , false          } },
["Root Sliver (Slivers 15)"]				= { "Root Sliver"					, { false         , "Slivers 2"    } },
["Sage Owl (Ninjas 7)"]						= { "Sage Owl"						, { "Ninjas 1"    , false          } },
["Sage Owl (Ninjas 31)"]					= { "Sage Owl"						, { false         , "Ninjas 2"     } },
["Saltblast (Cats 28)"]						= { "Saltblast"						, { "Cats 1"      , false          } },
["Saltblast (Cats 53)"]						= { "Saltblast"						, { false         , "Cats 2"       } },
["Sanctum Guardian"]						= { "Sanctum Guardian"				, { "Angels"     } },-- (Angels 51)
["Sandsower (Spirits 51)"]					= { "Sandsower"						, { "Spirits" 	  , false          } },
["Sandsower (Thallids 26)"]					= { "Sandsower"						, { false         , "Thallids" 	   } },
["Sanguine Praetor"]						= { "Sanguine Praetor"				, { "Zombies"    } },-- (Zombies 49)
["Savage Offensive"]						= { "Savage Offensive"				, { "Slivers"    } },-- (Slivers 18)
["Savage Thallid (Thallids 4)"]				= { "Savage Thallid"				, { "Thallids 1"  , false          } },
["Savage Thallid (Thallids 5)"]				= { "Savage Thallid"				, { false         , "Thallids 2"   } },
["Scab-Clan Mauler (Berserkers 31)"]		= { "Scab-Clan Mauler"				, { "Berserkers 1", false          } },
["Scab-Clan Mauler (Berserkers 56)"]		= { "Scab-Clan Mauler"				, { false         , "Berserkers 2" } },
["Scatter the Seeds"]						= { "Scatter the Seeds"				, { "Thallids"   } },-- (Thallids 18)
["Seed Spark"]								= { "Seed Spark"					, { "Thallids"   } },-- (Thallids 40)
["Seeker of Skybreak (Elves 29)"]			= { "Seeker of Skybreak"			, { "Elves 1"     , false          } },
["Seeker of Skybreak (Elves 30)"]			= { "Seeker of Skybreak"			, { false         , "Elves 2"      } },
["Seht’s Tiger"]							= { "Seht’s Tiger"					, { "Cats"       } },-- (Cats 13)
["Selesnya Evangel (Thallids 54)"]			= { "Selesnya Evangel"				, { "Thallids 1"  , false          } },
["Selesnya Evangel (Thallids 55)"]			= { "Selesnya Evangel"				, { false         , "Thallids 2"   } },
["Selesnya Guildmage (Elves 51)"]			= { "Selesnya Guildmage"			, { "Elves"       , false          } },
["Selesnya Guildmage (Thallids 51)"]		= { "Selesnya Guildmage"			, { false         , "Thallids"     } },
["Selesnya Sanctuary (Cats 33)"]			= { "Selesnya Sanctuary"			, { "Cats 1"      , false          } },
["Selesnya Sanctuary (Cats 44)"]			= { "Selesnya Sanctuary"			, { false         , "Cats 2"       } },
["Selesnya Signet (Cats 41)"]				= { "Selesnya Signet"				, { "Cats 1"      , false          , false          } },
["Selesnya Signet (Cats 55)"]				= { "Selesnya Signet"				, { false         , "Cats 2"       , false          } },
["Selesnya Signet (Cats 56)"]				= { "Selesnya Signet"				, { false         , false          , "Cats 3"       } },
["Serpent Skin"]							= { "Serpent Skin"					, { "Beasts"     } },-- (Beasts 44)
["Sever Soul (Rats 15)"]					= { "Sever Soul"					, { "Rats 1"      , false          } },
["Sever Soul (Rats 16)"]					= { "Sever Soul"					, { false         , "Rats 2"       } },
["Shinen of Fury’s Fire (Spirits 42)"]		= { "Shinen of Fury’s Fire"			, { "Spirits 1"   , false          , false          } },
["Shinen of Fury’s Fire (Spirits 54)"]		= { "Shinen of Fury’s Fire"			, { false         , "Spirits 2"    , false          } },
["Shinen of Fury’s Fire (Spirits 55)"]		= { "Shinen of Fury’s Fire"			, { false         , false          , "Spirits 3"    } },
["Shock (Berserkers 53)"]					= { "Shock"							, { "Berserkers 1", false          } },
["Shock (Berserkers 54)"]					= { "Shock"							, { false         , "Berserkers 2" } },
["Sinstriker’s Will"]						= { "Sinstriker’s Will"				, { "Angels"     } },-- (Angels 16)
["Skarrg, the Rage Pits"]					= { "Skarrg, the Rage Pits"			, { "Berserkers" } },-- (Berserkers 28)
["Skullsnatcher (Ninjas 17)"]				= { "Skullsnatcher"					, { "Ninjas 1"    , false          , false          , false          , false          , false          } },
["Skullsnatcher (Ninjas 18)"]				= { "Skullsnatcher"					, { false         , "Ninjas 2"     , false          , false          , false          , false          } },
["Skullsnatcher (Ninjas 19)"]				= { "Skullsnatcher"					, { false         , false          , "Ninjas 3"     , false          , false          , false          } },
["Skullsnatcher (Rats 4)"]					= { "Skullsnatcher"					, { false         , false          , false          , "Rats 1"       , false          , false          } },
["Skullsnatcher (Rats 42)"]					= { "Skullsnatcher"					, { false         , false          , false          , false          , "Rats 2"       , false          } },
["Skullsnatcher (Rats 43)"]					= { "Skullsnatcher"					, { false         , false          , false          , false          , false          , "Rats 3"       } },
["Skyhunter Cub (Cats 7)"]					= { "Skyhunter Cub"					, { "Cats 1"      , false          , false          } },
["Skyhunter Cub (Cats 18)"]					= { "Skyhunter Cub"					, { false         , "Cats 2"       , false          } },
["Skyhunter Cub (Cats 42)"]					= { "Skyhunter Cub"					, { false         , false          , "Cats 3"       } },
["Skyhunter Patrol (Cats 19)"]				= { "Skyhunter Patrol"				, { "Cats 1"      , false          } },
["Skyhunter Patrol (Cats 54)"]				= { "Skyhunter Patrol"				, { false         , "Cats 2"       } },
["Skyhunter Skirmisher (Cats 3)"]			= { "Skyhunter Skirmisher"			, { "Cats 1"      , false          } },
["Skyhunter Skirmisher (Cats 39)"]			= { "Skyhunter Skirmisher"			, { false         , "Cats 2"       } },
["Skyrider Trainee (Angels 6)"]				= { "Skyrider Trainee"				, { "Angels 1"    , false          } },
["Skyrider Trainee (Angels 54)"]			= { "Skyrider Trainee"				, { false         , "Angels 2"     } },
["Slagwurm Armor"]							= { "Slagwurm Armor"				, { "Cats"       } },-- (Cats 43)
["Soratami Mindsweeper (Wizards 3)"]		= { "Soratami Mindsweeper"			, { "Wizards 1"   , false          , false          } },
["Soratami Mindsweeper (Wizards 28)"]		= { "Soratami Mindsweeper"			, { false         , "Wizards 2"    , false          } },
["Soratami Mindsweeper (Wizards 50)"]		= { "Soratami Mindsweeper"			, { false         , false          , "Wizards 3"    } },
["Soratami Rainshaper (Wizards 30)"]		= { "Soratami Rainshaper"			, { "Wizards 1"   , false          } },
["Soratami Rainshaper (Wizards 43)"]		= { "Soratami Rainshaper"			, { false         , "Wizards 2"    } },
["Soul of Magma (Spirits 18)"]				= { "Soul of Magma"					, { "Spirits 1"   , false          } },
["Soul of Magma (Spirits 19)"]				= { "Soul of Magma"					, { false         , "Spirits 2"    } },
["Soul Warden (Thallids 14)"]				= { "Soul Warden"					, { "Thallids 1"  , false          } },
["Soul Warden (Thallids 27)"]				= { "Soul Warden"					, { false         , "Thallids 2"   } },
["Soulsworn Jury (Angels 43)"]				= { "Soulsworn Jury"				, { "Angels 1"    , false          } },
["Soulsworn Jury (Angels 44)"]				= { "Soulsworn Jury"				, { false         , "Angels 2"     } },
["Specter’s Shroud"]						= { "Specter’s Shroud"				, { "Cats"       } },-- (Cats 15)
["Spectral Sliver (Slivers 27)"]			= { "Spectral Sliver"				, { "Slivers 1"   , false          } },
["Spectral Sliver (Slivers 28)"]			= { "Spectral Sliver"				, { false         , "Slivers 2"    } },
["Spineless Thug (Zombies 18)"]				= { "Spineless Thug"				, { "Zombies 1"   , false          , false          } },
["Spineless Thug (Zombies 19)"]				= { "Spineless Thug"				, { false         , "Zombies 2"    , false          } },
["Spineless Thug (Zombies 31)"]				= { "Spineless Thug"				, { false         , false          , "Zombies 3"    } },
["Spirit Link (Angels 3)"]					= { "Spirit Link"					, { "Angels"      , false          } },
["Spirit Link (Spirits 40)"]				= { "Spirit Link"					, { false         ,  "Spirits"     } },
["Sporesower Thallid"]						= { "Sporesower Thallid"			, { "Thallids"   } },-- (Thallids 3)
["Sprout (Thallids 30)"]					= { "Sprout"						, { "Thallids 1"  , false          } },
["Sprout (Thallids 41)"]					= { "Sprout"						, { false         , "Thallids 2"   } },
["Stalking Vengeance"]						= { "Stalking Vengeance"			, { "Berserkers" } },-- (Berserkers 25)
["Stir the Pride"]							= { "Stir the Pride"				, { "Spirits"    } },-- (Spirits 52)
["Stormscape Battlemage"]					= { "Stormscape Battlemage"			, { "Ninjas"     } },-- (Ninjas 40)
["Strength in Numbers (Thallids 42)"]		= { "Strength in Numbers"			, { "Thallids 1"  , false          , false          } },
["Strength in Numbers (Thallids 52)"]		= { "Strength in Numbers"			, { false         , "Thallids 2"   , false          } },
["Strength in Numbers (Thallids 53)"]		= { "Strength in Numbers"			, { false         , false          , "Thallids 3"   } },
["Struggle for Sanity"]						= { "Struggle for Sanity"			, { "Ninjas"     } },-- (Ninjas 16)
["Supply|Demand (Thallids 16)"]				= { "Supply|Demand"					, { "Thallids 1"  , false          } },
["Supply|Demand (Thallids 28)"]				= { "Supply|Demand"					, { false         , "Thallids 2"   } },
["Suppress"]								= { "Suppress"						, { "Rats"       } },-- (Rats 26)
["Swarm of Rats (Rats 2)"]					= { "Swarm of Rats"					, { "Rats 1"      , false          , false          } },
["Swarm of Rats (Rats 14)"]					= { "Swarm of Rats"					, { false         , "Rats 2"       , false          } },
["Swarm of Rats (Rats 27)"]					= { "Swarm of Rats"					, { false         , false          , "Rats 3"       } },
["Sylvan Messenger (Elves 14)"]				= { "Sylvan Messenger"				, { "Elves 1"     , false          } },
["Sylvan Messenger (Elves 15)"]				= { "Sylvan Messenger"				, { false         , "Elves 2"      } },
["Taj-Nar Swordsmith"]						= { "Taj-Nar Swordsmith"			, { "Cats"       } },-- (Cats 4)
["Tears of Rage"]							= { "Tears of Rage"					, { "Berserkers" } },-- (Berserkers 3)
["Terramorphic Expanse (Cats 8)"]			= { "Terramorphic Expanse"			, { "Cats 1"      , false          , false          , false          } },
["Terramorphic Expanse (Cats 20)"]			= { "Terramorphic Expanse"			, { false         , "Cats 2"       , false          , false          } },
["Terramorphic Expanse (Cats 34)"]			= { "Terramorphic Expanse"			, { false         , false          , "Cats 3"       , false          } },
["Terramorphic Expanse (Cats 45)"]			= { "Terramorphic Expanse"			, { false         , false          , false          , "Cats 4"       } },
["Terrarion (Slivers 19)"]					= { "Terrarion"						, { "Slivers 1"   , false          } },
["Terrarion (Slivers 20)"]					= { "Terrarion"						, { false         , "Slivers 2"    } },
["Thallid Germinator (Thallids 19)"]		= { "Thallid Germinator"			, { "Thallids 1"  , false          , false          } },
["Thallid Germinator (Thallids 31)"]		= { "Thallid Germinator"			, { false         , "Thallids 2"   , false          } },
["Thallid Germinator (Thallids 43)"]		= { "Thallid Germinator"			, { false         , false          , "Thallids 3"   } },
["Thallid Shell-Dweller (Thallids 6)"]		= { "Thallid Shell-Dweller"			, { "Thallids 1"  , false          } },
["Thallid Shell-Dweller (Thallids 7)"]		= { "Thallid Shell-Dweller"			, { false         , "Thallids 2"   } },
["Thelonite Hermit"]						= { "Thelonite Hermit"				, { "Thallids"   } },-- (Thallids 49)
["Thran Golem"]								= { "Thran Golem"					, { "Angels"     } },-- (Angels 13)
["Threaten (Berserkers 26)"]				= { "Threaten"						, { "Berserkers 1", false          } },
["Threaten (Berserkers 27)"]				= { "Threaten"						, { false         , "Berserkers 2" } },
["Three Dreams"]							= { "Three Dreams"					, { "Angels"     } },-- (Angels 49)
["Throat Slitter (Ninjas 2)"]				= { "Throat Slitter"				, { "Ninjas 1"    , false          } },
["Throat Slitter (Ninjas 3)"]				= { "Throat Slitter"				, { false         , "Ninjas 2"     } },
["Thundermare"]								= { "Thundermare"					, { "Berserkers" } },-- (Berserkers 49)
["Timberwatch Elf (Elves 18)"]				= { "Timberwatch Elf"				, { "Elves 1"     , false          } },
["Timberwatch Elf (Elves 19)"]				= { "Timberwatch Elf"				, { false         , "Elves 2"      } },
["Tolsimir Wolfblood"]						= { "Tolsimir Wolfblood"			, { "Thallids"   } },-- (Thallids 1)
["Tower of Murmurs"]						= { "Tower of Murmurs"				, { "Wizards"    } },-- (Wizards 25)
["Toxin Sliver"]							= { "Toxin Sliver"					, { "Slivers"    } },-- (Slivers 25)
["Treetop Scout (Elves 5)"]					= { "Treetop Scout"					, { "Elves 1"     , false          } },
["Treetop Scout (Elves 6)"]					= { "Treetop Scout"					, { false         , "Elves 2"      } },
["Twilight Drover"]							= { "Twilight Drover"				, { "Thallids"   } },-- (Thallids 37)
["Undying Rage"]							= { "Undying Rage"					, { "Berserkers" } },-- (Berserkers 51)
["Urborg Emissary"]							= { "Urborg Emissary"				, { "Ninjas"     } },-- (Ninjas 50)
["Ursapine"]								= { "Ursapine"						, { "Beasts"     } },-- (Beasts 49)
["Vacuumelt (Wizards 4)"]					= { "Vacuumelt"						, { "Wizards 1"   , false          } },
["Vacuumelt (Wizards 40)"]					= { "Vacuumelt"						, { false         , "Wizards 2"    } },
["Vedalken Dismisser (Wizards 54)"]			= { "Vedalken Dismisser"			, { "Wizards 1"   , false          } },
["Vedalken Dismisser (Wizards 55)"]			= { "Vedalken Dismisser"			, { false         , "Wizards 2"    } },
["Vedalken Entrancer (Wizards 7)"]			= { "Vedalken Entrancer"			, { "Wizards 1"   , false          , false          , false          } },
["Vedalken Entrancer (Wizards 18)"]			= { "Vedalken Entrancer"			, { false         , "Wizards 2"    , false          , false          } },
["Vedalken Entrancer (Wizards 31)"]			= { "Vedalken Entrancer"			, { false         , false          , "Wizards 3"    , false          } },
["Vedalken Entrancer (Wizards 44)"]			= { "Vedalken Entrancer"			, { false         , false          , false          , "Wizards 4"    } },
["Vedalken Mastermind"]						= { "Vedalken Mastermind"			, { "Wizards"    } },-- (Wizards 51)
["Vesper Ghoul"]							= { "Vesper Ghoul"					, { "Ninjas"     } },-- (Ninjas 44)
["Viridian Scout"]							= { "Viridian Scout"				, { "Elves"      } },-- (Elves 31)
["Voice of the Woods"]						= { "Voice of the Woods"			, { "Elves"      } },-- (Elves 1)
["Volcanic Hammer (Beasts 17)"]				= { "Volcanic Hammer"				, { "Beasts 1"    , false          , false          } },
["Volcanic Hammer (Beasts 31)"]				= { "Volcanic Hammer"				, { false         , "Beasts 2"     , false          } },
["Volcanic Hammer (Spirits 43)"]			= { "Volcanic Hammer"				, { false         , false          , "Spirits"      } },
["Vulshok Gauntlets"]						= { "Vulshok Gauntlets"				, { "Cats"       } },-- (Cats 31)
["Vulshok Sorcerer"]						= { "Vulshok Sorcerer"				, { "Berserkers" } },-- (Berserkers 8)
["Walker of Secret Ways (Ninjas 51)"]		= { "Walker of Secret Ways"			, { "Ninjas 1"    , false          } },
["Walker of Secret Ways (Ninjas 52)"]		= { "Walker of Secret Ways"			, { false         , "Ninjas 2"     } },
["Waxmane Baku (Spirits 31)"]				= { "Waxmane Baku"					, { "Spirits 1"   , false          } },
["Waxmane Baku (Spirits 32)"]				= { "Waxmane Baku"					, { false         , "Spirits 2"    } },
["Wayfarer’s Bauble (Slivers 43)"]			= { "Wayfarer’s Bauble"				, { "Slivers 1"   , false          } },
["Wayfarer’s Bauble (Slivers 44)"]			= { "Wayfarer’s Bauble"				, { false         , "Slivers 2"    } },
["Wellwisher"]								= { "Wellwisher"					, { "Elves"      } },-- (Elves 7)
["Whitemane Lion"]							= { "Whitemane Lion"				, { "Cats"       } },-- (Cats 32)
["Wirewood Channeler"]						= { "Wirewood Channeler"			, { "Elves"      } },-- (Elves 27)
["Wirewood Herald"]							= { "Wirewood Herald"				, { "Elves"      } },-- (Elves 43)
["Wirewood Hivemaster (Elves 3)"]			= { "Wirewood Hivemaster"			, { "Elves 1"     , false          } },
["Wirewood Hivemaster (Elves 4)"]			= { "Wirewood Hivemaster"			, { false         , "Elves 2"      } },
["Wirewood Lodge"]							= { "Wirewood Lodge"				, { "Elves"      } },-- (Elves 28)
["Wirewood Pride (Elves 32)"]				= { "Wirewood Pride"				, { "Elves 1"     , false          , false          } },
["Wirewood Pride (Elves 44)"]				= { "Wirewood Pride"				, { false         , "Elves 2"      , false          } },
["Wirewood Pride (Elves 55)"]				= { "Wirewood Pride"				, { false         , false          , "Elves 3"      } },
["Wizard Replica"]							= { "Wizard Replica"				, { "Wizards"    } },-- (Wizards 19)
["Woebearer (Zombies 16)"]					= { "Woebearer"						, { "Zombies 1"   , false          } },
["Woebearer (Zombies 51)"]					= { "Woebearer"						, { false         , "Zombies 2"    } },
["Wojek Apothecary"]						= { "Wojek Apothecary"				, { "Thallids"   } },-- (Thallids 50)
["Yuki-Onna"]								= { "Yuki-Onna"						, { "Spirits"    } },-- (Spirits 41)
	},
},
[600] = { name="Unhinged",
	tla="UNH",
	foil="y",
	cardcount={ reg = 141, tok = 0 },
	variants={},
	foiltweak={
["Super Secret Tech"]			= { foil = true},
	},
},
[490] = { name="Deckmasters",
	tla="DKM",
	foil="n",
	cardcount={ reg=58, tok=0, nontrad=0, repl=0 }, 
	variants={
["Swamp"] 						= { "Swamp"		, { 1    , 2    , 3     } },
["Mountain"] 					= { "Mountain"	, { 1    , 2    , 3     } },
["Forest"] 						= { "Forest" 	, { 1    , 2    , 3     } },
["Swamp (42)"]					= { "Swamp"		, { 1    , false, false } },
["Swamp (43)"]					= { "Swamp"		, { false, 2    , false } },
["Swamp (44)"]					= { "Swamp"		, { false, false, 3     } },
["Mountain (45)"]				= { "Mountain"	, { 1    , false, false } },
["Mountain (46)"]				= { "Mountain"	, { false, 2    , false } },
["Mountain (47)"]				= { "Mountain"	, { false, false, 3     } },
["Forest (48)"]					= { "Forest"	, { 1    , false, false } },
["Forest (49)"]					= { "Forest"	, { false, 2    , false } },
["Forest (50)"]					= { "Forest"	, { false, false, 3     } },
["Lim-Dûl’s High Guard"] 		= { "Lim-Dûl’s High Guard"	, { 1    , 2     } },
["Lim-Dûl’s High Guard (6a)"] 	= { "Lim-Dûl’s High Guard"	, { 1    , false } },
["Lim-Dûl’s High Guard (6b)"] 	= { "Lim-Dûl’s High Guard"	, { false, 2     } },
["Phantasmal Fiend"] 			= { "Phantasmal Fiend"		, { 1    , 2     } },
["Phantasmal Fiend (8a)"] 		= { "Phantasmal Fiend"		, { 1    , false } },
["Phantasmal Fiend (8b)"] 		= { "Phantasmal Fiend"		, { false, 2     } },
["Guerrilla Tactics"] 			= { "Guerrilla Tactics"		, { 1    , 2     } },
["Guerrilla Tactics (13a)"]		= { "Guerrilla Tactics"		, { 1    , false } },
["Guerrilla Tactics (13b)"]		= { "Guerrilla Tactics"		, { false, 2     } },
--["Incinerate"] 				= { "Incinerate"			, { 1    , 2     } },
--["Incinerate (regular)"] 		= { "Incinerate"			, { 1    , false } },
["Incinerate"] 					= { "Incinerate"			, { 1    , false } },
["Incinerate (premium)"] 		= { "Incinerate"			, { false, 2     } },
["Storm Shaman"] 				= { "Storm Shaman"			, { 1    , 2     } },
["Storm Shaman (21a)"] 			= { "Storm Shaman"			, { 1    , false } },
["Storm Shaman (21b)"] 			= { "Storm Shaman"			, { false, 2     } },
["Yavimaya Ancients"] 			= { "Yavimaya Ancients"		, { 1    , 2     } },
["Yavimaya Ancients (31a)"]		= { "Yavimaya Ancients"		, { 1    , false } },
["Yavimaya Ancients (31b)"]		= { "Yavimaya Ancients"		, { false, 2     } },
--["Icy Manipulator"] 			= { "Icy Manipulator"		, { 1    , 2     } },
--["Icy Manipulator (regular)"] = { "Icy Manipulator"		, { 1    , false } },
["Icy Manipulator"] 			= { "Icy Manipulator"		, { 1    , false } },
["Icy Manipulator (premium)"] 	= { "Icy Manipulator"		, { false, 2     } },
["Phyrexian War Beast"] 		= { "Phyrexian War Beast"	, { 1    , 2     } },
["Phyrexian War Beast (37a)"] 	= { "Phyrexian War Beast"	, { 1    , false } },
["Phyrexian War Beast (37b)"] 	= { "Phyrexian War Beast"	, { false, 2     } },
	},
	foiltweak={
["Necropotence"]				= { foil = true},
["Incinerate (premium)"]		= { foil = true},
["Lhurgoyf"]					= { foil = true},
["Icy Manipulator (premium)"]	= { foil = true},
	},
},
[440] = { name="Beatdown",
	tla="BTD",
	foil="n",
	cardcount={ reg=90, tok=0, nontrad=0, repl=0 }, 
	variants={
["Island"] 						= { "Island" 	, { 1    , 2    , 3     } },
["Swamp"] 						= { "Swamp"		, { 1    , 2    , 3     } },
["Mountain"] 					= { "Mountain"	, { 1    , 2    , 3     } },
["Forest"] 						= { "Forest" 	, { 1    , 2    , 3     } },
["Island (79)"]					= { "Island"	, { 1    , false, false } },
["Island (80)"]					= { "Island"	, { false, 2    , false } },
["Island (81)"]					= { "Island"	, { false, false, 3     } },
["Swamp (82)"]					= { "Swamp"		, { 1    , false, false } },
["Swamp (83)"]					= { "Swamp"		, { false, 2    , false } },
["Swamp (84)"]					= { "Swamp"		, { false, false, 3     } },
["Mountain (85)"]				= { "Mountain"	, { 1    , false, false } },
["Mountain (86)"]				= { "Mountain"	, { false, 2    , false } },
["Mountain (87)"]				= { "Mountain"	, { false, false, 3     } },
["Forest (88)"]					= { "Forest"	, { 1    , false, false } },
["Forest (89)"]					= { "Forest"	, { false, 2    , false } },
["Forest (90)"]					= { "Forest"	, { false, false, 3     } },
	},
	foiltweak={
["Erhnam Djinn"]				= { foil = true},
["Sengir Vampire"]				= { foil = true},
	},
},
[415] = { name="Starter 2000",
	tla="S00",
	foil="n",
	cardcount={ reg=20, tok=0, nontrad=0, repl=0 }, 
	foiltweak={
["Rhox"]						= { foil = true},
	},
},
[405] = { name="Battle Royale",
	tla="BRB",
	foil="n",
	cardcount={ reg=136, tok=0, nontrad=0, repl=0 }, 
	variants={
["Plains"] 				= { "Plains"	, { 1    , 2    , 3    , 4    , 5    , 6    , 7    , 8   , 9     } },
["Island"] 				= { "Island"	, { 1    , 2    , 3    , 4    , 5 } },
["Swamp"] 				= { "Swamp"		, { 1    , 2    , 3    , 4 } },
["Mountain"] 			= { "Mountain"	, { 1    , 2    , 3    , 4    , 5    , 6    , 7    , 8   , 9     } },
["Forest"] 				= { "Forest"	, { 1    , 2    , 3    , 4    , 5    , 6    , 7    , 8   , 9     } },
["Plains (1)"]			= { "Plains"	, { 1    , false, false, false, false, false, false, false, false } },
["Plains (2)"]			= { "Plains"	, { false, 2    , false, false, false, false, false, false, false } },
["Plains (3)"]			= { "Plains"	, { false, false, 3    , false, false, false, false, false, false } },
["Plains (4)"]			= { "Plains"	, { false, false, false, 4    , false, false, false, false, false } },
["Plains (5)"]			= { "Plains"	, { false, false, false, false, 5    , false, false, false, false } },
["Plains (6)"]			= { "Plains"	, { false, false, false, false, false, 6    , false, false, false } },
["Plains (7)"]			= { "Plains"	, { false, false, false, false, false, false, 7    , false, false } },
["Plains (8)"]			= { "Plains"	, { false, false, false, false, false, false, false, 8    , false } },
["Plains (9)"]			= { "Plains"	, { false, false, false, false, false, false, false, false, 9     } },
["Island (1)"]			= { "Island"	, { 1    , false, false, false, false } },--Spires Right
["Island (2)"]			= { "Island"	, { false, 2    , false, false, false } },--Spires Left
["Island (3)"]			= { "Island"	, { false, false, 3    , false, false } },--River
["Island (4)"]			= { "Island"	, { false, false, false, 4    , false } },--No Sky
["Island (5)"]			= { "Island"	, { false, false, false, false, 5     } },--Beach
["Swamp (1)"]			= { "Swamp"		, { 1    , false, false, false } },
["Swamp (2)"]			= { "Swamp"		, { false, 2    , false, false } },
["Swamp (3)"]			= { "Swamp"		, { false, false, 3    , false } },
["Swamp (4)"]			= { "Swamp"		, { false, false, false, 4     } },
["Mountain (1)"]		= { "Mountain"	, { 1    , false, false, false, false, false, false, false, false } },
["Mountain (2)"]		= { "Mountain"	, { false, 2    , false, false, false, false, false, false, false } },
["Mountain (3)"]		= { "Mountain"	, { false, false, 3    , false, false, false, false, false, false } },
["Mountain (4)"]		= { "Mountain"	, { false, false, false, 4    , false, false, false, false, false } },
["Mountain (5)"]		= { "Mountain"	, { false, false, false, false, 5    , false, false, false, false } },
["Mountain (6)"]		= { "Mountain"	, { false, false, false, false, false, 6    , false, false, false } },
["Mountain (7)"]		= { "Mountain"	, { false, false, false, false, false, false, 7    , false, false } },
["Mountain (8)"]		= { "Mountain"	, { false, false, false, false, false, false, false, 8    , false } },
["Mountain (9)"]		= { "Mountain"	, { false, false, false, false, false, false, false, false, 9     } },
["Forest (1)"]			= { "Forest"	, { 1    , false, false, false, false, false, false, false, false } },
["Forest (2)"]			= { "Forest"	, { false, 2    , false, false, false, false, false, false, false } },
["Forest (3)"]			= { "Forest"	, { false, false, 3    , false, false, false, false, false, false } },
["Forest (4)"]			= { "Forest"	, { false, false, false, 4    , false, false, false, false, false } },
["Forest (5)"]			= { "Forest"	, { false, false, false, false, 5    , false, false, false, false } },
["Forest (6)"]			= { "Forest"	, { false, false, false, false, false, 6    , false, false, false } },
["Forest (7)"]			= { "Forest"	, { false, false, false, false, false, false, 7    , false, false } },
["Forest (8)"]			= { "Forest"	, { false, false, false, false, false, false, false, 8    , false } },
["Forest (9)"]			= { "Forest"	, { false, false, false, false, false, false, false, false, 9     } },
	},
},
[390] = { name="Starter 1999",
	tla="S99",
	foil="n",
	cardcount={ reg=173, tok=0, nontrad=0, repl=1 }, 
	variants={
["Plains"] 					= { "Plains"	, { 1    , 2    , 3    , 4     } },
["Island"] 					= { "Island" 	, { 1    , 2    , 3    , 4     } },
["Swamp"] 					= { "Swamp"		, { 1    , 2    , 3    , 4     } },
["Mountain"] 				= { "Mountain"	, { 1    , 2    , 3    , 4     } },
["Forest"] 					= { "Forest" 	, { 1    , 2    , 3    , 4     } },
["Plains (154)"]			= { "Plains"	, { 1    , false, false, false } }, 
["Plains (155)"]			= { "Plains"	, { false, 2    , false, false } },
["Plains (156)"]			= { "Plains"	, { false, false, 3    , false } },
["Plains (157)"]			= { "Plains"	, { false, false, false, 4     } },
["Island (158)"]			= { "Island"	, { 1    , false, false, false } },
["Island (159)"]			= { "Island"	, { false, 2    , false, false } },
["Island (160)"]			= { "Island"	, { false, false, 3    , false } },
["Island (161)"]			= { "Island"	, { false, false, false, 4     } },
["Swamp (162)"]				= { "Swamp"		, { 1    , false, false, false } },
["Swamp (163)"]				= { "Swamp"		, { false, 2    , false, false } },
["Swamp (164)"]				= { "Swamp"		, { false, false, 3    , false } },
["Swamp (165)"]				= { "Swamp"		, { false, false, false, 4     } },
["Mountain (166)"]			= { "Mountain"	, { 1    , false, false, false } },
["Mountain (167)"]			= { "Mountain"	, { false, 2    , false, false } },
["Mountain (168)"]			= { "Mountain"	, { false, false, 3    , false } },
["Mountain (169)"]			= { "Mountain"	, { false, false, false, 4     } },
["Forest (170)"]			= { "Forest"	, { 1    , false, false, false } },
["Forest (171)"]			= { "Forest"	, { false, 2    , false, false } },
["Forest (172)"]			= { "Forest"	, { false, false, 3    , false } },
["Forest (173)"]			= { "Forest"	, { false, false, false, 4     } },
["Thorn Elemental"]				= { "Thorn Elemental"	, { ""    , false     } },
["Thorn Elemental (oversized)"]	= { "Thorn Elemental"	, { false , "Replica" } },
	},
},
[380] = { name="Portal Three Kingdoms",
	tla="PTK",
	foil="n",
	cardcount={ reg = 180, tok = 0 }, -- Portal Three Kingdoms
	variants={
["Plains"] 						= { "Plains"	, { 1    , 2    , 3     } },
["Island"] 						= { "Island" 	, { 1    , 2    , 3     } },
["Swamp"] 						= { "Swamp"		, { 1    , 2    , 3     } },
["Mountain"] 					= { "Mountain"	, { 1    , 2    , 3     } },
["Forest"] 						= { "Forest" 	, { 1    , 2    , 3     } },
["Plains (166)"]				= { "Plains"	, { 1    , false, false } },
["Plains (167)"]				= { "Plains"	, { false, 2    , false } },
["Plains (168)"]				= { "Plains"	, { false, false, 3     } },
["Island (169)"]				= { "Island"	, { 1    , false, false } },
["Island (170)"]				= { "Island"	, { false, 2    , false } },
["Island (171)"]				= { "Island"	, { false, false, 3     } },
["Swamp (172)"]					= { "Swamp"		, { 1    , false, false } },
["Swamp (173)"]					= { "Swamp"		, { false, 2    , false } },
["Swamp (174)"]					= { "Swamp"		, { false, false, 3     } },
["Mountain (175)"]				= { "Mountain"	, { 1    , false, false } },
["Mountain (176)"]				= { "Mountain"	, { false, 2    , false } },
["Mountain (177)"]				= { "Mountain"	, { false, false, 3     } },
["Forest (178)"]				= { "Forest"	, { 1    , false, false } },
["Forest (179)"]				= { "Forest"	, { false, 2    , false } },
["Forest (180)"]				= { "Forest"	, { false, false, 3     } },
	},
},
[340] = { name="Anthologies",
	tla="ATH",
	foil="n",
	cardcount={ reg=85, tok=0, nontrad=0, repl=0 }, 
	variants={
["Plains"] 						= { "Plains" 	, { 1    , 2     } },
["Swamp"] 						= { "Swamp"		, { 1    , 2     } },
["Mountain"] 					= { "Mountain"	, { 1    , 2     } },
["Forest"] 						= { "Forest" 	, { 1    , 2     } },
["Plains (1)"]					= { "Plains"	, { 1    , false } },
["Plains (2)"]					= { "Plains"	, { false, 2     } },
["Swamp (1)"]					= { "Swamp"		, { 1    , false } },
["Swamp (2)"]					= { "Swamp"		, { false, 2     } },
["Mountain (1)"]				= { "Mountain"	, { 1    , false } },
["Mountain (2)"]				= { "Mountain"	, { false, 2     } },
["Forest (1)"]					= { "Forest"	, { 1    , false } },
["Forest (2)"]					= { "Forest"	, { false, 2     } },
	},
},
[320] = { name="Unglued",
	tla="UGL",
	foil="n",
	cardcount={ reg = 88 , tok = 6 },
	variants={
["B.F.M."] 						= { "B.F.M."	, { "Left", "Right" } },
["B.F.M. (Left)"] 				= { "B.F.M."	, { "Left", false   } },
["B.F.M. (Right)"] 				= { "B.F.M."	, { false , "Right" } },
	},
},
[310] = { name="Portal Second Age",
	tla="PO2",
	foil="n",
	cardcount={ reg = 165, tok = 0 },
	variants={
["Plains"] 						= { "Plains"	, { 1    , 2    , 3     } },
["Island"] 						= { "Island" 	, { 1    , 2    , 3     } },
["Swamp"] 						= { "Swamp"		, { 1    , 2    , 3     } },
["Mountain"] 					= { "Mountain"	, { 1    , 2    , 3     } },
["Forest"] 						= { "Forest" 	, { 1    , 2    , 3     } },
["Plains (1)"]					= { "Plains"	, { 1    , false, false } },
["Plains (2)"]					= { "Plains"	, { false, 2    , false } },
["Plains (3)"]					= { "Plains"	, { false, false, 3     } },
["Island (1)"]					= { "Island"	, { 1    , false, false } },
["Island (2)"]					= { "Island"	, { false, 2    , false } },
["Island (3)"]					= { "Island"	, { false, false, 3     } },
["Swamp (1)"]					= { "Swamp"		, { 1    , false, false } },
["Swamp (2)"]					= { "Swamp"		, { false, 2    , false } },
["Swamp (3)"]					= { "Swamp"		, { false, false, 3     } },
["Mountain (1)"]				= { "Mountain"	, { 1    , false, false } },
["Mountain (2)"]				= { "Mountain"	, { false, 2    , false } },
["Mountain (3)"]				= { "Mountain"	, { false, false, 3     } },
["Forest (1)"]					= { "Forest"	, { 1    , false, false } },
["Forest (2)"]					= { "Forest"	, { false, 2    , false } },
["Forest (3)"]					= { "Forest"	, { false, false, 3     } },
	},
},
[260] = { name="Portal",
	tla="POR",
	foil="n",
	cardcount={ reg = 228, tok = 0 },
	variants={
["Plains"] 						= { "Plains"	, { 1    , 2    , 3    , 4     } },
["Island"] 						= { "Island" 	, { 1    , 2    , 3    , 4     } },
["Swamp"] 						= { "Swamp"		, { 1    , 2    , 3    , 4     } },
["Mountain"] 					= { "Mountain"	, { 1    , 2    , 3    , 4     } },
["Forest"] 						= { "Forest" 	, { 1    , 2    , 3    , 4     } },
["Plains (1)"]					= { "Plains"	, { 1    , false, false, false } },--Clouds Right
["Plains (2)"]					= { "Plains"	, { false, 2    , false, false } },--White Sky
["Plains (3)"]					= { "Plains"	, { false, false, 3    , false } },--No Flowers
["Plains (4)"]					= { "Plains"	, { false, false, false, 4     } },--Clouds Left
["Island (1)"]					= { "Island"	, { 1    , false, false, false } },--Waterfall
["Island (2)"]					= { "Island"	, { false, 2    , false, false } },--Castle Cove
["Island (3)"]					= { "Island"	, { false, false, 3    , false } },--Beach Right
["Island (4)"]					= { "Island"	, { false, false, false, 4     } },--Sea Arch
["Swamp (1)"]					= { "Swamp"		, { 1    , false, false, false } },--Hanging Moss
["Swamp (2)"]					= { "Swamp"		, { false, 2    , false, false } },--Crossed Trees
["Swamp (3)"]					= { "Swamp"		, { false, false, 3    , false } },--White Tree
["Swamp (4)"]					= { "Swamp"		, { false, false, false, 4     } },--Yellow Sun
["Mountain (1)"]				= { "Mountain"	, { 1    , false, false, false } },--Middle Chasm
["Mountain (2)"]				= { "Mountain"	, { false, 2    , false, false } },--Peaks Right
["Mountain (3)"]				= { "Mountain"	, { false, false, 3    , false } },--Trees Center
["Mountain (4)"]				= { "Mountain"	, { false, false, false, 4     } },--Three Peaks
["Forest (1)"]					= { "Forest"	, { 1    , false, false, false } },--Large Middle
["Forest (2)"]					= { "Forest"	, { false, 2    , false, false } },--Slanted Tree
["Forest (3)"]					= { "Forest"	, { false, false, 3    , false } },--Ferns on Ground
["Forest (4)"]					= { "Forest"	, { false, false, false, 4     } },--Pale Trees
["Anaconda"]					= { "Anaconda"				, { ""	 , false } },
["Anaconda (ST)"]				= { "Anaconda"				, { false, "ST"	 } },
["Blaze"]						= { "Blaze"					, { ""	 , false } },
["Blaze (ST)"]					= { "Blaze"					, { false, "ST"	 } },
["Elite Cat Warrior"]			= { "Elite Cat Warrior"		, { ""	 , false } },
["Elite Cat Warrior (ST)"]		= { "Elite Cat Warrior"		, { false, "ST"	 } },
["Hand of Death"]				= { "Hand of Death"			, { ""	 , false } },
["Hand of Death (ST)"]			= { "Hand of Death"			, { false, "ST"	 } },
["Monstrous Growth"]			= { "Monstrous Growth"		, { ""	 , false } },
["Monstrous Growth (ST)"]		= { "Monstrous Growth"		, { false, "ST"	 } },
["Raging Goblin"]				= { "Raging Goblin"			, { ""	 , false } },
["Raging Goblin (ST)"]			= { "Raging Goblin"			, { false, "ST"	 } },
["Warrior's Charge"]			= { "Warrior's Charge"		, { ""	 , false } },
["Warrior's Charge (ST)"]		= { "Warrior's Charge"		, { false, "ST"	 } },
["Armored Pegasus"]				= { "Armored Pegasus"		, { ""	 , false } },
["Armored Pegasus (DG)"]		= { "Armored Pegasus"		, { false, "DG"	 } },
["Bull Hippo"]					= { "Bull Hippo"			, { ""	 , false } },
["Bull Hippo (DG)"]				= { "Bull Hippo"			, { false, "DG"	 } },
["Cloud Pirates"]				= { "Cloud Pirates"			, { ""	 , false } },
["Cloud Pirates (DG)"]			= { "Cloud Pirates"			, { false, "DG"	 } },
["Feral Shadow"]				= { "Feral Shadow"			, { ""	 , false } },
["Feral Shadow (DG)"]			= { "Feral Shadow"			, { false, "DG"	 } },
["Snapping Drake"]				= { "Snapping Drake"		, { ""	 , false } },
["Snapping Drake (DG)"]			= { "Snapping Drake"		, { false, "DG"	 } },
["Storm Crow"]					= { "Storm Crow"			, { ""	 , false } },
["Storm Crow (DG)"]				= { "Storm Crow"			, { false, "DG"	 } },
["Anakonda"]					= { "Anakonda"				, { ""	 , false } },
["Anakonda (ST)"]				= { "Anakonda"				, { false, "ST"	 } },
["Heiße Glut"]					= { "Heiße Glut"			, { ""	 , false } },
["Heiße Glut (ST)"]				= { "Heiße Glut"			, { false, "ST"	 } },
["Katzenkriegerelite"]			= { "Katzenkriegerelite"	, { ""	 , false } },
["Katzenkriegerelite (ST)"]		= { "Katzenkriegerelite"	, { false, "ST"	 } },
["Todbringende Hand"]			= { "Todbringende Hand"		, { ""	 , false } },
["Todbringende Hand (ST)"]		= { "Todbringende Hand"		, { false, "ST"	 } },
["Unheimliches Wachstum"]		= { "Unheimliches Wachstum"	, { ""	 , false } },
["Unheimliches Wachstum (ST)"]	= { "Unheimliches Wachstum"	, { false, "ST"	 } },
["Wütender Goblin"]				= { "Wütender Goblin"		, { ""	 , false } },
["Wütender Goblin (ST)"]		= { "Wütender Goblin"		, { false, "ST"	 } },
["Attacke der Krieger"]			= { "Attacke der Krieger"	, { ""	 , false } },
["Attacke der Krieger (ST)"]	= { "Attacke der Krieger"	, { false, "ST"	 } },
	},
},
[235] = { name="Multiverse Gift Box",
	tla="MGB",
	foil="n",
	cardcount={ reg=10, tok=0, nontrad=0, repl=0 }, 
},
[225] = { name="Introductory Two-Player Set",
	tla="I2P",
	foil="n",
	cardcount={ reg=67, tok=0, nontrad=0, repl=0 }, 
	variants={
["Plains"] 						= { "Plains"	, { 1    , 2    , 3     } },
["Island"] 						= { "Island" 	, { 1    , 2    , 3     } },
["Swamp"] 						= { "Swamp"		, { 1    , 2    , 3     } },
["Mountain"] 					= { "Mountain"	, { 1    , 2    , 3     } },
["Forest"] 						= { "Forest" 	, { 1    , 2    , 3     } },
["Plains (1)"]					= { "Plains"	, { 1    , false, false } },
["Plains (2)"]					= { "Plains"	, { false, 2    , false } },
["Plains (3)"]					= { "Plains"	, { false, false, 3     } },
["Island (1)"]					= { "Island"	, { 1    , false, false } },
["Island (2)"]					= { "Island"	, { false, 2    , false } },
["Island (3)"]					= { "Island"	, { false, false, 3     } },
["Swamp (1)"]					= { "Swamp"		, { 1    , false, false } },
["Swamp (2)"]					= { "Swamp"		, { false, 2    , false } },
["Swamp (3)"]					= { "Swamp"		, { false, false, 3     } },
["Mountain (1)"]				= { "Mountain"	, { 1    , false, false } },
["Mountain (2)"]				= { "Mountain"	, { false, 2    , false } },
["Mountain (3)"]				= { "Mountain"	, { false, false, 3     } },
["Forest (1)"]					= { "Forest"	, { 1    , false, false } },
["Forest (2)"]					= { "Forest"	, { false, 2    , false } },
["Forest (3)"]					= { "Forest"	, { false, false, 3     } },
	},
},
[201] = { name="Renaissance",-- (GER,FRA,ITA)
	tla="REN",
	foil="n",
	cardcount={ reg = 122, tok = 0 },
	-- only reg=69 in Rinascimento
	variants={
["Urza's Mine (1)"] 			= { "Urza's Mine"			, { 1    , false, false, false } },--Mouth
["Urza's Mine (2)"] 			= { "Urza's Mine"			, { false, 2    , false, false } },--Clawed Sphere
["Urza's Mine (3)"] 			= { "Urza's Mine"			, { false, false, 3    , false } },--Pully
["Urza's Mine (4)"] 			= { "Urza's Mine"			, { false, false, false, 4     } },--Tower
["Urza's Power Plant (1)"] 		= { "Urza's Power Plant"	, { 1    , false, false, false } },--Rock in Pot
["Urza's Power Plant (2)"] 		= { "Urza's Power Plant"	, { false, 2    , false, false } },--Columns
["Urza's Power Plant (3)"] 		= { "Urza's Power Plant"	, { false, false, 3    , false } },--Bug
["Urza's Power Plant (4)"] 		= { "Urza's Power Plant"	, { false, false, false, 4     } },--Sphere
["Urza's Tower (1)"] 			= { "Urza's Tower"			, { 1    , false, false, false } },--Forest
["Urza's Tower (2)"] 			= { "Urza's Tower"			, { false, 2    , false, false } },--Plains
["Urza's Tower (3)"] 			= { "Urza's Tower"			, { false, false, 3    , false } },--Mountains
["Urza's Tower (4)"] 			= { "Urza's Tower"			, { false, false, false, 4     } },--Shore
	},
},
[200] = { name="Chronicles",
	tla="CHR",
	foil="n",
	cardcount={ reg = 125, tok = 0 },
	variants={
["Urza's Mine"] 				= { "Urza's Mine"			, { 1    , 2    , 3    , 4 } },
["Urza's Power Plant"] 			= { "Urza's Power Plant"	, { 1    , 2    , 3    , 4 } },
["Urza's Tower"] 				= { "Urza's Tower"			, { 1    , 2    , 3    , 4 } },
["Urza's Mine (1)"] 			= { "Urza's Mine"			, { 1    , false, false, false } },--Mouth
["Urza's Mine (2)"] 			= { "Urza's Mine"			, { false, 2    , false, false } },--Clawed Sphere
["Urza's Mine (3)"] 			= { "Urza's Mine"			, { false, false, 3    , false } },--Pulley
["Urza's Mine (4)"] 			= { "Urza's Mine"			, { false, false, false, 4     } },--Tower
["Urza's Power Plant (1)"] 		= { "Urza's Power Plant"	, { 1    , false, false, false } },--Rock in Pot
["Urza's Power Plant (2)"] 		= { "Urza's Power Plant"	, { false, 2    , false, false } },--Columns
["Urza's Power Plant (3)"] 		= { "Urza's Power Plant"	, { false, false, 3    , false } },--Bug
["Urza's Power Plant (4)"] 		= { "Urza's Power Plant"	, { false, false, false, 4     } },--Sphere
["Urza's Tower (1)"] 			= { "Urza's Tower"			, { 1    , false, false, false } },--Forest
["Urza's Tower (2)"] 			= { "Urza's Tower"			, { false, 2    , false, false } },--Plains
["Urza's Tower (3)"] 			= { "Urza's Tower"			, { false, false, 3    , false } },--Mountains
["Urza's Tower (4)"] 			= { "Urza's Tower"			, { false, false, false, 4     } },--Shore
	},
},
[106] = { name="Collectors’ Edition (International)",
	tla="CEI",
	foil="n",
	cardcount={ reg=0, tok=0, nontrad=0, repl=302 },
	variants={
["Plains"] 						= { "Plains"	, { 1    , 2    , 3     } },
["Island"] 						= { "Island" 	, { 1    , 2    , 3     } },
["Swamp"] 						= { "Swamp"		, { 1    , 2    , 3     } },
["Mountain"] 					= { "Mountain"	, { 1    , 2    , 3     } },
["Forest"] 						= { "Forest" 	, { 1    , 2    , 3     } },
["Plains (1)"]					= { "Plains"	, { 1    , false, false } },
["Plains (2)"]					= { "Plains"	, { false, 2    , false } },
["Plains (3)"]					= { "Plains"	, { false, false, 3     } },
["Island (1)"]					= { "Island"	, { 1    , false, false } },
["Island (2)"]					= { "Island"	, { false, 2    , false } },
["Island (3)"]					= { "Island"	, { false, false, 3     } },
["Swamp (1)"]					= { "Swamp"		, { 1    , false, false } },
["Swamp (2)"]					= { "Swamp"		, { false, 2    , false } },
["Swamp (3)"]					= { "Swamp"		, { false, false, 3     } },
["Mountain (1)"]				= { "Mountain"	, { 1    , false, false } },
["Mountain (2)"]				= { "Mountain"	, { false, 2    , false } },
["Mountain (3)"]				= { "Mountain"	, { false, false, 3     } },
["Forest (1)"]					= { "Forest"	, { 1    , false, false } },
["Forest (2)"]					= { "Forest"	, { false, 2    , false } },
["Forest (3)"]					= { "Forest"	, { false, false, 3     } },
	},
},
[105] = { name="Collectors’ Edition (Domestic)",
	tla="CED",
	foil="n",
	cardcount={ reg=0, tok=0, nontrad=0, repl=302 },
	variants={
["Plains"] 						= { "Plains"	, { 1    , 2    , 3     } },
["Island"] 						= { "Island" 	, { 1    , 2    , 3     } },
["Swamp"] 						= { "Swamp"		, { 1    , 2    , 3     } },
["Mountain"] 					= { "Mountain"	, { 1    , 2    , 3     } },
["Forest"] 						= { "Forest" 	, { 1    , 2    , 3     } },
["Plains (1)"]					= { "Plains"	, { 1    , false, false } },--No Trees
["Plains (2)"]					= { "Plains"	, { false, 2    , false } },--Trees
["Plains (3)"]					= { "Plains"	, { false, false, 3     } },--No Mountains
["Island (1)"]					= { "Island"	, { 1    , false, false } },--Purple
["Island (2)"]					= { "Island"	, { false, 2    , false } },--Green
["Island (3)"]					= { "Island"	, { false, false, 3     } },--Blue
["Swamp (1)"]					= { "Swamp"		, { 1    , false, false } },--Low Branch
["Swamp (2)"]					= { "Swamp"		, { false, 2    , false } },--High Branch
["Swamp (3)"]					= { "Swamp"		, { false, false, 3     } },--Two Branches
["Mountain (1)"]				= { "Mountain"	, { 1    , false, false } },--Slate
["Mountain (2)"]				= { "Mountain"	, { false, 2    , false } },--Fog
["Mountain (3)"]				= { "Mountain"	, { false, false, 3     } },--Dirt
["Forest (1)"]					= { "Forest"	, { 1    , false, false } },--Rocks
["Forest (2)"]					= { "Forest"	, { false, 2    , false } },--Path
["Forest (3)"]					= { "Forest"	, { false, false, 3     } },--Eyes
	},
},
[70] = { name="Vanguard",
	tla="VNG",
	foil="n",
	cardcount={ reg=0, tok=0, nontrad=32, repl=0 },
	variants = {
["Ashnod"]		= { "Ashnod" 		, { "Nontrad" } },
["Barrin"]		= { "Barrin" 		, { "Nontrad" } },
["Crovax"]		= { "Crovax" 		, { "Nontrad" } },
["Eladamri"]	= { "Eladamri" 		, { "Nontrad" } },
["Ertai"]		= { "Ertai" 		, { "Nontrad" } },
["Gerrard"]		= { "Gerrard" 		, { "Nontrad" } },
["Gix"]			= { "Gix" 			, { "Nontrad" } },
["Greven il-Vec"]	= { "Greven il-Vec"	, { "Nontrad" } },
["Hanna"]		= { "Hanna" 		, { "Nontrad" } },
["Karn"]		= { "Karn" 			, { "Nontrad" } },
["Lyna"]		= { "Lyna" 			, { "Nontrad" } },
["Maraxus"]		= { "Maraxus" 		, { "Nontrad" } },
["Mirri"]		= { "Mirri" 		, { "Nontrad" } },
["Mishra"]		= { "Mishra" 		, { "Nontrad" } },
["Multani"]		= { "Multani" 		, { "Nontrad" } },
["Oracle"]		= { "Oracle" 		, { "Nontrad" } },
["Orim"]		= { "Orim" 			, { "Nontrad" } },
["Rofellos"]	= { "Rofellos" 		, { "Nontrad" } },
["Selenia"]		= { "Selenia" 		, { "Nontrad" } },
["Serra"]		= { "Serra" 		, { "Nontrad" } },
["Sidar Kondo"]	= { "Sidar Kondo"	, { "Nontrad" } },
["Sisay"]		= { "Sisay" 		, { "Nontrad" } },
["Sliver Queen, Brood Mother"]	= { "Sliver Queen, Brood Mother"	, { "Nontrad" } },
["Squee"]		= { "Squee" 		, { "Nontrad" } },
["Starke"]		= { "Starke" 		, { "Nontrad" } },
["Tahngarth"]	= { "Tahngarth" 	, { "Nontrad" } },
["Takara"]		= { "Takara" 		, { "Nontrad" } },
["Tawnos"]		= { "Tawnos" 		, { "Nontrad" } },
["Titania"]		= { "Titania" 		, { "Nontrad" } },
["Urza"]		= { "Urza" 			, { "Nontrad" } },
["Volrath"]		= { "Volrath" 		, { "Nontrad" } },
["Xantcha"]		= { "Xantcha" 		, { "Nontrad" } },
	},
},
[69] = { name="Box Topper Cards",
	tla="BTP",
	foil="n",
	cardcount={ reg=0, tok=0, nontrad=0, repl=52 }, 
	variants={
["Ambition’s Cost"]				= { "Ambition’s Cost"			, { "8ED" } },
["Avatar of Hope"]				= { "Avatar of Hope"			, { "8ED", "PRM" } },
["Avatar of Hope (8ED)"]		= { "Avatar of Hope"			, { "8ED", false } },
["Avatar of Hope (PRM)"]		= { "Avatar of Hope"			, { false, "PRM" } },
["Blinding Angel"]				= { "Blinding Angel"			, { "8ED" } },
["Clone"]						= { "Clone"						, { "9ED" } },
["Curiosity"]					= { "Curiosity"					, { "8ED" } },
["Diabolic Tutor"]				= { "Diabolic Tutor"			, { "8ED" } },
["Enrage"]						= { "Enrage"					, { "8ED" } },
["Force of Nature"]				= { "Force of Nature"			, { "9ED" } },
["Furnace of Rath"]				= { "Furnace of Rath"			, { "8ED" } },
["Guerrilla Tactics"]			= { "Guerrilla Tactics"			, { "8ED" } },
["Hell’s Caretaker"]			= { "Hell’s Caretaker"			, { "9ED" } },
["Hypnotic Specter"]			= { "Hypnotic Specter"			, { "9ED" } },
["Icy Manipulator"]				= { "Icy Manipulator"			, { "9ED" } },
["Intruder Alarm"]				= { "Intruder Alarm"			, { "8ED" } },
["Jester’s Cap"]				= { "Jester’s Cap"				, { "9ED" } },
["Kird Ape"]					= { "Kird Ape"					, { "9ED" } },
["Llanowar Behemoth"]			= { "Llanowar Behemoth"			, { "8ED" } },
["Llanowar Elves"]				= { "Llanowar Elves"			, { "9ED" } },
["Lord of the Undead"]			= { "Lord of the Undead"		, { "8ED", "PRM" } },
["Lord of the Undead (8ED)"]	= { "Lord of the Undead"		, { "8ED", false } },
["Lord of the Undead (PRM)"]	= { "Lord of the Undead"		, { false, "PRM" } },
["Mahamoti Djinn"]				= { "Mahamoti Djinn"			, { "9ED" } },
["Merchant of Secrets"]			= { "Merchant of Secrets"		, { "8ED" } },
["Merchant Scroll"]			 	= { "Merchant Scroll"			, { "8ED" } },
["Mind Bend"]					= { "Mind Bend"					, { "8ED" } },
["Mind Sludge"]					= { "Mind Sludge"				, { "8ED" } },
["Naturalize"]					= { "Naturalize"				, { "8ED" } },
["Nekrataal"]					= { "Nekrataal"					, { "8ED" } },
["Obliterate"]					= { "Obliterate"				, { "8ED", "PRM" } },
["Obliterate (8ED)"]			= { "Obliterate"				, { "8ED", false } },
["Obliterate (PRM)"]			= { "Obliterate"				, { false, "PRM" } },
["Orcish Spy"]					= { "Orcish Spy"				, { "8ED" } },
["Paladin en-Vec"]				= { "Paladin en-Vec"			, { "9ED" } },
["Phyrexian Arena"]				= { "Phyrexian Arena"			, { "8ED" } },
["Phyrexian Plaguelord"]		= { "Phyrexian Plaguelord"		, { "8ED", "PRM" } },
["Phyrexian Plaguelord (8ED)"]	= { "Phyrexian Plaguelord"		, { "8ED", false } },
["Phyrexian Plaguelord (PRM)"]	= { "Phyrexian Plaguelord"		, { false, "PRM" } },
["Plow Under"]					= { "Plow Under"				, { "8ED" } },
["Primeval Force"]				= { "Primeval Force"			, { "8ED" } },
["Rathi Dragon"]				= { "Rathi Dragon"				, { "9ED" } },
["Rewind"]						= { "Rewind"					, { "8ED" } },
["Rukh Egg"]					= { "Rukh Egg"					, { "8ED" } },
["Sage of Lat-Nam"]				= { "Sage of Lat-Nam"			, { "8ED" } },
["Savannah Lions"]				= { "Savannah Lions"			, { "8ED", "PRM" } },
["Savannah Lions (8ED)"]		= { "Savannah Lions"			, { "8ED", false } },
["Savannah Lions (PRM)"]		= { "Savannah Lions"			, { false, "PRM" } },
["Serra Angel"]					= { "Serra Angel"				, { "9ED" } },
["Skull of Orm"]				= { "Skull of Orm"				, { "8ED" } },
["Suntail Hawk"]				= { "Suntail Hawk"				, { "8ED" } },
["Two-Headed Dragon"]			= { "Two-Headed Dragon"			, { "8ED", "PRM" } },
["Two-Headed Dragon (8ED)"]		= { "Two-Headed Dragon"			, { "8ED", false } }, 
["Two-Headed Dragon (PRM)"]		= { "Two-Headed Dragon"			, { false, "PRM" } }, 
["Underworld Dreams"]			= { "Underworld Dreams"			, { "8ED" } },
["Vampiric Spirit"]				= { "Vampiric Spirit"			, { "8ED" } },
["Verdant Force"]				= { "Verdant Force"				, { "9ED" } },
["Vexing Arcanix"]				= { "Vexing Arcanix"			, { "8ED" } },
	},
},
---not really a seperate subtable, just a bookmark for quick navigation in eclipse.
-- @field [parent=#Data.sets] #table Promos
Promos = nil,
[55] = { name="Ugin’s Fate Promos",
	tla="UGF",
	foil="n",
	cardcount={ reg=26, tok=0, nontrad=0, repl=0 },
},
[53] = { name="Holiday Gift Box Promos",
	tla="GFB",
	foilonly=true,
	cardcount={ reg=4, tok=0, nontrad=0, repl=0 },
},
[52] = { name="Intro Pack Promos",
	tla="INP",
	foilonly=true,
	cardcount={ reg=20, tok=0, nontrad=0, repl=0 },
	variants={
["Ankle Shanker"]				= { "Ankle Shanker"				, { "KTK" } },
["Avalanche Tusker"]			= { "Avalanche Tusker"			, { "KTK" } },
["Ivorytusk Fortress"]			= { "Ivorytusk Fortress"		, { "KTK" } },
["Rakshasa Vizier"]				= { "Rakshasa Vizier"			, { "KTK" } },
["Sage of the Inward Eye"]		= { "Sage of the Inward Eye"	, { "KTK" } },
["Archfiend of Depravity"]		= { "Archfiend of Depravity"	, { "FRF" } },
["Dragonscale General"]			= { "Dragonscale General"		, { "FRF" } },
["Flamerush Rider"]				= { "Flamerush Rider"			, { "FRF" } },
["Sage-Eye Avengers"]			= { "Sage-Eye Avengers"			, { "FRF" } },
["Temur War Shaman"]			= { "Temur War Shaman"			, { "FRF" } },
["Arashin Sovereign"]			= { "Arashin Sovereign"			, { "DTK" } },
["Boltwing Marauder"]			= { "Boltwing Marauder"			, { "DTK" } },
["Harbinger of the Hunt"]		= { "Harbinger of the Hunt"		, { "DTK" } },
["Necromaster Dragon"]			= { "Necromaster Dragon"		, { "DTK" } },
["Pristine Skywise"]			= { "Pristine Skywise"			, { "DTK" } },
["Alhammarret, High Arbiter"]	= { "Alhammarret, High Arbiter"	, { "ORI" } },
["Dwynen, Gilt-Leaf Daen"]		= { "Dwynen, Gilt-Leaf Daen"	, { "ORI" } },
["Hixus, Prison Warden"]		= { "Hixus, Prison Warden"		, { "ORI" } },
["Kothophed, Soul Hoarder"]		= { "Kothophed, Soul Hoarder"	, { "ORI" } },
["Pia and Kiran Nalaar"]		= { "Pia and Kiran Nalaar"		, { "ORI" } },
["Drowner of Hope"]				= { "Drowner of Hope"			, { "BFZ" } },
	}, 
},
[50] = { name="Full Box Promotion",
	tla="FBP",
	foilonly=true,
	cardcount={ reg=26, tok=0, nontrad=0, repl=0 },-- 1 FRA, 19 GER, 1 POR, 1 RUS, 5 SPA
},
[45] = { name="Magic Premiere Shop",
	tla="MPS",
--JPN only
	foil="y",
	cardcount={ reg=51, tok=0, nontrad=0, repl=0 }, 
--TODO [45] foiltweak - check whether "yes" are really "yes", if they're "Only" change to foilonly=true.
	variants={
["Plains (ALA)"]		= { "Plains"	, { "ALA", false, false, false, false, false, false    , false  , false   , false      } },
["Plains (ISD)"]		= { "Plains"	, { false, "ISD", false, false, false, false, false    , false  , false   , false      } },
["Plains (LRW)"]		= { "Plains"	, { false, false, "LRW", false, false, false, false    , false  , false   , false      } },
["Plains (SOM)"]		= { "Plains"	, { false, false, false, "SOM", false, false, false    , false  , false   , false      } },
["Plains (TSP)"]		= { "Plains"	, { false, false, false, false, "TSP", false, false    , false  , false   , false      } },
["Plains (ZEN)"]		= { "Plains"	, { false, false, false, false, false, "ZEN", false    , false  , false   , false      } },
["Plains (Azorius)"]	= { "Plains"	, { false, false, false, false, false, false, "Azorius", false  , false   , false      } },
["Plains (Boros)"]		= { "Plains"	, { false, false, false, false, false, false, false    , "Boros", false   , false      } },
["Plains (Orzhov)"]		= { "Plains"	, { false, false, false, false, false, false, false    , false  , "Orzhov", false      } },
["Plains (Selesnya)"]	= { "Plains"	, { false, false, false, false, false, false, false    , false  , false   , "Selesnya" } },
["Island (ALA)"]		= { "Island"	, { "ALA", false, false, false, false, false, false    , false  , false  , false    } },
["Island (ISD)"]		= { "Island"	, { false, "ISD", false, false, false, false, false    , false  , false  , false    } },
["Island (LRW)"]		= { "Island"	, { false, false, "LRW", false, false, false, false    , false  , false  , false    } },
["Island (SOM)"]		= { "Island"	, { false, false, false, "SOM", false, false, false    , false  , false  , false    } },
["Island (TSP)"]		= { "Island"	, { false, false, false, false, "TSP", false, false    , false  , false  , false    } },
["Island (ZEN)"]		= { "Island"	, { false, false, false, false, false, "ZEN", false    , false  , false  , false    } },
["Island (Azorius)"]	= { "Island"	, { false, false, false, false, false, false, "Azorius", false  , false  , false    } },
["Island (Dimir)"]		= { "Island"	, { false, false, false, false, false, false, false    , "Dimir", false  , false    } },
["Island (Izzet)"]		= { "Island"	, { false, false, false, false, false, false, false    , false  , "Izzet", false    } },
["Island (Simic)"]		= { "Island"	, { false, false, false, false, false, false, false    , false  , false  , "Simic" } },
["Swamp (ALA)"]			= { "Swamp"		, { "ALA", false, false, false, false, false, false  , false    , false   , false    } },
["Swamp (ISD)"]			= { "Swamp"		, { false, "ISD", false, false, false, false, false  , false    , false   , false    } },
["Swamp (LRW)"]			= { "Swamp"		, { false, false, "LRW", false, false, false, false  , false    , false   , false    } },
["Swamp (SOM)"]			= { "Swamp"		, { false, false, false, "SOM", false, false, false  , false    , false   , false    } },
["Swamp (TSP)"]			= { "Swamp"		, { false, false, false, false, "TSP", false, false  , false    , false   , false    } },
["Swamp (ZEN)"]			= { "Swamp"		, { false, false, false, false, false, "ZEN", false  , false    , false   , false    } },
["Swamp (Dimir)"]		= { "Swamp"		, { false, false, false, false, false, false, "Dimir", false    , false   , false    } },
["Swamp (Golgari)"]		= { "Swamp"		, { false, false, false, false, false, false, false  , "Golgari", false   , false    } },
["Swamp (Orzhov)"]		= { "Swamp"		, { false, false, false, false, false, false, false  , false    , "Orzhov", false    } },
["Swamp (Rakdos)"]		= { "Swamp"		, { false, false, false, false, false, false, false  , false    , false   , "Rakdos" } },
["Mountain (ALA)"]		= { "Mountain"	, { "ALA", false, false, false, false, false, false  , false  , false  , false    } },
["Mountain (ISD)"]		= { "Mountain"	, { false, "ISD", false, false, false, false, false  , false  , false  , false    } },
["Mountain (LRW)"]		= { "Mountain"	, { false, false, "LRW", false, false, false, false  , false  , false  , false    } },
["Mountain (SOM)"]		= { "Mountain"	, { false, false, false, "SOM", false, false, false  , false  , false  , false    } },
["Mountain (TSP)"]		= { "Mountain"	, { false, false, false, false, "TSP", false, false  , false  , false  , false    } },
["Mountain (ZEN)"]		= { "Mountain"	, { false, false, false, false, false, "ZEN", false  , false  , false  , false    } },
["Mountain (Boros)"]	= { "Mountain"	, { false, false, false, false, false, false, "Boros", false  , false  , false    } },
["Mountain (Gruul)"]	= { "Mountain"	, { false, false, false, false, false, false, false  , "Gruul", false  , false    } },
["Mountain (Izzet)"]	= { "Mountain"	, { false, false, false, false, false, false, false  , false  , "Izzet", false    } },
["Mountain (Rakdos)"]	= { "Mountain"	, { false, false, false, false, false, false, false  , false  , false  , "Rakdos" } },
["Forest (ALA)"]		= { "Forest"	, { "ALA", false, false, false, false, false, false    , false  , false     , false    } },
["Forest (ISD)"]		= { "Forest"	, { false, "ISD", false, false, false, false, false    , false  , false     , false    } },
["Forest (LRW)"]		= { "Forest"	, { false, false, "LRW", false, false, false, false    , false  , false     , false    } },
["Forest (SOM)"]		= { "Forest"	, { false, false, false, "SOM", false, false, false    , false  , false     , false    } },
["Forest (TSP)"]		= { "Forest"	, { false, false, false, false, "TSP", false, false    , false  , false     , false    } },
["Forest (ZEN)"]		= { "Forest"	, { false, false, false, false, false, "ZEN", false    , false  , false     , false    } },
["Forest (Golgari)"]	= { "Forest"	, { false, false, false, false, false, false, "Golgari", false  , false     , false    } },
["Forest (Gruul)"]		= { "Forest"	, { false, false, false, false, false, false, false    , "Gruul", false     , false    } },
["Forest (Selesnya)"]	= { "Forest"	, { false, false, false, false, false, false, false    , false  , "Selesnya", false    } },
["Forest (Simic)"]		= { "Forest"	, { false, false, false, false, false, false, false    , false  , false     , "Simic" } },
	},
},
[43] = { name="Two-Headed Giant Promos",
	tla="THG",
	foilonly=true,
	cardcount={ reg=1, tok=0, nontrad=0, repl=0 }, 
},
[42] = { name="Summer of Magic Promos",
	tla="SUM",
	foilonly=true,
	cardcount={ reg=2, tok=0, nontrad=0, repl=0 }, 
},
[41] = { name="Happy Holidays Promos",
	tla="HHL",
	foilonly=true,
	cardcount={ reg=8, tok=0, nontrad=0, repl=0 }, 
},
[40] = { name="Arena/Colosseo Leagues Promos",
	tla="ARE",
	foil="y",
	cardcount={ reg=83, tok=5, nontrad=0, repl=83 },
--FIXME [40] foiltweak
	variants={
["Plains (1996)"]		= { "Plains",	{ "1996", false , false , false , false , false , false , false } },
["Plains (1999)"]		= { "Plains",	{ false , "1999", false , false , false , false , false , false } },
["Plains (2000)"]		= { "Plains",	{ false , false , "2000", false , false , false , false , false } },
["Plains (2001)"]		= { "Plains",	{ false , false , false , "2001", false , false , false , false } },
["Plains (2003)"]		= { "Plains",	{ false , false , false , false , "2003", false , false , false } },
["Plains (2004)"]		= { "Plains",	{ false , false , false , false , false , "2004", false , false } },
["Plains (2005)"]		= { "Plains",	{ false , false , false , false , false , false , "2005", false } },
["Plains (2006)"]		= { "Plains",	{ false , false , false , false , false , false , false , "2006"} },
["Island (1996)"]		= { "Island",	{ "1996", false , false , false  , false  , false , false , false , false } },
["Island (1999)"]		= { "Island",	{ false , "1999", false , false  , false  , false , false , false , false } },
["Island (2000)"]		= { "Island",	{ false , false , "2000", false  , false  , false , false , false , false } },
["Island (2001a)"]		= { "Island",	{ false , false , false , "2001a", false  , false , false , false , false } },--
["Island (2001b)"]		= { "Island",	{ false , false , false , false  , "2001b", false , false , false , false } },--
["Island (2003)"]		= { "Island",	{ false , false , false , false  , false  , "2003", false , false , false } },
["Island (2004)"]		= { "Island",	{ false , false , false , false  , false  , false , "2004", false , false } },
["Island (2005)"]		= { "Island",	{ false , false , false , false  , false  , false , false , "2005", false } },
["Island (2006)"]		= { "Island",	{ false , false , false , false  , false  , false , false , false , "2006"} },
["Swamp (1996)"]		= { "Swamp",	{ "1996", false , false , false , false , false , false , false } },
["Swamp (1999)"]		= { "Swamp",	{ false , "1999", false , false , false , false , false , false } },
["Swamp (2000)"]		= { "Swamp",	{ false , false , "2000", false , false , false , false , false } },
["Swamp (2001)"]		= { "Swamp",	{ false , false , false , "2001", false , false , false , false } },
["Swamp (2003)"]		= { "Swamp",	{ false , false , false , false , "2003", false , false , false } },
["Swamp (2004)"]		= { "Swamp",	{ false , false , false , false , false , "2004", false , false } },
["Swamp (2005)"]		= { "Swamp",	{ false , false , false , false , false , false , "2005", false } },
["Swamp (2006)"]		= { "Swamp",	{ false , false , false , false , false , false , false , "2006"} },
["Mountain (1996)"]		= { "Mountain",	{ "1996", false , false , false , false , false , false , false } },
["Mountain (1999)"]		= { "Mountain",	{ false , "1999", false , false , false , false , false , false } },
["Mountain (2000)"]		= { "Mountain",	{ false , false , "2000", false , false , false , false , false } },
["Mountain (2001)"]		= { "Mountain",	{ false , false , false , "2001", false , false , false , false } },
["Mountain (2003)"]		= { "Mountain",	{ false , false , false , false , "2003", false , false , false } },
["Mountain (2004)"]		= { "Mountain",	{ false , false , false , false , false , "2004", false , false } },
["Mountain (2005)"]		= { "Mountain",	{ false , false , false , false , false , false , "2005", false } },
["Mountain (2006)"]		= { "Mountain",	{ false , false , false , false , false , false , false , "2006"} },
["Forest (1996)"]		= { "Forest",	{ "1996", false , false , false  , false  , false , false , false , false } },
["Forest (1999)"]		= { "Forest",	{ false , "1999", false , false  , false  , false , false , false , false } },
["Forest (2000)"]		= { "Forest",	{ false , false , "2000", false  , false  , false , false , false , false } },
["Forest (2001a)"]		= { "Forest",	{ false , false , false , "2001a", false  , false , false , false , false } },--Ice Age
["Forest (2001b)"]		= { "Forest",	{ false , false , false , false  , "2001b", false , false , false , false } },--Beta
["Forest (2003)"]		= { "Forest",	{ false , false , false , false  , false  , "2003", false , false , false } },
["Forest (2004)"]		= { "Forest",	{ false , false , false , false  , false  , false , "2004", false , false } },
["Forest (2005)"]		= { "Forest",	{ false , false , false , false  , false  , false , false , "2005", false } },
["Forest (2006)"]		= { "Forest",	{ false , false , false , false  , false  , false , false , false , "2006"} },
["Plains (oversized)"]		= { "Plains",	{ false , false , false , false , false , false , false , false , "Replica" } },
["Island (oversized)"]		= { "Island",	{ false , false , false , false , false , false , false , false , false , "Replica" } },
["Swamp (oversized)"]		= { "Swamp",	{ false , false , false , false , false , false , false , false , "Replica" } },
["Mountain (oversized)"]	= { "Mountain",	{ false , false , false , false , false , false , false , false , "Replica" } },
["Forest (oversized)"]		= { "Forest",	{ false , false , false , false , false , false , false , false , false , "Replica" } },
--["Soldier Token"]				= { "Soldier Token"	, { true , true , true  } },
["Soldier Token (GTC)"]			= { "Soldier Token"	, { "" } },-- others not yet in MA
--["Soldier Token (GTC)"]			= { "Soldier Token"	, { "GTC", false, false } },-- RW 1/1
--["Soldier Token (THS)"]			= { "Soldier Token"	, { false, "THS", false } },-- W 1/1
--["Soldier Token (BNG)"]			= { "Soldier Token"	, { false, false, "BNG" } },-- W 1/1 Enchantment
["Disenchant"]					= { "Disenchant"	, { ""   , false     } },
["Disenchant (oversized)"]		= { "Disenchant"	, { false, "Replica" } },
["Fireball"]					= { "Fireball"		, { ""   , false     } },
["Fireball (oversized)"]		= { "Fireball"		, { false, "Replica" } },
["Abeyance (oversized)"]						= {"Abeyance"						, {"Replica" } },
["Adarkar Wastes (oversized)"]					= {"Adarkar Wastes"					, {"Replica" } },
["All Hallow’s Eve (oversized)"]				= {"All Hallow’s Eve"				, {"Replica" } },
["Autumn Willow (oversized)"]					= {"Autumn Willow"					, {"Replica" } },
["Balduvian Horde (oversized)"]					= {"Balduvian Horde"				, {"Replica" } },
["Baron Sengir (oversized)"]					= {"Baron Sengir"					, {"Replica" } },
["Balance (oversized)"]							= {"Balance"						, {"Replica" } },
["Black Knight (oversized)"]					= {"Black Knight"					, {"Replica" } },
["Blacker Lotus (oversized)"]					= {"Blacker Lotus"					, {"Replica" } },
["Blinking Spirit (oversized)"]					= {"Blinking Spirit"				, {"Replica" } },
["Brushland (oversized)"]						= {"Brushland"						, {"Replica" } },
["Cadaverous Bloom (oversized)"]				= {"Cadaverous Bloom"				, {"Replica" } },
["Crimson Hellkite (oversized)"]				= {"Crimson Hellkite"				, {"Replica" } },
["Cursed Scroll (oversized)"]					= {"Cursed Scroll"					, {"Replica" } },
["Dark Banishing (oversized)"]					= {"Dark Banishing"					, {"Replica" } },
["Drain Life (oversized)"]						= {"Drain Life"						, {"Replica" } },
["Earthquake (oversized)"]						= {"Earthquake"						, {"Replica" } },
["Force of Nature (oversized)"]					= {"Force of Nature"				, {"Replica" } },
["Greater Realm of Preservation (oversized)"]	= {"Greater Realm of Preservation"	, {"Replica" } },
["Hurricane (oversized)"]						= {"Hurricane"						, {"Replica" } },
["Icy Manipulator (oversized)"]					= {"Icy Manipulator"				, {"Replica" } },
["Incinerate (oversized)"]						= {"Incinerate"						, {"Replica" } },
["Infernal Contract (oversized)"]				= {"Infernal Contract"				, {"Replica" } },
["Infernal Spawn of Evil (oversized)"]			= {"Infernal Spawn of Evil"			, {"Replica" } },
["Ivory Tower (oversized)"]						= {"Ivory Tower"					, {"Replica" } },
["Jokulhaups (oversized)"]						= {"Jokulhaups"						, {"Replica" } },
["Karplusan Forest (oversized)"]				= {"Karplusan Forest"				, {"Replica" } },
["Lhurgoyf (oversized)"]						= {"Lhurgoyf"						, {"Replica" } },
["Library of Alexandria (oversized)"]			= {"Library of Alexandria"			, {"Replica" } },
["Mirror Mirror (oversized)"]					= {"Mirror Mirror"					, {"Replica" } },
["Mirror Universe (oversized)"]					= {"Mirror Universe"				, {"Replica" } },
["Necropotence (oversized)"]					= {"Necropotence"					, {"Replica" } },
["Order of the White Shield (oversized)"]		= {"Order of the White Shield"		, {"Replica" } },
["Pox (oversized)"]								= {"Pox"							, {"Replica" } },
["Prosperity (oversized)"]						= {"Prosperity"						, {"Replica" } },
["Personal Incarnation (oversized)"]			= {"Personal Incarnation"			, {"Replica" } },
["Recall (oversized)"]							= {"Recall"							, {"Replica" } },
["Shatterstorm (oversized)"]					= {"Shatterstorm"					, {"Replica" } },
["Sibilant Spirit (oversized)"]					= {"Sibilant Spirit"				, {"Replica" } },
["Sol’kanar the Swamp King (oversized)"]		= {"Sol’kanar the Swamp King"		, {"Replica" } },
["Squandered Resources (oversized)"]			= {"Squandered Resources"			, {"Replica" } },
["Stormbind (oversized)"]						= {"Stormbind"						, {"Replica" } },
["Vampiric Tutor (oversized)"]					= {"Vampiric Tutor"					, {"Replica" } },
["Vesuvan Doppelganger (oversized)"]			= {"Vesuvan Doppelganger"			, {"Replica" } },
["Wheel of Fortune (oversized)"]				= {"Wheel of Fortune"				, {"Replica" } },
["Zuran Orb (oversized)"]						= {"Zuran Orb"						, {"Replica" } },
["City of Brass (3rd) (oversized)"]			= { "City of Brass"			, { "3rd Replica", false         } },
["City of Brass (4th) (oversized)"]			= { "City of Brass"			, { false        , "4th Replica" } },
["Deflection (3rd) (oversized)"]			= { "Deflection"			, { "3rd Replica", false         } },
["Deflection (4th) (oversized)"]			= { "Deflection"			, { false        , "4th Replica" } },
["Dissipate (3rd) (oversized)"]				= { "Dissipate"				, { "3rd Replica", false         } },
["Dissipate (4th) (oversized)"]				= { "Dissipate"				, { false        , "4th Replica" } },
["Enduring Renewal (3rd) (oversized)"]		= { "Enduring Renewal"		, { "3rd Replica", false         } },
["Enduring Renewal (4th) (oversized)"]		= { "Enduring Renewal"		, { false        , "4th Replica" } },
["Erhnam Djinn (3rd) (oversized)"]			= { "Erhnam Djinn"			, { "3rd Replica", false         } },
["Erhnam Djinn (4th) (oversized)"]			= { "Erhnam Djinn"			, { false        , "4th Replica" } },
["Fallen Angel (3rd) (oversized)"]			= { "Fallen Angel"			, { "3rd Replica", false         } },
["Fallen Angel (4th) (oversized)"]			= { "Fallen Angel"			, { false        , "4th Replica" } },
["Guardian Beast (3rd) (oversized)"]		= { "Guardian Beast"		, { "3rd Replica", false         } },
["Guardian Beast (4th) (oversized)"]		= { "Guardian Beast"		, { false        , "4th Replica" } },
["Meditate (3rd) (oversized)"]				= { "Meditate"				, { "3rd Replica", false         } },
["Meditate (4th) (oversized)"]				= { "Meditate"				, { false        , "4th Replica" } },
["Natural Balance (3rd) (oversized)"]		= { "Natural Balance"		, { "3rd Replica", false         } },
["Natural Balance (4th) (oversized)"]		= { "Natural Balance"		, { false        , "4th Replica" } },
["Nether Shadow (3rd) (oversized)"]			= { "Nether Shadow"			, { "3rd Replica", false         } },
["Nether Shadow (4th) (oversized)"]			= { "Nether Shadow"			, { false        , "4th Replica" } },
["Hydroblast (3rd) (oversized)"]			= { "Hydroblast"			, { "3rd Replica", false         } },
["Hydroblast (4th) (oversized)"]			= { "Hydroblast"			, { false        , "4th Replica" } },
["Pyroblast (3rd) (oversized)"]				= { "Pyroblast"				, { "3rd Replica", false         } },
["Pyroblast (4th) (oversized)"]				= { "Pyroblast"				, { false        , "4th Replica" } },
["Pyroclasm (3rd) (oversized)"]				= { "Pyroclasm"				, { "3rd Replica", false         } },
["Pyroclasm (4th) (oversized)"]				= { "Pyroclasm"				, { false        , "4th Replica" } },
["Squirrel Farm (3rd) (oversized)"]			= { "Squirrel Farm"			, { "3rd Replica", false         } },
["Squirrel Farm (4th) (oversized)"]			= { "Squirrel Farm"			, { false        , "4th Replica" } },
["Swords to Plowshares (3rd) (oversized)"]	= { "Swords to Plowshares"	, { "3rd Replica", false         } },
["Swords to Plowshares (4th) (oversized)"]	= { "Swords to Plowshares"	, { false        , "4th Replica" } },
	},
},
[33] = { name="Championships Prizes",
	tla="WLD",
	foil="n",
	cardcount={ reg=4, tok=0, nontrad=0, repl=14 }, 
	variants={
["Black Lotus"]		= { "Black Lotus"	, { "Replica" } },
["Brainstorm"]		= { "Brainstorm"	, { "Replica" } },
["Force of Will"]	= { "Force of Will"	, { "Replica" } },
["Mox Emerald"]		= { "Mox Emerald"	, { "Replica" } },
["Mox Jet"]			= { "Mox Jet"		, { "Replica" } },
["Mox Pearl"]		= { "Mox Pearl"		, { "Replica" } },
["Mox Ruby"]		= { "Mox Ruby"		, { "Replica" } },
["Mox Sapphire"]	= { "Mox Sapphire"	, { "Replica" } },
["Wime Walk"]		= { "Wime Walk"		, { "Replica" } },
["Wasteland"]		= { "Wasteland"		, { "Replica" } },
["Ancestral Recall (2005)"]	= { "Ancestral Recall"	, { "2005 Replica" , false          } },
["Ancestral Recall (2013)"]	= { "Ancestral Recall"	, { false          , "2013 Replica" } },	
["Timetwister (2004)"]		= { "Timetwister"		, { "2004 Replica" , false          } },		
["Timetwister (2012)"]		= { "Timetwister"		, { false          , "2012 Replica" } },		
	},
	foiltweak={
["Vengevine"]				= { foil = true },
["Geist of Saint Traft"]	= { foil = true },
["Balduvian Horde"]			= { foil = true },
	},
},
[32] = { name="Pro Tour Promos",
	tla="PTR",
	foilony=true,
	cardcount={ reg=5, tok=0, nontrad=0, repl=0 },--JPN reg=1	
},
[31] = { name="Grand Prix Promos",
	tla="GPX",
	foilonly=true,
	cardcount={ reg=10, tok=0, nontrad=0, repl=0 }, 
},
[30] = { name="Friday Night Magic Promos",
	tla="FNM",
	foilonly=true,
	cardcount={ reg=183, tok=1, nontrad=0, repl=0 }, 
	foiltweak={
["Human|Wolf Token"] 				= { foil = false},
	},
},
[27] = { name="Alternate Art Lands",
	tla="LND",
	foil="n",
	cardcount={ reg=35, tok=0, nontrad=0, repl=0 }, 
	variants={
["Plains (APAC Blue)"]		= { "Plains"	, { "APAC Blue" ,false        ,false      ,false       ,false         ,false      ,false  } },-- Art: Colin MacNeil
["Plains (APAC Clear)"]		= { "Plains"	, { false       ,"APAC Clear" ,false      ,false       ,false         ,false      ,false  } },-- Art: Rebecca Guay
["Plains (APAC Red)"]		= { "Plains"	, { false       ,false        ,"APAC Red" ,false       ,false         ,false      ,false  } },-- Art: Ron Spears
["Plains (Euro Blue)"]		= { "Plains"	, { false       ,false        ,false      ,"Euro Blue" ,false         ,false      ,false  } },-- Scottish Highlands, UK
["Plains (Euro Purple)"]	= { "Plains"	, { false       ,false        ,false      ,false       ,"Euro Purple" ,false      ,false  } },-- Steppe Tundra, Russia
["Plains (Euro Red)"]		= { "Plains"	, { false       ,false        ,false      ,false       ,false         ,"Euro Red" ,false  } },-- Lowlands, Netherlands
["Plains (Guru)"]			= { "Plains"	, { false       ,false        ,false      ,false       ,false         ,false      ,"Guru" } },-- 
["Island (APAC Blue)"]		= { "Island"	, { "APAC Blue" ,false        ,false      ,false       ,false         ,false      ,false  } },-- Art: Bob Eggleton
["Island (APAC Clear)"]		= { "Island"	, { false       ,"APAC Clear" ,false      ,false       ,false         ,false      ,false  } },-- Art: Rob Alexander
["Island (APAC Red)"]		= { "Island"	, { false       ,false        ,"APAC Red" ,false       ,false         ,false      ,false  } },-- Art: Edward P. Beard Jr.
["Island (Euro Blue)"]		= { "Island"	, { false       ,false        ,false      ,"Euro Blue" ,false         ,false      ,false  } },-- Danish Island, Scandinavia
["Island (Euro Purple)"]	= { "Island"	, { false       ,false        ,false      ,false       ,"Euro Purple" ,false      ,false  } },-- White Cliffs of Dover, UK
["Island (Euro Red)"]		= { "Island"	, { false       ,false        ,false      ,false       ,false         ,"Euro Red" ,false  } },-- Venezia, Italy
["Island (Guru)"]			= { "Island"	, { false       ,false        ,false      ,false       ,false         ,false      ,"Guru" } },-- 
["Swamp (APAC Blue)"]		= { "Swamp"		, { "APAC Blue" ,false        ,false      ,false       ,false         ,false      ,false  } },-- Art: Ron Spears
["Swamp (APAC Clear)"]		= { "Swamp"		, { false       ,"APAC Clear" ,false      ,false       ,false         ,false      ,false  } },-- Art: Ron Spears
["Swamp (APAC Red)"]		= { "Swamp"		, { false       ,false        ,"APAC Red" ,false       ,false         ,false      ,false  } },-- Art: Edward P. Beard Jr.
["Swamp (Euro Blue)"]		= { "Swamp"		, { false       ,false        ,false      ,"Euro Blue" ,false         ,false      ,false  } },-- Ardennes Fagnes, Belgium
["Swamp (Euro Purple)"]		= { "Swamp"		, { false       ,false        ,false      ,false       ,"Euro Purple" ,false      ,false  } },-- Camargue, France
["Swamp (Euro Red)"]		= { "Swamp"		, { false       ,false        ,false      ,false       ,false         ,"Euro Red" ,false  } },-- Lake District National Park, UK
["Swamp (Guru)"]			= { "Swamp"		, { false       ,false        ,false      ,false       ,false         ,false      ,"Guru" } },-- 
["Mountain (APAC Blue)"]	= { "Mountain"	, { "APAC Blue" ,false        ,false      ,false       ,false         ,false      ,false  } },-- Art: Rebecca Guay
["Mountain (APAC Clear)"]	= { "Mountain"	, { false       ,"APAC Clear" ,false      ,false       ,false         ,false      ,false  } },-- Art: Edward P. Beard Jr.
["Mountain (APAC Red)"]		= { "Mountain"	, { false       ,false        ,"APAC Red" ,false       ,false         ,false      ,false  } },-- Art: Heather Hudson
["Mountain (Euro Blue)"]	= { "Mountain"	, { false       ,false        ,false      ,"Euro Blue" ,false         ,false      ,false  } },-- Vesuvio, Italy
["Mountain (Euro Purple)"]	= { "Mountain"	, { false       ,false        ,false      ,false       ,"Euro Purple" ,false      ,false  } },-- Mont Blanc, France
["Mountain (Euro Red)"]		= { "Mountain"	, { false       ,false        ,false      ,false       ,false         ,"Euro Red" ,false  } },-- Pyrenees, Spain
["Mountain (Guru)"]			= { "Mountain"	, { false       ,false        ,false      ,false       ,false         ,false      ,"Guru" } },-- 
["Forest (APAC Blue)"]		= { "Forest"	, { "APAC Blue" ,false        ,false      ,false       ,false         ,false      ,false  } },-- Art: Christopher Rush
["Forest (APAC Clear)"]		= { "Forest"	, { false       ,"APAC Clear" ,false      ,false       ,false         ,false      ,false  } },-- Art: Edward P. Beard Jr.
["Forest (APAC Red)"]		= { "Forest"	, { false       ,false        ,"APAC Red" ,false       ,false         ,false      ,false  } },-- Art: Pete Venters
["Forest (Euro Blue)"]		= { "Forest"	, { false       ,false        ,false      ,"Euro Blue" ,false         ,false      ,false  } },-- Schwarzwald, Germany
["Forest (Euro Purple)"]	= { "Forest"	, { false       ,false        ,false      ,false       ,"Euro Purple" ,false      ,false  } },-- Nottingham Forest, UK
["Forest (Euro Red)"]		= { "Forest"	, { false       ,false        ,false      ,false       ,false         ,"Euro Red" ,false  } },-- Brocéliande, France
["Forest (Guru)"]			= { "Forest"	, { false       ,false        ,false      ,false       ,false         ,false      ,"Guru" } },-- 
	},
},
[26] = { name="Magic Game Day",
	tla="MGD",
	foil="y",--some no, some only, no yes
	cardcount={ reg=55, tok=0, nontrad=3, repl=0 },
	variants= {
["The Champion"]		= { "The Champion"		, { "Nontrad" } },
["The Slayer"]			= { "The Slayer"		, { "Nontrad" } },
["The Vanquisher"]		= { "The Vanquisher"	, { "Nontrad" } },
	},
	foiltweak={
	--FIXME update [26] foiltweak
["Black Sun’s Zenith"] 				= { foil = true},
["Cryptborn Horror"] 				= { foil = true},
["Deathless Angel"] 				= { foil = true},
["Dictate of Kruphix"] 				= { foil = true},
["Dungrove Elder"] 					= { foil = true},
["Elite Inquisitor"] 				= { foil = true},
["Emeria Angel"] 					= { foil = true},
["Firemane Av"] 					= { foil = true},
["Goblin Diplomats"] 				= { foil = true},
["Kalastria Highborn"] 				= { foil = true},
["Killing Wave"] 					= { foil = true},
["Magmaquake"] 						= { foil = true},
["Melek, Izzet Paragon"] 			= { foil = true},
["Mitotic Slime"] 					= { foil = true},
["Mycoid Shepherd"] 				= { foil = true},
["Myr Superion"] 					= { foil = true},
["Naya Sojourners"] 				= { foil = true},
["Nighthowler"] 					= { foil = true},
["Pain Seer"] 						= { foil = true},
["Reya Dawnbringer"] 				= { foil = true},
["Tempered Steel"] 					= { foil = true},
["Zombie Apocalypse"] 				= { foil = true},
	},
},
[25] = { name="Judge Gift Cards",
	tla="JGC",
	foilonly=true,
	cardcount={ reg=87, tok=4, nontrad=0, repl=0 },
	variants = {
["Vindicate"]					= { "Vindicate"	, { 1     , 2     } },
["Vindicate (4)"]				= { "Vindicate"	, { 1     , false } },--2007
["Vindicate (7)"]				= { "Vindicate"	, { false , 2     } },--2013
--["Wasteland"]					= { "Wasteland"	, { 1     , 2     } },
--["Wasteland (2010)"]			= { "Wasteland"	, { 1     , false } },--2010
--["Wasteland (2015)"]			= { "Wasteland"	, { false , 2     } },--2015
--["Wolf│Make a Positive Mark"]	= { "Wolf"	, { "" } },
--["Wolf│Open New Worlds"]		= { "Wolf"	, { "" } },
	},
	foiltweak={
["Centaur Token"]				= { foil = false},
["Golem Token"]					= { foil = false},
["Wolf Token"]					= { foil = false},
	},
},
[24] = { name="Champs Promos",
	tla="CHP",
	foilonly=true,
	cardcount={ reg=12, tok=0, nontrad=0, repl=0 }, 
	foiltweak={
["Blood Knight"]					= { foil = false},
["Bramblewood Paragon"]				= { foil = false},
["Electrolyze"]						= { foil = false},
["Imperious Perfect"]				= { foil = false},
["Rakdos Guildmage"]				= { foil = false},
["Urza’s Factory"]					= { foil = false},
	},
},
[23] = { name="Gateway & WPN Promos",
	tla="GTW",
	foilonly=true,
	cardcount={ reg=57, tok=0, nontrad=7, repl=0 },
	variants={
["Drench the Soil in Their Blood"]	= { "Drench the Soil in Their Blood"	, { "Nontrad" } },
["Horizon Boughs"]					= { "Horizon Boughs"					, { "Nontrad" } },
["Imprison This Insolent Wretch"]	= { "Imprison This Insolent Wretch"		, { "Nontrad" } },
["Mirrored Depths"]					= { "Mirrored Depths"					, { "Nontrad" } },
["Perhaps You’ve Met My Cohort"]	= { "Perhaps You’ve Met My Cohort"		, { "Nontrad" } },
["Tember City"]						= { "Tember City"						, { "Nontrad" } },
["Your Inescapable Doom"]			= { "Your Inescapable Doom"				, { "Nontrad" } },
["Fling (50 DCI)"]					= { "Fling"				, { "1"  , false} },-- variant "" in GER
["Fling (69 DCI)"]					= { "Fling"				, { false, "2"  } },
["Sylvan Ranger (51 DCI)"]			= { "Sylvan Ranger"		, { "1"  , false} },-- variant "" in GER
["Sylvan Ranger (70 DCI)"]			= { "Sylvan Ranger"		, { false, "2"  } },
	}, 
	foiltweak={
["Drench the Soil in Their Blood"]	= { foil = false},
["Horizon Boughs"]					= { foil = false},
["Imprison This Insolent Wretch"]	= { foil = false},
["Mirrored Depths"]					= { foil = false},
["Perhaps You’ve Met My Cohort"]	= { foil = false},
["Tember City"]						= { foil = false},
["Your Inescapable Doom"]			= { foil = false},
	},
},
[22] = { name="Prerelease Promos",
	tla="PRE",
	foil="y",-- "o" might be better to catch most foils, but there are 5 "yes" cards in here...
	--TODO [22] foiltweak - check whether the 5 "yes" are really "yes", if they're "Only" change to foilonly=true and cut "true" from foiltweak.
	cardcount={ reg=235, tok=2, nontrad=17, repl=5 },
	variants={
["Lu Bu, Master-at-Arms"] 				= { "Lu Bu, Master-at-Arms"		, { "April", "July" } },
["Lu Bu, Master-at-Arms (April)"] 		= { "Lu Bu, Master-at-Arms"		, { "April", false  } },
["Lu Bu, Master-at-Arms (July)"] 		= { "Lu Bu, Master-at-Arms"		, { false  , "July" } },
["Plains"] 								= { "Plains"					, { "DGM" } },
["Plains (DGM)"] 						= { "Plains"					, { "DGM" } },
["Foe-Razer Regent"] 					= { "Foe-Razer Regent"			, { ""          , false        } },
["Foe-Razer Regent (Dragonfury)"] 		= { "Foe-Razer Regent"			, { false       , "Dragonfury" } },
["Evolving Wilds"] 						= { "Evolving Wilds"			, { "Dragonfury" } },
["Evolving Wilds (Dragonfury)"] 		= { "Evolving Wilds"			, { "Dragonfury" } },
["Dragonlord’s Servant"] 				= { "Dragonlord’s Servant"		, { "Dragonfury" } },
["Dragonlord’s Servant (Dragonfury)"]	= { "Dragonlord’s Servant"		, { "Dragonfury" } },
["Dragon Fodder"] 						= { "Dragon Fodder"				, { "Dragonfury" } },
["Dragon Fodder (Dragonfury)"] 			= { "Dragon Fodder"				, { "Dragonfury" } },
["Celestine Reef"]						= { "Celestine Reef"			, { "Nontrad" } },	
["Garruk the Slayer"]					= { "Garruk the Slayer"			, { "Nontrad" } },
["Avacyn, Angel of Hope"]				= { "Avacyn, Angel of Hope"		, { "Replica" } },
["Bruna, Light of Alabaster"]			= { "Bruna, Light of Alabaster"	, { "Replica" } },
["Sigarda, Host of Herons"]				= { "Sigarda, Host of Herons"	, { "Replica" } },
["Gisela, Blade of Goldnight"]			= { "Gisela, Blade of Goldnight", { "Replica" } },
["Griselbrand"]							= { "Griselbrand"				, { "Replica" } },
["The Avenger"]					= { "The Avenger"				, { "Nontrad" } },
["The General"]					= { "The General"				, { "Nontrad" } },
["The Hunter"]					= { "The Hunter"				, { "Nontrad" } },
["The Philosopher"]				= { "The Philosopher"			, { "Nontrad" } },
["The Protector"]				= { "The Protector"				, { "Nontrad" } },
["The Provider"]				= { "The Provider"				, { "Nontrad" } },
["The Savant"]					= { "The Savant"				, { "Nontrad" } },
["The Tyrant"]					= { "The Tyrant"				, { "Nontrad" } },
["The Warmonger"]				= { "The Warmonger"				, { "Nontrad" } },
["The Warrior"]					= { "The Warrior"				, { "Nontrad" } },
["Axe of the Warmonger"]		= { "Axe of the Warmonger"		, { "Nontrad" } },
["Bow of the Hunter"]			= { "Bow of the Hunter"			, { "Nontrad" } },
["Spear of the General"]		= { "Spear of the General"		, { "Nontrad" } },
["Lash of the Tyrant"]			= { "Lash of the Tyrant"		, { "Nontrad" } },
["Cloak of the Philosopher"]	= { "Cloak of the Philosopher"	, { "Nontrad" } },
	},
	foiltweak={
	--FIXME foiltweak [22] update
["Garruk the Slayer"]				= { foil = false },
["The Avenger"]						= { foil = false },
["The General"]						= { foil = false },
["The Hunter"]						= { foil = false },
["The Philosopher"]					= { foil = false },
["The Protector"]					= { foil = false },
["The Provider"]					= { foil = false },
["The Savant"]						= { foil = false },
["The Tyrant"]						= { foil = false },
["The Warmonger"]					= { foil = false },
["The Warrior"]						= { foil = false },
["Axe of the Warmonger"]			= { foil = false },
["Bow of the Hunter"]				= { foil = false },
["Spear of the General"]			= { foil = false },
["Lash of the Tyrant"]				= { foil = false },
["Cloak of the Philosopher"]		= { foil = false },
["Celestine Reef"]					= { foil = false },
["Wolf Token"]						= { foil = false },
["Dirtcowl Wurm"]					= { foil = false },
["Lu Bu, Master-at-Arms"]			= { foil = false },
["Lu Bu, Master-at-Arms (April)"]	= { foil = false },
["Lu Bu, Master-at-Arms (July)"]	= { foil = false },
["Monstrous Hound"]					= { foil = false },
["Revenant"]						= { foil = false },
["Abhorrent Overlord"]					= { foil = true },
["Abzan Ascendancy"]					= { foil = true },
["Ajani Vengeant"]						= { foil = true },
["Allosaurus Rider"]					= { foil = true },
["Anafenza, the Foremost"]				= { foil = true },
["Ankle Shanker"]						= { foil = true },
["Anthousa, Setessan Hero"]				= { foil = true },
["Arbiter of the Ideal"]				= { foil = true },
["Archon of the Triumvirate"]			= { foil = true },
["Avalanche Tusker"]					= { foil = true },
["Avatar of Discord"]					= { foil = true },
["Avatar of Hope"]						= { foil = true },
["Beast of Burden"]						= { foil = true },
["Bloodlord of Vaasgoth"]				= { foil = true },
["Bloodsoaked Champion"]				= { foil = true },
["Butcher of the Horde"]				= { foil = true },
["Carnival Hellsteed"]					= { foil = true },
["Celestial Archon"]					= { foil = true },
["Comet Storm"]							= { foil = true },
["Consuming Aberration"]				= { foil = true },
["Corpsejack Menace"]					= { foil = true },
["Crackling Doom"]						= { foil = true },
["Crater’s Claws"]						= { foil = true },
["Dawnbringer Charioteers"]				= { foil = true },
["Deflecting Palm"]						= { foil = true },
["Demigod of Revenge"]					= { foil = true },
["Dig Through Time"]					= { foil = true },
["Djinn Illuminatus"]					= { foil = true },
["Doomwake Giant"]						= { foil = true },
["Door of Destinies"]					= { foil = true },
["Dragon-Style Twins"]					= { foil = true },
["Dragon Broodmother"]					= { foil = true },
["Duneblast"]							= { foil = true },
["Eater of Hope"]						= { foil = true },
["Ember Swallower"]						= { foil = true },
["Emrakul, the Aeons Torn"]				= { foil = true },
["False Prophet"]						= { foil = true },
["Fathom Mage"]							= { foil = true },
["Feral Throwback"]						= { foil = true },
["Flying Crane Technique"]				= { foil = true },
["Forgestoker Dragon"]					= { foil = true },
["Foundry Champion"]					= { foil = true },
["Gleancrawler"]						= { foil = true },
["Glissa, the Traitor"]					= { foil = true },
["Grim Haruspex"]						= { foil = true },
["Grove of the Guardian"]				= { foil = true },
["Hardened Scales"]						= { foil = true },
["Helm of Kaldra"]						= { foil = true },
["Herald of Anafenza"]					= { foil = true },
["Hero of Bladehold"]					= { foil = true },
["Heroes’ Bane"]						= { foil = true },
["High Sentinels of Arashin"]			= { foil = true },
["Hypersonic Dragon"]					= { foil = true },
["Icy Blast"]							= { foil = true },
["Indulgent Tormentor"]					= { foil = true },
["Ink-Eyes, Servant of Oni"]			= { foil = true },
["Ivorytusk Fortress"]					= { foil = true },
["Jeering Instigator"]					= { foil = true },
["Jeskai Ascendancy"]					= { foil = true },
["Kheru Lich Lord"]						= { foil = true },
["Kiyomaro, First to Stand"]			= { foil = true },
["Korlash, Heir to Blackblade"]			= { foil = true },
["Lightning Dragon"]					= { foil = true },
["Lotus Bloom"]							= { foil = true },
["Malfegor"]							= { foil = true },
["Mardu Ascendancy"]					= { foil = true },
["Master of Pearls"]					= { foil = true },
["Mayor of Avabruck|Howlpack Alpha"]	= { foil = true },
["Maze’s End"]							= { foil = true },
["Megantic Sliver"]						= { foil = true },
["Mercurial Pretender"]					= { foil = true },
["Moonsilver Spear"]					= { foil = true },
["Narset, Enlightened Master"]			= { foil = true },
["Necropolis Fiend"]					= { foil = true },
["Nessian Wilds Ravager"]				= { foil = true },
["Oros, the Avenger"]					= { foil = true },
["Overbeing of Myth"]					= { foil = true },
["Overtaker"]							= { foil = true },
["Phytotitan"]							= { foil = true },
["Plains"]								= { foil = true },
["Rakshasa Vizier"]						= { foil = true },
["Rampaging Baloths"]					= { foil = true },
["Rathi Assassin"]						= { foil = true },
["Rattleclaw Mystic"]					= { foil = true },
["Ravenous Demon|Archdemon of Greed"]	= { foil = true },
["Resolute Archangel"]					= { foil = true },
["Rubblehulk"]							= { foil = true },
["Ryusei, the Falling Star"]			= { foil = true },
["Sage of the Inward Eye"]				= { foil = true },
["Scourge of Fleets"]					= { foil = true },
["Sheoldred, Whispering One"]			= { foil = true },
["Shield of Kaldra"]					= { foil = true },
["Shipbreaker Kraken"]					= { foil = true },
["Sidisi, Brood Tyrant"]				= { foil = true },
["Siege Dragon"]						= { foil = true },
["Siege Rhino"]							= { foil = true },
["Silent Sentinel"]						= { foil = true },
["Silent Specter"]						= { foil = true },
["Soul Collector"]						= { foil = true },
["Spawn of Thraxes"]					= { foil = true },
["Sultai Ascendancy"]					= { foil = true },
["Sun Titan"]							= { foil = true },
["Surrak Dragonclaw"]					= { foil = true },
["Sword of Kaldra"]						= { foil = true },
["Temur Ascendancy"]					= { foil = true },
["Thousand Winds"]						= { foil = true },
["Trail of Mystery"]					= { foil = true },
["Trap Essence"]						= { foil = true },
["Treasury Thrull"]						= { foil = true },
["Utter End"]							= { foil = true },
["Vampire Nocturnus"]					= { foil = true },
["Villainous Wealth"]					= { foil = true },
["Wren’s Run Packmaster"]				= { foil = true },
["Wurmcoil Engine"]						= { foil = true },
["Xathrid Gorgon"]						= { foil = true },
["Zurgo Helmsmasher"]					= { foil = true },
	},
},
[21] = { name="Release & Launch Parties Promos",
	tla="REL",
	foilonly=true,
	cardcount={ reg=44, tok=1, nontrad=6, repl=6 },
	variants={
["Plots that Span Centuries"]		= { "Plots that Span Centuries"		, { "Nontrad" } },
["Stairs to Infinity"]				= { "Stairs to Infinity"			, { "Nontrad" } },
["Tazeem"]							= { "Tazeem"						, { "Nontrad" } },
["The Destined"]					= { "The Destined"					, { "Nontrad" } },
["The Explorer"]					= { "The Explorer"					, { "Nontrad" } },
["The Harvester"]					= { "The Harvester"					, { "Nontrad" } },
["Edric, Spymaster of Trest"]		= { "Edric, Spymaster of Trest"		, { "Replica" } },
["Basandra, Battle Seraph"]			= { "Basandra, Battle Seraph"		, { "Replica" } },
["Skullbriar, the Walking Grave"]	= { "Skullbriar, the Walking Grave"	, { "Replica" } },
["Vish Kal, Blood Arbiter"]			= { "Vish Kal, Blood Arbiter"		, { "Replica" } },
["Nin, the Pain Artist"]			= { "Nin, the Pain Artist"			, { "Replica" } },
["Incoming!"]						= { "Incoming!"						, { "Replica" } },
	}, 
	foiltweak={
--FIXME [21] foiltweak update
["Incoming!"]						= { foil = false},
["Tazeem"]							= { foil = false},
["Plots that Span Centuries"]		= { foil = false},
["Stairs to Infinity"]				= { foil = false},
["The Destined"]					= { foil = false},
["The Explorer"]					= { foil = false},
["The Harvester"]					= { foil = false},
	},
},
[20] = { name="Magic Player Rewards",
	tla="MPR",
	foil="y",
	cardcount={ reg=53, tok=24, nontrad=0, repl=10 }, 
	variants={
["Bear Token"] 					= { "Bear Token"		, { "ONS", "ODY" } },
["Bear Token (ONS)"] 			= { "Bear Token"		, { "ONS", false } },
["Bear Token (ODY)"] 			= { "Bear Token"		, { false, "ODY" } },
["Beast Token"] 				= { "Beast Token"		, { "DST", "ODY" } },
["Beast Token (DST)"] 			= { "Beast Token"		, { "DST", false } },
["Beast Token (ODY)"] 			= { "Beast Token"		, { false, "ODY" } },
["Elephant Token"] 				= { "Elephant Token"	, { "INV", "ODY" } },
["Elephant Token (INV)"]		= { "Elephant Token"	, { "INV", false } },
["Elephant Token (ODY)"]		= { "Elephant Token"	, { false, "ODY" } },
["Spirit Token"] 				= { "Spirit Token"		, { "CHK", "PLS" } },
["Spirit Token (CHK)"] 			= { "Spirit Token"		, { "CHK", false } },
["Spirit Token (PLS)"] 			= { "Spirit Token"		, { false, "PLS" } },
["Comet Storm"]					= { "Comet Storm"				, { "Replica" } },
["Emrakul, the Aeons Torn"]		= { "Emrakul, the Aeons Torn"	, { "Replica" } },
["Feral Hydra"]					= { "Feral Hydra"				, { "Replica" } },
["Glissa, the Traitor"]			= { "Glissa, the Traitor"		, { "Replica" } },
["Hero of Bladehold"]			= { "Hero of Bladehold"			, { "Replica" } },
["Rampaging Baloths"]			= { "Rampaging Baloths"			, { "Replica" } },
["Spellbreaker Behemoth"]		= { "Spellbreaker Behemoth"		, { "Replica" } },
["Sun Titan"]					= { "Sun Titan"					, { "Replica" } },
["Wurmcoil Engine"]				= { "Wurmcoil Engine"			, { "Replica" } },
["Lightning Bolt (146)"]		= { "Lightning Bolt"			, { false, "Replica" } },--oversized
["Lightning Bolt (1)"]			= { "Lightning Bolt"			, { ""  , false } },--full art
	},
	foiltweak={
["Lightning Bolt (146)"]		= { foil = false},
["Lightning Bolt (1)"]			= { foil = true },
["Cryptic Command"]				= { foil = true },
["Damnation"]					= { foil = true },
["Day of Judgment"]				= { foil = true },
["Hypnotic Specter"]			= { foil = true },
["Powder Keg"]					= { foil = true },
["Psychatog"]					= { foil = true },
["Wasteland"]					= { foil = true },
["Wrath of God"]				= { foil = true },
	},
},
[15] = { name="Convention Promos",
	tla="CVP",
	foilonly=true,
	cardcount={ reg=12, tok=0, nontrad=0, repl=2 }, 
	variants={
["Hurloon Minotaur"]			= { "Hurloon Minotaur"	, { "Replica" } },
["Serra Angel"]					= { "Serra Angel"		, { "Replica" } },
	},
	foiltweak={
["Hurloon Minotaur"]			= { foil = false},
["Serra Angel"]					= { foil = false},
	},
},
[12] = { name="Hobby Japan Commemorative Cards",
	tla="HJP",
-- JPN only
	foil="n",
	cardcount={ reg=5, tok=0, nontrad=0, repl=0 }, 
},
[11] = { name="Redemption Program Cards",
	tla="RED",
-- JPN only
	foil="n",
	cardcount={ reg=1, tok=0, nontrad=0, repl=0 }, 
},
[10] = { name="Junior Series Promos",
	tla="JUN",
	foilonly=true,
	cardcount={ reg=32, tok=0, nontrad=0, repl=0 },-- 11 JPN
	variants={
["Elvish Champion (E)"]			= {	"Elvish Champion"	, { "E"	 , false, false, false } },
["Elvish Champion (J)"]			= {	"Elvish Champion"	, { false, "J"  , false, false } },
["Elvish Champion (U)"]			= {	"Elvish Champion"	, { false, false, "U"  , false } },
["Elvish Champion (JPN)"]		= {	"Elvish Champion"	, { false, false, false, ""    } },
["Glorious Anthem (E)"]			= {	"Glorious Anthem"	, { "E"	 , false, false, false } },
["Glorious Anthem (J)"]			= {	"Glorious Anthem"	, { false, "J"  , false, false } },
["Glorious Anthem (U)"]			= {	"Glorious Anthem"	, { false, false, "U"  , false } },
["Glorious Anthem (JPN)"]		= {	"Glorious Anthem"	, { false, false, false, ""    } },
["Royal Assassin (E)"]			= {	"Royal Assassin"	, { "E"	 , false, false } },
["Royal Assassin (J)"]			= {	"Royal Assassin"	, { false, "J"  , false } },
["Royal Assassin (JPN)"]		= {	"Royal Assassin"	, { false, false, ""    } },
["Sakura-Tribe Elder (E)"]		= {	"Sakura-Tribe Elder", { "E"	 , false, false, false } },
["Sakura-Tribe Elder (J)"]		= {	"Sakura-Tribe Elder", { false, "J"  , false, false } },
["Sakura-Tribe Elder (U)"]		= {	"Sakura-Tribe Elder", { false, false, "U"  , false } },
["Sakura-Tribe Elder (JPN)"]	= {	"Sakura-Tribe Elder", { false, false, false, ""    } },
["Shard Phoenix (E)"]			= {	"Shard Phoenix"		, { "E"	 , false, false, false } },
["Shard Phoenix (J)"]			= {	"Shard Phoenix"		, { false, "J"  , false, false } },
["Shard Phoenix (U)"]			= {	"Shard Phoenix"		, { false, false, "U"  , false } },
["Shard Phoenix (JPN)"]			= {	"Shard Phoenix"		, { false, false, false, ""    } },
["Slith Firewalker (E)"]		= {	"Slith Firewalker"	, { "E"	 , false, false } },
["Slith Firewalker (J)"]		= {	"Slith Firewalker"	, { false, "J"  , false } },
["Slith Firewalker (JPN)"]		= {	"Slith Firewalker"	, { false, false, ""    } },
["Soltari Priest (E)"]			= {	"Soltari Priest"	, { "E"	 , false, false, false } },
["Soltari Priest (J)"]			= {	"Soltari Priest"	, { false, "J"  , false, false } },
["Soltari Priest (U)"]			= {	"Soltari Priest"	, { false, false, "U"  , false } },
["Soltari Priest (JPN)"]		= {	"Soltari Priest"	, { false, false, false, ""    } },
["Whirling Dervish (E)"]		= {	"Whirling Dervish"	, { "E"	 , false, false, false } },
["Whirling Dervish (J)"]		= {	"Whirling Dervish"	, { false, "J"  , false, false } },
["Whirling Dervish (U)"]		= {	"Whirling Dervish"	, { false, false, "U"  , false } },
["Whirling Dervish (JPN)"]		= {	"Whirling Dervish"	, { false, false, false, ""    } },
	},
},
[9] = { name="Video Game Promos",
	tla="GAM",
	foilonly=true,
	cardcount={ reg=14, tok=0, nontrad=0, repl=1 }, 
	variants={
["Aswan Jaguar"]		= { "Aswan Jaguar", { "Replica"} },
	},
	foiltweak={
["Aswan Jaguar"] 				= { foil = false},
["Primordial Hydra"]			= { foil = false},
["Serra Avatar"] 				= { foil = false},
["Soul of Ravnica"]				= { foil = false},
["Vampire Nocturnus"]			= { foil = false},
	},
},
[8] = { name="Stores Promos",
	tla="STO",
	foilonly=true,
	cardcount={ reg=13, tok=0, nontrad=0, repl=0 }, -- 1 ITA, 3 JPN
},
[7] = { name="Magazine Inserts",
	tla="MIN",
	foil="n",
	cardcount={ reg=7, tok=0, nontrad=0, repl=5 }, 
	variants={
["Shivan Dragon"]		= { "Shivan Dragon",	{ "Replica"} },
["Jester’s Cap"]		= { "Jester’s Cap",		{ "Replica"} },
["Juzám Djinn"]			= { "Juzám Djinn",		{ "Replica"} },
["Black Lotus"]			= { "Black Lotus",		{ "Replica"} },
["Chaos Orb"]			= { "Chaos Orb",		{ "Replica"} },
	},
	foiltweak={
["Lightning Hounds"]	 		= { foil = true },
["Warmonger"]					= { foil = true },
	},
},
[6] = { name="Comic Inserts",
	tla="CIN",
	foil="n",
	cardcount={ reg=19, tok=0, nontrad=0, repl=1 }, 
	variants={
["Serra Angel"]		= { "Serra Angel", { "Replica"} },
	},
},
[5] = { name="Book Inserts",
	tla="BIN",
	foil="n",
	cardcount={ reg=6, tok=0, nontrad=0, repl=0 }, 
},
[4] = { name="Ultra Rare Cards",
	tla="URC",
	foil="n",
	cardcount={ reg=5, tok=0, nontrad=0, repl=0 }, 
},
[2] = { name="DCI Legend Membership",
	tla="DLM",
	foil="n",
	cardcount={ reg=2, tok=0, nontrad=0, repl=0 }, 
},
[0] = { name="fakeset for Debug",
	tla="DEB",
	variants={
["data"]			= { "inDataOnly"		, { "one", "two" } },
["data (1)"]		= { "inDataOnly"		, { "one", false } },
["data (2)"]		= { "inDataOnly"		, { false, "two" } },
["same"]			= { "samefromData"		, { "one", "two" } },
["same (1)"]		= { "samefromData"		, { "one", false } },
["same (2)"]		= { "samefromData"		, { false, "two" } },
	},
},
}-- end table Data.sets

for sid,set in pairs(Data.sets) do
	if set.cardcount then
		set.cardcount.both = set.cardcount.reg + (set.cardcount.tok or 0)
		set.cardcount.all = set.cardcount.both + (set.cardcount.nontrad or 0) + (set.cardcount.repl or 0)
	end --if
end -- for sid,count

--LHpi.Log( "LHpi.Data loaded and executed successfully." , 0 , nil )
ma.Log("LHpi.Data " .. Data.version .. " loaded.")
return Data
--EOF
